//
// Copyright (c) 2003, 2013, Oracle and/or its affiliates. All rights reserved.
// DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
//
// This code is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License version 2 only, as
// published by the Free Software Foundation.
//
// This code is distributed in the hope that it will be useful, but WITHOUT
// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
// FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
// version 2 for more details (a copy is included in the LICENSE file that
// accompanied this code).
//
// You should have received a copy of the GNU General Public License version
// 2 along with this work; if not, write to the Free Software Foundation,
// Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
//
// Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
// or visit www.oracle.com if you need additional information or have any
// questions.
//
//

// Machine Generated File.  Do Not Edit!

#include "precompiled.hpp"
#include "adfiles/adGlobals_x86_64.hpp"
#include "adfiles/ad_x86_64.hpp"
#include "memory/allocation.inline.hpp"
#include "asm/macroAssembler.inline.hpp"
#include "code/compiledIC.hpp"
#include "code/vmreg.hpp"
#include "gc_interface/collectedHeap.inline.hpp"
#include "oops/compiledICHolder.hpp"
#include "oops/markOop.hpp"
#include "oops/method.hpp"
#include "oops/oop.inline.hpp"
#include "oops/oop.inline2.hpp"
#include "opto/cfgnode.hpp"
#include "opto/locknode.hpp"
#include "opto/opcodes.hpp"
#include "opto/regalloc.hpp"
#include "opto/regmask.hpp"
#include "opto/runtime.hpp"
#include "runtime/biasedLocking.hpp"
#include "runtime/sharedRuntime.hpp"
#include "runtime/stubRoutines.hpp"
#include "utilities/growableArray.hpp"
#include "nativeInst_x86.hpp"
#include "vmreg_x86.inline.hpp"

//SourceForm

#line 532 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

#define   RELOC_IMM64    Assembler::imm_operand
#define   RELOC_DISP32   Assembler::disp32_operand

#define __ _masm.

static int clear_avx_size() {
  return (Compile::current()->max_vector_size() > 16) ? 3 : 0;  // vzeroupper
}

// !!!!! Special hack to get all types of calls to specify the byte offset
//       from the start of the call to the point where the return address
//       will point.
int MachCallStaticJavaNode::ret_addr_offset()
{
  int offset = 5; // 5 bytes from start of call to where return address points
  offset += clear_avx_size();  
  return offset;
}

int MachCallDynamicJavaNode::ret_addr_offset()
{
  int offset = 15; // 15 bytes from start of call to where return address points
  offset += clear_avx_size();
  return offset;
}

int MachCallRuntimeNode::ret_addr_offset() {
  int offset = 13; // movq r10,#addr; callq (r10)
  offset += clear_avx_size();
  return offset;
}

// Indicate if the safepoint node needs the polling page as an input,
// it does if the polling page is more than disp32 away.
bool SafePointNode::needs_polling_address_input()
{
  return Assembler::is_polling_page_far();
}

//
// Compute padding required for nodes which need alignment
//

// The address of the call instruction needs to be 4-byte aligned to
// ensure that it does not span a cache line so that it can be patched.
int CallStaticJavaDirectNode::compute_padding(int current_offset) const
{
  current_offset += clear_avx_size(); // skip vzeroupper
  current_offset += 1; // skip call opcode byte
  return round_to(current_offset, alignment_required()) - current_offset;
}

// The address of the call instruction needs to be 4-byte aligned to
// ensure that it does not span a cache line so that it can be patched.
int CallDynamicJavaDirectNode::compute_padding(int current_offset) const
{
  current_offset += clear_avx_size(); // skip vzeroupper
  current_offset += 11; // skip movq instruction + call opcode byte
  return round_to(current_offset, alignment_required()) - current_offset;
}

// EMIT_RM()
void emit_rm(CodeBuffer &cbuf, int f1, int f2, int f3) {
  unsigned char c = (unsigned char) ((f1 << 6) | (f2 << 3) | f3);
  cbuf.insts()->emit_int8(c);
}

// EMIT_CC()
void emit_cc(CodeBuffer &cbuf, int f1, int f2) {
  unsigned char c = (unsigned char) (f1 | f2);
  cbuf.insts()->emit_int8(c);
}

// EMIT_OPCODE()
void emit_opcode(CodeBuffer &cbuf, int code) {
  cbuf.insts()->emit_int8((unsigned char) code);
}

// EMIT_OPCODE() w/ relocation information
void emit_opcode(CodeBuffer &cbuf,
                 int code, relocInfo::relocType reloc, int offset, int format)
{
  cbuf.relocate(cbuf.insts_mark() + offset, reloc, format);
  emit_opcode(cbuf, code);
}

// EMIT_D8()
void emit_d8(CodeBuffer &cbuf, int d8) {
  cbuf.insts()->emit_int8((unsigned char) d8);
}

// EMIT_D16()
void emit_d16(CodeBuffer &cbuf, int d16) {
  cbuf.insts()->emit_int16(d16);
}

// EMIT_D32()
void emit_d32(CodeBuffer &cbuf, int d32) {
  cbuf.insts()->emit_int32(d32);
}

// EMIT_D64()
void emit_d64(CodeBuffer &cbuf, int64_t d64) {
  cbuf.insts()->emit_int64(d64);
}

// emit 32 bit value and construct relocation entry from relocInfo::relocType
void emit_d32_reloc(CodeBuffer& cbuf,
                    int d32,
                    relocInfo::relocType reloc,
                    int format)
{
  assert(reloc != relocInfo::external_word_type, "use 2-arg emit_d32_reloc");
  cbuf.relocate(cbuf.insts_mark(), reloc, format);
  cbuf.insts()->emit_int32(d32);
}

// emit 32 bit value and construct relocation entry from RelocationHolder
void emit_d32_reloc(CodeBuffer& cbuf, int d32, RelocationHolder const& rspec, int format) {
#ifdef ASSERT
  if (rspec.reloc()->type() == relocInfo::oop_type &&
      d32 != 0 && d32 != (intptr_t) Universe::non_oop_word()) {
    assert(Universe::heap()->is_in_reserved((address)(intptr_t)d32), "should be real oop");
    assert(cast_to_oop((intptr_t)d32)->is_oop() && (ScavengeRootsInCode || !cast_to_oop((intptr_t)d32)->is_scavengable()), "cannot embed scavengable oops in code");
  }
#endif
  cbuf.relocate(cbuf.insts_mark(), rspec, format);
  cbuf.insts()->emit_int32(d32);
}

void emit_d32_reloc(CodeBuffer& cbuf, address addr) {
  address next_ip = cbuf.insts_end() + 4;
  emit_d32_reloc(cbuf, (int) (addr - next_ip),
                 external_word_Relocation::spec(addr),
                 RELOC_DISP32);
}


// emit 64 bit value and construct relocation entry from relocInfo::relocType
void emit_d64_reloc(CodeBuffer& cbuf, int64_t d64, relocInfo::relocType reloc, int format) {
  cbuf.relocate(cbuf.insts_mark(), reloc, format);
  cbuf.insts()->emit_int64(d64);
}

// emit 64 bit value and construct relocation entry from RelocationHolder
void emit_d64_reloc(CodeBuffer& cbuf, int64_t d64, RelocationHolder const& rspec, int format) {
#ifdef ASSERT
  if (rspec.reloc()->type() == relocInfo::oop_type &&
      d64 != 0 && d64 != (int64_t) Universe::non_oop_word()) {
    assert(Universe::heap()->is_in_reserved((address)d64), "should be real oop");
    assert(cast_to_oop(d64)->is_oop() && (ScavengeRootsInCode || !cast_to_oop(d64)->is_scavengable()),
           "cannot embed scavengable oops in code");
  }
#endif
  cbuf.relocate(cbuf.insts_mark(), rspec, format);
  cbuf.insts()->emit_int64(d64);
}

// Access stack slot for load or store
void store_to_stackslot(CodeBuffer &cbuf, int opcode, int rm_field, int disp)
{
  emit_opcode(cbuf, opcode);                  // (e.g., FILD   [RSP+src])
  if (-0x80 <= disp && disp < 0x80) {
    emit_rm(cbuf, 0x01, rm_field, RSP_enc);   // R/M byte
    emit_rm(cbuf, 0x00, RSP_enc, RSP_enc);    // SIB byte
    emit_d8(cbuf, disp);     // Displacement  // R/M byte
  } else {
    emit_rm(cbuf, 0x02, rm_field, RSP_enc);   // R/M byte
    emit_rm(cbuf, 0x00, RSP_enc, RSP_enc);    // SIB byte
    emit_d32(cbuf, disp);     // Displacement // R/M byte
  }
}

   // rRegI ereg, memory mem) %{    // emit_reg_mem
void encode_RegMem(CodeBuffer &cbuf,
                   int reg,
                   int base, int index, int scale, int disp, relocInfo::relocType disp_reloc)
{
  assert(disp_reloc == relocInfo::none, "cannot have disp");
  int regenc = reg & 7;
  int baseenc = base & 7;
  int indexenc = index & 7;

  // There is no index & no scale, use form without SIB byte
  if (index == 0x4 && scale == 0 && base != RSP_enc && base != R12_enc) {
    // If no displacement, mode is 0x0; unless base is [RBP] or [R13]
    if (disp == 0 && base != RBP_enc && base != R13_enc) {
      emit_rm(cbuf, 0x0, regenc, baseenc); // *
    } else if (-0x80 <= disp && disp < 0x80 && disp_reloc == relocInfo::none) {
      // If 8-bit displacement, mode 0x1
      emit_rm(cbuf, 0x1, regenc, baseenc); // *
      emit_d8(cbuf, disp);
    } else {
      // If 32-bit displacement
      if (base == -1) { // Special flag for absolute address
        emit_rm(cbuf, 0x0, regenc, 0x5); // *
        if (disp_reloc != relocInfo::none) {
          emit_d32_reloc(cbuf, disp, relocInfo::oop_type, RELOC_DISP32);
        } else {
          emit_d32(cbuf, disp);
        }
      } else {
        // Normal base + offset
        emit_rm(cbuf, 0x2, regenc, baseenc); // *
        if (disp_reloc != relocInfo::none) {
          emit_d32_reloc(cbuf, disp, relocInfo::oop_type, RELOC_DISP32);
        } else {
          emit_d32(cbuf, disp);
        }
      }
    }
  } else {
    // Else, encode with the SIB byte
    // If no displacement, mode is 0x0; unless base is [RBP] or [R13]
    if (disp == 0 && base != RBP_enc && base != R13_enc) {
      // If no displacement
      emit_rm(cbuf, 0x0, regenc, 0x4); // *
      emit_rm(cbuf, scale, indexenc, baseenc);
    } else {
      if (-0x80 <= disp && disp < 0x80 && disp_reloc == relocInfo::none) {
        // If 8-bit displacement, mode 0x1
        emit_rm(cbuf, 0x1, regenc, 0x4); // *
        emit_rm(cbuf, scale, indexenc, baseenc);
        emit_d8(cbuf, disp);
      } else {
        // If 32-bit displacement
        if (base == 0x04 ) {
          emit_rm(cbuf, 0x2, regenc, 0x4);
          emit_rm(cbuf, scale, indexenc, 0x04); // XXX is this valid???
        } else {
          emit_rm(cbuf, 0x2, regenc, 0x4);
          emit_rm(cbuf, scale, indexenc, baseenc); // *
        }
        if (disp_reloc != relocInfo::none) {
          emit_d32_reloc(cbuf, disp, relocInfo::oop_type, RELOC_DISP32);
        } else {
          emit_d32(cbuf, disp);
        }
      }
    }
  }
}

// This could be in MacroAssembler but it's fairly C2 specific
void emit_cmpfp_fixup(MacroAssembler& _masm) {
  Label exit;
  __ jccb(Assembler::noParity, exit);
  __ pushf();
  //
  // comiss/ucomiss instructions set ZF,PF,CF flags and
  // zero OF,AF,SF for NaN values.
  // Fixup flags by zeroing ZF,PF so that compare of NaN
  // values returns 'less than' result (CF is set).
  // Leave the rest of flags unchanged.
  //
  //    7 6 5 4 3 2 1 0
  //   |S|Z|r|A|r|P|r|C|  (r - reserved bit)
  //    0 0 1 0 1 0 1 1   (0x2B)
  //
  __ andq(Address(rsp, 0), 0xffffff2b);
  __ popf();
  __ bind(exit);
}

void emit_cmpfp3(MacroAssembler& _masm, Register dst) {
  Label done;
  __ movl(dst, -1);
  __ jcc(Assembler::parity, done);
  __ jcc(Assembler::below, done);
  __ setb(Assembler::notEqual, dst);
  __ movzbl(dst, dst);
  __ bind(done);
}


//=============================================================================
const RegMask& MachConstantBaseNode::_out_RegMask = RegMask::Empty;

int Compile::ConstantTable::calculate_table_base_offset() const {
  return 0;  // absolute addressing, no offset
}

bool MachConstantBaseNode::requires_postalloc_expand() const { return false; }
void MachConstantBaseNode::postalloc_expand(GrowableArray <Node *> *nodes, PhaseRegAlloc *ra_) {
  ShouldNotReachHere();
}

void MachConstantBaseNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  // Empty encoding
}

uint MachConstantBaseNode::size(PhaseRegAlloc* ra_) const {
  return 0;
}

#ifndef PRODUCT
void MachConstantBaseNode::format(PhaseRegAlloc* ra_, outputStream* st) const {
  st->print("# MachConstantBaseNode (empty encoding)");
}
#endif


//=============================================================================
#ifndef PRODUCT
void MachPrologNode::format(PhaseRegAlloc* ra_, outputStream* st) const {
  Compile* C = ra_->C;

  int framesize = C->frame_size_in_bytes();
  int bangsize = C->bang_size_in_bytes();
  assert((framesize & (StackAlignmentInBytes-1)) == 0, "frame size not aligned");
  // Remove wordSize for return addr which is already pushed.
  framesize -= wordSize;

  if (C->need_stack_bang(bangsize)) {
    framesize -= wordSize;
    st->print("# stack bang (%d bytes)", bangsize);
    st->print("\n\t");
    st->print("pushq   rbp\t# Save rbp");
    if (PreserveFramePointer) {
        st->print("\n\t");
        st->print("movq    rbp, rsp\t# Save the caller's SP into rbp");
    }
    if (framesize) {
      st->print("\n\t");
      st->print("subq    rsp, #%d\t# Create frame",framesize);
    }
  } else {
    st->print("subq    rsp, #%d\t# Create frame",framesize);
    st->print("\n\t");
    framesize -= wordSize;
    st->print("movq    [rsp + #%d], rbp\t# Save rbp",framesize);    
    if (PreserveFramePointer) {
      st->print("\n\t");
      st->print("movq    rbp, rsp\t# Save the caller's SP into rbp");
      if (framesize > 0) {
        st->print("\n\t");
        st->print("addq    rbp, #%d", framesize);
      }      
    }
  }

  if (VerifyStackAtCalls) {
    st->print("\n\t");
    framesize -= wordSize;
    st->print("movq    [rsp + #%d], 0xbadb100d\t# Majik cookie for stack depth check",framesize);
#ifdef ASSERT
    st->print("\n\t");
    st->print("# stack alignment check");
#endif
  }
  st->cr();
}
#endif

void MachPrologNode::emit(CodeBuffer &cbuf, PhaseRegAlloc *ra_) const {
  Compile* C = ra_->C;
  MacroAssembler _masm(&cbuf);

  int framesize = C->frame_size_in_bytes();
  int bangsize = C->bang_size_in_bytes();

  __ verified_entry(framesize, C->need_stack_bang(bangsize)?bangsize:0, false);

  C->set_frame_complete(cbuf.insts_size());

  if (C->has_mach_constant_base_node()) {
    // NOTE: We set the table base offset here because users might be
    // emitted before MachConstantBaseNode.
    Compile::ConstantTable& constant_table = C->constant_table();
    constant_table.set_table_base_offset(constant_table.calculate_table_base_offset());
  }
}

uint MachPrologNode::size(PhaseRegAlloc* ra_) const
{
  return MachNode::size(ra_); // too many variables; just compute it
                              // the hard way
}

int MachPrologNode::reloc() const
{
  return 0; // a large enough number
}

//=============================================================================
#ifndef PRODUCT
void MachEpilogNode::format(PhaseRegAlloc* ra_, outputStream* st) const
{
  Compile* C = ra_->C;
  if (C->max_vector_size() > 16) {
    st->print("vzeroupper");
    st->cr(); st->print("\t");
  }

  int framesize = C->frame_size_in_bytes();
  assert((framesize & (StackAlignmentInBytes-1)) == 0, "frame size not aligned");
  // Remove word for return adr already pushed
  // and RBP
  framesize -= 2*wordSize;

  if (framesize) {
    st->print_cr("addq    rsp, %d\t# Destroy frame", framesize);
    st->print("\t");
  }

  st->print_cr("popq   rbp");
  if (do_polling() && C->is_method_compilation()) {
    st->print("\t");
    if (Assembler::is_polling_page_far()) {
      st->print_cr("movq   rscratch1, #polling_page_address\n\t"
                   "testl  rax, [rscratch1]\t"
                   "# Safepoint: poll for GC");
    } else {
      st->print_cr("testl  rax, [rip + #offset_to_poll_page]\t"
                   "# Safepoint: poll for GC");
    }
  }
}
#endif

void MachEpilogNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const
{
  Compile* C = ra_->C;
  if (C->max_vector_size() > 16) {
    // Clear upper bits of YMM registers when current compiled code uses
    // wide vectors to avoid AVX <-> SSE transition penalty during call.
    MacroAssembler _masm(&cbuf);
    __ vzeroupper();
  }

  int framesize = C->frame_size_in_bytes();
  assert((framesize & (StackAlignmentInBytes-1)) == 0, "frame size not aligned");
  // Remove word for return adr already pushed
  // and RBP
  framesize -= 2*wordSize;

  // Note that VerifyStackAtCalls' Majik cookie does not change the frame size popped here

  if (framesize) {
    emit_opcode(cbuf, Assembler::REX_W);
    if (framesize < 0x80) {
      emit_opcode(cbuf, 0x83); // addq rsp, #framesize
      emit_rm(cbuf, 0x3, 0x00, RSP_enc);
      emit_d8(cbuf, framesize);
    } else {
      emit_opcode(cbuf, 0x81); // addq rsp, #framesize
      emit_rm(cbuf, 0x3, 0x00, RSP_enc);
      emit_d32(cbuf, framesize);
    }
  }

  // popq rbp
  emit_opcode(cbuf, 0x58 | RBP_enc);

  if (do_polling() && C->is_method_compilation()) {
    MacroAssembler _masm(&cbuf);
    AddressLiteral polling_page(os::get_polling_page(), relocInfo::poll_return_type);
    if (Assembler::is_polling_page_far()) {
      __ lea(rscratch1, polling_page);
      __ relocate(relocInfo::poll_return_type);
      __ testl(rax, Address(rscratch1, 0));
    } else {
      __ testl(rax, polling_page);
    }
  }
}

uint MachEpilogNode::size(PhaseRegAlloc* ra_) const
{
  return MachNode::size(ra_); // too many variables; just compute it
                              // the hard way
}

int MachEpilogNode::reloc() const
{
  return 2; // a large enough number
}

const Pipeline* MachEpilogNode::pipeline() const
{
  return MachNode::pipeline_class();
}

int MachEpilogNode::safepoint_offset() const
{
  return 0;
}

//=============================================================================

enum RC {
  rc_bad,
  rc_int,
  rc_float,
  rc_stack
};

static enum RC rc_class(OptoReg::Name reg)
{
  if( !OptoReg::is_valid(reg)  ) return rc_bad;

  if (OptoReg::is_stack(reg)) return rc_stack;

  VMReg r = OptoReg::as_VMReg(reg);

  if (r->is_Register()) return rc_int;

  assert(r->is_XMMRegister(), "must be");
  return rc_float;
}

// Next two methods are shared by 32- and 64-bit VM. They are defined in x86.ad.
static int vec_mov_helper(CodeBuffer *cbuf, bool do_size, int src_lo, int dst_lo,
                          int src_hi, int dst_hi, uint ireg, outputStream* st);

static int vec_spill_helper(CodeBuffer *cbuf, bool do_size, bool is_load,
                            int stack_offset, int reg, uint ireg, outputStream* st);

static void vec_stack_to_stack_helper(CodeBuffer *cbuf, int src_offset,
                                      int dst_offset, uint ireg, outputStream* st) {
  if (cbuf) {
    MacroAssembler _masm(cbuf);
    switch (ireg) {
    case Op_VecS:
      __ movq(Address(rsp, -8), rax);
      __ movl(rax, Address(rsp, src_offset));
      __ movl(Address(rsp, dst_offset), rax);
      __ movq(rax, Address(rsp, -8));
      break;
    case Op_VecD:
      __ pushq(Address(rsp, src_offset));
      __ popq (Address(rsp, dst_offset));
      break;
    case Op_VecX:
      __ pushq(Address(rsp, src_offset));
      __ popq (Address(rsp, dst_offset));
      __ pushq(Address(rsp, src_offset+8));
      __ popq (Address(rsp, dst_offset+8));
      break;
    case Op_VecY:
      __ vmovdqu(Address(rsp, -32), xmm0);
      __ vmovdqu(xmm0, Address(rsp, src_offset));
      __ vmovdqu(Address(rsp, dst_offset), xmm0);
      __ vmovdqu(xmm0, Address(rsp, -32));
      break;
    default:
      ShouldNotReachHere();
    }
#ifndef PRODUCT
  } else {
    switch (ireg) {
    case Op_VecS:
      st->print("movq    [rsp - #8], rax\t# 32-bit mem-mem spill\n\t"
                "movl    rax, [rsp + #%d]\n\t"
                "movl    [rsp + #%d], rax\n\t"
                "movq    rax, [rsp - #8]",
                src_offset, dst_offset);
      break;
    case Op_VecD:
      st->print("pushq   [rsp + #%d]\t# 64-bit mem-mem spill\n\t"
                "popq    [rsp + #%d]",
                src_offset, dst_offset);
      break;
     case Op_VecX:
      st->print("pushq   [rsp + #%d]\t# 128-bit mem-mem spill\n\t"
                "popq    [rsp + #%d]\n\t"
                "pushq   [rsp + #%d]\n\t"
                "popq    [rsp + #%d]",
                src_offset, dst_offset, src_offset+8, dst_offset+8);
      break;
    case Op_VecY:
      st->print("vmovdqu [rsp - #32], xmm0\t# 256-bit mem-mem spill\n\t"
                "vmovdqu xmm0, [rsp + #%d]\n\t"
                "vmovdqu [rsp + #%d], xmm0\n\t"
                "vmovdqu xmm0, [rsp - #32]",
                src_offset, dst_offset);
      break;
    default:
      ShouldNotReachHere();
    }
#endif
  }
}

uint MachSpillCopyNode::implementation(CodeBuffer* cbuf,
                                       PhaseRegAlloc* ra_,
                                       bool do_size,
                                       outputStream* st) const {
  assert(cbuf != NULL || st  != NULL, "sanity");
  // Get registers to move
  OptoReg::Name src_second = ra_->get_reg_second(in(1));
  OptoReg::Name src_first = ra_->get_reg_first(in(1));
  OptoReg::Name dst_second = ra_->get_reg_second(this);
  OptoReg::Name dst_first = ra_->get_reg_first(this);

  enum RC src_second_rc = rc_class(src_second);
  enum RC src_first_rc = rc_class(src_first);
  enum RC dst_second_rc = rc_class(dst_second);
  enum RC dst_first_rc = rc_class(dst_first);

  assert(OptoReg::is_valid(src_first) && OptoReg::is_valid(dst_first),
         "must move at least 1 register" );

  if (src_first == dst_first && src_second == dst_second) {
    // Self copy, no move
    return 0;
  }
  if (bottom_type()->isa_vect() != NULL) {
    uint ireg = ideal_reg();
    assert((src_first_rc != rc_int && dst_first_rc != rc_int), "sanity");
    assert((ireg == Op_VecS || ireg == Op_VecD || ireg == Op_VecX || ireg == Op_VecY), "sanity");
    if( src_first_rc == rc_stack && dst_first_rc == rc_stack ) {
      // mem -> mem
      int src_offset = ra_->reg2offset(src_first);
      int dst_offset = ra_->reg2offset(dst_first);
      vec_stack_to_stack_helper(cbuf, src_offset, dst_offset, ireg, st);
    } else if (src_first_rc == rc_float && dst_first_rc == rc_float ) {
      vec_mov_helper(cbuf, false, src_first, dst_first, src_second, dst_second, ireg, st);
    } else if (src_first_rc == rc_float && dst_first_rc == rc_stack ) {
      int stack_offset = ra_->reg2offset(dst_first);
      vec_spill_helper(cbuf, false, false, stack_offset, src_first, ireg, st);
    } else if (src_first_rc == rc_stack && dst_first_rc == rc_float ) {
      int stack_offset = ra_->reg2offset(src_first);
      vec_spill_helper(cbuf, false, true,  stack_offset, dst_first, ireg, st);
    } else {
      ShouldNotReachHere();
    }
    return 0;
  }
  if (src_first_rc == rc_stack) {
    // mem ->
    if (dst_first_rc == rc_stack) {
      // mem -> mem
      assert(src_second != dst_first, "overlap");
      if ((src_first & 1) == 0 && src_first + 1 == src_second &&
          (dst_first & 1) == 0 && dst_first + 1 == dst_second) {
        // 64-bit
        int src_offset = ra_->reg2offset(src_first);
        int dst_offset = ra_->reg2offset(dst_first);
        if (cbuf) {
          MacroAssembler _masm(cbuf);
          __ pushq(Address(rsp, src_offset));
          __ popq (Address(rsp, dst_offset));
#ifndef PRODUCT
        } else {
          st->print("pushq   [rsp + #%d]\t# 64-bit mem-mem spill\n\t"
                    "popq    [rsp + #%d]",
                     src_offset, dst_offset);
#endif
        }
      } else {
        // 32-bit
        assert(!((src_first & 1) == 0 && src_first + 1 == src_second), "no transform");
        assert(!((dst_first & 1) == 0 && dst_first + 1 == dst_second), "no transform");
        // No pushl/popl, so:
        int src_offset = ra_->reg2offset(src_first);
        int dst_offset = ra_->reg2offset(dst_first);
        if (cbuf) {
          MacroAssembler _masm(cbuf);
          __ movq(Address(rsp, -8), rax);
          __ movl(rax, Address(rsp, src_offset));
          __ movl(Address(rsp, dst_offset), rax);
          __ movq(rax, Address(rsp, -8));
#ifndef PRODUCT
        } else {
          st->print("movq    [rsp - #8], rax\t# 32-bit mem-mem spill\n\t"
                    "movl    rax, [rsp + #%d]\n\t"
                    "movl    [rsp + #%d], rax\n\t"
                    "movq    rax, [rsp - #8]",
                     src_offset, dst_offset);
#endif
        }
      }
      return 0;
    } else if (dst_first_rc == rc_int) {
      // mem -> gpr
      if ((src_first & 1) == 0 && src_first + 1 == src_second &&
          (dst_first & 1) == 0 && dst_first + 1 == dst_second) {
        // 64-bit
        int offset = ra_->reg2offset(src_first);
        if (cbuf) {
          MacroAssembler _masm(cbuf);
          __ movq(as_Register(Matcher::_regEncode[dst_first]), Address(rsp, offset));
#ifndef PRODUCT
        } else {
          st->print("movq    %s, [rsp + #%d]\t# spill",
                     Matcher::regName[dst_first],
                     offset);
#endif
        }
      } else {
        // 32-bit
        assert(!((src_first & 1) == 0 && src_first + 1 == src_second), "no transform");
        assert(!((dst_first & 1) == 0 && dst_first + 1 == dst_second), "no transform");
        int offset = ra_->reg2offset(src_first);
        if (cbuf) {
          MacroAssembler _masm(cbuf);
          __ movl(as_Register(Matcher::_regEncode[dst_first]), Address(rsp, offset));
#ifndef PRODUCT
        } else {
          st->print("movl    %s, [rsp + #%d]\t# spill",
                     Matcher::regName[dst_first],
                     offset);
#endif
        }
      }
      return 0;
    } else if (dst_first_rc == rc_float) {
      // mem-> xmm
      if ((src_first & 1) == 0 && src_first + 1 == src_second &&
          (dst_first & 1) == 0 && dst_first + 1 == dst_second) {
        // 64-bit
        int offset = ra_->reg2offset(src_first);
        if (cbuf) {
          MacroAssembler _masm(cbuf);
          __ movdbl( as_XMMRegister(Matcher::_regEncode[dst_first]), Address(rsp, offset));
#ifndef PRODUCT
        } else {
          st->print("%s  %s, [rsp + #%d]\t# spill",
                     UseXmmLoadAndClearUpper ? "movsd " : "movlpd",
                     Matcher::regName[dst_first],
                     offset);
#endif
        }
      } else {
        // 32-bit
        assert(!((src_first & 1) == 0 && src_first + 1 == src_second), "no transform");
        assert(!((dst_first & 1) == 0 && dst_first + 1 == dst_second), "no transform");
        int offset = ra_->reg2offset(src_first);
        if (cbuf) {
          MacroAssembler _masm(cbuf);
          __ movflt( as_XMMRegister(Matcher::_regEncode[dst_first]), Address(rsp, offset));
#ifndef PRODUCT
        } else {
          st->print("movss   %s, [rsp + #%d]\t# spill",
                     Matcher::regName[dst_first],
                     offset);
#endif
        }
      }
      return 0;
    }
  } else if (src_first_rc == rc_int) {
    // gpr ->
    if (dst_first_rc == rc_stack) {
      // gpr -> mem
      if ((src_first & 1) == 0 && src_first + 1 == src_second &&
          (dst_first & 1) == 0 && dst_first + 1 == dst_second) {
        // 64-bit
        int offset = ra_->reg2offset(dst_first);
        if (cbuf) {
          MacroAssembler _masm(cbuf);
          __ movq(Address(rsp, offset), as_Register(Matcher::_regEncode[src_first]));
#ifndef PRODUCT
        } else {
          st->print("movq    [rsp + #%d], %s\t# spill",
                     offset,
                     Matcher::regName[src_first]);
#endif
        }
      } else {
        // 32-bit
        assert(!((src_first & 1) == 0 && src_first + 1 == src_second), "no transform");
        assert(!((dst_first & 1) == 0 && dst_first + 1 == dst_second), "no transform");
        int offset = ra_->reg2offset(dst_first);
        if (cbuf) {
          MacroAssembler _masm(cbuf);
          __ movl(Address(rsp, offset), as_Register(Matcher::_regEncode[src_first]));
#ifndef PRODUCT
        } else {
          st->print("movl    [rsp + #%d], %s\t# spill",
                     offset,
                     Matcher::regName[src_first]);
#endif
        }
      }
      return 0;
    } else if (dst_first_rc == rc_int) {
      // gpr -> gpr
      if ((src_first & 1) == 0 && src_first + 1 == src_second &&
          (dst_first & 1) == 0 && dst_first + 1 == dst_second) {
        // 64-bit
        if (cbuf) {
          MacroAssembler _masm(cbuf);
          __ movq(as_Register(Matcher::_regEncode[dst_first]),
                  as_Register(Matcher::_regEncode[src_first]));
#ifndef PRODUCT
        } else {
          st->print("movq    %s, %s\t# spill",
                     Matcher::regName[dst_first],
                     Matcher::regName[src_first]);
#endif
        }
        return 0;
      } else {
        // 32-bit
        assert(!((src_first & 1) == 0 && src_first + 1 == src_second), "no transform");
        assert(!((dst_first & 1) == 0 && dst_first + 1 == dst_second), "no transform");
        if (cbuf) {
          MacroAssembler _masm(cbuf);
          __ movl(as_Register(Matcher::_regEncode[dst_first]),
                  as_Register(Matcher::_regEncode[src_first]));
#ifndef PRODUCT
        } else {
          st->print("movl    %s, %s\t# spill",
                     Matcher::regName[dst_first],
                     Matcher::regName[src_first]);
#endif
        }
        return 0;
      }
    } else if (dst_first_rc == rc_float) {
      // gpr -> xmm
      if ((src_first & 1) == 0 && src_first + 1 == src_second &&
          (dst_first & 1) == 0 && dst_first + 1 == dst_second) {
        // 64-bit
        if (cbuf) {
          MacroAssembler _masm(cbuf);
          __ movdq( as_XMMRegister(Matcher::_regEncode[dst_first]), as_Register(Matcher::_regEncode[src_first]));
#ifndef PRODUCT
        } else {
          st->print("movdq   %s, %s\t# spill",
                     Matcher::regName[dst_first],
                     Matcher::regName[src_first]);
#endif
        }
      } else {
        // 32-bit
        assert(!((src_first & 1) == 0 && src_first + 1 == src_second), "no transform");
        assert(!((dst_first & 1) == 0 && dst_first + 1 == dst_second), "no transform");
        if (cbuf) {
          MacroAssembler _masm(cbuf);
          __ movdl( as_XMMRegister(Matcher::_regEncode[dst_first]), as_Register(Matcher::_regEncode[src_first]));
#ifndef PRODUCT
        } else {
          st->print("movdl   %s, %s\t# spill",
                     Matcher::regName[dst_first],
                     Matcher::regName[src_first]);
#endif
        }
      }
      return 0;
    }
  } else if (src_first_rc == rc_float) {
    // xmm ->
    if (dst_first_rc == rc_stack) {
      // xmm -> mem
      if ((src_first & 1) == 0 && src_first + 1 == src_second &&
          (dst_first & 1) == 0 && dst_first + 1 == dst_second) {
        // 64-bit
        int offset = ra_->reg2offset(dst_first);
        if (cbuf) {
          MacroAssembler _masm(cbuf);
          __ movdbl( Address(rsp, offset), as_XMMRegister(Matcher::_regEncode[src_first]));
#ifndef PRODUCT
        } else {
          st->print("movsd   [rsp + #%d], %s\t# spill",
                     offset,
                     Matcher::regName[src_first]);
#endif
        }
      } else {
        // 32-bit
        assert(!((src_first & 1) == 0 && src_first + 1 == src_second), "no transform");
        assert(!((dst_first & 1) == 0 && dst_first + 1 == dst_second), "no transform");
        int offset = ra_->reg2offset(dst_first);
        if (cbuf) {
          MacroAssembler _masm(cbuf);
          __ movflt(Address(rsp, offset), as_XMMRegister(Matcher::_regEncode[src_first]));
#ifndef PRODUCT
        } else {
          st->print("movss   [rsp + #%d], %s\t# spill",
                     offset,
                     Matcher::regName[src_first]);
#endif
        }
      }
      return 0;
    } else if (dst_first_rc == rc_int) {
      // xmm -> gpr
      if ((src_first & 1) == 0 && src_first + 1 == src_second &&
          (dst_first & 1) == 0 && dst_first + 1 == dst_second) {
        // 64-bit
        if (cbuf) {
          MacroAssembler _masm(cbuf);
          __ movdq( as_Register(Matcher::_regEncode[dst_first]), as_XMMRegister(Matcher::_regEncode[src_first]));
#ifndef PRODUCT
        } else {
          st->print("movdq   %s, %s\t# spill",
                     Matcher::regName[dst_first],
                     Matcher::regName[src_first]);
#endif
        }
      } else {
        // 32-bit
        assert(!((src_first & 1) == 0 && src_first + 1 == src_second), "no transform");
        assert(!((dst_first & 1) == 0 && dst_first + 1 == dst_second), "no transform");
        if (cbuf) {
          MacroAssembler _masm(cbuf);
          __ movdl( as_Register(Matcher::_regEncode[dst_first]), as_XMMRegister(Matcher::_regEncode[src_first]));
#ifndef PRODUCT
        } else {
          st->print("movdl   %s, %s\t# spill",
                     Matcher::regName[dst_first],
                     Matcher::regName[src_first]);
#endif
        }
      }
      return 0;
    } else if (dst_first_rc == rc_float) {
      // xmm -> xmm
      if ((src_first & 1) == 0 && src_first + 1 == src_second &&
          (dst_first & 1) == 0 && dst_first + 1 == dst_second) {
        // 64-bit
        if (cbuf) {
          MacroAssembler _masm(cbuf);
          __ movdbl( as_XMMRegister(Matcher::_regEncode[dst_first]), as_XMMRegister(Matcher::_regEncode[src_first]));
#ifndef PRODUCT
        } else {
          st->print("%s  %s, %s\t# spill",
                     UseXmmRegToRegMoveAll ? "movapd" : "movsd ",
                     Matcher::regName[dst_first],
                     Matcher::regName[src_first]);
#endif
        }
      } else {
        // 32-bit
        assert(!((src_first & 1) == 0 && src_first + 1 == src_second), "no transform");
        assert(!((dst_first & 1) == 0 && dst_first + 1 == dst_second), "no transform");
        if (cbuf) {
          MacroAssembler _masm(cbuf);
          __ movflt( as_XMMRegister(Matcher::_regEncode[dst_first]), as_XMMRegister(Matcher::_regEncode[src_first]));
#ifndef PRODUCT
        } else {
          st->print("%s  %s, %s\t# spill",
                     UseXmmRegToRegMoveAll ? "movaps" : "movss ",
                     Matcher::regName[dst_first],
                     Matcher::regName[src_first]);
#endif
        }
      }
      return 0;
    }
  }

  assert(0," foo ");
  Unimplemented();
  return 0;
}

#ifndef PRODUCT
void MachSpillCopyNode::format(PhaseRegAlloc *ra_, outputStream* st) const {
  implementation(NULL, ra_, false, st);
}
#endif

void MachSpillCopyNode::emit(CodeBuffer &cbuf, PhaseRegAlloc *ra_) const {
  implementation(&cbuf, ra_, false, NULL);
}

uint MachSpillCopyNode::size(PhaseRegAlloc *ra_) const {
  return MachNode::size(ra_);
}

//=============================================================================
#ifndef PRODUCT
void BoxLockNode::format(PhaseRegAlloc* ra_, outputStream* st) const
{
  int offset = ra_->reg2offset(in_RegMask(0).find_first_elem());
  int reg = ra_->get_reg_first(this);
  st->print("leaq    %s, [rsp + #%d]\t# box lock",
            Matcher::regName[reg], offset);
}
#endif

void BoxLockNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const
{
  int offset = ra_->reg2offset(in_RegMask(0).find_first_elem());
  int reg = ra_->get_encode(this);
  if (offset >= 0x80) {
    emit_opcode(cbuf, reg < 8 ? Assembler::REX_W : Assembler::REX_WR);
    emit_opcode(cbuf, 0x8D); // LEA  reg,[SP+offset]
    emit_rm(cbuf, 0x2, reg & 7, 0x04);
    emit_rm(cbuf, 0x0, 0x04, RSP_enc);
    emit_d32(cbuf, offset);
  } else {
    emit_opcode(cbuf, reg < 8 ? Assembler::REX_W : Assembler::REX_WR);
    emit_opcode(cbuf, 0x8D); // LEA  reg,[SP+offset]
    emit_rm(cbuf, 0x1, reg & 7, 0x04);
    emit_rm(cbuf, 0x0, 0x04, RSP_enc);
    emit_d8(cbuf, offset);
  }
}

uint BoxLockNode::size(PhaseRegAlloc *ra_) const
{
  int offset = ra_->reg2offset(in_RegMask(0).find_first_elem());
  return (offset < 0x80) ? 5 : 8; // REX
}

//=============================================================================
#ifndef PRODUCT
void MachUEPNode::format(PhaseRegAlloc* ra_, outputStream* st) const
{
  if (UseCompressedClassPointers) {
    st->print_cr("movl    rscratch1, [j_rarg0 + oopDesc::klass_offset_in_bytes()]\t# compressed klass");
    st->print_cr("\tdecode_klass_not_null rscratch1, rscratch1");
    st->print_cr("\tcmpq    rax, rscratch1\t # Inline cache check");
  } else {
    st->print_cr("\tcmpq    rax, [j_rarg0 + oopDesc::klass_offset_in_bytes()]\t"
                 "# Inline cache check");
  }
  st->print_cr("\tjne     SharedRuntime::_ic_miss_stub");
  st->print_cr("\tnop\t# nops to align entry point");
}
#endif

void MachUEPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const
{
  MacroAssembler masm(&cbuf);
  uint insts_size = cbuf.insts_size();
  if (UseCompressedClassPointers) {
    masm.load_klass(rscratch1, j_rarg0);
    masm.cmpptr(rax, rscratch1);
  } else {
    masm.cmpptr(rax, Address(j_rarg0, oopDesc::klass_offset_in_bytes()));
  }

  masm.jump_cc(Assembler::notEqual, RuntimeAddress(SharedRuntime::get_ic_miss_stub()));

  /* WARNING these NOPs are critical so that verified entry point is properly
     4 bytes aligned for patching by NativeJump::patch_verified_entry() */
  int nops_cnt = 4 - ((cbuf.insts_size() - insts_size) & 0x3);
  if (OptoBreakpoint) {
    // Leave space for int3
    nops_cnt -= 1;
  }
  nops_cnt &= 0x3; // Do not add nops if code is aligned.
  if (nops_cnt > 0)
    masm.nop(nops_cnt);
}

uint MachUEPNode::size(PhaseRegAlloc* ra_) const
{
  return MachNode::size(ra_); // too many variables; just compute it
                              // the hard way
}
 

//=============================================================================

int Matcher::regnum_to_fpu_offset(int regnum)
{
  return regnum - 32; // The FP registers are in the second chunk
}

// This is UltraSparc specific, true just means we have fast l2f conversion
const bool Matcher::convL2FSupported(void) {
  return true;
}

// Is this branch offset short enough that a short branch can be used?
//
// NOTE: If the platform does not provide any short branch variants, then
//       this method should return false for offset 0.
bool Matcher::is_short_branch_offset(int rule, int br_size, int offset) {
  // The passed offset is relative to address of the branch.
  // On 86 a branch displacement is calculated relative to address
  // of a next instruction.
  offset -= br_size;

  // the short version of jmpConUCF2 contains multiple branches,
  // making the reach slightly less
  if (rule == jmpConUCF2_rule)
    return (-126 <= offset && offset <= 125);
  return (-128 <= offset && offset <= 127);
}

const bool Matcher::isSimpleConstant64(jlong value) {
  // Will one (StoreL ConL) be cheaper than two (StoreI ConI)?.
  //return value == (int) value;  // Cf. storeImmL and immL32.

  // Probably always true, even if a temp register is required.
  return true;
}

// The ecx parameter to rep stosq for the ClearArray node is in words.
const bool Matcher::init_array_count_is_in_bytes = false;

// Threshold size for cleararray.
const int Matcher::init_array_short_size = 8 * BytesPerLong;

// No additional cost for CMOVL.
const int Matcher::long_cmove_cost() { return 0; }

// No CMOVF/CMOVD with SSE2
const int Matcher::float_cmove_cost() { return ConditionalMoveLimit; }

// Does the CPU require late expand (see block.cpp for description of late expand)?
const bool Matcher::require_postalloc_expand = false;

// Should the Matcher clone shifts on addressing modes, expecting them
// to be subsumed into complex addressing expressions or compute them
// into registers?  True for Intel but false for most RISCs
const bool Matcher::clone_shift_expressions = true;

// Do we need to mask the count passed to shift instructions or does
// the cpu only look at the lower 5/6 bits anyway?
const bool Matcher::need_masked_shift_count = false;

bool Matcher::narrow_oop_use_complex_address() {
  assert(UseCompressedOops, "only for compressed oops code");
  return (LogMinObjAlignmentInBytes <= 3);
}

bool Matcher::narrow_klass_use_complex_address() {
  assert(UseCompressedClassPointers, "only for compressed klass code");
  return (LogKlassAlignmentInBytes <= 3);
}

// Is it better to copy float constants, or load them directly from
// memory?  Intel can load a float constant from a direct address,
// requiring no extra registers.  Most RISCs will have to materialize
// an address into a register first, so they would do better to copy
// the constant from stack.
const bool Matcher::rematerialize_float_constants = true; // XXX

// If CPU can load and store mis-aligned doubles directly then no
// fixup is needed.  Else we split the double into 2 integer pieces
// and move it piece-by-piece.  Only happens when passing doubles into
// C code as the Java calling convention forces doubles to be aligned.
const bool Matcher::misaligned_doubles_ok = true;

// No-op on amd64
void Matcher::pd_implicit_null_fixup(MachNode *node, uint idx) {}

// Advertise here if the CPU requires explicit rounding operations to
// implement the UseStrictFP mode.
const bool Matcher::strict_fp_requires_explicit_rounding = true;

// Are floats conerted to double when stored to stack during deoptimization?
// On x64 it is stored without convertion so we can use normal access.
bool Matcher::float_in_double() { return false; }

// Do ints take an entire long register or just half?
const bool Matcher::int_in_long = true;

// Return whether or not this register is ever used as an argument.
// This function is used on startup to build the trampoline stubs in
// generateOptoStub.  Registers not mentioned will be killed by the VM
// call in the trampoline, and arguments in those registers not be
// available to the callee.
bool Matcher::can_be_java_arg(int reg)
{
  return
    reg ==  RDI_num || reg == RDI_H_num ||
    reg ==  RSI_num || reg == RSI_H_num ||
    reg ==  RDX_num || reg == RDX_H_num ||
    reg ==  RCX_num || reg == RCX_H_num ||
    reg ==   R8_num || reg ==  R8_H_num ||
    reg ==   R9_num || reg ==  R9_H_num ||
    reg ==  R12_num || reg == R12_H_num ||
    reg == XMM0_num || reg == XMM0b_num ||
    reg == XMM1_num || reg == XMM1b_num ||
    reg == XMM2_num || reg == XMM2b_num ||
    reg == XMM3_num || reg == XMM3b_num ||
    reg == XMM4_num || reg == XMM4b_num ||
    reg == XMM5_num || reg == XMM5b_num ||
    reg == XMM6_num || reg == XMM6b_num ||
    reg == XMM7_num || reg == XMM7b_num;
}

bool Matcher::is_spillable_arg(int reg)
{
  return can_be_java_arg(reg);
}

bool Matcher::use_asm_for_ldiv_by_con( jlong divisor ) {
  // In 64 bit mode a code which use multiply when
  // devisor is constant is faster than hardware
  // DIV instruction (it uses MulHiL).
  return false;
}

// Register for DIVI projection of divmodI
RegMask Matcher::divI_proj_mask() {
  return INT_RAX_REG_mask();
}

// Register for MODI projection of divmodI
RegMask Matcher::modI_proj_mask() {
  return INT_RDX_REG_mask();
}

// Register for DIVL projection of divmodL
RegMask Matcher::divL_proj_mask() {
  return LONG_RAX_REG_mask();
}

// Register for MODL projection of divmodL
RegMask Matcher::modL_proj_mask() {
  return LONG_RDX_REG_mask();
}

// Register for saving SP into on method handle invokes. Not used on x86_64.
const RegMask Matcher::method_handle_invoke_SP_save_mask() {
    return NO_REG_mask();
}


#line 1268 "../generated/adfiles/ad_x86_64.cpp"


//SourceForm

#line 543 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"


// Emit exception handler code.
// Stuff framesize into a register and call a VM stub routine.
int HandlerImpl::emit_exception_handler(CodeBuffer& cbuf) {

  // Note that the code buffer's insts_mark is always relative to insts.
  // That's why we must use the macroassembler to generate a handler.
  MacroAssembler _masm(&cbuf);
  address base = __ start_a_stub(size_exception_handler());
  if (base == NULL) {
    ciEnv::current()->record_failure("CodeCache is full");
    return 0;  // CodeBuffer::expand failed
  }
  int offset = __ offset();
  __ jump(RuntimeAddress(OptoRuntime::exception_blob()->entry_point()));
  assert(__ offset() - offset <= (int) size_exception_handler(), "overflow");
  __ end_a_stub();
  return offset;
}

// Emit deopt handler code.
int HandlerImpl::emit_deopt_handler(CodeBuffer& cbuf) {

  // Note that the code buffer's insts_mark is always relative to insts.
  // That's why we must use the macroassembler to generate a handler.
  MacroAssembler _masm(&cbuf);
  address base = __ start_a_stub(size_deopt_handler());
  if (base == NULL) {
    ciEnv::current()->record_failure("CodeCache is full");
    return 0;  // CodeBuffer::expand failed
  }
  int offset = __ offset();

#ifdef _LP64
  address the_pc = (address) __ pc();
  Label next;
  // push a "the_pc" on the stack without destroying any registers
  // as they all may be live.

  // push address of "next"
  __ call(next, relocInfo::none); // reloc none is fine since it is a disp32
  __ bind(next);
  // adjust it so it matches "the_pc"
  __ subptr(Address(rsp, 0), __ offset() - offset);
#else
  InternalAddress here(__ pc());
  __ pushptr(here.addr());
#endif

  __ jump(RuntimeAddress(SharedRuntime::deopt_blob()->unpack()));
  assert(__ offset() - offset <= (int) size_deopt_handler(), "overflow");
  __ end_a_stub();
  return offset;
}


//=============================================================================

  // Float masks come from different places depending on platform.
#ifdef _LP64
  static address float_signmask()  { return StubRoutines::x86::float_sign_mask(); }
  static address float_signflip()  { return StubRoutines::x86::float_sign_flip(); }
  static address double_signmask() { return StubRoutines::x86::double_sign_mask(); }
  static address double_signflip() { return StubRoutines::x86::double_sign_flip(); }
#else
  static address float_signmask()  { return (address)float_signmask_pool; }
  static address float_signflip()  { return (address)float_signflip_pool; }
  static address double_signmask() { return (address)double_signmask_pool; }
  static address double_signflip() { return (address)double_signflip_pool; }
#endif


const bool Matcher::match_rule_supported(int opcode) {
  if (!has_match_rule(opcode))
    return false;

  switch (opcode) {
    case Op_PopCountI:
    case Op_PopCountL:
      if (!UsePopCountInstruction)
        return false;
    break;
    case Op_MulVI:
      if ((UseSSE < 4) && (UseAVX < 1)) // only with SSE4_1 or AVX
        return false;
    break;
    case Op_CompareAndSwapL:
#ifdef _LP64
    case Op_CompareAndSwapP:
#endif
      if (!VM_Version::supports_cx8())
        return false;
    break;
  }

  return true;  // Per default match rules are supported.
}

// Max vector size in bytes. 0 if not supported.
const int Matcher::vector_width_in_bytes(BasicType bt) {
  assert(is_java_primitive(bt), "only primitive type vectors");
  if (UseSSE < 2) return 0;
  // SSE2 supports 128bit vectors for all types.
  // AVX2 supports 256bit vectors for all types.
  int size = (UseAVX > 1) ? 32 : 16;
  // AVX1 supports 256bit vectors only for FLOAT and DOUBLE.
  if (UseAVX > 0 && (bt == T_FLOAT || bt == T_DOUBLE))
    size = 32;
  // Use flag to limit vector size.
  size = MIN2(size,(int)MaxVectorSize);
  // Minimum 2 values in vector (or 4 for bytes).
  switch (bt) {
  case T_DOUBLE:
  case T_LONG:
    if (size < 16) return 0;
  case T_FLOAT:
  case T_INT:
    if (size < 8) return 0;
  case T_BOOLEAN:
  case T_BYTE:
  case T_CHAR:
  case T_SHORT:
    if (size < 4) return 0;
    break;
  default:
    ShouldNotReachHere();
  }
  return size;
}

// Limits on vector size (number of elements) loaded into vector.
const int Matcher::max_vector_size(const BasicType bt) {
  return vector_width_in_bytes(bt)/type2aelembytes(bt);
}
const int Matcher::min_vector_size(const BasicType bt) {
  int max_size = max_vector_size(bt);
  // Min size which can be loaded into vector is 4 bytes.
  int size = (type2aelembytes(bt) == 1) ? 4 : 2;
  return MIN2(size,max_size);
}

// Vector ideal reg corresponding to specidied size in bytes
const int Matcher::vector_ideal_reg(int size) {
  assert(MaxVectorSize >= size, "");
  switch(size) {
    case  4: return Op_VecS;
    case  8: return Op_VecD;
    case 16: return Op_VecX;
    case 32: return Op_VecY;
  }
  ShouldNotReachHere();
  return 0;
}

// Only lowest bits of xmm reg are used for vector shift count.
const int Matcher::vector_shift_count_ideal_reg(int size) {
  return Op_VecS;
}

// x86 supports misaligned vectors store/load.
const bool Matcher::misaligned_vectors_ok() {
  return !AlignVector; // can be changed by flag
}

// x86 AES instructions are compatible with SunJCE expanded
// keys, hence we do not need to pass the original key to stubs
const bool Matcher::pass_original_key_for_aes() {
  return false;
}

// Helper methods for MachSpillCopyNode::implementation().
static int vec_mov_helper(CodeBuffer *cbuf, bool do_size, int src_lo, int dst_lo,
                          int src_hi, int dst_hi, uint ireg, outputStream* st) {
  // In 64-bit VM size calculation is very complex. Emitting instructions
  // into scratch buffer is used to get size in 64-bit VM.
  LP64_ONLY( assert(!do_size, "this method calculates size only for 32-bit VM"); )
  assert(ireg == Op_VecS || // 32bit vector
         (src_lo & 1) == 0 && (src_lo + 1) == src_hi &&
         (dst_lo & 1) == 0 && (dst_lo + 1) == dst_hi,
         "no non-adjacent vector moves" );
  if (cbuf) {
    MacroAssembler _masm(cbuf);
    int offset = __ offset();
    switch (ireg) {
    case Op_VecS: // copy whole register
    case Op_VecD:
    case Op_VecX:
      __ movdqu(as_XMMRegister(Matcher::_regEncode[dst_lo]), as_XMMRegister(Matcher::_regEncode[src_lo]));
      break;
    case Op_VecY:
      __ vmovdqu(as_XMMRegister(Matcher::_regEncode[dst_lo]), as_XMMRegister(Matcher::_regEncode[src_lo]));
      break;
    default:
      ShouldNotReachHere();
    }
    int size = __ offset() - offset;
#ifdef ASSERT
    // VEX_2bytes prefix is used if UseAVX > 0, so it takes the same 2 bytes as SIMD prefix.
    assert(!do_size || size == 4, "incorrect size calculattion");
#endif
    return size;
#ifndef PRODUCT
  } else if (!do_size) {
    switch (ireg) {
    case Op_VecS:
    case Op_VecD:
    case Op_VecX:
      st->print("movdqu  %s,%s\t# spill",Matcher::regName[dst_lo],Matcher::regName[src_lo]);
      break;
    case Op_VecY:
      st->print("vmovdqu %s,%s\t# spill",Matcher::regName[dst_lo],Matcher::regName[src_lo]);
      break;
    default:
      ShouldNotReachHere();
    }
#endif
  }
  // VEX_2bytes prefix is used if UseAVX > 0, and it takes the same 2 bytes as SIMD prefix.
  return 4;
}

static int vec_spill_helper(CodeBuffer *cbuf, bool do_size, bool is_load,
                            int stack_offset, int reg, uint ireg, outputStream* st) {
  // In 64-bit VM size calculation is very complex. Emitting instructions
  // into scratch buffer is used to get size in 64-bit VM.
  LP64_ONLY( assert(!do_size, "this method calculates size only for 32-bit VM"); )
  if (cbuf) {
    MacroAssembler _masm(cbuf);
    int offset = __ offset();
    if (is_load) {
      switch (ireg) {
      case Op_VecS:
        __ movdl(as_XMMRegister(Matcher::_regEncode[reg]), Address(rsp, stack_offset));
        break;
      case Op_VecD:
        __ movq(as_XMMRegister(Matcher::_regEncode[reg]), Address(rsp, stack_offset));
        break;
      case Op_VecX:
        __ movdqu(as_XMMRegister(Matcher::_regEncode[reg]), Address(rsp, stack_offset));
        break;
      case Op_VecY:
        __ vmovdqu(as_XMMRegister(Matcher::_regEncode[reg]), Address(rsp, stack_offset));
        break;
      default:
        ShouldNotReachHere();
      }
    } else { // store
      switch (ireg) {
      case Op_VecS:
        __ movdl(Address(rsp, stack_offset), as_XMMRegister(Matcher::_regEncode[reg]));
        break;
      case Op_VecD:
        __ movq(Address(rsp, stack_offset), as_XMMRegister(Matcher::_regEncode[reg]));
        break;
      case Op_VecX:
        __ movdqu(Address(rsp, stack_offset), as_XMMRegister(Matcher::_regEncode[reg]));
        break;
      case Op_VecY:
        __ vmovdqu(Address(rsp, stack_offset), as_XMMRegister(Matcher::_regEncode[reg]));
        break;
      default:
        ShouldNotReachHere();
      }
    }
    int size = __ offset() - offset;
#ifdef ASSERT
    int offset_size = (stack_offset == 0) ? 0 : ((stack_offset < 0x80) ? 1 : 4);
    // VEX_2bytes prefix is used if UseAVX > 0, so it takes the same 2 bytes as SIMD prefix.
    assert(!do_size || size == (5+offset_size), "incorrect size calculattion");
#endif
    return size;
#ifndef PRODUCT
  } else if (!do_size) {
    if (is_load) {
      switch (ireg) {
      case Op_VecS:
        st->print("movd    %s,[rsp + %d]\t# spill", Matcher::regName[reg], stack_offset);
        break;
      case Op_VecD:
        st->print("movq    %s,[rsp + %d]\t# spill", Matcher::regName[reg], stack_offset);
        break;
       case Op_VecX:
        st->print("movdqu  %s,[rsp + %d]\t# spill", Matcher::regName[reg], stack_offset);
        break;
      case Op_VecY:
        st->print("vmovdqu %s,[rsp + %d]\t# spill", Matcher::regName[reg], stack_offset);
        break;
      default:
        ShouldNotReachHere();
      }
    } else { // store
      switch (ireg) {
      case Op_VecS:
        st->print("movd    [rsp + %d],%s\t# spill", stack_offset, Matcher::regName[reg]);
        break;
      case Op_VecD:
        st->print("movq    [rsp + %d],%s\t# spill", stack_offset, Matcher::regName[reg]);
        break;
       case Op_VecX:
        st->print("movdqu  [rsp + %d],%s\t# spill", stack_offset, Matcher::regName[reg]);
        break;
      case Op_VecY:
        st->print("vmovdqu [rsp + %d],%s\t# spill", stack_offset, Matcher::regName[reg]);
        break;
      default:
        ShouldNotReachHere();
      }
    }
#endif
  }
  int offset_size = (stack_offset == 0) ? 0 : ((stack_offset < 0x80) ? 1 : 4);
  // VEX_2bytes prefix is used if UseAVX > 0, so it takes the same 2 bytes as SIMD prefix.
  return 5+offset_size;
}

static inline jfloat replicate4_imm(int con, int width) {
  // Load a constant of "width" (in bytes) and replicate it to fill 32bit.
  assert(width == 1 || width == 2, "only byte or short types here");
  int bit_width = width * 8;
  jint val = con;
  val &= (1 << bit_width) - 1;  // mask off sign bits
  while(bit_width < 32) {
    val |= (val << bit_width);
    bit_width <<= 1;
  }
  jfloat fval = *((jfloat*) &val);  // coerce to float type
  return fval;
}

static inline jdouble replicate8_imm(int con, int width) {
  // Load a constant of "width" (in bytes) and replicate it to fill 64bit.
  assert(width == 1 || width == 2 || width == 4, "only byte, short or int types here");
  int bit_width = width * 8;
  jlong val = con;
  val &= (((jlong) 1) << bit_width) - 1;  // mask off sign bits
  while(bit_width < 64) {
    val |= (val << bit_width);
    bit_width <<= 1;
  }
  jdouble dval = *((jdouble*) &val);  // coerce to double type
  return dval;
}

#ifndef PRODUCT
  void MachNopNode::format(PhaseRegAlloc*, outputStream* st) const {
    st->print("nop \t# %d bytes pad for loops and calls", _count);
  }
#endif

  void MachNopNode::emit(CodeBuffer &cbuf, PhaseRegAlloc*) const {
    MacroAssembler _masm(&cbuf);
    __ nop(_count);
  }

  uint MachNopNode::size(PhaseRegAlloc*) const {
    return _count;
  }

#ifndef PRODUCT
  void MachBreakpointNode::format(PhaseRegAlloc*, outputStream* st) const {
    st->print("# breakpoint");
  }
#endif

  void MachBreakpointNode::emit(CodeBuffer &cbuf, PhaseRegAlloc* ra_) const {
    MacroAssembler _masm(&cbuf);
    __ int3();
  }

  uint MachBreakpointNode::size(PhaseRegAlloc* ra_) const {
    return MachNode::size(ra_);
  }


#line 1649 "../generated/adfiles/ad_x86_64.cpp"


#ifndef PRODUCT
void Compile::adlc_verification() {

  // Following assertions generated from definition section
}
#endif

// Map from machine-independent register number to register_save_policy
const        char register_save_policy[] = {
  'C', // R10
  'C', // R10_H
  'C', // R11
  'C', // R11_H
  'C', // R8
  'C', // R8_H
  'C', // R9
  'C', // R9_H
  'C', // R12
  'C', // R12_H
  'C', // RCX
  'C', // RCX_H
  'C', // RBX
  'C', // RBX_H
  'C', // RDI
  'C', // RDI_H
  'C', // RDX
  'C', // RDX_H
  'C', // RSI
  'C', // RSI_H
  'C', // RAX
  'C', // RAX_H
  'N', // RBP
  'N', // RBP_H
  'C', // R13
  'C', // R13_H
  'C', // R14
  'C', // R14_H
  'C', // R15
  'C', // R15_H
  'N', // RSP
  'N', // RSP_H
  'C', // XMM0
  'C', // XMM0b
  'C', // XMM0c
  'C', // XMM0d
  'C', // XMM0e
  'C', // XMM0f
  'C', // XMM0g
  'C', // XMM0h
  'C', // XMM1
  'C', // XMM1b
  'C', // XMM1c
  'C', // XMM1d
  'C', // XMM1e
  'C', // XMM1f
  'C', // XMM1g
  'C', // XMM1h
  'C', // XMM2
  'C', // XMM2b
  'C', // XMM2c
  'C', // XMM2d
  'C', // XMM2e
  'C', // XMM2f
  'C', // XMM2g
  'C', // XMM2h
  'C', // XMM3
  'C', // XMM3b
  'C', // XMM3c
  'C', // XMM3d
  'C', // XMM3e
  'C', // XMM3f
  'C', // XMM3g
  'C', // XMM3h
  'C', // XMM4
  'C', // XMM4b
  'C', // XMM4c
  'C', // XMM4d
  'C', // XMM4e
  'C', // XMM4f
  'C', // XMM4g
  'C', // XMM4h
  'C', // XMM5
  'C', // XMM5b
  'C', // XMM5c
  'C', // XMM5d
  'C', // XMM5e
  'C', // XMM5f
  'C', // XMM5g
  'C', // XMM5h
  'C', // XMM6
  'C', // XMM6b
  'C', // XMM6c
  'C', // XMM6d
  'C', // XMM6e
  'C', // XMM6f
  'C', // XMM6g
  'C', // XMM6h
  'C', // XMM7
  'C', // XMM7b
  'C', // XMM7c
  'C', // XMM7d
  'C', // XMM7e
  'C', // XMM7f
  'C', // XMM7g
  'C', // XMM7h
  'C', // XMM8
  'C', // XMM8b
  'C', // XMM8c
  'C', // XMM8d
  'C', // XMM8e
  'C', // XMM8f
  'C', // XMM8g
  'C', // XMM8h
  'C', // XMM9
  'C', // XMM9b
  'C', // XMM9c
  'C', // XMM9d
  'C', // XMM9e
  'C', // XMM9f
  'C', // XMM9g
  'C', // XMM9h
  'C', // XMM10
  'C', // XMM10b
  'C', // XMM10c
  'C', // XMM10d
  'C', // XMM10e
  'C', // XMM10f
  'C', // XMM10g
  'C', // XMM10h
  'C', // XMM11
  'C', // XMM11b
  'C', // XMM11c
  'C', // XMM11d
  'C', // XMM11e
  'C', // XMM11f
  'C', // XMM11g
  'C', // XMM11h
  'C', // XMM12
  'C', // XMM12b
  'C', // XMM12c
  'C', // XMM12d
  'C', // XMM12e
  'C', // XMM12f
  'C', // XMM12g
  'C', // XMM12h
  'C', // XMM13
  'C', // XMM13b
  'C', // XMM13c
  'C', // XMM13d
  'C', // XMM13e
  'C', // XMM13f
  'C', // XMM13g
  'C', // XMM13h
  'C', // XMM14
  'C', // XMM14b
  'C', // XMM14c
  'C', // XMM14d
  'C', // XMM14e
  'C', // XMM14f
  'C', // XMM14g
  'C', // XMM14h
  'C', // XMM15
  'C', // XMM15b
  'C', // XMM15c
  'C', // XMM15d
  'C', // XMM15e
  'C', // XMM15f
  'C', // XMM15g
  'C', // XMM15h
  'C' // no trailing comma // RFLAGS
};

// Map from machine-independent register number to c_reg_save_policy
const        char c_reg_save_policy[] = {
  'C', // R10
  'C', // R10_H
  'C', // R11
  'C', // R11_H
  'C', // R8
  'C', // R8_H
  'C', // R9
  'C', // R9_H
  'E', // R12
  'E', // R12_H
  'C', // RCX
  'C', // RCX_H
  'E', // RBX
  'E', // RBX_H
  'C', // RDI
  'C', // RDI_H
  'C', // RDX
  'C', // RDX_H
  'C', // RSI
  'C', // RSI_H
  'C', // RAX
  'C', // RAX_H
  'E', // RBP
  'E', // RBP_H
  'E', // R13
  'E', // R13_H
  'E', // R14
  'E', // R14_H
  'E', // R15
  'E', // R15_H
  'N', // RSP
  'N', // RSP_H
  'C', // XMM0
  'C', // XMM0b
  'C', // XMM0c
  'C', // XMM0d
  'C', // XMM0e
  'C', // XMM0f
  'C', // XMM0g
  'C', // XMM0h
  'C', // XMM1
  'C', // XMM1b
  'C', // XMM1c
  'C', // XMM1d
  'C', // XMM1e
  'C', // XMM1f
  'C', // XMM1g
  'C', // XMM1h
  'C', // XMM2
  'C', // XMM2b
  'C', // XMM2c
  'C', // XMM2d
  'C', // XMM2e
  'C', // XMM2f
  'C', // XMM2g
  'C', // XMM2h
  'C', // XMM3
  'C', // XMM3b
  'C', // XMM3c
  'C', // XMM3d
  'C', // XMM3e
  'C', // XMM3f
  'C', // XMM3g
  'C', // XMM3h
  'C', // XMM4
  'C', // XMM4b
  'C', // XMM4c
  'C', // XMM4d
  'C', // XMM4e
  'C', // XMM4f
  'C', // XMM4g
  'C', // XMM4h
  'C', // XMM5
  'C', // XMM5b
  'C', // XMM5c
  'C', // XMM5d
  'C', // XMM5e
  'C', // XMM5f
  'C', // XMM5g
  'C', // XMM5h
  'C', // XMM6
  'C', // XMM6b
  'C', // XMM6c
  'C', // XMM6d
  'C', // XMM6e
  'C', // XMM6f
  'C', // XMM6g
  'C', // XMM6h
  'C', // XMM7
  'C', // XMM7b
  'C', // XMM7c
  'C', // XMM7d
  'C', // XMM7e
  'C', // XMM7f
  'C', // XMM7g
  'C', // XMM7h
  'C', // XMM8
  'C', // XMM8b
  'C', // XMM8c
  'C', // XMM8d
  'C', // XMM8e
  'C', // XMM8f
  'C', // XMM8g
  'C', // XMM8h
  'C', // XMM9
  'C', // XMM9b
  'C', // XMM9c
  'C', // XMM9d
  'C', // XMM9e
  'C', // XMM9f
  'C', // XMM9g
  'C', // XMM9h
  'C', // XMM10
  'C', // XMM10b
  'C', // XMM10c
  'C', // XMM10d
  'C', // XMM10e
  'C', // XMM10f
  'C', // XMM10g
  'C', // XMM10h
  'C', // XMM11
  'C', // XMM11b
  'C', // XMM11c
  'C', // XMM11d
  'C', // XMM11e
  'C', // XMM11f
  'C', // XMM11g
  'C', // XMM11h
  'C', // XMM12
  'C', // XMM12b
  'C', // XMM12c
  'C', // XMM12d
  'C', // XMM12e
  'C', // XMM12f
  'C', // XMM12g
  'C', // XMM12h
  'C', // XMM13
  'C', // XMM13b
  'C', // XMM13c
  'C', // XMM13d
  'C', // XMM13e
  'C', // XMM13f
  'C', // XMM13g
  'C', // XMM13h
  'C', // XMM14
  'C', // XMM14b
  'C', // XMM14c
  'C', // XMM14d
  'C', // XMM14e
  'C', // XMM14f
  'C', // XMM14g
  'C', // XMM14h
  'C', // XMM15
  'C', // XMM15b
  'C', // XMM15c
  'C', // XMM15d
  'C', // XMM15e
  'C', // XMM15f
  'C', // XMM15g
  'C', // XMM15h
  'C' // no trailing comma // RFLAGS
};

// Map from machine-independent register number to register_save_type
const        int register_save_type[] = {
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  0 // no trailing comma
};


const        int   reduceOp[] = {
  /*    0 */  0,
  /*    1 */  0,
  /*    2 */  0,
  /*    3 */  0,
  /*    4 */  0,
  /*    5 */  0,
  /*    6 */  0,
  /*    7 */  0,
  /*    8 */  immI_rule,
  /*    9 */  immI0_rule,
  /*   10 */  immI1_rule,
  /*   11 */  immI_M1_rule,
  /*   12 */  immI2_rule,
  /*   13 */  immI8_rule,
  /*   14 */  immI16_rule,
  /*   15 */  immU31_rule,
  /*   16 */  immI_32_rule,
  /*   17 */  immI_64_rule,
  /*   18 */  immP_rule,
  /*   19 */  immP0_rule,
  /*   20 */  immN_rule,
  /*   21 */  immNKlass_rule,
  /*   22 */  immN0_rule,
  /*   23 */  immP31_rule,
  /*   24 */  immL_rule,
  /*   25 */  immL8_rule,
  /*   26 */  immUL32_rule,
  /*   27 */  immL32_rule,
  /*   28 */  immL0_rule,
  /*   29 */  immL1_rule,
  /*   30 */  immL_M1_rule,
  /*   31 */  immL10_rule,
  /*   32 */  immL_127_rule,
  /*   33 */  immL_32bits_rule,
  /*   34 */  immF0_rule,
  /*   35 */  immF_rule,
  /*   36 */  immD0_rule,
  /*   37 */  immD_rule,
  /*   38 */  immI_16_rule,
  /*   39 */  immI_24_rule,
  /*   40 */  immI_255_rule,
  /*   41 */  immI_65535_rule,
  /*   42 */  immL_255_rule,
  /*   43 */  immL_65535_rule,
  /*   44 */  rRegI_rule,
  /*   45 */  rax_RegI_rule,
  /*   46 */  rbx_RegI_rule,
  /*   47 */  rcx_RegI_rule,
  /*   48 */  rdx_RegI_rule,
  /*   49 */  rdi_RegI_rule,
  /*   50 */  no_rcx_RegI_rule,
  /*   51 */  no_rax_rdx_RegI_rule,
  /*   52 */  any_RegP_rule,
  /*   53 */  rRegP_rule,
  /*   54 */  rRegN_rule,
  /*   55 */  no_rax_RegP_rule,
  /*   56 */  no_rbp_RegP_rule,
  /*   57 */  no_rax_rbx_RegP_rule,
  /*   58 */  rax_RegP_rule,
  /*   59 */  rax_RegN_rule,
  /*   60 */  rbx_RegP_rule,
  /*   61 */  rsi_RegP_rule,
  /*   62 */  rdi_RegP_rule,
  /*   63 */  r15_RegP_rule,
  /*   64 */  rRegL_rule,
  /*   65 */  no_rax_rdx_RegL_rule,
  /*   66 */  no_rax_RegL_rule,
  /*   67 */  no_rcx_RegL_rule,
  /*   68 */  rax_RegL_rule,
  /*   69 */  rcx_RegL_rule,
  /*   70 */  rdx_RegL_rule,
  /*   71 */  rFlagsReg_rule,
  /*   72 */  rFlagsRegU_rule,
  /*   73 */  rFlagsRegUCF_rule,
  /*   74 */  regF_rule,
  /*   75 */  regD_rule,
  /*   76 */  indirect_rule,
  /*   77 */  indOffset8_rule,
  /*   78 */  indOffset32_rule,
  /*   79 */  indIndexOffset_rule,
  /*   80 */  indIndex_rule,
  /*   81 */  indIndexScale_rule,
  /*   82 */  indIndexScaleOffset_rule,
  /*   83 */  indPosIndexScaleOffset_rule,
  /*   84 */  indCompressedOopOffset_rule,
  /*   85 */  indirectNarrow_rule,
  /*   86 */  indOffset8Narrow_rule,
  /*   87 */  indOffset32Narrow_rule,
  /*   88 */  indIndexOffsetNarrow_rule,
  /*   89 */  indIndexNarrow_rule,
  /*   90 */  indIndexScaleNarrow_rule,
  /*   91 */  indIndexScaleOffsetNarrow_rule,
  /*   92 */  indPosIndexScaleOffsetNarrow_rule,
  /*   93 */  stackSlotP_rule,
  /*   94 */  stackSlotI_rule,
  /*   95 */  stackSlotF_rule,
  /*   96 */  stackSlotD_rule,
  /*   97 */  stackSlotL_rule,
  /*   98 */  cmpOp_rule,
  /*   99 */  cmpOpU_rule,
  /*  100 */  cmpOpUCF_rule,
  /*  101 */  cmpOpUCF2_rule,
  /*  102 */  vecS_rule,
  /*  103 */  vecD_rule,
  /*  104 */  vecX_rule,
  /*  105 */  vecY_rule,
  // last operand
  /*  106 */  memory_rule,
  // last operand class
  /*  107 */  _AddP_any_RegP_rRegL_rule,
  /*  108 */  _LShiftL_rRegL_immI2_rule,
  /*  109 */  _AddP_any_RegP__LShiftL_rRegL_immI2_rule,
  /*  110 */  _ConvI2L_rRegI__rule,
  /*  111 */  _LShiftL__ConvI2L_rRegI__immI2_rule,
  /*  112 */  _AddP_any_RegP__LShiftL__ConvI2L_rRegI__immI2_rule,
  /*  113 */  _DecodeN_rRegN__rule,
  /*  114 */  _AddP__DecodeN_rRegN__rRegL_rule,
  /*  115 */  _AddP__DecodeN_rRegN___LShiftL_rRegL_immI2_rule,
  /*  116 */  _AddP__DecodeN_rRegN___LShiftL__ConvI2L_rRegI__immI2_rule,
  /*  117 */  _LoadB_memory__rule,
  /*  118 */  _LoadUB_memory__rule,
  /*  119 */  _AndI__LoadUB_memory__immI8_rule,
  /*  120 */  _LoadS_memory__rule,
  /*  121 */  _LShiftI__LoadS_memory__immI_24_rule,
  /*  122 */  _LoadUS_memory__rule,
  /*  123 */  _LShiftI__LoadUS_memory__immI_24_rule,
  /*  124 */  _AndI__LoadUS_memory__immI_255_rule,
  /*  125 */  _AndI__LoadUS_memory__immI16_rule,
  /*  126 */  _LoadI_memory__rule,
  /*  127 */  _LShiftI__LoadI_memory__immI_24_rule,
  /*  128 */  _LShiftI__LoadI_memory__immI_16_rule,
  /*  129 */  _AndI__LoadI_memory__immI_255_rule,
  /*  130 */  _AndI__LoadI_memory__immI_65535_rule,
  /*  131 */  _AndI__LoadI_memory__immU31_rule,
  /*  132 */  _ConvI2L__LoadI_memory___rule,
  /*  133 */  _LoadL_memory__rule,
  /*  134 */  _CastP2X_rRegP__rule,
  /*  135 */  _CastP2X__DecodeN_rRegN___rule,
  /*  136 */  _AddL__LShiftL_rRegL_immI2_immL32_rule,
  /*  137 */  _Binary_cmpOp_rFlagsReg_rule,
  /*  138 */  _Binary_rRegI_rRegI_rule,
  /*  139 */  _Binary_cmpOpU_rFlagsRegU_rule,
  /*  140 */  _Binary_cmpOpUCF_rFlagsRegUCF_rule,
  /*  141 */  _Binary_rRegI__LoadI_memory__rule,
  /*  142 */  _Binary_rRegN_rRegN_rule,
  /*  143 */  _Binary_rRegP_rRegP_rule,
  /*  144 */  _Binary_rRegL_rRegL_rule,
  /*  145 */  _Binary_rRegL__LoadL_memory__rule,
  /*  146 */  _Binary_regF_regF_rule,
  /*  147 */  _Binary_regD_regD_rule,
  /*  148 */  _AddI__LoadI_memory__rRegI_rule,
  /*  149 */  _AddI_rRegI__LoadI_memory__rule,
  /*  150 */  _AddI__LoadI_memory__immI_rule,
  /*  151 */  _AddI__LoadI_memory__immI1_rule,
  /*  152 */  _AddI__LoadI_memory__immI_M1_rule,
  /*  153 */  _AddL__LoadL_memory__rRegL_rule,
  /*  154 */  _AddL_rRegL__LoadL_memory__rule,
  /*  155 */  _AddL__LoadL_memory__immL32_rule,
  /*  156 */  _AddL__LoadL_memory__immL1_rule,
  /*  157 */  _AddL__LoadL_memory__immL_M1_rule,
  /*  158 */  _Binary_rax_RegP_rRegP_rule,
  /*  159 */  _Binary_rax_RegI_rRegI_rule,
  /*  160 */  _Binary_rax_RegL_rRegL_rule,
  /*  161 */  _Binary_rax_RegN_rRegN_rule,
  /*  162 */  _SubI__LoadI_memory__rRegI_rule,
  /*  163 */  _SubI__LoadI_memory__immI_rule,
  /*  164 */  _SubL__LoadL_memory__rRegL_rule,
  /*  165 */  _SubL__LoadL_memory__immL32_rule,
  /*  166 */  _SubI_immI0_rRegI_rule,
  /*  167 */  _SubI_immI0__LoadI_memory__rule,
  /*  168 */  _SubL_immL0__LoadL_memory__rule,
  /*  169 */  _LShiftI__LoadI_memory__immI1_rule,
  /*  170 */  _LShiftI__LoadI_memory__immI8_rule,
  /*  171 */  _LShiftI__LoadI_memory__rcx_RegI_rule,
  /*  172 */  _RShiftI__LoadI_memory__immI1_rule,
  /*  173 */  _RShiftI__LoadI_memory__immI8_rule,
  /*  174 */  _RShiftI__LoadI_memory__rcx_RegI_rule,
  /*  175 */  _URShiftI__LoadI_memory__immI1_rule,
  /*  176 */  _URShiftI__LoadI_memory__immI8_rule,
  /*  177 */  _URShiftI__LoadI_memory__rcx_RegI_rule,
  /*  178 */  _LShiftL__LoadL_memory__immI1_rule,
  /*  179 */  _LShiftL__LoadL_memory__immI8_rule,
  /*  180 */  _LShiftL__LoadL_memory__rcx_RegI_rule,
  /*  181 */  _RShiftL__LoadL_memory__immI1_rule,
  /*  182 */  _RShiftL__LoadL_memory__immI8_rule,
  /*  183 */  _RShiftL__LoadL_memory__rcx_RegI_rule,
  /*  184 */  _URShiftL__LoadL_memory__immI1_rule,
  /*  185 */  _URShiftL__LoadL_memory__immI8_rule,
  /*  186 */  _URShiftL__LoadL_memory__rcx_RegI_rule,
  /*  187 */  _LShiftI_rRegI_immI_24_rule,
  /*  188 */  _LShiftI_rRegI_immI_16_rule,
  /*  189 */  _LShiftI_rRegI_immI1_rule,
  /*  190 */  _URShiftI_rRegI_immI_M1_rule,
  /*  191 */  _LShiftI_rRegI_immI8_rule,
  /*  192 */  _URShiftI_rRegI_immI8_rule,
  /*  193 */  _LShiftI_no_rcx_RegI_rcx_RegI_rule,
  /*  194 */  _SubI_immI0_rcx_RegI_rule,
  /*  195 */  _URShiftI_no_rcx_RegI__SubI_immI0_rcx_RegI_rule,
  /*  196 */  _SubI_immI_32_rcx_RegI_rule,
  /*  197 */  _URShiftI_no_rcx_RegI__SubI_immI_32_rcx_RegI_rule,
  /*  198 */  _URShiftI_rRegI_immI1_rule,
  /*  199 */  _LShiftI_rRegI_immI_M1_rule,
  /*  200 */  _URShiftI_no_rcx_RegI_rcx_RegI_rule,
  /*  201 */  _LShiftI_no_rcx_RegI__SubI_immI0_rcx_RegI_rule,
  /*  202 */  _LShiftI_no_rcx_RegI__SubI_immI_32_rcx_RegI_rule,
  /*  203 */  _LShiftL_rRegL_immI1_rule,
  /*  204 */  _URShiftL_rRegL_immI_M1_rule,
  /*  205 */  _LShiftL_rRegL_immI8_rule,
  /*  206 */  _URShiftL_rRegL_immI8_rule,
  /*  207 */  _LShiftL_no_rcx_RegL_rcx_RegI_rule,
  /*  208 */  _URShiftL_no_rcx_RegL__SubI_immI0_rcx_RegI_rule,
  /*  209 */  _SubI_immI_64_rcx_RegI_rule,
  /*  210 */  _URShiftL_no_rcx_RegL__SubI_immI_64_rcx_RegI_rule,
  /*  211 */  _URShiftL_rRegL_immI1_rule,
  /*  212 */  _LShiftL_rRegL_immI_M1_rule,
  /*  213 */  _URShiftL_no_rcx_RegL_rcx_RegI_rule,
  /*  214 */  _LShiftL_no_rcx_RegL__SubI_immI0_rcx_RegI_rule,
  /*  215 */  _LShiftL_no_rcx_RegL__SubI_immI_64_rcx_RegI_rule,
  /*  216 */  _AndI_rRegI_immI_255_rule,
  /*  217 */  _AndI_rRegI_immI_65535_rule,
  /*  218 */  _AndI__LoadI_memory__rRegI_rule,
  /*  219 */  _AndI_rRegI__LoadI_memory__rule,
  /*  220 */  _AndI__LoadI_memory__immI_rule,
  /*  221 */  _XorI_rRegI_immI_M1_rule,
  /*  222 */  _AddI_rRegI_immI_M1_rule,
  /*  223 */  _OrI__LoadI_memory__rRegI_rule,
  /*  224 */  _OrI_rRegI__LoadI_memory__rule,
  /*  225 */  _OrI__LoadI_memory__immI_rule,
  /*  226 */  _XorI__LoadI_memory__rRegI_rule,
  /*  227 */  _XorI_rRegI__LoadI_memory__rule,
  /*  228 */  _XorI__LoadI_memory__immI_rule,
  /*  229 */  _AndL__LoadL_memory__rRegL_rule,
  /*  230 */  _AndL_rRegL__LoadL_memory__rule,
  /*  231 */  _AndL__LoadL_memory__immL32_rule,
  /*  232 */  _XorL_rRegL_immL_M1_rule,
  /*  233 */  _SubL_immL0_rRegL_rule,
  /*  234 */  _AddL_rRegL_immL_M1_rule,
  /*  235 */  _CastP2X_any_RegP__rule,
  /*  236 */  _OrL__LoadL_memory__rRegL_rule,
  /*  237 */  _OrL_rRegL__LoadL_memory__rule,
  /*  238 */  _OrL__LoadL_memory__immL32_rule,
  /*  239 */  _XorL__LoadL_memory__rRegL_rule,
  /*  240 */  _XorL_rRegL__LoadL_memory__rule,
  /*  241 */  _XorL__LoadL_memory__immL32_rule,
  /*  242 */  _CmpLTMask_rRegI_rRegI_rule,
  /*  243 */  _AndI__CmpLTMask_rRegI_rRegI_rRegI_rule,
  /*  244 */  _SubI_rRegI_rRegI_rule,
  /*  245 */  _AndI_rRegI__CmpLTMask_rRegI_rRegI_rule,
  /*  246 */  _LoadF_memory__rule,
  /*  247 */  _LoadD_memory__rule,
  /*  248 */  _Binary_rdi_RegP_rcx_RegI_rule,
  /*  249 */  _Binary_rsi_RegP_rdx_RegI_rule,
  /*  250 */  _Binary_rdi_RegP_rdx_RegI_rule,
  /*  251 */  _Binary_rsi_RegP_immI_rule,
  /*  252 */  _Binary_rsi_RegP_rax_RegI_rule,
  /*  253 */  _Binary_rdi_RegP_rsi_RegP_rule,
  /*  254 */  _AndI_rRegI_immI_rule,
  /*  255 */  _LoadP_memory__rule,
  /*  256 */  _LoadN_memory__rule,
  /*  257 */  _LoadNKlass_memory__rule,
  /*  258 */  _AndL_rRegL_immL32_rule,
  /*  259 */  _PartialSubtypeCheck_rsi_RegP_rax_RegP_rule,
  /*  260 */  _ConvF2D_regF__rule,
  /*  261 */  _SqrtD__ConvF2D_regF___rule,
  /*  262 */  _ConvF2D__LoadF_memory___rule,
  /*  263 */  _SqrtD__ConvF2D__LoadF_memory____rule,
  /*  264 */  _ConvF2D_immF__rule,
  /*  265 */  _SqrtD__ConvF2D_immF___rule,
  /*  266 */  _LoadVector_memory__rule,
  // last internally defined operand
  /*  267 */  stackSlotI_rule,
  /*  268 */  stackSlotL_rule,
  /*  269 */  stackSlotP_rule,
  /*  270 */  stackSlotF_rule,
  /*  271 */  stackSlotD_rule,
  /*  272 */  rRegP_rule,
  /*  273 */  rRegP_rule,
  /*  274 */  rRegP_rule,
  /*  275 */  rRegP_rule,
  /*  276 */  rRegP_rule,
  /*  277 */  rRegP_rule,
  /*  278 */  rRegP_rule,
  /*  279 */  rRegP_rule,
  /*  280 */  rRegP_rule,
  /*  281 */  rRegP_rule,
  /*  282 */  rRegP_rule,
  /*  283 */  rRegP_rule,
  /*  284 */  rRegP_rule,
  /*  285 */  rRegI_rule,
  /*  286 */  rRegI_rule,
  /*  287 */  rRegL_rule,
  /*  288 */  rRegL_rule,
  /*  289 */  rRegL_rule,
  /*  290 */  rRegL_rule,
  /*  291 */  rRegP_rule,
  /*  292 */  rRegP_rule,
  /*  293 */  rRegP_rule,
  /*  294 */  regF_rule,
  /*  295 */  rRegN_rule,
  /*  296 */  rRegN_rule,
  /*  297 */  rRegN_rule,
  /*  298 */  regF_rule,
  /*  299 */  regD_rule,
  /*  300 */  regD_rule,
  /*  301 */  rRegI_rule,
  /*  302 */  rRegL_rule,
  /*  303 */  rRegP_rule,
  /*  304 */  regF_rule,
  /*  305 */  regD_rule,
  /*  306 */  Universe_rule,
  /*  307 */  rRegP_rule,
  /*  308 */  rRegL_rule,
  /*  309 */  rRegP_rule,
  /*  310 */  rRegP_rule,
  /*  311 */  rRegI_rule,
  /*  312 */  rFlagsReg_rule,
  /*  313 */  rFlagsReg_rule,
  /*  314 */  rFlagsReg_rule,
  /*  315 */  rFlagsRegU_rule,
  /*  316 */  rFlagsRegUCF_rule,
  /*  317 */  rFlagsRegU_rule,
  /*  318 */  rFlagsRegUCF_rule,
  /*  319 */  rFlagsRegU_rule,
  /*  320 */  rFlagsRegUCF_rule,
  /*  321 */  rFlagsRegU_rule,
  /*  322 */  rFlagsRegUCF_rule,
  /*  323 */  rFlagsRegU_rule,
  /*  324 */  rFlagsRegUCF_rule,
  /*  325 */  rFlagsRegU_rule,
  /*  326 */  rFlagsRegUCF_rule,
  /*  327 */  regF_rule,
  /*  328 */  regD_rule,
  /*  329 */  rRegI_rule,
  /*  330 */  regF_rule,
  /*  331 */  rRegL_rule,
  /*  332 */  regD_rule,
  /*  333 */  regD_rule,
  /*  334 */  rRegI_rule,
  /*  335 */  rRegL_rule,
  /*  336 */  regF_rule,
  /*  337 */  regD_rule,
  /*  338 */  rFlagsReg_rule,
  /*  339 */  rFlagsReg_rule,
  /*  340 */  rFlagsReg_rule,
  /*  341 */  rFlagsReg_rule,
  /*  342 */  rFlagsReg_rule,
  /*  343 */  rFlagsReg_rule,
  /*  344 */  rFlagsReg_rule,
  /*  345 */  rFlagsReg_rule,
  /*  346 */  rFlagsReg_rule,
  /*  347 */  rFlagsReg_rule,
  /*  348 */  rFlagsReg_rule,
  /*  349 */  rFlagsReg_rule,
  /*  350 */  rFlagsReg_rule,
  /*  351 */  rFlagsReg_rule,
  /*  352 */  rFlagsReg_rule,
  /*  353 */  rFlagsReg_rule,
  /*  354 */  rFlagsReg_rule,
  /*  355 */  rFlagsReg_rule,
  /*  356 */  rFlagsReg_rule,
  /*  357 */  rFlagsReg_rule,
  /*  358 */  rFlagsReg_rule,
  /*  359 */  rFlagsRegU_rule,
  /*  360 */  rFlagsRegU_rule,
  /*  361 */  rFlagsRegU_rule,
  /*  362 */  rFlagsRegU_rule,
  /*  363 */  rFlagsRegU_rule,
  /*  364 */  rFlagsRegU_rule,
  /*  365 */  rFlagsRegU_rule,
  /*  366 */  rFlagsReg_rule,
  /*  367 */  rFlagsReg_rule,
  /*  368 */  rFlagsReg_rule,
  /*  369 */  rFlagsRegU_rule,
  /*  370 */  rFlagsRegU_rule,
  /*  371 */  rFlagsRegU_rule,
  /*  372 */  rFlagsRegU_rule,
  /*  373 */  rFlagsRegU_rule,
  /*  374 */  rFlagsRegU_rule,
  /*  375 */  rFlagsReg_rule,
  /*  376 */  rFlagsReg_rule,
  /*  377 */  rFlagsReg_rule,
  /*  378 */  rFlagsReg_rule,
  /*  379 */  rFlagsReg_rule,
  /*  380 */  rFlagsReg_rule,
  /*  381 */  rFlagsReg_rule,
  /*  382 */  rFlagsReg_rule,
  /*  383 */  rFlagsReg_rule,
  /*  384 */  rFlagsReg_rule,
  /*  385 */  rFlagsRegU_rule,
  /*  386 */  rFlagsRegU_rule,
  /*  387 */  rFlagsRegU_rule,
  /*  388 */  rFlagsRegU_rule,
  /*  389 */  rFlagsReg_rule,
  /*  390 */  rFlagsReg_rule,
  /*  391 */  rFlagsReg_rule,
  /*  392 */  rFlagsReg_rule,
  /*  393 */  Universe_rule,
  /*  394 */  r15_RegP_rule,
  /*  395 */  regF_rule,
  /*  396 */  regF_rule,
  /*  397 */  regD_rule,
  /*  398 */  regD_rule,
  /*  399 */  regF_rule,
  /*  400 */  regF_rule,
  /*  401 */  regD_rule,
  /*  402 */  regD_rule,
  /*  403 */  vecS_rule,
  /*  404 */  vecS_rule,
  /*  405 */  rRegI_rule,
  /*  406 */  rRegL_rule,
  /*  407 */  rRegI_rule,
  /*  408 */  rRegL_rule,
  /*  409 */  rRegL_rule,
  /*  410 */  rRegI_rule,
  /*  411 */  rRegI_rule,
  /*  412 */  rRegL_rule,
  /*  413 */  rRegI_rule,
  /*  414 */  rRegI_rule,
  /*  415 */  rRegL_rule,
  /*  416 */  rRegL_rule,
  /*  417 */  rRegL_rule,
  /*  418 */  rRegI_rule,
  /*  419 */  rRegI_rule,
  /*  420 */  rRegI_rule,
  /*  421 */  rRegI_rule,
  /*  422 */  rRegI_rule,
  /*  423 */  rRegL_rule,
  /*  424 */  rRegL_rule,
  /*  425 */  rRegL_rule,
  /*  426 */  rRegL_rule,
  /*  427 */  rRegL_rule,
  /*  428 */  rRegL_rule,
  /*  429 */  rRegI_rule,
  /*  430 */  rRegP_rule,
  /*  431 */  rRegN_rule,
  /*  432 */  rRegP_rule,
  /*  433 */  rRegN_rule,
  /*  434 */  regF_rule,
  /*  435 */  regD_rule,
  /*  436 */  regD_rule,
  /*  437 */  Universe_rule,
  /*  438 */  Universe_rule,
  /*  439 */  Universe_rule,
  /*  440 */  Universe_rule,
  /*  441 */  Universe_rule,
  /*  442 */  Universe_rule,
  /*  443 */  Universe_rule,
  /*  444 */  Universe_rule,
  /*  445 */  Universe_rule,
  /*  446 */  Universe_rule,
  /*  447 */  Universe_rule,
  /*  448 */  Universe_rule,
  /*  449 */  Universe_rule,
  /*  450 */  Universe_rule,
  /*  451 */  Universe_rule,
  /*  452 */  Universe_rule,
  /*  453 */  Universe_rule,
  /*  454 */  Universe_rule,
  /*  455 */  Universe_rule,
  /*  456 */  Universe_rule,
  /*  457 */  Universe_rule,
  /*  458 */  Universe_rule,
  /*  459 */  Universe_rule,
  /*  460 */  Universe_rule,
  /*  461 */  Universe_rule,
  /*  462 */  Universe_rule,
  /*  463 */  Universe_rule,
  /*  464 */  Universe_rule,
  /*  465 */  Universe_rule,
  /*  466 */  Universe_rule,
  /*  467 */  Universe_rule,
  /*  468 */  Universe_rule,
  /*  469 */  Universe_rule,
  /*  470 */  Universe_rule,
  /*  471 */  Universe_rule,
  /*  472 */  Universe_rule,
  /*  473 */  Universe_rule,
  /*  474 */  rRegI_rule,
  /*  475 */  rRegL_rule,
  /*  476 */  rRegI_rule,
  /*  477 */  rRegI_rule,
  /*  478 */  rRegI_rule,
  /*  479 */  rRegI_rule,
  /*  480 */  rRegI_rule,
  /*  481 */  rRegI_rule,
  /*  482 */  rRegI_rule,
  /*  483 */  rRegI_rule,
  /*  484 */  rRegI_rule,
  /*  485 */  rRegI_rule,
  /*  486 */  rRegI_rule,
  /*  487 */  rRegI_rule,
  /*  488 */  rRegI_rule,
  /*  489 */  rRegI_rule,
  /*  490 */  Universe_rule,
  /*  491 */  Universe_rule,
  /*  492 */  Universe_rule,
  /*  493 */  Universe_rule,
  /*  494 */  Universe_rule,
  /*  495 */  Universe_rule,
  /*  496 */  Universe_rule,
  /*  497 */  Universe_rule,
  /*  498 */  rRegI_rule,
  /*  499 */  rRegI_rule,
  /*  500 */  rRegN_rule,
  /*  501 */  rRegN_rule,
  /*  502 */  rRegP_rule,
  /*  503 */  rRegP_rule,
  /*  504 */  rRegN_rule,
  /*  505 */  rRegP_rule,
  /*  506 */  Universe_rule,
  /*  507 */  Universe_rule,
  /*  508 */  Universe_rule,
  /*  509 */  rRegI_rule,
  /*  510 */  rRegI_rule,
  /*  511 */  rRegI_rule,
  /*  512 */  rRegI_rule,
  /*  513 */  rRegI_rule,
  /*  514 */  rRegI_rule,
  /*  515 */  rRegN_rule,
  /*  516 */  rRegN_rule,
  /*  517 */  rRegN_rule,
  /*  518 */  rRegP_rule,
  /*  519 */  rRegP_rule,
  /*  520 */  rRegP_rule,
  /*  521 */  rRegL_rule,
  /*  522 */  rRegL_rule,
  /*  523 */  rRegL_rule,
  /*  524 */  rRegL_rule,
  /*  525 */  rRegL_rule,
  /*  526 */  rRegL_rule,
  /*  527 */  regF_rule,
  /*  528 */  regF_rule,
  /*  529 */  regF_rule,
  /*  530 */  regD_rule,
  /*  531 */  regD_rule,
  /*  532 */  regD_rule,
  /*  533 */  rRegI_rule,
  /*  534 */  rRegI_rule,
  /*  535 */  rRegI_rule,
  /*  536 */  rRegI_rule,
  /*  537 */  Universe_rule,
  /*  538 */  Universe_rule,
  /*  539 */  Universe_rule,
  /*  540 */  rRegI_rule,
  /*  541 */  Universe_rule,
  /*  542 */  rRegI_rule,
  /*  543 */  Universe_rule,
  /*  544 */  rRegI_rule,
  /*  545 */  rRegL_rule,
  /*  546 */  rRegL_rule,
  /*  547 */  rRegL_rule,
  /*  548 */  rRegL_rule,
  /*  549 */  Universe_rule,
  /*  550 */  Universe_rule,
  /*  551 */  Universe_rule,
  /*  552 */  rRegI_rule,
  /*  553 */  Universe_rule,
  /*  554 */  rRegL_rule,
  /*  555 */  Universe_rule,
  /*  556 */  rRegL_rule,
  /*  557 */  rRegP_rule,
  /*  558 */  rRegP_rule,
  /*  559 */  rRegP_rule,
  /*  560 */  rRegP_rule,
  /*  561 */  rRegI_rule,
  /*  562 */  rRegI_rule,
  /*  563 */  rRegI_rule,
  /*  564 */  rRegI_rule,
  /*  565 */  Universe_rule,
  /*  566 */  rRegI_rule,
  /*  567 */  Universe_rule,
  /*  568 */  rRegL_rule,
  /*  569 */  rRegI_rule,
  /*  570 */  rRegL_rule,
  /*  571 */  rRegP_rule,
  /*  572 */  rRegN_rule,
  /*  573 */  rRegI_rule,
  /*  574 */  rRegI_rule,
  /*  575 */  rRegI_rule,
  /*  576 */  Universe_rule,
  /*  577 */  Universe_rule,
  /*  578 */  rRegL_rule,
  /*  579 */  rRegI_rule,
  /*  580 */  rRegL_rule,
  /*  581 */  Universe_rule,
  /*  582 */  Universe_rule,
  /*  583 */  rRegP_rule,
  /*  584 */  rRegI_rule,
  /*  585 */  Universe_rule,
  /*  586 */  rRegL_rule,
  /*  587 */  Universe_rule,
  /*  588 */  rRegI_rule,
  /*  589 */  rRegI_rule,
  /*  590 */  rRegI_rule,
  /*  591 */  rRegI_rule,
  /*  592 */  rRegI_rule,
  /*  593 */  rRegL_rule,
  /*  594 */  rRegL_rule,
  /*  595 */  rRegL_rule,
  /*  596 */  rRegL_rule,
  /*  597 */  rRegL_rule,
  /*  598 */  rdx_RegL_rule,
  /*  599 */  rax_RegI_rule,
  /*  600 */  rax_RegL_rule,
  /*  601 */  Universe_rule,
  /*  602 */  Universe_rule,
  /*  603 */  0,
  /*  604 */  0,
  /*  605 */  0,
  /*  606 */  0,
  /*  607 */  rdx_RegL_rule,
  /*  608 */  rdx_RegI_rule,
  /*  609 */  rdx_RegL_rule,
  /*  610 */  rRegI_rule,
  /*  611 */  Universe_rule,
  /*  612 */  rRegI_rule,
  /*  613 */  Universe_rule,
  /*  614 */  rRegI_rule,
  /*  615 */  Universe_rule,
  /*  616 */  rRegI_rule,
  /*  617 */  Universe_rule,
  /*  618 */  rRegI_rule,
  /*  619 */  Universe_rule,
  /*  620 */  rRegI_rule,
  /*  621 */  Universe_rule,
  /*  622 */  rRegI_rule,
  /*  623 */  Universe_rule,
  /*  624 */  rRegI_rule,
  /*  625 */  Universe_rule,
  /*  626 */  rRegI_rule,
  /*  627 */  Universe_rule,
  /*  628 */  rRegL_rule,
  /*  629 */  Universe_rule,
  /*  630 */  rRegL_rule,
  /*  631 */  Universe_rule,
  /*  632 */  rRegL_rule,
  /*  633 */  Universe_rule,
  /*  634 */  rRegL_rule,
  /*  635 */  Universe_rule,
  /*  636 */  rRegL_rule,
  /*  637 */  Universe_rule,
  /*  638 */  rRegL_rule,
  /*  639 */  Universe_rule,
  /*  640 */  rRegL_rule,
  /*  641 */  Universe_rule,
  /*  642 */  rRegL_rule,
  /*  643 */  Universe_rule,
  /*  644 */  rRegL_rule,
  /*  645 */  Universe_rule,
  /*  646 */  rRegI_rule,
  /*  647 */  rRegI_rule,
  /*  648 */  0,
  /*  649 */  0,
  /*  650 */  0,
  /*  651 */  rRegI_rule,
  /*  652 */  rRegI_rule,
  /*  653 */  rRegI_rule,
  /*  654 */  rRegI_rule,
  /*  655 */  no_rcx_RegI_rule,
  /*  656 */  no_rcx_RegI_rule,
  /*  657 */  no_rcx_RegI_rule,
  /*  658 */  no_rcx_RegI_rule,
  /*  659 */  0,
  /*  660 */  0,
  /*  661 */  0,
  /*  662 */  rRegI_rule,
  /*  663 */  rRegI_rule,
  /*  664 */  rRegI_rule,
  /*  665 */  rRegI_rule,
  /*  666 */  no_rcx_RegI_rule,
  /*  667 */  no_rcx_RegI_rule,
  /*  668 */  no_rcx_RegI_rule,
  /*  669 */  no_rcx_RegI_rule,
  /*  670 */  0,
  /*  671 */  0,
  /*  672 */  0,
  /*  673 */  rRegL_rule,
  /*  674 */  rRegL_rule,
  /*  675 */  rRegL_rule,
  /*  676 */  rRegL_rule,
  /*  677 */  no_rcx_RegL_rule,
  /*  678 */  no_rcx_RegL_rule,
  /*  679 */  no_rcx_RegL_rule,
  /*  680 */  no_rcx_RegL_rule,
  /*  681 */  0,
  /*  682 */  0,
  /*  683 */  0,
  /*  684 */  rRegL_rule,
  /*  685 */  rRegL_rule,
  /*  686 */  rRegL_rule,
  /*  687 */  rRegL_rule,
  /*  688 */  no_rcx_RegL_rule,
  /*  689 */  no_rcx_RegL_rule,
  /*  690 */  no_rcx_RegL_rule,
  /*  691 */  no_rcx_RegL_rule,
  /*  692 */  rRegI_rule,
  /*  693 */  rRegI_rule,
  /*  694 */  rRegL_rule,
  /*  695 */  rRegI_rule,
  /*  696 */  rRegL_rule,
  /*  697 */  rRegI_rule,
  /*  698 */  rRegI_rule,
  /*  699 */  rRegI_rule,
  /*  700 */  Universe_rule,
  /*  701 */  Universe_rule,
  /*  702 */  Universe_rule,
  /*  703 */  rRegI_rule,
  /*  704 */  rRegI_rule,
  /*  705 */  rRegI_rule,
  /*  706 */  rRegI_rule,
  /*  707 */  rRegI_rule,
  /*  708 */  rRegI_rule,
  /*  709 */  rRegI_rule,
  /*  710 */  rRegI_rule,
  /*  711 */  rRegI_rule,
  /*  712 */  rRegI_rule,
  /*  713 */  rRegI_rule,
  /*  714 */  rRegI_rule,
  /*  715 */  rRegI_rule,
  /*  716 */  rRegI_rule,
  /*  717 */  rRegI_rule,
  /*  718 */  rRegI_rule,
  /*  719 */  rRegI_rule,
  /*  720 */  rRegI_rule,
  /*  721 */  rRegI_rule,
  /*  722 */  rRegI_rule,
  /*  723 */  Universe_rule,
  /*  724 */  Universe_rule,
  /*  725 */  Universe_rule,
  /*  726 */  rRegI_rule,
  /*  727 */  rRegI_rule,
  /*  728 */  rRegI_rule,
  /*  729 */  rRegI_rule,
  /*  730 */  rRegI_rule,
  /*  731 */  Universe_rule,
  /*  732 */  Universe_rule,
  /*  733 */  Universe_rule,
  /*  734 */  rRegL_rule,
  /*  735 */  rRegL_rule,
  /*  736 */  rRegL_rule,
  /*  737 */  rRegL_rule,
  /*  738 */  rRegL_rule,
  /*  739 */  rRegL_rule,
  /*  740 */  Universe_rule,
  /*  741 */  Universe_rule,
  /*  742 */  Universe_rule,
  /*  743 */  rRegL_rule,
  /*  744 */  rRegL_rule,
  /*  745 */  rRegL_rule,
  /*  746 */  rRegL_rule,
  /*  747 */  rRegL_rule,
  /*  748 */  rRegL_rule,
  /*  749 */  rRegL_rule,
  /*  750 */  rRegL_rule,
  /*  751 */  rRegL_rule,
  /*  752 */  rRegL_rule,
  /*  753 */  rRegL_rule,
  /*  754 */  rRegL_rule,
  /*  755 */  rRegL_rule,
  /*  756 */  rRegL_rule,
  /*  757 */  rRegL_rule,
  /*  758 */  rRegL_rule,
  /*  759 */  rRegL_rule,
  /*  760 */  rRegL_rule,
  /*  761 */  rRegL_rule,
  /*  762 */  rRegL_rule,
  /*  763 */  rRegL_rule,
  /*  764 */  rRegL_rule,
  /*  765 */  Universe_rule,
  /*  766 */  Universe_rule,
  /*  767 */  Universe_rule,
  /*  768 */  rRegL_rule,
  /*  769 */  rRegL_rule,
  /*  770 */  rRegL_rule,
  /*  771 */  rRegL_rule,
  /*  772 */  rRegL_rule,
  /*  773 */  Universe_rule,
  /*  774 */  Universe_rule,
  /*  775 */  Universe_rule,
  /*  776 */  rRegI_rule,
  /*  777 */  rRegI_rule,
  /*  778 */  rRegI_rule,
  /*  779 */  rRegI_rule,
  /*  780 */  rRegI_rule,
  /*  781 */  rRegI_rule,
  /*  782 */  rRegI_rule,
  /*  783 */  rRegI_rule,
  /*  784 */  rRegI_rule,
  /*  785 */  rRegI_rule,
  /*  786 */  rRegI_rule,
  /*  787 */  rRegI_rule,
  /*  788 */  rRegI_rule,
  /*  789 */  rRegI_rule,
  /*  790 */  rRegI_rule,
  /*  791 */  rRegI_rule,
  /*  792 */  regD_rule,
  /*  793 */  regD_rule,
  /*  794 */  regD_rule,
  /*  795 */  regD_rule,
  /*  796 */  regD_rule,
  /*  797 */  regD_rule,
  /*  798 */  regD_rule,
  /*  799 */  regD_rule,
  /*  800 */  regD_rule,
  /*  801 */  regF_rule,
  /*  802 */  regF_rule,
  /*  803 */  rRegI_rule,
  /*  804 */  rRegL_rule,
  /*  805 */  rRegI_rule,
  /*  806 */  rRegL_rule,
  /*  807 */  regF_rule,
  /*  808 */  regF_rule,
  /*  809 */  regD_rule,
  /*  810 */  regD_rule,
  /*  811 */  regF_rule,
  /*  812 */  regD_rule,
  /*  813 */  regF_rule,
  /*  814 */  regF_rule,
  /*  815 */  regD_rule,
  /*  816 */  regD_rule,
  /*  817 */  rRegL_rule,
  /*  818 */  rRegL_rule,
  /*  819 */  rRegL_rule,
  /*  820 */  rRegL_rule,
  /*  821 */  rRegI_rule,
  /*  822 */  stackSlotI_rule,
  /*  823 */  stackSlotF_rule,
  /*  824 */  stackSlotL_rule,
  /*  825 */  stackSlotD_rule,
  /*  826 */  Universe_rule,
  /*  827 */  Universe_rule,
  /*  828 */  rax_RegI_rule,
  /*  829 */  rbx_RegI_rule,
  /*  830 */  rbx_RegI_rule,
  /*  831 */  rax_RegI_rule,
  /*  832 */  rax_RegI_rule,
  /*  833 */  rax_RegI_rule,
  /*  834 */  rRegI_rule,
  /*  835 */  0,
  /*  836 */  rRegI_rule,
  /*  837 */  0,
  /*  838 */  rRegI_rule,
  /*  839 */  Universe_rule,
  /*  840 */  Universe_rule,
  /*  841 */  Universe_rule,
  /*  842 */  Universe_rule,
  /*  843 */  Universe_rule,
  /*  844 */  Universe_rule,
  /*  845 */  Universe_rule,
  /*  846 */  Universe_rule,
  /*  847 */  rdi_RegP_rule,
  /*  848 */  Universe_rule,
  /*  849 */  Universe_rule,
  /*  850 */  Universe_rule,
  /*  851 */  Universe_rule,
  /*  852 */  Universe_rule,
  /*  853 */  Universe_rule,
  /*  854 */  Universe_rule,
  /*  855 */  Universe_rule,
  /*  856 */  Universe_rule,
  /*  857 */  Universe_rule,
  /*  858 */  Universe_rule,
  /*  859 */  Universe_rule,
  /*  860 */  Universe_rule,
  /*  861 */  Universe_rule,
  /*  862 */  Universe_rule,
  /*  863 */  Universe_rule,
  /*  864 */  Universe_rule,
  /*  865 */  rax_RegP_rule,
  /*  866 */  Universe_rule,
  /*  867 */  Universe_rule,
  /*  868 */  regF_rule,
  /*  869 */  regF_rule,
  /*  870 */  regF_rule,
  /*  871 */  regF_rule,
  /*  872 */  regF_rule,
  /*  873 */  regF_rule,
  /*  874 */  regF_rule,
  /*  875 */  regF_rule,
  /*  876 */  regD_rule,
  /*  877 */  regD_rule,
  /*  878 */  regD_rule,
  /*  879 */  regD_rule,
  /*  880 */  regD_rule,
  /*  881 */  regD_rule,
  /*  882 */  regD_rule,
  /*  883 */  regD_rule,
  /*  884 */  regF_rule,
  /*  885 */  regF_rule,
  /*  886 */  regF_rule,
  /*  887 */  regF_rule,
  /*  888 */  regF_rule,
  /*  889 */  regF_rule,
  /*  890 */  regD_rule,
  /*  891 */  regD_rule,
  /*  892 */  regD_rule,
  /*  893 */  regD_rule,
  /*  894 */  regD_rule,
  /*  895 */  regD_rule,
  /*  896 */  regF_rule,
  /*  897 */  regF_rule,
  /*  898 */  regF_rule,
  /*  899 */  regF_rule,
  /*  900 */  regF_rule,
  /*  901 */  regF_rule,
  /*  902 */  regF_rule,
  /*  903 */  regF_rule,
  /*  904 */  regD_rule,
  /*  905 */  regD_rule,
  /*  906 */  regD_rule,
  /*  907 */  regD_rule,
  /*  908 */  regD_rule,
  /*  909 */  regD_rule,
  /*  910 */  regD_rule,
  /*  911 */  regD_rule,
  /*  912 */  regF_rule,
  /*  913 */  regF_rule,
  /*  914 */  regF_rule,
  /*  915 */  regF_rule,
  /*  916 */  regF_rule,
  /*  917 */  regF_rule,
  /*  918 */  regD_rule,
  /*  919 */  regD_rule,
  /*  920 */  regD_rule,
  /*  921 */  regD_rule,
  /*  922 */  regD_rule,
  /*  923 */  regD_rule,
  /*  924 */  regF_rule,
  /*  925 */  regF_rule,
  /*  926 */  regF_rule,
  /*  927 */  regD_rule,
  /*  928 */  regD_rule,
  /*  929 */  regD_rule,
  /*  930 */  vecS_rule,
  /*  931 */  vecD_rule,
  /*  932 */  vecX_rule,
  /*  933 */  vecY_rule,
  /*  934 */  Universe_rule,
  /*  935 */  Universe_rule,
  /*  936 */  Universe_rule,
  /*  937 */  Universe_rule,
  /*  938 */  vecS_rule,
  /*  939 */  vecD_rule,
  /*  940 */  vecX_rule,
  /*  941 */  vecY_rule,
  /*  942 */  vecS_rule,
  /*  943 */  vecD_rule,
  /*  944 */  vecX_rule,
  /*  945 */  vecY_rule,
  /*  946 */  vecS_rule,
  /*  947 */  vecD_rule,
  /*  948 */  vecX_rule,
  /*  949 */  vecY_rule,
  /*  950 */  vecS_rule,
  /*  951 */  vecD_rule,
  /*  952 */  vecX_rule,
  /*  953 */  vecY_rule,
  /*  954 */  vecS_rule,
  /*  955 */  vecD_rule,
  /*  956 */  vecX_rule,
  /*  957 */  vecY_rule,
  /*  958 */  vecS_rule,
  /*  959 */  vecD_rule,
  /*  960 */  vecX_rule,
  /*  961 */  vecY_rule,
  /*  962 */  vecD_rule,
  /*  963 */  vecX_rule,
  /*  964 */  vecY_rule,
  /*  965 */  vecD_rule,
  /*  966 */  vecX_rule,
  /*  967 */  vecY_rule,
  /*  968 */  vecD_rule,
  /*  969 */  vecX_rule,
  /*  970 */  vecY_rule,
  /*  971 */  vecD_rule,
  /*  972 */  vecX_rule,
  /*  973 */  vecY_rule,
  /*  974 */  vecX_rule,
  /*  975 */  vecY_rule,
  /*  976 */  vecX_rule,
  /*  977 */  vecY_rule,
  /*  978 */  vecX_rule,
  /*  979 */  vecY_rule,
  /*  980 */  vecX_rule,
  /*  981 */  vecY_rule,
  /*  982 */  vecD_rule,
  /*  983 */  vecX_rule,
  /*  984 */  vecY_rule,
  /*  985 */  vecD_rule,
  /*  986 */  vecX_rule,
  /*  987 */  vecY_rule,
  /*  988 */  vecX_rule,
  /*  989 */  vecY_rule,
  /*  990 */  vecX_rule,
  /*  991 */  vecY_rule,
  /*  992 */  vecS_rule,
  /*  993 */  vecS_rule,
  /*  994 */  vecD_rule,
  /*  995 */  vecD_rule,
  /*  996 */  vecX_rule,
  /*  997 */  vecX_rule,
  /*  998 */  vecX_rule,
  /*  999 */  vecY_rule,
  /* 1000 */  vecY_rule,
  /* 1001 */  vecS_rule,
  /* 1002 */  vecS_rule,
  /* 1003 */  vecD_rule,
  /* 1004 */  vecD_rule,
  /* 1005 */  vecX_rule,
  /* 1006 */  vecX_rule,
  /* 1007 */  vecX_rule,
  /* 1008 */  vecY_rule,
  /* 1009 */  vecY_rule,
  /* 1010 */  vecD_rule,
  /* 1011 */  vecD_rule,
  /* 1012 */  vecX_rule,
  /* 1013 */  vecX_rule,
  /* 1014 */  vecX_rule,
  /* 1015 */  vecY_rule,
  /* 1016 */  vecY_rule,
  /* 1017 */  vecX_rule,
  /* 1018 */  vecX_rule,
  /* 1019 */  vecX_rule,
  /* 1020 */  vecY_rule,
  /* 1021 */  vecY_rule,
  /* 1022 */  vecD_rule,
  /* 1023 */  vecD_rule,
  /* 1024 */  vecX_rule,
  /* 1025 */  vecX_rule,
  /* 1026 */  vecX_rule,
  /* 1027 */  vecY_rule,
  /* 1028 */  vecY_rule,
  /* 1029 */  vecX_rule,
  /* 1030 */  vecX_rule,
  /* 1031 */  vecX_rule,
  /* 1032 */  vecY_rule,
  /* 1033 */  vecY_rule,
  /* 1034 */  vecS_rule,
  /* 1035 */  vecS_rule,
  /* 1036 */  vecD_rule,
  /* 1037 */  vecD_rule,
  /* 1038 */  vecX_rule,
  /* 1039 */  vecX_rule,
  /* 1040 */  vecX_rule,
  /* 1041 */  vecY_rule,
  /* 1042 */  vecY_rule,
  /* 1043 */  vecS_rule,
  /* 1044 */  vecS_rule,
  /* 1045 */  vecD_rule,
  /* 1046 */  vecD_rule,
  /* 1047 */  vecX_rule,
  /* 1048 */  vecX_rule,
  /* 1049 */  vecX_rule,
  /* 1050 */  vecY_rule,
  /* 1051 */  vecY_rule,
  /* 1052 */  vecD_rule,
  /* 1053 */  vecD_rule,
  /* 1054 */  vecX_rule,
  /* 1055 */  vecX_rule,
  /* 1056 */  vecX_rule,
  /* 1057 */  vecY_rule,
  /* 1058 */  vecY_rule,
  /* 1059 */  vecX_rule,
  /* 1060 */  vecX_rule,
  /* 1061 */  vecX_rule,
  /* 1062 */  vecY_rule,
  /* 1063 */  vecY_rule,
  /* 1064 */  vecD_rule,
  /* 1065 */  vecD_rule,
  /* 1066 */  vecX_rule,
  /* 1067 */  vecX_rule,
  /* 1068 */  vecX_rule,
  /* 1069 */  vecY_rule,
  /* 1070 */  vecY_rule,
  /* 1071 */  vecX_rule,
  /* 1072 */  vecX_rule,
  /* 1073 */  vecX_rule,
  /* 1074 */  vecY_rule,
  /* 1075 */  vecY_rule,
  /* 1076 */  vecS_rule,
  /* 1077 */  vecS_rule,
  /* 1078 */  vecD_rule,
  /* 1079 */  vecD_rule,
  /* 1080 */  vecX_rule,
  /* 1081 */  vecX_rule,
  /* 1082 */  vecX_rule,
  /* 1083 */  vecY_rule,
  /* 1084 */  vecY_rule,
  /* 1085 */  vecD_rule,
  /* 1086 */  vecD_rule,
  /* 1087 */  vecX_rule,
  /* 1088 */  vecX_rule,
  /* 1089 */  vecX_rule,
  /* 1090 */  vecY_rule,
  /* 1091 */  vecY_rule,
  /* 1092 */  vecD_rule,
  /* 1093 */  vecD_rule,
  /* 1094 */  vecX_rule,
  /* 1095 */  vecX_rule,
  /* 1096 */  vecX_rule,
  /* 1097 */  vecY_rule,
  /* 1098 */  vecY_rule,
  /* 1099 */  vecX_rule,
  /* 1100 */  vecX_rule,
  /* 1101 */  vecX_rule,
  /* 1102 */  vecY_rule,
  /* 1103 */  vecY_rule,
  /* 1104 */  vecD_rule,
  /* 1105 */  vecD_rule,
  /* 1106 */  vecX_rule,
  /* 1107 */  vecX_rule,
  /* 1108 */  vecX_rule,
  /* 1109 */  vecY_rule,
  /* 1110 */  vecY_rule,
  /* 1111 */  vecX_rule,
  /* 1112 */  vecX_rule,
  /* 1113 */  vecX_rule,
  /* 1114 */  vecY_rule,
  /* 1115 */  vecY_rule,
  /* 1116 */  vecS_rule,
  /* 1117 */  vecS_rule,
  /* 1118 */  vecS_rule,
  /* 1119 */  vecS_rule,
  /* 1120 */  vecD_rule,
  /* 1121 */  vecD_rule,
  /* 1122 */  vecD_rule,
  /* 1123 */  vecD_rule,
  /* 1124 */  vecX_rule,
  /* 1125 */  vecX_rule,
  /* 1126 */  vecX_rule,
  /* 1127 */  vecX_rule,
  /* 1128 */  vecY_rule,
  /* 1129 */  vecY_rule,
  /* 1130 */  vecD_rule,
  /* 1131 */  vecD_rule,
  /* 1132 */  vecD_rule,
  /* 1133 */  vecD_rule,
  /* 1134 */  vecX_rule,
  /* 1135 */  vecX_rule,
  /* 1136 */  vecX_rule,
  /* 1137 */  vecX_rule,
  /* 1138 */  vecY_rule,
  /* 1139 */  vecY_rule,
  /* 1140 */  vecX_rule,
  /* 1141 */  vecX_rule,
  /* 1142 */  vecX_rule,
  /* 1143 */  vecX_rule,
  /* 1144 */  vecY_rule,
  /* 1145 */  vecY_rule,
  /* 1146 */  vecS_rule,
  /* 1147 */  vecS_rule,
  /* 1148 */  vecS_rule,
  /* 1149 */  vecS_rule,
  /* 1150 */  vecD_rule,
  /* 1151 */  vecD_rule,
  /* 1152 */  vecD_rule,
  /* 1153 */  vecD_rule,
  /* 1154 */  vecX_rule,
  /* 1155 */  vecX_rule,
  /* 1156 */  vecX_rule,
  /* 1157 */  vecX_rule,
  /* 1158 */  vecY_rule,
  /* 1159 */  vecY_rule,
  /* 1160 */  vecD_rule,
  /* 1161 */  vecD_rule,
  /* 1162 */  vecD_rule,
  /* 1163 */  vecD_rule,
  /* 1164 */  vecX_rule,
  /* 1165 */  vecX_rule,
  /* 1166 */  vecX_rule,
  /* 1167 */  vecX_rule,
  /* 1168 */  vecY_rule,
  /* 1169 */  vecY_rule,
  /* 1170 */  vecX_rule,
  /* 1171 */  vecX_rule,
  /* 1172 */  vecX_rule,
  /* 1173 */  vecX_rule,
  /* 1174 */  vecY_rule,
  /* 1175 */  vecY_rule,
  /* 1176 */  vecS_rule,
  /* 1177 */  vecS_rule,
  /* 1178 */  vecS_rule,
  /* 1179 */  vecS_rule,
  /* 1180 */  vecD_rule,
  /* 1181 */  vecD_rule,
  /* 1182 */  vecD_rule,
  /* 1183 */  vecD_rule,
  /* 1184 */  vecX_rule,
  /* 1185 */  vecX_rule,
  /* 1186 */  vecX_rule,
  /* 1187 */  vecX_rule,
  /* 1188 */  vecY_rule,
  /* 1189 */  vecY_rule,
  /* 1190 */  vecD_rule,
  /* 1191 */  vecD_rule,
  /* 1192 */  vecD_rule,
  /* 1193 */  vecD_rule,
  /* 1194 */  vecX_rule,
  /* 1195 */  vecX_rule,
  /* 1196 */  vecX_rule,
  /* 1197 */  vecX_rule,
  /* 1198 */  vecY_rule,
  /* 1199 */  vecY_rule,
  /* 1200 */  vecS_rule,
  /* 1201 */  vecS_rule,
  /* 1202 */  vecD_rule,
  /* 1203 */  vecD_rule,
  /* 1204 */  vecX_rule,
  /* 1205 */  vecX_rule,
  /* 1206 */  vecX_rule,
  /* 1207 */  vecY_rule,
  /* 1208 */  vecY_rule,
  /* 1209 */  vecS_rule,
  /* 1210 */  vecS_rule,
  /* 1211 */  vecD_rule,
  /* 1212 */  vecD_rule,
  /* 1213 */  vecX_rule,
  /* 1214 */  vecX_rule,
  /* 1215 */  vecX_rule,
  /* 1216 */  vecY_rule,
  /* 1217 */  vecY_rule,
  /* 1218 */  vecS_rule,
  /* 1219 */  vecS_rule,
  /* 1220 */  vecD_rule,
  /* 1221 */  vecD_rule,
  /* 1222 */  vecX_rule,
  /* 1223 */  vecX_rule,
  /* 1224 */  vecX_rule,
  /* 1225 */  vecY_rule,
  /* 1226 */  vecY_rule,
  // last instruction
  0 // no trailing comma
};

const        int   leftOp[] = {
  /*    0 */  0,
  /*    1 */  0,
  /*    2 */  0,
  /*    3 */  0,
  /*    4 */  0,
  /*    5 */  0,
  /*    6 */  0,
  /*    7 */  0,
  /*    8 */  0,
  /*    9 */  0,
  /*   10 */  0,
  /*   11 */  0,
  /*   12 */  0,
  /*   13 */  0,
  /*   14 */  0,
  /*   15 */  0,
  /*   16 */  0,
  /*   17 */  0,
  /*   18 */  0,
  /*   19 */  0,
  /*   20 */  0,
  /*   21 */  0,
  /*   22 */  0,
  /*   23 */  0,
  /*   24 */  0,
  /*   25 */  0,
  /*   26 */  0,
  /*   27 */  0,
  /*   28 */  0,
  /*   29 */  0,
  /*   30 */  0,
  /*   31 */  0,
  /*   32 */  0,
  /*   33 */  0,
  /*   34 */  0,
  /*   35 */  0,
  /*   36 */  0,
  /*   37 */  0,
  /*   38 */  0,
  /*   39 */  0,
  /*   40 */  0,
  /*   41 */  0,
  /*   42 */  0,
  /*   43 */  0,
  /*   44 */  0,
  /*   45 */  0,
  /*   46 */  0,
  /*   47 */  0,
  /*   48 */  0,
  /*   49 */  0,
  /*   50 */  0,
  /*   51 */  0,
  /*   52 */  0,
  /*   53 */  0,
  /*   54 */  0,
  /*   55 */  0,
  /*   56 */  0,
  /*   57 */  0,
  /*   58 */  0,
  /*   59 */  0,
  /*   60 */  0,
  /*   61 */  0,
  /*   62 */  0,
  /*   63 */  0,
  /*   64 */  0,
  /*   65 */  0,
  /*   66 */  0,
  /*   67 */  0,
  /*   68 */  0,
  /*   69 */  0,
  /*   70 */  0,
  /*   71 */  0,
  /*   72 */  0,
  /*   73 */  0,
  /*   74 */  0,
  /*   75 */  0,
  /*   76 */  0,
  /*   77 */  any_RegP_rule,
  /*   78 */  any_RegP_rule,
  /*   79 */  _AddP_any_RegP_rRegL_rule,
  /*   80 */  any_RegP_rule,
  /*   81 */  any_RegP_rule,
  /*   82 */  _AddP_any_RegP__LShiftL_rRegL_immI2_rule,
  /*   83 */  _AddP_any_RegP__LShiftL__ConvI2L_rRegI__immI2_rule,
  /*   84 */  _DecodeN_rRegN__rule,
  /*   85 */  rRegN_rule,
  /*   86 */  _DecodeN_rRegN__rule,
  /*   87 */  _DecodeN_rRegN__rule,
  /*   88 */  _AddP__DecodeN_rRegN__rRegL_rule,
  /*   89 */  _DecodeN_rRegN__rule,
  /*   90 */  _DecodeN_rRegN__rule,
  /*   91 */  _AddP__DecodeN_rRegN___LShiftL_rRegL_immI2_rule,
  /*   92 */  _AddP__DecodeN_rRegN___LShiftL__ConvI2L_rRegI__immI2_rule,
  /*   93 */  0,
  /*   94 */  0,
  /*   95 */  0,
  /*   96 */  0,
  /*   97 */  0,
  /*   98 */  0,
  /*   99 */  0,
  /*  100 */  0,
  /*  101 */  0,
  /*  102 */  0,
  /*  103 */  0,
  /*  104 */  0,
  /*  105 */  0,
  // last operand
  /*  106 */  0,
  // last operand class
  /*  107 */  any_RegP_rule,
  /*  108 */  rRegL_rule,
  /*  109 */  any_RegP_rule,
  /*  110 */  rRegI_rule,
  /*  111 */  _ConvI2L_rRegI__rule,
  /*  112 */  any_RegP_rule,
  /*  113 */  rRegN_rule,
  /*  114 */  _DecodeN_rRegN__rule,
  /*  115 */  _DecodeN_rRegN__rule,
  /*  116 */  _DecodeN_rRegN__rule,
  /*  117 */  memory_rule,
  /*  118 */  memory_rule,
  /*  119 */  _LoadUB_memory__rule,
  /*  120 */  memory_rule,
  /*  121 */  _LoadS_memory__rule,
  /*  122 */  memory_rule,
  /*  123 */  _LoadUS_memory__rule,
  /*  124 */  _LoadUS_memory__rule,
  /*  125 */  _LoadUS_memory__rule,
  /*  126 */  memory_rule,
  /*  127 */  _LoadI_memory__rule,
  /*  128 */  _LoadI_memory__rule,
  /*  129 */  _LoadI_memory__rule,
  /*  130 */  _LoadI_memory__rule,
  /*  131 */  _LoadI_memory__rule,
  /*  132 */  _LoadI_memory__rule,
  /*  133 */  memory_rule,
  /*  134 */  rRegP_rule,
  /*  135 */  _DecodeN_rRegN__rule,
  /*  136 */  _LShiftL_rRegL_immI2_rule,
  /*  137 */  cmpOp_rule,
  /*  138 */  rRegI_rule,
  /*  139 */  cmpOpU_rule,
  /*  140 */  cmpOpUCF_rule,
  /*  141 */  rRegI_rule,
  /*  142 */  rRegN_rule,
  /*  143 */  rRegP_rule,
  /*  144 */  rRegL_rule,
  /*  145 */  rRegL_rule,
  /*  146 */  regF_rule,
  /*  147 */  regD_rule,
  /*  148 */  _LoadI_memory__rule,
  /*  149 */  rRegI_rule,
  /*  150 */  _LoadI_memory__rule,
  /*  151 */  _LoadI_memory__rule,
  /*  152 */  _LoadI_memory__rule,
  /*  153 */  _LoadL_memory__rule,
  /*  154 */  rRegL_rule,
  /*  155 */  _LoadL_memory__rule,
  /*  156 */  _LoadL_memory__rule,
  /*  157 */  _LoadL_memory__rule,
  /*  158 */  rax_RegP_rule,
  /*  159 */  rax_RegI_rule,
  /*  160 */  rax_RegL_rule,
  /*  161 */  rax_RegN_rule,
  /*  162 */  _LoadI_memory__rule,
  /*  163 */  _LoadI_memory__rule,
  /*  164 */  _LoadL_memory__rule,
  /*  165 */  _LoadL_memory__rule,
  /*  166 */  immI0_rule,
  /*  167 */  immI0_rule,
  /*  168 */  immL0_rule,
  /*  169 */  _LoadI_memory__rule,
  /*  170 */  _LoadI_memory__rule,
  /*  171 */  _LoadI_memory__rule,
  /*  172 */  _LoadI_memory__rule,
  /*  173 */  _LoadI_memory__rule,
  /*  174 */  _LoadI_memory__rule,
  /*  175 */  _LoadI_memory__rule,
  /*  176 */  _LoadI_memory__rule,
  /*  177 */  _LoadI_memory__rule,
  /*  178 */  _LoadL_memory__rule,
  /*  179 */  _LoadL_memory__rule,
  /*  180 */  _LoadL_memory__rule,
  /*  181 */  _LoadL_memory__rule,
  /*  182 */  _LoadL_memory__rule,
  /*  183 */  _LoadL_memory__rule,
  /*  184 */  _LoadL_memory__rule,
  /*  185 */  _LoadL_memory__rule,
  /*  186 */  _LoadL_memory__rule,
  /*  187 */  rRegI_rule,
  /*  188 */  rRegI_rule,
  /*  189 */  rRegI_rule,
  /*  190 */  rRegI_rule,
  /*  191 */  rRegI_rule,
  /*  192 */  rRegI_rule,
  /*  193 */  no_rcx_RegI_rule,
  /*  194 */  immI0_rule,
  /*  195 */  no_rcx_RegI_rule,
  /*  196 */  immI_32_rule,
  /*  197 */  no_rcx_RegI_rule,
  /*  198 */  rRegI_rule,
  /*  199 */  rRegI_rule,
  /*  200 */  no_rcx_RegI_rule,
  /*  201 */  no_rcx_RegI_rule,
  /*  202 */  no_rcx_RegI_rule,
  /*  203 */  rRegL_rule,
  /*  204 */  rRegL_rule,
  /*  205 */  rRegL_rule,
  /*  206 */  rRegL_rule,
  /*  207 */  no_rcx_RegL_rule,
  /*  208 */  no_rcx_RegL_rule,
  /*  209 */  immI_64_rule,
  /*  210 */  no_rcx_RegL_rule,
  /*  211 */  rRegL_rule,
  /*  212 */  rRegL_rule,
  /*  213 */  no_rcx_RegL_rule,
  /*  214 */  no_rcx_RegL_rule,
  /*  215 */  no_rcx_RegL_rule,
  /*  216 */  rRegI_rule,
  /*  217 */  rRegI_rule,
  /*  218 */  _LoadI_memory__rule,
  /*  219 */  rRegI_rule,
  /*  220 */  _LoadI_memory__rule,
  /*  221 */  rRegI_rule,
  /*  222 */  rRegI_rule,
  /*  223 */  _LoadI_memory__rule,
  /*  224 */  rRegI_rule,
  /*  225 */  _LoadI_memory__rule,
  /*  226 */  _LoadI_memory__rule,
  /*  227 */  rRegI_rule,
  /*  228 */  _LoadI_memory__rule,
  /*  229 */  _LoadL_memory__rule,
  /*  230 */  rRegL_rule,
  /*  231 */  _LoadL_memory__rule,
  /*  232 */  rRegL_rule,
  /*  233 */  immL0_rule,
  /*  234 */  rRegL_rule,
  /*  235 */  any_RegP_rule,
  /*  236 */  _LoadL_memory__rule,
  /*  237 */  rRegL_rule,
  /*  238 */  _LoadL_memory__rule,
  /*  239 */  _LoadL_memory__rule,
  /*  240 */  rRegL_rule,
  /*  241 */  _LoadL_memory__rule,
  /*  242 */  rRegI_rule,
  /*  243 */  _CmpLTMask_rRegI_rRegI_rule,
  /*  244 */  rRegI_rule,
  /*  245 */  rRegI_rule,
  /*  246 */  memory_rule,
  /*  247 */  memory_rule,
  /*  248 */  rdi_RegP_rule,
  /*  249 */  rsi_RegP_rule,
  /*  250 */  rdi_RegP_rule,
  /*  251 */  rsi_RegP_rule,
  /*  252 */  rsi_RegP_rule,
  /*  253 */  rdi_RegP_rule,
  /*  254 */  rRegI_rule,
  /*  255 */  memory_rule,
  /*  256 */  memory_rule,
  /*  257 */  memory_rule,
  /*  258 */  rRegL_rule,
  /*  259 */  rsi_RegP_rule,
  /*  260 */  regF_rule,
  /*  261 */  _ConvF2D_regF__rule,
  /*  262 */  _LoadF_memory__rule,
  /*  263 */  _ConvF2D__LoadF_memory___rule,
  /*  264 */  immF_rule,
  /*  265 */  _ConvF2D_immF__rule,
  /*  266 */  memory_rule,
  // last internally defined operand
  /*  267 */  rRegI_rule,
  /*  268 */  rRegL_rule,
  /*  269 */  rRegP_rule,
  /*  270 */  regF_rule,
  /*  271 */  regD_rule,
  /*  272 */  indOffset8_rule,
  /*  273 */  indOffset32_rule,
  /*  274 */  indIndexOffset_rule,
  /*  275 */  indIndexScale_rule,
  /*  276 */  indIndexScaleOffset_rule,
  /*  277 */  indPosIndexScaleOffset_rule,
  /*  278 */  indCompressedOopOffset_rule,
  /*  279 */  indOffset8Narrow_rule,
  /*  280 */  indOffset32Narrow_rule,
  /*  281 */  indIndexOffsetNarrow_rule,
  /*  282 */  indIndexScaleNarrow_rule,
  /*  283 */  indIndexScaleOffsetNarrow_rule,
  /*  284 */  indPosIndexScaleOffsetNarrow_rule,
  /*  285 */  immI_rule,
  /*  286 */  immI0_rule,
  /*  287 */  immL_rule,
  /*  288 */  immL0_rule,
  /*  289 */  immUL32_rule,
  /*  290 */  immL32_rule,
  /*  291 */  immP_rule,
  /*  292 */  immP0_rule,
  /*  293 */  immP31_rule,
  /*  294 */  immF_rule,
  /*  295 */  immN0_rule,
  /*  296 */  immN_rule,
  /*  297 */  immNKlass_rule,
  /*  298 */  immF0_rule,
  /*  299 */  immD_rule,
  /*  300 */  immD0_rule,
  /*  301 */  stackSlotI_rule,
  /*  302 */  stackSlotL_rule,
  /*  303 */  stackSlotP_rule,
  /*  304 */  stackSlotF_rule,
  /*  305 */  stackSlotD_rule,
  /*  306 */  0,
  /*  307 */  rRegL_rule,
  /*  308 */  rRegP_rule,
  /*  309 */  rRegP_rule,
  /*  310 */  rRegP_rule,
  /*  311 */  rRegI_rule,
  /*  312 */  memory_rule,
  /*  313 */  memory_rule,
  /*  314 */  memory_rule,
  /*  315 */  regF_rule,
  /*  316 */  regF_rule,
  /*  317 */  regF_rule,
  /*  318 */  regF_rule,
  /*  319 */  regF_rule,
  /*  320 */  regF_rule,
  /*  321 */  regD_rule,
  /*  322 */  regD_rule,
  /*  323 */  regD_rule,
  /*  324 */  regD_rule,
  /*  325 */  regD_rule,
  /*  326 */  regD_rule,
  /*  327 */  regF_rule,
  /*  328 */  regD_rule,
  /*  329 */  stackSlotF_rule,
  /*  330 */  stackSlotI_rule,
  /*  331 */  stackSlotD_rule,
  /*  332 */  stackSlotL_rule,
  /*  333 */  stackSlotL_rule,
  /*  334 */  regF_rule,
  /*  335 */  regD_rule,
  /*  336 */  rRegI_rule,
  /*  337 */  rRegL_rule,
  /*  338 */  rax_RegI_rule,
  /*  339 */  rax_RegI_rule,
  /*  340 */  rax_RegL_rule,
  /*  341 */  rax_RegL_rule,
  /*  342 */  rRegI_rule,
  /*  343 */  rRegI_rule,
  /*  344 */  rRegL_rule,
  /*  345 */  rRegL_rule,
  /*  346 */  immI0_rule,
  /*  347 */  immL0_rule,
  /*  348 */  rax_RegI_rule,
  /*  349 */  rRegI_rule,
  /*  350 */  rax_RegL_rule,
  /*  351 */  rRegL_rule,
  /*  352 */  rRegI_rule,
  /*  353 */  rRegI_rule,
  /*  354 */  rRegI_rule,
  /*  355 */  rRegI_rule,
  /*  356 */  _AndI_rRegI_immI_rule,
  /*  357 */  _AndI_rRegI__LoadI_memory__rule,
  /*  358 */  _AndI__LoadI_memory__rRegI_rule,
  /*  359 */  rRegI_rule,
  /*  360 */  rRegI_rule,
  /*  361 */  rRegI_rule,
  /*  362 */  rRegI_rule,
  /*  363 */  rRegP_rule,
  /*  364 */  rRegP_rule,
  /*  365 */  rRegP_rule,
  /*  366 */  rRegP_rule,
  /*  367 */  _LoadP_memory__rule,
  /*  368 */  _LoadP_memory__rule,
  /*  369 */  rRegN_rule,
  /*  370 */  rRegN_rule,
  /*  371 */  rRegN_rule,
  /*  372 */  immN_rule,
  /*  373 */  rRegN_rule,
  /*  374 */  immNKlass_rule,
  /*  375 */  rRegN_rule,
  /*  376 */  _LoadN_memory__rule,
  /*  377 */  _LoadN_memory__rule,
  /*  378 */  rRegL_rule,
  /*  379 */  rRegL_rule,
  /*  380 */  rRegL_rule,
  /*  381 */  rRegL_rule,
  /*  382 */  _AndL_rRegL_immL32_rule,
  /*  383 */  _AndL_rRegL__LoadL_memory__rule,
  /*  384 */  _AndL__LoadL_memory__rRegL_rule,
  /*  385 */  rRegL_rule,
  /*  386 */  rRegL_rule,
  /*  387 */  rRegL_rule,
  /*  388 */  rRegL_rule,
  /*  389 */  _PartialSubtypeCheck_rsi_RegP_rax_RegP_rule,
  /*  390 */  rRegP_rule,
  /*  391 */  rRegP_rule,
  /*  392 */  rRegP_rule,
  /*  393 */  0,
  /*  394 */  0,
  /*  395 */  regF_rule,
  /*  396 */  regF_rule,
  /*  397 */  regD_rule,
  /*  398 */  regD_rule,
  /*  399 */  regF_rule,
  /*  400 */  regF_rule,
  /*  401 */  regD_rule,
  /*  402 */  regD_rule,
  /*  403 */  rRegI_rule,
  /*  404 */  rRegI_rule,
  /*  405 */  memory_rule,
  /*  406 */  _LoadB_memory__rule,
  /*  407 */  memory_rule,
  /*  408 */  _LoadUB_memory__rule,
  /*  409 */  _AndI__LoadUB_memory__immI8_rule,
  /*  410 */  memory_rule,
  /*  411 */  _LShiftI__LoadS_memory__immI_24_rule,
  /*  412 */  _LoadS_memory__rule,
  /*  413 */  memory_rule,
  /*  414 */  _LShiftI__LoadUS_memory__immI_24_rule,
  /*  415 */  _LoadUS_memory__rule,
  /*  416 */  _AndI__LoadUS_memory__immI_255_rule,
  /*  417 */  _AndI__LoadUS_memory__immI16_rule,
  /*  418 */  memory_rule,
  /*  419 */  _LShiftI__LoadI_memory__immI_24_rule,
  /*  420 */  _LoadI_memory__rule,
  /*  421 */  _LShiftI__LoadI_memory__immI_16_rule,
  /*  422 */  _LoadI_memory__rule,
  /*  423 */  _LoadI_memory__rule,
  /*  424 */  _AndI__LoadI_memory__immI_255_rule,
  /*  425 */  _AndI__LoadI_memory__immI_65535_rule,
  /*  426 */  _AndI__LoadI_memory__immU31_rule,
  /*  427 */  _ConvI2L__LoadI_memory___rule,
  /*  428 */  memory_rule,
  /*  429 */  memory_rule,
  /*  430 */  memory_rule,
  /*  431 */  memory_rule,
  /*  432 */  memory_rule,
  /*  433 */  memory_rule,
  /*  434 */  memory_rule,
  /*  435 */  memory_rule,
  /*  436 */  memory_rule,
  /*  437 */  memory_rule,
  /*  438 */  memory_rule,
  /*  439 */  memory_rule,
  /*  440 */  memory_rule,
  /*  441 */  memory_rule,
  /*  442 */  memory_rule,
  /*  443 */  memory_rule,
  /*  444 */  memory_rule,
  /*  445 */  memory_rule,
  /*  446 */  memory_rule,
  /*  447 */  memory_rule,
  /*  448 */  memory_rule,
  /*  449 */  memory_rule,
  /*  450 */  memory_rule,
  /*  451 */  memory_rule,
  /*  452 */  memory_rule,
  /*  453 */  memory_rule,
  /*  454 */  memory_rule,
  /*  455 */  memory_rule,
  /*  456 */  memory_rule,
  /*  457 */  memory_rule,
  /*  458 */  memory_rule,
  /*  459 */  memory_rule,
  /*  460 */  memory_rule,
  /*  461 */  memory_rule,
  /*  462 */  memory_rule,
  /*  463 */  memory_rule,
  /*  464 */  memory_rule,
  /*  465 */  memory_rule,
  /*  466 */  memory_rule,
  /*  467 */  memory_rule,
  /*  468 */  memory_rule,
  /*  469 */  memory_rule,
  /*  470 */  memory_rule,
  /*  471 */  memory_rule,
  /*  472 */  memory_rule,
  /*  473 */  memory_rule,
  /*  474 */  rRegI_rule,
  /*  475 */  rRegL_rule,
  /*  476 */  rRegI_rule,
  /*  477 */  rRegI_rule,
  /*  478 */  rRegI_rule,
  /*  479 */  rRegI_rule,
  /*  480 */  rRegL_rule,
  /*  481 */  rRegL_rule,
  /*  482 */  rRegI_rule,
  /*  483 */  rRegI_rule,
  /*  484 */  rRegL_rule,
  /*  485 */  rRegL_rule,
  /*  486 */  rRegI_rule,
  /*  487 */  _LoadI_memory__rule,
  /*  488 */  rRegL_rule,
  /*  489 */  _LoadL_memory__rule,
  /*  490 */  0,
  /*  491 */  0,
  /*  492 */  0,
  /*  493 */  0,
  /*  494 */  0,
  /*  495 */  0,
  /*  496 */  0,
  /*  497 */  0,
  /*  498 */  _CastP2X_rRegP__rule,
  /*  499 */  _CastP2X__DecodeN_rRegN___rule,
  /*  500 */  rRegP_rule,
  /*  501 */  rRegP_rule,
  /*  502 */  rRegN_rule,
  /*  503 */  rRegN_rule,
  /*  504 */  rRegP_rule,
  /*  505 */  rRegN_rule,
  /*  506 */  _LShiftL_rRegL_immI2_rule,
  /*  507 */  _AddL__LShiftL_rRegL_immI2_immL32_rule,
  /*  508 */  rRegL_rule,
  /*  509 */  _Binary_cmpOp_rFlagsReg_rule,
  /*  510 */  _Binary_cmpOpU_rFlagsRegU_rule,
  /*  511 */  _Binary_cmpOpUCF_rFlagsRegUCF_rule,
  /*  512 */  _Binary_cmpOp_rFlagsReg_rule,
  /*  513 */  _Binary_cmpOpU_rFlagsRegU_rule,
  /*  514 */  _Binary_cmpOpUCF_rFlagsRegUCF_rule,
  /*  515 */  _Binary_cmpOp_rFlagsReg_rule,
  /*  516 */  _Binary_cmpOpU_rFlagsRegU_rule,
  /*  517 */  _Binary_cmpOpUCF_rFlagsRegUCF_rule,
  /*  518 */  _Binary_cmpOp_rFlagsReg_rule,
  /*  519 */  _Binary_cmpOpU_rFlagsRegU_rule,
  /*  520 */  _Binary_cmpOpUCF_rFlagsRegUCF_rule,
  /*  521 */  _Binary_cmpOp_rFlagsReg_rule,
  /*  522 */  _Binary_cmpOp_rFlagsReg_rule,
  /*  523 */  _Binary_cmpOpU_rFlagsRegU_rule,
  /*  524 */  _Binary_cmpOpUCF_rFlagsRegUCF_rule,
  /*  525 */  _Binary_cmpOpU_rFlagsRegU_rule,
  /*  526 */  _Binary_cmpOpUCF_rFlagsRegUCF_rule,
  /*  527 */  _Binary_cmpOp_rFlagsReg_rule,
  /*  528 */  _Binary_cmpOpU_rFlagsRegU_rule,
  /*  529 */  _Binary_cmpOpUCF_rFlagsRegUCF_rule,
  /*  530 */  _Binary_cmpOp_rFlagsReg_rule,
  /*  531 */  _Binary_cmpOpU_rFlagsRegU_rule,
  /*  532 */  _Binary_cmpOpUCF_rFlagsRegUCF_rule,
  /*  533 */  rRegI_rule,
  /*  534 */  rRegI_rule,
  /*  535 */  rRegI_rule,
  /*  536 */  _LoadI_memory__rule,
  /*  537 */  memory_rule,
  /*  538 */  memory_rule,
  /*  539 */  memory_rule,
  /*  540 */  rRegI_rule,
  /*  541 */  memory_rule,
  /*  542 */  rRegI_rule,
  /*  543 */  memory_rule,
  /*  544 */  rRegI_rule,
  /*  545 */  rRegL_rule,
  /*  546 */  rRegL_rule,
  /*  547 */  rRegL_rule,
  /*  548 */  _LoadL_memory__rule,
  /*  549 */  memory_rule,
  /*  550 */  memory_rule,
  /*  551 */  memory_rule,
  /*  552 */  rRegI_rule,
  /*  553 */  memory_rule,
  /*  554 */  rRegL_rule,
  /*  555 */  memory_rule,
  /*  556 */  rRegL_rule,
  /*  557 */  rRegP_rule,
  /*  558 */  rRegP_rule,
  /*  559 */  rRegP_rule,
  /*  560 */  memory_rule,
  /*  561 */  memory_rule,
  /*  562 */  memory_rule,
  /*  563 */  memory_rule,
  /*  564 */  memory_rule,
  /*  565 */  memory_rule,
  /*  566 */  memory_rule,
  /*  567 */  memory_rule,
  /*  568 */  memory_rule,
  /*  569 */  memory_rule,
  /*  570 */  memory_rule,
  /*  571 */  memory_rule,
  /*  572 */  memory_rule,
  /*  573 */  rRegI_rule,
  /*  574 */  rRegI_rule,
  /*  575 */  rRegI_rule,
  /*  576 */  memory_rule,
  /*  577 */  memory_rule,
  /*  578 */  rRegL_rule,
  /*  579 */  rRegI_rule,
  /*  580 */  rRegL_rule,
  /*  581 */  memory_rule,
  /*  582 */  memory_rule,
  /*  583 */  rRegP_rule,
  /*  584 */  immI0_rule,
  /*  585 */  memory_rule,
  /*  586 */  immL0_rule,
  /*  587 */  memory_rule,
  /*  588 */  rRegI_rule,
  /*  589 */  rRegI_rule,
  /*  590 */  rRegI_rule,
  /*  591 */  _LoadI_memory__rule,
  /*  592 */  _LoadI_memory__rule,
  /*  593 */  rRegL_rule,
  /*  594 */  rRegL_rule,
  /*  595 */  rRegL_rule,
  /*  596 */  _LoadL_memory__rule,
  /*  597 */  _LoadL_memory__rule,
  /*  598 */  no_rax_RegL_rule,
  /*  599 */  rax_RegI_rule,
  /*  600 */  rax_RegL_rule,
  /*  601 */  rax_RegI_rule,
  /*  602 */  rax_RegL_rule,
  /*  603 */  0,
  /*  604 */  0,
  /*  605 */  0,
  /*  606 */  0,
  /*  607 */  no_rax_RegL_rule,
  /*  608 */  rax_RegI_rule,
  /*  609 */  rax_RegL_rule,
  /*  610 */  rRegI_rule,
  /*  611 */  memory_rule,
  /*  612 */  rRegI_rule,
  /*  613 */  memory_rule,
  /*  614 */  rRegI_rule,
  /*  615 */  memory_rule,
  /*  616 */  rRegI_rule,
  /*  617 */  memory_rule,
  /*  618 */  rRegI_rule,
  /*  619 */  memory_rule,
  /*  620 */  rRegI_rule,
  /*  621 */  memory_rule,
  /*  622 */  rRegI_rule,
  /*  623 */  memory_rule,
  /*  624 */  rRegI_rule,
  /*  625 */  memory_rule,
  /*  626 */  rRegI_rule,
  /*  627 */  memory_rule,
  /*  628 */  rRegL_rule,
  /*  629 */  memory_rule,
  /*  630 */  rRegL_rule,
  /*  631 */  memory_rule,
  /*  632 */  rRegL_rule,
  /*  633 */  memory_rule,
  /*  634 */  rRegL_rule,
  /*  635 */  memory_rule,
  /*  636 */  rRegL_rule,
  /*  637 */  memory_rule,
  /*  638 */  rRegL_rule,
  /*  639 */  memory_rule,
  /*  640 */  rRegL_rule,
  /*  641 */  memory_rule,
  /*  642 */  rRegL_rule,
  /*  643 */  memory_rule,
  /*  644 */  rRegL_rule,
  /*  645 */  memory_rule,
  /*  646 */  _LShiftI_rRegI_immI_24_rule,
  /*  647 */  _LShiftI_rRegI_immI_16_rule,
  /*  648 */  0,
  /*  649 */  0,
  /*  650 */  0,
  /*  651 */  _LShiftI_rRegI_immI1_rule,
  /*  652 */  _URShiftI_rRegI_immI_M1_rule,
  /*  653 */  _LShiftI_rRegI_immI8_rule,
  /*  654 */  _URShiftI_rRegI_immI8_rule,
  /*  655 */  _LShiftI_no_rcx_RegI_rcx_RegI_rule,
  /*  656 */  _URShiftI_no_rcx_RegI__SubI_immI0_rcx_RegI_rule,
  /*  657 */  _LShiftI_no_rcx_RegI_rcx_RegI_rule,
  /*  658 */  _URShiftI_no_rcx_RegI__SubI_immI_32_rcx_RegI_rule,
  /*  659 */  0,
  /*  660 */  0,
  /*  661 */  0,
  /*  662 */  _URShiftI_rRegI_immI1_rule,
  /*  663 */  _LShiftI_rRegI_immI_M1_rule,
  /*  664 */  _URShiftI_rRegI_immI8_rule,
  /*  665 */  _LShiftI_rRegI_immI8_rule,
  /*  666 */  _URShiftI_no_rcx_RegI_rcx_RegI_rule,
  /*  667 */  _LShiftI_no_rcx_RegI__SubI_immI0_rcx_RegI_rule,
  /*  668 */  _URShiftI_no_rcx_RegI_rcx_RegI_rule,
  /*  669 */  _LShiftI_no_rcx_RegI__SubI_immI_32_rcx_RegI_rule,
  /*  670 */  0,
  /*  671 */  0,
  /*  672 */  0,
  /*  673 */  _LShiftL_rRegL_immI1_rule,
  /*  674 */  _URShiftL_rRegL_immI_M1_rule,
  /*  675 */  _LShiftL_rRegL_immI8_rule,
  /*  676 */  _URShiftL_rRegL_immI8_rule,
  /*  677 */  _LShiftL_no_rcx_RegL_rcx_RegI_rule,
  /*  678 */  _URShiftL_no_rcx_RegL__SubI_immI0_rcx_RegI_rule,
  /*  679 */  _LShiftL_no_rcx_RegL_rcx_RegI_rule,
  /*  680 */  _URShiftL_no_rcx_RegL__SubI_immI_64_rcx_RegI_rule,
  /*  681 */  0,
  /*  682 */  0,
  /*  683 */  0,
  /*  684 */  _URShiftL_rRegL_immI1_rule,
  /*  685 */  _LShiftL_rRegL_immI_M1_rule,
  /*  686 */  _URShiftL_rRegL_immI8_rule,
  /*  687 */  _LShiftL_rRegL_immI8_rule,
  /*  688 */  _URShiftL_no_rcx_RegL_rcx_RegI_rule,
  /*  689 */  _LShiftL_no_rcx_RegL__SubI_immI0_rcx_RegI_rule,
  /*  690 */  _URShiftL_no_rcx_RegL_rcx_RegI_rule,
  /*  691 */  _LShiftL_no_rcx_RegL__SubI_immI_64_rcx_RegI_rule,
  /*  692 */  rRegI_rule,
  /*  693 */  rRegI_rule,
  /*  694 */  _AndI_rRegI_immI_255_rule,
  /*  695 */  rRegI_rule,
  /*  696 */  _AndI_rRegI_immI_65535_rule,
  /*  697 */  rRegI_rule,
  /*  698 */  rRegI_rule,
  /*  699 */  _LoadI_memory__rule,
  /*  700 */  memory_rule,
  /*  701 */  memory_rule,
  /*  702 */  memory_rule,
  /*  703 */  _XorI_rRegI_immI_M1_rule,
  /*  704 */  _LoadI_memory__rule,
  /*  705 */  _XorI_rRegI_immI_M1_rule,
  /*  706 */  rRegI_rule,
  /*  707 */  _SubI_immI0_rRegI_rule,
  /*  708 */  rRegI_rule,
  /*  709 */  _SubI_immI0__LoadI_memory__rule,
  /*  710 */  _LoadI_memory__rule,
  /*  711 */  _AddI__LoadI_memory__immI_M1_rule,
  /*  712 */  _LoadI_memory__rule,
  /*  713 */  _AddI_rRegI_immI_M1_rule,
  /*  714 */  rRegI_rule,
  /*  715 */  _AddI_rRegI_immI_M1_rule,
  /*  716 */  rRegI_rule,
  /*  717 */  _AddI__LoadI_memory__immI_M1_rule,
  /*  718 */  _LoadI_memory__rule,
  /*  719 */  rRegI_rule,
  /*  720 */  rRegI_rule,
  /*  721 */  rRegI_rule,
  /*  722 */  _LoadI_memory__rule,
  /*  723 */  memory_rule,
  /*  724 */  memory_rule,
  /*  725 */  memory_rule,
  /*  726 */  rRegI_rule,
  /*  727 */  rRegI_rule,
  /*  728 */  rRegI_rule,
  /*  729 */  rRegI_rule,
  /*  730 */  _LoadI_memory__rule,
  /*  731 */  memory_rule,
  /*  732 */  memory_rule,
  /*  733 */  memory_rule,
  /*  734 */  rRegL_rule,
  /*  735 */  rRegL_rule,
  /*  736 */  rRegL_rule,
  /*  737 */  rRegL_rule,
  /*  738 */  rRegL_rule,
  /*  739 */  _LoadL_memory__rule,
  /*  740 */  memory_rule,
  /*  741 */  memory_rule,
  /*  742 */  memory_rule,
  /*  743 */  _XorL_rRegL_immL_M1_rule,
  /*  744 */  _LoadL_memory__rule,
  /*  745 */  _XorL_rRegL_immL_M1_rule,
  /*  746 */  rRegL_rule,
  /*  747 */  _SubL_immL0_rRegL_rule,
  /*  748 */  rRegL_rule,
  /*  749 */  _SubL_immL0__LoadL_memory__rule,
  /*  750 */  _LoadL_memory__rule,
  /*  751 */  _AddL__LoadL_memory__immL_M1_rule,
  /*  752 */  _LoadL_memory__rule,
  /*  753 */  _AddL_rRegL_immL_M1_rule,
  /*  754 */  rRegL_rule,
  /*  755 */  _AddL_rRegL_immL_M1_rule,
  /*  756 */  rRegL_rule,
  /*  757 */  _AddL__LoadL_memory__immL_M1_rule,
  /*  758 */  _LoadL_memory__rule,
  /*  759 */  rRegL_rule,
  /*  760 */  rRegL_rule,
  /*  761 */  _CastP2X_any_RegP__rule,
  /*  762 */  rRegL_rule,
  /*  763 */  rRegL_rule,
  /*  764 */  _LoadL_memory__rule,
  /*  765 */  memory_rule,
  /*  766 */  memory_rule,
  /*  767 */  memory_rule,
  /*  768 */  rRegL_rule,
  /*  769 */  rRegL_rule,
  /*  770 */  rRegL_rule,
  /*  771 */  rRegL_rule,
  /*  772 */  _LoadL_memory__rule,
  /*  773 */  memory_rule,
  /*  774 */  memory_rule,
  /*  775 */  memory_rule,
  /*  776 */  rRegI_rule,
  /*  777 */  rRegP_rule,
  /*  778 */  rRegI_rule,
  /*  779 */  rRegI_rule,
  /*  780 */  _AndI__CmpLTMask_rRegI_rRegI_rRegI_rule,
  /*  781 */  _SubI_rRegI_rRegI_rule,
  /*  782 */  _AndI_rRegI__CmpLTMask_rRegI_rRegI_rule,
  /*  783 */  _SubI_rRegI_rRegI_rule,
  /*  784 */  _CmpLTMask_rRegI_rRegI_rule,
  /*  785 */  rRegI_rule,
  /*  786 */  regF_rule,
  /*  787 */  regF_rule,
  /*  788 */  regF_rule,
  /*  789 */  regD_rule,
  /*  790 */  regD_rule,
  /*  791 */  regD_rule,
  /*  792 */  regD_rule,
  /*  793 */  regD_rule,
  /*  794 */  regD_rule,
  /*  795 */  regD_rule,
  /*  796 */  regD_rule,
  /*  797 */  regD_rule,
  /*  798 */  regD_rule,
  /*  799 */  regF_rule,
  /*  800 */  _LoadF_memory__rule,
  /*  801 */  regD_rule,
  /*  802 */  _LoadD_memory__rule,
  /*  803 */  regF_rule,
  /*  804 */  regF_rule,
  /*  805 */  regD_rule,
  /*  806 */  regD_rule,
  /*  807 */  rRegI_rule,
  /*  808 */  _LoadI_memory__rule,
  /*  809 */  rRegI_rule,
  /*  810 */  _LoadI_memory__rule,
  /*  811 */  rRegI_rule,
  /*  812 */  rRegI_rule,
  /*  813 */  rRegL_rule,
  /*  814 */  _LoadL_memory__rule,
  /*  815 */  rRegL_rule,
  /*  816 */  _LoadL_memory__rule,
  /*  817 */  rRegI_rule,
  /*  818 */  _ConvI2L_rRegI__rule,
  /*  819 */  _ConvI2L__LoadI_memory___rule,
  /*  820 */  rRegL_rule,
  /*  821 */  rRegL_rule,
  /*  822 */  regF_rule,
  /*  823 */  rRegI_rule,
  /*  824 */  regD_rule,
  /*  825 */  rRegL_rule,
  /*  826 */  rcx_RegL_rule,
  /*  827 */  rcx_RegL_rule,
  /*  828 */  _Binary_rdi_RegP_rcx_RegI_rule,
  /*  829 */  _Binary_rdi_RegP_rdx_RegI_rule,
  /*  830 */  _Binary_rdi_RegP_rdx_RegI_rule,
  /*  831 */  _Binary_rdi_RegP_rsi_RegP_rule,
  /*  832 */  rdi_RegP_rule,
  /*  833 */  rsi_RegP_rule,
  /*  834 */  rRegL_rule,
  /*  835 */  0,
  /*  836 */  rRegI_rule,
  /*  837 */  0,
  /*  838 */  rRegI_rule,
  /*  839 */  0,
  /*  840 */  cmpOp_rule,
  /*  841 */  cmpOp_rule,
  /*  842 */  cmpOpU_rule,
  /*  843 */  cmpOpUCF_rule,
  /*  844 */  cmpOpU_rule,
  /*  845 */  cmpOpUCF_rule,
  /*  846 */  cmpOpUCF2_rule,
  /*  847 */  rsi_RegP_rule,
  /*  848 */  0,
  /*  849 */  cmpOp_rule,
  /*  850 */  cmpOp_rule,
  /*  851 */  cmpOpU_rule,
  /*  852 */  cmpOpUCF_rule,
  /*  853 */  cmpOpU_rule,
  /*  854 */  cmpOpUCF_rule,
  /*  855 */  cmpOpUCF2_rule,
  /*  856 */  rRegP_rule,
  /*  857 */  0,
  /*  858 */  0,
  /*  859 */  0,
  /*  860 */  0,
  /*  861 */  0,
  /*  862 */  0,
  /*  863 */  no_rbp_RegP_rule,
  /*  864 */  no_rbp_RegP_rule,
  /*  865 */  0,
  /*  866 */  0,
  /*  867 */  0,
  /*  868 */  regF_rule,
  /*  869 */  regF_rule,
  /*  870 */  _LoadF_memory__rule,
  /*  871 */  regF_rule,
  /*  872 */  regF_rule,
  /*  873 */  regF_rule,
  /*  874 */  _LoadF_memory__rule,
  /*  875 */  regF_rule,
  /*  876 */  regD_rule,
  /*  877 */  regD_rule,
  /*  878 */  _LoadD_memory__rule,
  /*  879 */  regD_rule,
  /*  880 */  regD_rule,
  /*  881 */  regD_rule,
  /*  882 */  _LoadD_memory__rule,
  /*  883 */  regD_rule,
  /*  884 */  regF_rule,
  /*  885 */  regF_rule,
  /*  886 */  regF_rule,
  /*  887 */  regF_rule,
  /*  888 */  regF_rule,
  /*  889 */  regF_rule,
  /*  890 */  regD_rule,
  /*  891 */  regD_rule,
  /*  892 */  regD_rule,
  /*  893 */  regD_rule,
  /*  894 */  regD_rule,
  /*  895 */  regD_rule,
  /*  896 */  regF_rule,
  /*  897 */  regF_rule,
  /*  898 */  _LoadF_memory__rule,
  /*  899 */  regF_rule,
  /*  900 */  regF_rule,
  /*  901 */  regF_rule,
  /*  902 */  _LoadF_memory__rule,
  /*  903 */  regF_rule,
  /*  904 */  regD_rule,
  /*  905 */  regD_rule,
  /*  906 */  _LoadD_memory__rule,
  /*  907 */  regD_rule,
  /*  908 */  regD_rule,
  /*  909 */  regD_rule,
  /*  910 */  _LoadD_memory__rule,
  /*  911 */  regD_rule,
  /*  912 */  regF_rule,
  /*  913 */  regF_rule,
  /*  914 */  regF_rule,
  /*  915 */  regF_rule,
  /*  916 */  regF_rule,
  /*  917 */  regF_rule,
  /*  918 */  regD_rule,
  /*  919 */  regD_rule,
  /*  920 */  regD_rule,
  /*  921 */  regD_rule,
  /*  922 */  regD_rule,
  /*  923 */  regD_rule,
  /*  924 */  _SqrtD__ConvF2D_regF___rule,
  /*  925 */  _SqrtD__ConvF2D__LoadF_memory____rule,
  /*  926 */  _SqrtD__ConvF2D_immF___rule,
  /*  927 */  regD_rule,
  /*  928 */  _LoadD_memory__rule,
  /*  929 */  immD_rule,
  /*  930 */  memory_rule,
  /*  931 */  memory_rule,
  /*  932 */  memory_rule,
  /*  933 */  memory_rule,
  /*  934 */  memory_rule,
  /*  935 */  memory_rule,
  /*  936 */  memory_rule,
  /*  937 */  memory_rule,
  /*  938 */  rRegI_rule,
  /*  939 */  rRegI_rule,
  /*  940 */  rRegI_rule,
  /*  941 */  rRegI_rule,
  /*  942 */  immI_rule,
  /*  943 */  immI_rule,
  /*  944 */  immI_rule,
  /*  945 */  immI_rule,
  /*  946 */  immI0_rule,
  /*  947 */  immI0_rule,
  /*  948 */  immI0_rule,
  /*  949 */  immI0_rule,
  /*  950 */  rRegI_rule,
  /*  951 */  rRegI_rule,
  /*  952 */  rRegI_rule,
  /*  953 */  rRegI_rule,
  /*  954 */  immI_rule,
  /*  955 */  immI_rule,
  /*  956 */  immI_rule,
  /*  957 */  immI_rule,
  /*  958 */  immI0_rule,
  /*  959 */  immI0_rule,
  /*  960 */  immI0_rule,
  /*  961 */  immI0_rule,
  /*  962 */  rRegI_rule,
  /*  963 */  rRegI_rule,
  /*  964 */  rRegI_rule,
  /*  965 */  immI_rule,
  /*  966 */  immI_rule,
  /*  967 */  immI_rule,
  /*  968 */  _LoadI_memory__rule,
  /*  969 */  _LoadI_memory__rule,
  /*  970 */  _LoadI_memory__rule,
  /*  971 */  immI0_rule,
  /*  972 */  immI0_rule,
  /*  973 */  immI0_rule,
  /*  974 */  rRegL_rule,
  /*  975 */  rRegL_rule,
  /*  976 */  immL_rule,
  /*  977 */  immL_rule,
  /*  978 */  _LoadL_memory__rule,
  /*  979 */  _LoadL_memory__rule,
  /*  980 */  immL0_rule,
  /*  981 */  immL0_rule,
  /*  982 */  regF_rule,
  /*  983 */  regF_rule,
  /*  984 */  regF_rule,
  /*  985 */  immF0_rule,
  /*  986 */  immF0_rule,
  /*  987 */  immF0_rule,
  /*  988 */  regD_rule,
  /*  989 */  regD_rule,
  /*  990 */  immD0_rule,
  /*  991 */  immD0_rule,
  /*  992 */  vecS_rule,
  /*  993 */  vecS_rule,
  /*  994 */  vecD_rule,
  /*  995 */  vecD_rule,
  /*  996 */  vecX_rule,
  /*  997 */  vecX_rule,
  /*  998 */  vecX_rule,
  /*  999 */  vecY_rule,
  /* 1000 */  vecY_rule,
  /* 1001 */  vecS_rule,
  /* 1002 */  vecS_rule,
  /* 1003 */  vecD_rule,
  /* 1004 */  vecD_rule,
  /* 1005 */  vecX_rule,
  /* 1006 */  vecX_rule,
  /* 1007 */  vecX_rule,
  /* 1008 */  vecY_rule,
  /* 1009 */  vecY_rule,
  /* 1010 */  vecD_rule,
  /* 1011 */  vecD_rule,
  /* 1012 */  vecX_rule,
  /* 1013 */  vecX_rule,
  /* 1014 */  vecX_rule,
  /* 1015 */  vecY_rule,
  /* 1016 */  vecY_rule,
  /* 1017 */  vecX_rule,
  /* 1018 */  vecX_rule,
  /* 1019 */  vecX_rule,
  /* 1020 */  vecY_rule,
  /* 1021 */  vecY_rule,
  /* 1022 */  vecD_rule,
  /* 1023 */  vecD_rule,
  /* 1024 */  vecX_rule,
  /* 1025 */  vecX_rule,
  /* 1026 */  vecX_rule,
  /* 1027 */  vecY_rule,
  /* 1028 */  vecY_rule,
  /* 1029 */  vecX_rule,
  /* 1030 */  vecX_rule,
  /* 1031 */  vecX_rule,
  /* 1032 */  vecY_rule,
  /* 1033 */  vecY_rule,
  /* 1034 */  vecS_rule,
  /* 1035 */  vecS_rule,
  /* 1036 */  vecD_rule,
  /* 1037 */  vecD_rule,
  /* 1038 */  vecX_rule,
  /* 1039 */  vecX_rule,
  /* 1040 */  vecX_rule,
  /* 1041 */  vecY_rule,
  /* 1042 */  vecY_rule,
  /* 1043 */  vecS_rule,
  /* 1044 */  vecS_rule,
  /* 1045 */  vecD_rule,
  /* 1046 */  vecD_rule,
  /* 1047 */  vecX_rule,
  /* 1048 */  vecX_rule,
  /* 1049 */  vecX_rule,
  /* 1050 */  vecY_rule,
  /* 1051 */  vecY_rule,
  /* 1052 */  vecD_rule,
  /* 1053 */  vecD_rule,
  /* 1054 */  vecX_rule,
  /* 1055 */  vecX_rule,
  /* 1056 */  vecX_rule,
  /* 1057 */  vecY_rule,
  /* 1058 */  vecY_rule,
  /* 1059 */  vecX_rule,
  /* 1060 */  vecX_rule,
  /* 1061 */  vecX_rule,
  /* 1062 */  vecY_rule,
  /* 1063 */  vecY_rule,
  /* 1064 */  vecD_rule,
  /* 1065 */  vecD_rule,
  /* 1066 */  vecX_rule,
  /* 1067 */  vecX_rule,
  /* 1068 */  vecX_rule,
  /* 1069 */  vecY_rule,
  /* 1070 */  vecY_rule,
  /* 1071 */  vecX_rule,
  /* 1072 */  vecX_rule,
  /* 1073 */  vecX_rule,
  /* 1074 */  vecY_rule,
  /* 1075 */  vecY_rule,
  /* 1076 */  vecS_rule,
  /* 1077 */  vecS_rule,
  /* 1078 */  vecD_rule,
  /* 1079 */  vecD_rule,
  /* 1080 */  vecX_rule,
  /* 1081 */  vecX_rule,
  /* 1082 */  vecX_rule,
  /* 1083 */  vecY_rule,
  /* 1084 */  vecY_rule,
  /* 1085 */  vecD_rule,
  /* 1086 */  vecD_rule,
  /* 1087 */  vecX_rule,
  /* 1088 */  vecX_rule,
  /* 1089 */  vecX_rule,
  /* 1090 */  vecY_rule,
  /* 1091 */  vecY_rule,
  /* 1092 */  vecD_rule,
  /* 1093 */  vecD_rule,
  /* 1094 */  vecX_rule,
  /* 1095 */  vecX_rule,
  /* 1096 */  vecX_rule,
  /* 1097 */  vecY_rule,
  /* 1098 */  vecY_rule,
  /* 1099 */  vecX_rule,
  /* 1100 */  vecX_rule,
  /* 1101 */  vecX_rule,
  /* 1102 */  vecY_rule,
  /* 1103 */  vecY_rule,
  /* 1104 */  vecD_rule,
  /* 1105 */  vecD_rule,
  /* 1106 */  vecX_rule,
  /* 1107 */  vecX_rule,
  /* 1108 */  vecX_rule,
  /* 1109 */  vecY_rule,
  /* 1110 */  vecY_rule,
  /* 1111 */  vecX_rule,
  /* 1112 */  vecX_rule,
  /* 1113 */  vecX_rule,
  /* 1114 */  vecY_rule,
  /* 1115 */  vecY_rule,
  /* 1116 */  vecS_rule,
  /* 1117 */  vecS_rule,
  /* 1118 */  vecS_rule,
  /* 1119 */  vecS_rule,
  /* 1120 */  vecD_rule,
  /* 1121 */  vecD_rule,
  /* 1122 */  vecD_rule,
  /* 1123 */  vecD_rule,
  /* 1124 */  vecX_rule,
  /* 1125 */  vecX_rule,
  /* 1126 */  vecX_rule,
  /* 1127 */  vecX_rule,
  /* 1128 */  vecY_rule,
  /* 1129 */  vecY_rule,
  /* 1130 */  vecD_rule,
  /* 1131 */  vecD_rule,
  /* 1132 */  vecD_rule,
  /* 1133 */  vecD_rule,
  /* 1134 */  vecX_rule,
  /* 1135 */  vecX_rule,
  /* 1136 */  vecX_rule,
  /* 1137 */  vecX_rule,
  /* 1138 */  vecY_rule,
  /* 1139 */  vecY_rule,
  /* 1140 */  vecX_rule,
  /* 1141 */  vecX_rule,
  /* 1142 */  vecX_rule,
  /* 1143 */  vecX_rule,
  /* 1144 */  vecY_rule,
  /* 1145 */  vecY_rule,
  /* 1146 */  vecS_rule,
  /* 1147 */  vecS_rule,
  /* 1148 */  vecS_rule,
  /* 1149 */  vecS_rule,
  /* 1150 */  vecD_rule,
  /* 1151 */  vecD_rule,
  /* 1152 */  vecD_rule,
  /* 1153 */  vecD_rule,
  /* 1154 */  vecX_rule,
  /* 1155 */  vecX_rule,
  /* 1156 */  vecX_rule,
  /* 1157 */  vecX_rule,
  /* 1158 */  vecY_rule,
  /* 1159 */  vecY_rule,
  /* 1160 */  vecD_rule,
  /* 1161 */  vecD_rule,
  /* 1162 */  vecD_rule,
  /* 1163 */  vecD_rule,
  /* 1164 */  vecX_rule,
  /* 1165 */  vecX_rule,
  /* 1166 */  vecX_rule,
  /* 1167 */  vecX_rule,
  /* 1168 */  vecY_rule,
  /* 1169 */  vecY_rule,
  /* 1170 */  vecX_rule,
  /* 1171 */  vecX_rule,
  /* 1172 */  vecX_rule,
  /* 1173 */  vecX_rule,
  /* 1174 */  vecY_rule,
  /* 1175 */  vecY_rule,
  /* 1176 */  vecS_rule,
  /* 1177 */  vecS_rule,
  /* 1178 */  vecS_rule,
  /* 1179 */  vecS_rule,
  /* 1180 */  vecD_rule,
  /* 1181 */  vecD_rule,
  /* 1182 */  vecD_rule,
  /* 1183 */  vecD_rule,
  /* 1184 */  vecX_rule,
  /* 1185 */  vecX_rule,
  /* 1186 */  vecX_rule,
  /* 1187 */  vecX_rule,
  /* 1188 */  vecY_rule,
  /* 1189 */  vecY_rule,
  /* 1190 */  vecD_rule,
  /* 1191 */  vecD_rule,
  /* 1192 */  vecD_rule,
  /* 1193 */  vecD_rule,
  /* 1194 */  vecX_rule,
  /* 1195 */  vecX_rule,
  /* 1196 */  vecX_rule,
  /* 1197 */  vecX_rule,
  /* 1198 */  vecY_rule,
  /* 1199 */  vecY_rule,
  /* 1200 */  vecS_rule,
  /* 1201 */  vecS_rule,
  /* 1202 */  vecD_rule,
  /* 1203 */  vecD_rule,
  /* 1204 */  vecX_rule,
  /* 1205 */  vecX_rule,
  /* 1206 */  vecX_rule,
  /* 1207 */  vecY_rule,
  /* 1208 */  vecY_rule,
  /* 1209 */  vecS_rule,
  /* 1210 */  vecS_rule,
  /* 1211 */  vecD_rule,
  /* 1212 */  vecD_rule,
  /* 1213 */  vecX_rule,
  /* 1214 */  vecX_rule,
  /* 1215 */  vecX_rule,
  /* 1216 */  vecY_rule,
  /* 1217 */  vecY_rule,
  /* 1218 */  vecS_rule,
  /* 1219 */  vecS_rule,
  /* 1220 */  vecD_rule,
  /* 1221 */  vecD_rule,
  /* 1222 */  vecX_rule,
  /* 1223 */  vecX_rule,
  /* 1224 */  vecX_rule,
  /* 1225 */  vecY_rule,
  /* 1226 */  vecY_rule,
  // last instruction
  0 // no trailing comma
};

const        int   rightOp[] = {
  /*    0 */  0,
  /*    1 */  0,
  /*    2 */  0,
  /*    3 */  0,
  /*    4 */  0,
  /*    5 */  0,
  /*    6 */  0,
  /*    7 */  0,
  /*    8 */  0,
  /*    9 */  0,
  /*   10 */  0,
  /*   11 */  0,
  /*   12 */  0,
  /*   13 */  0,
  /*   14 */  0,
  /*   15 */  0,
  /*   16 */  0,
  /*   17 */  0,
  /*   18 */  0,
  /*   19 */  0,
  /*   20 */  0,
  /*   21 */  0,
  /*   22 */  0,
  /*   23 */  0,
  /*   24 */  0,
  /*   25 */  0,
  /*   26 */  0,
  /*   27 */  0,
  /*   28 */  0,
  /*   29 */  0,
  /*   30 */  0,
  /*   31 */  0,
  /*   32 */  0,
  /*   33 */  0,
  /*   34 */  0,
  /*   35 */  0,
  /*   36 */  0,
  /*   37 */  0,
  /*   38 */  0,
  /*   39 */  0,
  /*   40 */  0,
  /*   41 */  0,
  /*   42 */  0,
  /*   43 */  0,
  /*   44 */  0,
  /*   45 */  0,
  /*   46 */  0,
  /*   47 */  0,
  /*   48 */  0,
  /*   49 */  0,
  /*   50 */  0,
  /*   51 */  0,
  /*   52 */  0,
  /*   53 */  0,
  /*   54 */  0,
  /*   55 */  0,
  /*   56 */  0,
  /*   57 */  0,
  /*   58 */  0,
  /*   59 */  0,
  /*   60 */  0,
  /*   61 */  0,
  /*   62 */  0,
  /*   63 */  0,
  /*   64 */  0,
  /*   65 */  0,
  /*   66 */  0,
  /*   67 */  0,
  /*   68 */  0,
  /*   69 */  0,
  /*   70 */  0,
  /*   71 */  0,
  /*   72 */  0,
  /*   73 */  0,
  /*   74 */  0,
  /*   75 */  0,
  /*   76 */  0,
  /*   77 */  immL8_rule,
  /*   78 */  immL32_rule,
  /*   79 */  immL32_rule,
  /*   80 */  rRegL_rule,
  /*   81 */  _LShiftL_rRegL_immI2_rule,
  /*   82 */  immL32_rule,
  /*   83 */  immL32_rule,
  /*   84 */  immL32_rule,
  /*   85 */  0,
  /*   86 */  immL8_rule,
  /*   87 */  immL32_rule,
  /*   88 */  immL32_rule,
  /*   89 */  rRegL_rule,
  /*   90 */  _LShiftL_rRegL_immI2_rule,
  /*   91 */  immL32_rule,
  /*   92 */  immL32_rule,
  /*   93 */  0,
  /*   94 */  0,
  /*   95 */  0,
  /*   96 */  0,
  /*   97 */  0,
  /*   98 */  0,
  /*   99 */  0,
  /*  100 */  0,
  /*  101 */  0,
  /*  102 */  0,
  /*  103 */  0,
  /*  104 */  0,
  /*  105 */  0,
  // last operand
  /*  106 */  0,
  // last operand class
  /*  107 */  rRegL_rule,
  /*  108 */  immI2_rule,
  /*  109 */  _LShiftL_rRegL_immI2_rule,
  /*  110 */  0,
  /*  111 */  immI2_rule,
  /*  112 */  _LShiftL__ConvI2L_rRegI__immI2_rule,
  /*  113 */  0,
  /*  114 */  rRegL_rule,
  /*  115 */  _LShiftL_rRegL_immI2_rule,
  /*  116 */  _LShiftL__ConvI2L_rRegI__immI2_rule,
  /*  117 */  0,
  /*  118 */  0,
  /*  119 */  immI8_rule,
  /*  120 */  0,
  /*  121 */  immI_24_rule,
  /*  122 */  0,
  /*  123 */  immI_24_rule,
  /*  124 */  immI_255_rule,
  /*  125 */  immI16_rule,
  /*  126 */  0,
  /*  127 */  immI_24_rule,
  /*  128 */  immI_16_rule,
  /*  129 */  immI_255_rule,
  /*  130 */  immI_65535_rule,
  /*  131 */  immU31_rule,
  /*  132 */  0,
  /*  133 */  0,
  /*  134 */  0,
  /*  135 */  0,
  /*  136 */  immL32_rule,
  /*  137 */  rFlagsReg_rule,
  /*  138 */  rRegI_rule,
  /*  139 */  rFlagsRegU_rule,
  /*  140 */  rFlagsRegUCF_rule,
  /*  141 */  _LoadI_memory__rule,
  /*  142 */  rRegN_rule,
  /*  143 */  rRegP_rule,
  /*  144 */  rRegL_rule,
  /*  145 */  _LoadL_memory__rule,
  /*  146 */  regF_rule,
  /*  147 */  regD_rule,
  /*  148 */  rRegI_rule,
  /*  149 */  _LoadI_memory__rule,
  /*  150 */  immI_rule,
  /*  151 */  immI1_rule,
  /*  152 */  immI_M1_rule,
  /*  153 */  rRegL_rule,
  /*  154 */  _LoadL_memory__rule,
  /*  155 */  immL32_rule,
  /*  156 */  immL1_rule,
  /*  157 */  immL_M1_rule,
  /*  158 */  rRegP_rule,
  /*  159 */  rRegI_rule,
  /*  160 */  rRegL_rule,
  /*  161 */  rRegN_rule,
  /*  162 */  rRegI_rule,
  /*  163 */  immI_rule,
  /*  164 */  rRegL_rule,
  /*  165 */  immL32_rule,
  /*  166 */  rRegI_rule,
  /*  167 */  _LoadI_memory__rule,
  /*  168 */  _LoadL_memory__rule,
  /*  169 */  immI1_rule,
  /*  170 */  immI8_rule,
  /*  171 */  rcx_RegI_rule,
  /*  172 */  immI1_rule,
  /*  173 */  immI8_rule,
  /*  174 */  rcx_RegI_rule,
  /*  175 */  immI1_rule,
  /*  176 */  immI8_rule,
  /*  177 */  rcx_RegI_rule,
  /*  178 */  immI1_rule,
  /*  179 */  immI8_rule,
  /*  180 */  rcx_RegI_rule,
  /*  181 */  immI1_rule,
  /*  182 */  immI8_rule,
  /*  183 */  rcx_RegI_rule,
  /*  184 */  immI1_rule,
  /*  185 */  immI8_rule,
  /*  186 */  rcx_RegI_rule,
  /*  187 */  immI_24_rule,
  /*  188 */  immI_16_rule,
  /*  189 */  immI1_rule,
  /*  190 */  immI_M1_rule,
  /*  191 */  immI8_rule,
  /*  192 */  immI8_rule,
  /*  193 */  rcx_RegI_rule,
  /*  194 */  rcx_RegI_rule,
  /*  195 */  _SubI_immI0_rcx_RegI_rule,
  /*  196 */  rcx_RegI_rule,
  /*  197 */  _SubI_immI_32_rcx_RegI_rule,
  /*  198 */  immI1_rule,
  /*  199 */  immI_M1_rule,
  /*  200 */  rcx_RegI_rule,
  /*  201 */  _SubI_immI0_rcx_RegI_rule,
  /*  202 */  _SubI_immI_32_rcx_RegI_rule,
  /*  203 */  immI1_rule,
  /*  204 */  immI_M1_rule,
  /*  205 */  immI8_rule,
  /*  206 */  immI8_rule,
  /*  207 */  rcx_RegI_rule,
  /*  208 */  _SubI_immI0_rcx_RegI_rule,
  /*  209 */  rcx_RegI_rule,
  /*  210 */  _SubI_immI_64_rcx_RegI_rule,
  /*  211 */  immI1_rule,
  /*  212 */  immI_M1_rule,
  /*  213 */  rcx_RegI_rule,
  /*  214 */  _SubI_immI0_rcx_RegI_rule,
  /*  215 */  _SubI_immI_64_rcx_RegI_rule,
  /*  216 */  immI_255_rule,
  /*  217 */  immI_65535_rule,
  /*  218 */  rRegI_rule,
  /*  219 */  _LoadI_memory__rule,
  /*  220 */  immI_rule,
  /*  221 */  immI_M1_rule,
  /*  222 */  immI_M1_rule,
  /*  223 */  rRegI_rule,
  /*  224 */  _LoadI_memory__rule,
  /*  225 */  immI_rule,
  /*  226 */  rRegI_rule,
  /*  227 */  _LoadI_memory__rule,
  /*  228 */  immI_rule,
  /*  229 */  rRegL_rule,
  /*  230 */  _LoadL_memory__rule,
  /*  231 */  immL32_rule,
  /*  232 */  immL_M1_rule,
  /*  233 */  rRegL_rule,
  /*  234 */  immL_M1_rule,
  /*  235 */  0,
  /*  236 */  rRegL_rule,
  /*  237 */  _LoadL_memory__rule,
  /*  238 */  immL32_rule,
  /*  239 */  rRegL_rule,
  /*  240 */  _LoadL_memory__rule,
  /*  241 */  immL32_rule,
  /*  242 */  rRegI_rule,
  /*  243 */  rRegI_rule,
  /*  244 */  rRegI_rule,
  /*  245 */  _CmpLTMask_rRegI_rRegI_rule,
  /*  246 */  0,
  /*  247 */  0,
  /*  248 */  rcx_RegI_rule,
  /*  249 */  rdx_RegI_rule,
  /*  250 */  rdx_RegI_rule,
  /*  251 */  immI_rule,
  /*  252 */  rax_RegI_rule,
  /*  253 */  rsi_RegP_rule,
  /*  254 */  immI_rule,
  /*  255 */  0,
  /*  256 */  0,
  /*  257 */  0,
  /*  258 */  immL32_rule,
  /*  259 */  rax_RegP_rule,
  /*  260 */  0,
  /*  261 */  0,
  /*  262 */  0,
  /*  263 */  0,
  /*  264 */  0,
  /*  265 */  0,
  /*  266 */  0,
  // last internally defined operand
  /*  267 */  0,
  /*  268 */  0,
  /*  269 */  0,
  /*  270 */  0,
  /*  271 */  0,
  /*  272 */  0,
  /*  273 */  0,
  /*  274 */  0,
  /*  275 */  0,
  /*  276 */  0,
  /*  277 */  0,
  /*  278 */  0,
  /*  279 */  0,
  /*  280 */  0,
  /*  281 */  0,
  /*  282 */  0,
  /*  283 */  0,
  /*  284 */  0,
  /*  285 */  0,
  /*  286 */  0,
  /*  287 */  0,
  /*  288 */  0,
  /*  289 */  0,
  /*  290 */  0,
  /*  291 */  0,
  /*  292 */  0,
  /*  293 */  0,
  /*  294 */  0,
  /*  295 */  0,
  /*  296 */  0,
  /*  297 */  0,
  /*  298 */  0,
  /*  299 */  0,
  /*  300 */  0,
  /*  301 */  0,
  /*  302 */  0,
  /*  303 */  0,
  /*  304 */  0,
  /*  305 */  0,
  /*  306 */  0,
  /*  307 */  0,
  /*  308 */  0,
  /*  309 */  0,
  /*  310 */  0,
  /*  311 */  0,
  /*  312 */  _Binary_rax_RegP_rRegP_rule,
  /*  313 */  _Binary_rax_RegI_rRegI_rule,
  /*  314 */  _Binary_rax_RegL_rRegL_rule,
  /*  315 */  regF_rule,
  /*  316 */  regF_rule,
  /*  317 */  _LoadF_memory__rule,
  /*  318 */  _LoadF_memory__rule,
  /*  319 */  immF_rule,
  /*  320 */  immF_rule,
  /*  321 */  regD_rule,
  /*  322 */  regD_rule,
  /*  323 */  _LoadD_memory__rule,
  /*  324 */  _LoadD_memory__rule,
  /*  325 */  immD_rule,
  /*  326 */  immD_rule,
  /*  327 */  0,
  /*  328 */  0,
  /*  329 */  0,
  /*  330 */  0,
  /*  331 */  0,
  /*  332 */  0,
  /*  333 */  0,
  /*  334 */  0,
  /*  335 */  0,
  /*  336 */  0,
  /*  337 */  0,
  /*  338 */  rRegI_rule,
  /*  339 */  immI_rule,
  /*  340 */  rRegL_rule,
  /*  341 */  immL32_rule,
  /*  342 */  rRegI_rule,
  /*  343 */  immI_rule,
  /*  344 */  rRegL_rule,
  /*  345 */  immL32_rule,
  /*  346 */  rax_RegI_rule,
  /*  347 */  rax_RegL_rule,
  /*  348 */  rRegI_rule,
  /*  349 */  immI_rule,
  /*  350 */  rRegL_rule,
  /*  351 */  immL32_rule,
  /*  352 */  rRegI_rule,
  /*  353 */  immI_rule,
  /*  354 */  _LoadI_memory__rule,
  /*  355 */  immI0_rule,
  /*  356 */  immI0_rule,
  /*  357 */  immI0_rule,
  /*  358 */  immI0_rule,
  /*  359 */  rRegI_rule,
  /*  360 */  immI_rule,
  /*  361 */  _LoadI_memory__rule,
  /*  362 */  immI0_rule,
  /*  363 */  rRegP_rule,
  /*  364 */  _LoadP_memory__rule,
  /*  365 */  _LoadP_memory__rule,
  /*  366 */  immP0_rule,
  /*  367 */  immP0_rule,
  /*  368 */  immP0_rule,
  /*  369 */  rRegN_rule,
  /*  370 */  _LoadN_memory__rule,
  /*  371 */  immN_rule,
  /*  372 */  _LoadN_memory__rule,
  /*  373 */  immNKlass_rule,
  /*  374 */  _LoadNKlass_memory__rule,
  /*  375 */  immN0_rule,
  /*  376 */  immN0_rule,
  /*  377 */  immN0_rule,
  /*  378 */  rRegL_rule,
  /*  379 */  immL32_rule,
  /*  380 */  _LoadL_memory__rule,
  /*  381 */  immL0_rule,
  /*  382 */  immL0_rule,
  /*  383 */  immL0_rule,
  /*  384 */  immL0_rule,
  /*  385 */  rRegL_rule,
  /*  386 */  immL32_rule,
  /*  387 */  _LoadL_memory__rule,
  /*  388 */  immL0_rule,
  /*  389 */  immP0_rule,
  /*  390 */  rbx_RegP_rule,
  /*  391 */  rbx_RegP_rule,
  /*  392 */  rax_RegP_rule,
  /*  393 */  0,
  /*  394 */  0,
  /*  395 */  0,
  /*  396 */  0,
  /*  397 */  0,
  /*  398 */  0,
  /*  399 */  0,
  /*  400 */  0,
  /*  401 */  0,
  /*  402 */  0,
  /*  403 */  0,
  /*  404 */  0,
  /*  405 */  0,
  /*  406 */  0,
  /*  407 */  0,
  /*  408 */  0,
  /*  409 */  0,
  /*  410 */  0,
  /*  411 */  immI_24_rule,
  /*  412 */  0,
  /*  413 */  0,
  /*  414 */  immI_24_rule,
  /*  415 */  0,
  /*  416 */  0,
  /*  417 */  0,
  /*  418 */  0,
  /*  419 */  immI_24_rule,
  /*  420 */  immI_255_rule,
  /*  421 */  immI_16_rule,
  /*  422 */  immI_65535_rule,
  /*  423 */  0,
  /*  424 */  0,
  /*  425 */  0,
  /*  426 */  0,
  /*  427 */  immL_32bits_rule,
  /*  428 */  0,
  /*  429 */  0,
  /*  430 */  0,
  /*  431 */  0,
  /*  432 */  0,
  /*  433 */  0,
  /*  434 */  0,
  /*  435 */  0,
  /*  436 */  0,
  /*  437 */  0,
  /*  438 */  0,
  /*  439 */  0,
  /*  440 */  0,
  /*  441 */  0,
  /*  442 */  0,
  /*  443 */  0,
  /*  444 */  0,
  /*  445 */  0,
  /*  446 */  rRegI_rule,
  /*  447 */  rRegI_rule,
  /*  448 */  rRegI_rule,
  /*  449 */  rRegL_rule,
  /*  450 */  any_RegP_rule,
  /*  451 */  immP0_rule,
  /*  452 */  immP31_rule,
  /*  453 */  rRegN_rule,
  /*  454 */  rRegN_rule,
  /*  455 */  immN0_rule,
  /*  456 */  immN_rule,
  /*  457 */  immNKlass_rule,
  /*  458 */  immI0_rule,
  /*  459 */  immI_rule,
  /*  460 */  immL0_rule,
  /*  461 */  immL32_rule,
  /*  462 */  immI0_rule,
  /*  463 */  immI16_rule,
  /*  464 */  immI0_rule,
  /*  465 */  immI8_rule,
  /*  466 */  immI0_rule,
  /*  467 */  immI0_rule,
  /*  468 */  regF_rule,
  /*  469 */  immF0_rule,
  /*  470 */  immF_rule,
  /*  471 */  regD_rule,
  /*  472 */  immD0_rule,
  /*  473 */  immD0_rule,
  /*  474 */  0,
  /*  475 */  0,
  /*  476 */  0,
  /*  477 */  0,
  /*  478 */  0,
  /*  479 */  0,
  /*  480 */  0,
  /*  481 */  0,
  /*  482 */  0,
  /*  483 */  0,
  /*  484 */  0,
  /*  485 */  0,
  /*  486 */  0,
  /*  487 */  0,
  /*  488 */  0,
  /*  489 */  0,
  /*  490 */  0,
  /*  491 */  0,
  /*  492 */  0,
  /*  493 */  0,
  /*  494 */  0,
  /*  495 */  0,
  /*  496 */  0,
  /*  497 */  0,
  /*  498 */  0,
  /*  499 */  0,
  /*  500 */  0,
  /*  501 */  0,
  /*  502 */  0,
  /*  503 */  0,
  /*  504 */  0,
  /*  505 */  0,
  /*  506 */  0,
  /*  507 */  0,
  /*  508 */  0,
  /*  509 */  _Binary_rRegI_rRegI_rule,
  /*  510 */  _Binary_rRegI_rRegI_rule,
  /*  511 */  _Binary_rRegI_rRegI_rule,
  /*  512 */  _Binary_rRegI__LoadI_memory__rule,
  /*  513 */  _Binary_rRegI__LoadI_memory__rule,
  /*  514 */  _Binary_rRegI__LoadI_memory__rule,
  /*  515 */  _Binary_rRegN_rRegN_rule,
  /*  516 */  _Binary_rRegN_rRegN_rule,
  /*  517 */  _Binary_rRegN_rRegN_rule,
  /*  518 */  _Binary_rRegP_rRegP_rule,
  /*  519 */  _Binary_rRegP_rRegP_rule,
  /*  520 */  _Binary_rRegP_rRegP_rule,
  /*  521 */  _Binary_rRegL_rRegL_rule,
  /*  522 */  _Binary_rRegL__LoadL_memory__rule,
  /*  523 */  _Binary_rRegL_rRegL_rule,
  /*  524 */  _Binary_rRegL_rRegL_rule,
  /*  525 */  _Binary_rRegL__LoadL_memory__rule,
  /*  526 */  _Binary_rRegL__LoadL_memory__rule,
  /*  527 */  _Binary_regF_regF_rule,
  /*  528 */  _Binary_regF_regF_rule,
  /*  529 */  _Binary_regF_regF_rule,
  /*  530 */  _Binary_regD_regD_rule,
  /*  531 */  _Binary_regD_regD_rule,
  /*  532 */  _Binary_regD_regD_rule,
  /*  533 */  rRegI_rule,
  /*  534 */  immI_rule,
  /*  535 */  _LoadI_memory__rule,
  /*  536 */  rRegI_rule,
  /*  537 */  _AddI__LoadI_memory__rRegI_rule,
  /*  538 */  _AddI_rRegI__LoadI_memory__rule,
  /*  539 */  _AddI__LoadI_memory__immI_rule,
  /*  540 */  immI1_rule,
  /*  541 */  _AddI__LoadI_memory__immI1_rule,
  /*  542 */  immI_M1_rule,
  /*  543 */  _AddI__LoadI_memory__immI_M1_rule,
  /*  544 */  immI_rule,
  /*  545 */  rRegL_rule,
  /*  546 */  immL32_rule,
  /*  547 */  _LoadL_memory__rule,
  /*  548 */  rRegL_rule,
  /*  549 */  _AddL__LoadL_memory__rRegL_rule,
  /*  550 */  _AddL_rRegL__LoadL_memory__rule,
  /*  551 */  _AddL__LoadL_memory__immL32_rule,
  /*  552 */  immL1_rule,
  /*  553 */  _AddL__LoadL_memory__immL1_rule,
  /*  554 */  immL_M1_rule,
  /*  555 */  _AddL__LoadL_memory__immL_M1_rule,
  /*  556 */  immL32_rule,
  /*  557 */  rRegL_rule,
  /*  558 */  immL32_rule,
  /*  559 */  immL32_rule,
  /*  560 */  0,
  /*  561 */  _Binary_rax_RegP_rRegP_rule,
  /*  562 */  _Binary_rax_RegL_rRegL_rule,
  /*  563 */  _Binary_rax_RegI_rRegI_rule,
  /*  564 */  _Binary_rax_RegN_rRegN_rule,
  /*  565 */  immI_rule,
  /*  566 */  rRegI_rule,
  /*  567 */  immL32_rule,
  /*  568 */  rRegL_rule,
  /*  569 */  rRegI_rule,
  /*  570 */  rRegL_rule,
  /*  571 */  rRegP_rule,
  /*  572 */  rRegN_rule,
  /*  573 */  rRegI_rule,
  /*  574 */  immI_rule,
  /*  575 */  _LoadI_memory__rule,
  /*  576 */  _SubI__LoadI_memory__rRegI_rule,
  /*  577 */  _SubI__LoadI_memory__immI_rule,
  /*  578 */  rRegL_rule,
  /*  579 */  immL32_rule,
  /*  580 */  _LoadL_memory__rule,
  /*  581 */  _SubL__LoadL_memory__rRegL_rule,
  /*  582 */  _SubL__LoadL_memory__immL32_rule,
  /*  583 */  _SubI_immI0_rRegI_rule,
  /*  584 */  rRegI_rule,
  /*  585 */  _SubI_immI0__LoadI_memory__rule,
  /*  586 */  rRegL_rule,
  /*  587 */  _SubL_immL0__LoadL_memory__rule,
  /*  588 */  rRegI_rule,
  /*  589 */  immI_rule,
  /*  590 */  _LoadI_memory__rule,
  /*  591 */  rRegI_rule,
  /*  592 */  immI_rule,
  /*  593 */  rRegL_rule,
  /*  594 */  immL32_rule,
  /*  595 */  _LoadL_memory__rule,
  /*  596 */  rRegL_rule,
  /*  597 */  immL32_rule,
  /*  598 */  rax_RegL_rule,
  /*  599 */  no_rax_rdx_RegI_rule,
  /*  600 */  no_rax_rdx_RegL_rule,
  /*  601 */  no_rax_rdx_RegI_rule,
  /*  602 */  no_rax_rdx_RegL_rule,
  /*  603 */  0,
  /*  604 */  0,
  /*  605 */  0,
  /*  606 */  0,
  /*  607 */  immL10_rule,
  /*  608 */  no_rax_rdx_RegI_rule,
  /*  609 */  no_rax_rdx_RegL_rule,
  /*  610 */  immI1_rule,
  /*  611 */  _LShiftI__LoadI_memory__immI1_rule,
  /*  612 */  immI8_rule,
  /*  613 */  _LShiftI__LoadI_memory__immI8_rule,
  /*  614 */  rcx_RegI_rule,
  /*  615 */  _LShiftI__LoadI_memory__rcx_RegI_rule,
  /*  616 */  immI1_rule,
  /*  617 */  _RShiftI__LoadI_memory__immI1_rule,
  /*  618 */  immI8_rule,
  /*  619 */  _RShiftI__LoadI_memory__immI8_rule,
  /*  620 */  rcx_RegI_rule,
  /*  621 */  _RShiftI__LoadI_memory__rcx_RegI_rule,
  /*  622 */  immI1_rule,
  /*  623 */  _URShiftI__LoadI_memory__immI1_rule,
  /*  624 */  immI8_rule,
  /*  625 */  _URShiftI__LoadI_memory__immI8_rule,
  /*  626 */  rcx_RegI_rule,
  /*  627 */  _URShiftI__LoadI_memory__rcx_RegI_rule,
  /*  628 */  immI1_rule,
  /*  629 */  _LShiftL__LoadL_memory__immI1_rule,
  /*  630 */  immI8_rule,
  /*  631 */  _LShiftL__LoadL_memory__immI8_rule,
  /*  632 */  rcx_RegI_rule,
  /*  633 */  _LShiftL__LoadL_memory__rcx_RegI_rule,
  /*  634 */  immI1_rule,
  /*  635 */  _RShiftL__LoadL_memory__immI1_rule,
  /*  636 */  immI8_rule,
  /*  637 */  _RShiftL__LoadL_memory__immI8_rule,
  /*  638 */  rcx_RegI_rule,
  /*  639 */  _RShiftL__LoadL_memory__rcx_RegI_rule,
  /*  640 */  immI1_rule,
  /*  641 */  _URShiftL__LoadL_memory__immI1_rule,
  /*  642 */  immI8_rule,
  /*  643 */  _URShiftL__LoadL_memory__immI8_rule,
  /*  644 */  rcx_RegI_rule,
  /*  645 */  _URShiftL__LoadL_memory__rcx_RegI_rule,
  /*  646 */  immI_24_rule,
  /*  647 */  immI_16_rule,
  /*  648 */  0,
  /*  649 */  0,
  /*  650 */  0,
  /*  651 */  _URShiftI_rRegI_immI_M1_rule,
  /*  652 */  _LShiftI_rRegI_immI1_rule,
  /*  653 */  _URShiftI_rRegI_immI8_rule,
  /*  654 */  _LShiftI_rRegI_immI8_rule,
  /*  655 */  _URShiftI_no_rcx_RegI__SubI_immI0_rcx_RegI_rule,
  /*  656 */  _LShiftI_no_rcx_RegI_rcx_RegI_rule,
  /*  657 */  _URShiftI_no_rcx_RegI__SubI_immI_32_rcx_RegI_rule,
  /*  658 */  _LShiftI_no_rcx_RegI_rcx_RegI_rule,
  /*  659 */  0,
  /*  660 */  0,
  /*  661 */  0,
  /*  662 */  _LShiftI_rRegI_immI_M1_rule,
  /*  663 */  _URShiftI_rRegI_immI1_rule,
  /*  664 */  _LShiftI_rRegI_immI8_rule,
  /*  665 */  _URShiftI_rRegI_immI8_rule,
  /*  666 */  _LShiftI_no_rcx_RegI__SubI_immI0_rcx_RegI_rule,
  /*  667 */  _URShiftI_no_rcx_RegI_rcx_RegI_rule,
  /*  668 */  _LShiftI_no_rcx_RegI__SubI_immI_32_rcx_RegI_rule,
  /*  669 */  _URShiftI_no_rcx_RegI_rcx_RegI_rule,
  /*  670 */  0,
  /*  671 */  0,
  /*  672 */  0,
  /*  673 */  _URShiftL_rRegL_immI_M1_rule,
  /*  674 */  _LShiftL_rRegL_immI1_rule,
  /*  675 */  _URShiftL_rRegL_immI8_rule,
  /*  676 */  _LShiftL_rRegL_immI8_rule,
  /*  677 */  _URShiftL_no_rcx_RegL__SubI_immI0_rcx_RegI_rule,
  /*  678 */  _LShiftL_no_rcx_RegL_rcx_RegI_rule,
  /*  679 */  _URShiftL_no_rcx_RegL__SubI_immI_64_rcx_RegI_rule,
  /*  680 */  _LShiftL_no_rcx_RegL_rcx_RegI_rule,
  /*  681 */  0,
  /*  682 */  0,
  /*  683 */  0,
  /*  684 */  _LShiftL_rRegL_immI_M1_rule,
  /*  685 */  _URShiftL_rRegL_immI1_rule,
  /*  686 */  _LShiftL_rRegL_immI8_rule,
  /*  687 */  _URShiftL_rRegL_immI8_rule,
  /*  688 */  _LShiftL_no_rcx_RegL__SubI_immI0_rcx_RegI_rule,
  /*  689 */  _URShiftL_no_rcx_RegL_rcx_RegI_rule,
  /*  690 */  _LShiftL_no_rcx_RegL__SubI_immI_64_rcx_RegI_rule,
  /*  691 */  _URShiftL_no_rcx_RegL_rcx_RegI_rule,
  /*  692 */  rRegI_rule,
  /*  693 */  immI_255_rule,
  /*  694 */  0,
  /*  695 */  immI_65535_rule,
  /*  696 */  0,
  /*  697 */  immI_rule,
  /*  698 */  _LoadI_memory__rule,
  /*  699 */  rRegI_rule,
  /*  700 */  _AndI__LoadI_memory__rRegI_rule,
  /*  701 */  _AndI_rRegI__LoadI_memory__rule,
  /*  702 */  _AndI__LoadI_memory__immI_rule,
  /*  703 */  _LoadI_memory__rule,
  /*  704 */  _XorI_rRegI_immI_M1_rule,
  /*  705 */  rRegI_rule,
  /*  706 */  _XorI_rRegI_immI_M1_rule,
  /*  707 */  rRegI_rule,
  /*  708 */  _SubI_immI0_rRegI_rule,
  /*  709 */  _LoadI_memory__rule,
  /*  710 */  _SubI_immI0__LoadI_memory__rule,
  /*  711 */  _LoadI_memory__rule,
  /*  712 */  _AddI__LoadI_memory__immI_M1_rule,
  /*  713 */  rRegI_rule,
  /*  714 */  _AddI_rRegI_immI_M1_rule,
  /*  715 */  rRegI_rule,
  /*  716 */  _AddI_rRegI_immI_M1_rule,
  /*  717 */  _LoadI_memory__rule,
  /*  718 */  _AddI__LoadI_memory__immI_M1_rule,
  /*  719 */  rRegI_rule,
  /*  720 */  immI_rule,
  /*  721 */  _LoadI_memory__rule,
  /*  722 */  rRegI_rule,
  /*  723 */  _OrI__LoadI_memory__rRegI_rule,
  /*  724 */  _OrI_rRegI__LoadI_memory__rule,
  /*  725 */  _OrI__LoadI_memory__immI_rule,
  /*  726 */  rRegI_rule,
  /*  727 */  immI_M1_rule,
  /*  728 */  immI_rule,
  /*  729 */  _LoadI_memory__rule,
  /*  730 */  rRegI_rule,
  /*  731 */  _XorI__LoadI_memory__rRegI_rule,
  /*  732 */  _XorI_rRegI__LoadI_memory__rule,
  /*  733 */  _XorI__LoadI_memory__immI_rule,
  /*  734 */  rRegL_rule,
  /*  735 */  immL_255_rule,
  /*  736 */  immL_65535_rule,
  /*  737 */  immL32_rule,
  /*  738 */  _LoadL_memory__rule,
  /*  739 */  rRegL_rule,
  /*  740 */  _AndL__LoadL_memory__rRegL_rule,
  /*  741 */  _AndL_rRegL__LoadL_memory__rule,
  /*  742 */  _AndL__LoadL_memory__immL32_rule,
  /*  743 */  _LoadL_memory__rule,
  /*  744 */  _XorL_rRegL_immL_M1_rule,
  /*  745 */  rRegL_rule,
  /*  746 */  _XorL_rRegL_immL_M1_rule,
  /*  747 */  rRegL_rule,
  /*  748 */  _SubL_immL0_rRegL_rule,
  /*  749 */  _LoadL_memory__rule,
  /*  750 */  _SubL_immL0__LoadL_memory__rule,
  /*  751 */  _LoadL_memory__rule,
  /*  752 */  _AddL__LoadL_memory__immL_M1_rule,
  /*  753 */  rRegL_rule,
  /*  754 */  _AddL_rRegL_immL_M1_rule,
  /*  755 */  rRegL_rule,
  /*  756 */  _AddL_rRegL_immL_M1_rule,
  /*  757 */  _LoadL_memory__rule,
  /*  758 */  _AddL__LoadL_memory__immL_M1_rule,
  /*  759 */  rRegL_rule,
  /*  760 */  _CastP2X_any_RegP__rule,
  /*  761 */  rRegL_rule,
  /*  762 */  immL32_rule,
  /*  763 */  _LoadL_memory__rule,
  /*  764 */  rRegL_rule,
  /*  765 */  _OrL__LoadL_memory__rRegL_rule,
  /*  766 */  _OrL_rRegL__LoadL_memory__rule,
  /*  767 */  _OrL__LoadL_memory__immL32_rule,
  /*  768 */  rRegL_rule,
  /*  769 */  immL_M1_rule,
  /*  770 */  immL32_rule,
  /*  771 */  _LoadL_memory__rule,
  /*  772 */  rRegL_rule,
  /*  773 */  _XorL__LoadL_memory__rRegL_rule,
  /*  774 */  _XorL_rRegL__LoadL_memory__rule,
  /*  775 */  _XorL__LoadL_memory__immL32_rule,
  /*  776 */  0,
  /*  777 */  0,
  /*  778 */  rRegI_rule,
  /*  779 */  immI0_rule,
  /*  780 */  _SubI_rRegI_rRegI_rule,
  /*  781 */  _AndI__CmpLTMask_rRegI_rRegI_rRegI_rule,
  /*  782 */  _SubI_rRegI_rRegI_rule,
  /*  783 */  _AndI_rRegI__CmpLTMask_rRegI_rRegI_rule,
  /*  784 */  rRegI_rule,
  /*  785 */  _CmpLTMask_rRegI_rRegI_rule,
  /*  786 */  regF_rule,
  /*  787 */  _LoadF_memory__rule,
  /*  788 */  immF_rule,
  /*  789 */  regD_rule,
  /*  790 */  _LoadD_memory__rule,
  /*  791 */  immD_rule,
  /*  792 */  0,
  /*  793 */  0,
  /*  794 */  0,
  /*  795 */  0,
  /*  796 */  0,
  /*  797 */  regD_rule,
  /*  798 */  0,
  /*  799 */  0,
  /*  800 */  0,
  /*  801 */  0,
  /*  802 */  0,
  /*  803 */  0,
  /*  804 */  0,
  /*  805 */  0,
  /*  806 */  0,
  /*  807 */  0,
  /*  808 */  0,
  /*  809 */  0,
  /*  810 */  0,
  /*  811 */  0,
  /*  812 */  0,
  /*  813 */  0,
  /*  814 */  0,
  /*  815 */  0,
  /*  816 */  0,
  /*  817 */  0,
  /*  818 */  immL_32bits_rule,
  /*  819 */  immL_32bits_rule,
  /*  820 */  immL_32bits_rule,
  /*  821 */  0,
  /*  822 */  0,
  /*  823 */  0,
  /*  824 */  0,
  /*  825 */  0,
  /*  826 */  rdi_RegP_rule,
  /*  827 */  rdi_RegP_rule,
  /*  828 */  _Binary_rsi_RegP_rdx_RegI_rule,
  /*  829 */  _Binary_rsi_RegP_immI_rule,
  /*  830 */  _Binary_rsi_RegP_rax_RegI_rule,
  /*  831 */  rcx_RegI_rule,
  /*  832 */  rsi_RegP_rule,
  /*  833 */  _Binary_rdi_RegP_rdx_RegI_rule,
  /*  834 */  rRegL_rule,
  /*  835 */  0,
  /*  836 */  rRegI_rule,
  /*  837 */  0,
  /*  838 */  rRegI_rule,
  /*  839 */  0,
  /*  840 */  rFlagsReg_rule,
  /*  841 */  rFlagsReg_rule,
  /*  842 */  rFlagsRegU_rule,
  /*  843 */  rFlagsRegUCF_rule,
  /*  844 */  rFlagsRegU_rule,
  /*  845 */  rFlagsRegUCF_rule,
  /*  846 */  rFlagsRegUCF_rule,
  /*  847 */  rax_RegP_rule,
  /*  848 */  0,
  /*  849 */  rFlagsReg_rule,
  /*  850 */  rFlagsReg_rule,
  /*  851 */  rFlagsRegU_rule,
  /*  852 */  rFlagsRegUCF_rule,
  /*  853 */  rFlagsRegU_rule,
  /*  854 */  rFlagsRegUCF_rule,
  /*  855 */  rFlagsRegUCF_rule,
  /*  856 */  0,
  /*  857 */  0,
  /*  858 */  0,
  /*  859 */  0,
  /*  860 */  0,
  /*  861 */  0,
  /*  862 */  0,
  /*  863 */  rbx_RegP_rule,
  /*  864 */  rax_RegP_rule,
  /*  865 */  0,
  /*  866 */  0,
  /*  867 */  0,
  /*  868 */  regF_rule,
  /*  869 */  _LoadF_memory__rule,
  /*  870 */  regF_rule,
  /*  871 */  immF_rule,
  /*  872 */  regF_rule,
  /*  873 */  _LoadF_memory__rule,
  /*  874 */  regF_rule,
  /*  875 */  immF_rule,
  /*  876 */  regD_rule,
  /*  877 */  _LoadD_memory__rule,
  /*  878 */  regD_rule,
  /*  879 */  immD_rule,
  /*  880 */  regD_rule,
  /*  881 */  _LoadD_memory__rule,
  /*  882 */  regD_rule,
  /*  883 */  immD_rule,
  /*  884 */  regF_rule,
  /*  885 */  _LoadF_memory__rule,
  /*  886 */  immF_rule,
  /*  887 */  regF_rule,
  /*  888 */  _LoadF_memory__rule,
  /*  889 */  immF_rule,
  /*  890 */  regD_rule,
  /*  891 */  _LoadD_memory__rule,
  /*  892 */  immD_rule,
  /*  893 */  regD_rule,
  /*  894 */  _LoadD_memory__rule,
  /*  895 */  immD_rule,
  /*  896 */  regF_rule,
  /*  897 */  _LoadF_memory__rule,
  /*  898 */  regF_rule,
  /*  899 */  immF_rule,
  /*  900 */  regF_rule,
  /*  901 */  _LoadF_memory__rule,
  /*  902 */  regF_rule,
  /*  903 */  immF_rule,
  /*  904 */  regD_rule,
  /*  905 */  _LoadD_memory__rule,
  /*  906 */  regD_rule,
  /*  907 */  immD_rule,
  /*  908 */  regD_rule,
  /*  909 */  _LoadD_memory__rule,
  /*  910 */  regD_rule,
  /*  911 */  immD_rule,
  /*  912 */  regF_rule,
  /*  913 */  _LoadF_memory__rule,
  /*  914 */  immF_rule,
  /*  915 */  regF_rule,
  /*  916 */  _LoadF_memory__rule,
  /*  917 */  immF_rule,
  /*  918 */  regD_rule,
  /*  919 */  _LoadD_memory__rule,
  /*  920 */  immD_rule,
  /*  921 */  regD_rule,
  /*  922 */  _LoadD_memory__rule,
  /*  923 */  immD_rule,
  /*  924 */  0,
  /*  925 */  0,
  /*  926 */  0,
  /*  927 */  0,
  /*  928 */  0,
  /*  929 */  0,
  /*  930 */  0,
  /*  931 */  0,
  /*  932 */  0,
  /*  933 */  0,
  /*  934 */  vecS_rule,
  /*  935 */  vecD_rule,
  /*  936 */  vecX_rule,
  /*  937 */  vecY_rule,
  /*  938 */  0,
  /*  939 */  0,
  /*  940 */  0,
  /*  941 */  0,
  /*  942 */  0,
  /*  943 */  0,
  /*  944 */  0,
  /*  945 */  0,
  /*  946 */  0,
  /*  947 */  0,
  /*  948 */  0,
  /*  949 */  0,
  /*  950 */  0,
  /*  951 */  0,
  /*  952 */  0,
  /*  953 */  0,
  /*  954 */  0,
  /*  955 */  0,
  /*  956 */  0,
  /*  957 */  0,
  /*  958 */  0,
  /*  959 */  0,
  /*  960 */  0,
  /*  961 */  0,
  /*  962 */  0,
  /*  963 */  0,
  /*  964 */  0,
  /*  965 */  0,
  /*  966 */  0,
  /*  967 */  0,
  /*  968 */  0,
  /*  969 */  0,
  /*  970 */  0,
  /*  971 */  0,
  /*  972 */  0,
  /*  973 */  0,
  /*  974 */  0,
  /*  975 */  0,
  /*  976 */  0,
  /*  977 */  0,
  /*  978 */  0,
  /*  979 */  0,
  /*  980 */  0,
  /*  981 */  0,
  /*  982 */  0,
  /*  983 */  0,
  /*  984 */  0,
  /*  985 */  0,
  /*  986 */  0,
  /*  987 */  0,
  /*  988 */  0,
  /*  989 */  0,
  /*  990 */  0,
  /*  991 */  0,
  /*  992 */  vecS_rule,
  /*  993 */  vecS_rule,
  /*  994 */  vecD_rule,
  /*  995 */  vecD_rule,
  /*  996 */  vecX_rule,
  /*  997 */  vecX_rule,
  /*  998 */  _LoadVector_memory__rule,
  /*  999 */  vecY_rule,
  /* 1000 */  _LoadVector_memory__rule,
  /* 1001 */  vecS_rule,
  /* 1002 */  vecS_rule,
  /* 1003 */  vecD_rule,
  /* 1004 */  vecD_rule,
  /* 1005 */  vecX_rule,
  /* 1006 */  vecX_rule,
  /* 1007 */  _LoadVector_memory__rule,
  /* 1008 */  vecY_rule,
  /* 1009 */  _LoadVector_memory__rule,
  /* 1010 */  vecD_rule,
  /* 1011 */  vecD_rule,
  /* 1012 */  vecX_rule,
  /* 1013 */  vecX_rule,
  /* 1014 */  _LoadVector_memory__rule,
  /* 1015 */  vecY_rule,
  /* 1016 */  _LoadVector_memory__rule,
  /* 1017 */  vecX_rule,
  /* 1018 */  vecX_rule,
  /* 1019 */  _LoadVector_memory__rule,
  /* 1020 */  vecY_rule,
  /* 1021 */  _LoadVector_memory__rule,
  /* 1022 */  vecD_rule,
  /* 1023 */  vecD_rule,
  /* 1024 */  vecX_rule,
  /* 1025 */  vecX_rule,
  /* 1026 */  _LoadVector_memory__rule,
  /* 1027 */  vecY_rule,
  /* 1028 */  _LoadVector_memory__rule,
  /* 1029 */  vecX_rule,
  /* 1030 */  vecX_rule,
  /* 1031 */  _LoadVector_memory__rule,
  /* 1032 */  vecY_rule,
  /* 1033 */  _LoadVector_memory__rule,
  /* 1034 */  vecS_rule,
  /* 1035 */  vecS_rule,
  /* 1036 */  vecD_rule,
  /* 1037 */  vecD_rule,
  /* 1038 */  vecX_rule,
  /* 1039 */  vecX_rule,
  /* 1040 */  _LoadVector_memory__rule,
  /* 1041 */  vecY_rule,
  /* 1042 */  _LoadVector_memory__rule,
  /* 1043 */  vecS_rule,
  /* 1044 */  vecS_rule,
  /* 1045 */  vecD_rule,
  /* 1046 */  vecD_rule,
  /* 1047 */  vecX_rule,
  /* 1048 */  vecX_rule,
  /* 1049 */  _LoadVector_memory__rule,
  /* 1050 */  vecY_rule,
  /* 1051 */  _LoadVector_memory__rule,
  /* 1052 */  vecD_rule,
  /* 1053 */  vecD_rule,
  /* 1054 */  vecX_rule,
  /* 1055 */  vecX_rule,
  /* 1056 */  _LoadVector_memory__rule,
  /* 1057 */  vecY_rule,
  /* 1058 */  _LoadVector_memory__rule,
  /* 1059 */  vecX_rule,
  /* 1060 */  vecX_rule,
  /* 1061 */  _LoadVector_memory__rule,
  /* 1062 */  vecY_rule,
  /* 1063 */  _LoadVector_memory__rule,
  /* 1064 */  vecD_rule,
  /* 1065 */  vecD_rule,
  /* 1066 */  vecX_rule,
  /* 1067 */  vecX_rule,
  /* 1068 */  _LoadVector_memory__rule,
  /* 1069 */  vecY_rule,
  /* 1070 */  _LoadVector_memory__rule,
  /* 1071 */  vecX_rule,
  /* 1072 */  vecX_rule,
  /* 1073 */  _LoadVector_memory__rule,
  /* 1074 */  vecY_rule,
  /* 1075 */  _LoadVector_memory__rule,
  /* 1076 */  vecS_rule,
  /* 1077 */  vecS_rule,
  /* 1078 */  vecD_rule,
  /* 1079 */  vecD_rule,
  /* 1080 */  vecX_rule,
  /* 1081 */  vecX_rule,
  /* 1082 */  _LoadVector_memory__rule,
  /* 1083 */  vecY_rule,
  /* 1084 */  _LoadVector_memory__rule,
  /* 1085 */  vecD_rule,
  /* 1086 */  vecD_rule,
  /* 1087 */  vecX_rule,
  /* 1088 */  vecX_rule,
  /* 1089 */  _LoadVector_memory__rule,
  /* 1090 */  vecY_rule,
  /* 1091 */  _LoadVector_memory__rule,
  /* 1092 */  vecD_rule,
  /* 1093 */  vecD_rule,
  /* 1094 */  vecX_rule,
  /* 1095 */  vecX_rule,
  /* 1096 */  _LoadVector_memory__rule,
  /* 1097 */  vecY_rule,
  /* 1098 */  _LoadVector_memory__rule,
  /* 1099 */  vecX_rule,
  /* 1100 */  vecX_rule,
  /* 1101 */  _LoadVector_memory__rule,
  /* 1102 */  vecY_rule,
  /* 1103 */  _LoadVector_memory__rule,
  /* 1104 */  vecD_rule,
  /* 1105 */  vecD_rule,
  /* 1106 */  vecX_rule,
  /* 1107 */  vecX_rule,
  /* 1108 */  _LoadVector_memory__rule,
  /* 1109 */  vecY_rule,
  /* 1110 */  _LoadVector_memory__rule,
  /* 1111 */  vecX_rule,
  /* 1112 */  vecX_rule,
  /* 1113 */  _LoadVector_memory__rule,
  /* 1114 */  vecY_rule,
  /* 1115 */  _LoadVector_memory__rule,
  /* 1116 */  vecS_rule,
  /* 1117 */  immI8_rule,
  /* 1118 */  vecS_rule,
  /* 1119 */  immI8_rule,
  /* 1120 */  vecS_rule,
  /* 1121 */  immI8_rule,
  /* 1122 */  vecS_rule,
  /* 1123 */  immI8_rule,
  /* 1124 */  vecS_rule,
  /* 1125 */  immI8_rule,
  /* 1126 */  vecS_rule,
  /* 1127 */  immI8_rule,
  /* 1128 */  vecS_rule,
  /* 1129 */  immI8_rule,
  /* 1130 */  vecS_rule,
  /* 1131 */  immI8_rule,
  /* 1132 */  vecS_rule,
  /* 1133 */  immI8_rule,
  /* 1134 */  vecS_rule,
  /* 1135 */  immI8_rule,
  /* 1136 */  vecS_rule,
  /* 1137 */  immI8_rule,
  /* 1138 */  vecS_rule,
  /* 1139 */  immI8_rule,
  /* 1140 */  vecS_rule,
  /* 1141 */  immI8_rule,
  /* 1142 */  vecS_rule,
  /* 1143 */  immI8_rule,
  /* 1144 */  vecS_rule,
  /* 1145 */  immI8_rule,
  /* 1146 */  vecS_rule,
  /* 1147 */  immI8_rule,
  /* 1148 */  vecS_rule,
  /* 1149 */  immI8_rule,
  /* 1150 */  vecS_rule,
  /* 1151 */  immI8_rule,
  /* 1152 */  vecS_rule,
  /* 1153 */  immI8_rule,
  /* 1154 */  vecS_rule,
  /* 1155 */  immI8_rule,
  /* 1156 */  vecS_rule,
  /* 1157 */  immI8_rule,
  /* 1158 */  vecS_rule,
  /* 1159 */  immI8_rule,
  /* 1160 */  vecS_rule,
  /* 1161 */  immI8_rule,
  /* 1162 */  vecS_rule,
  /* 1163 */  immI8_rule,
  /* 1164 */  vecS_rule,
  /* 1165 */  immI8_rule,
  /* 1166 */  vecS_rule,
  /* 1167 */  immI8_rule,
  /* 1168 */  vecS_rule,
  /* 1169 */  immI8_rule,
  /* 1170 */  vecS_rule,
  /* 1171 */  immI8_rule,
  /* 1172 */  vecS_rule,
  /* 1173 */  immI8_rule,
  /* 1174 */  vecS_rule,
  /* 1175 */  immI8_rule,
  /* 1176 */  vecS_rule,
  /* 1177 */  immI8_rule,
  /* 1178 */  vecS_rule,
  /* 1179 */  immI8_rule,
  /* 1180 */  vecS_rule,
  /* 1181 */  immI8_rule,
  /* 1182 */  vecS_rule,
  /* 1183 */  immI8_rule,
  /* 1184 */  vecS_rule,
  /* 1185 */  immI8_rule,
  /* 1186 */  vecS_rule,
  /* 1187 */  immI8_rule,
  /* 1188 */  vecS_rule,
  /* 1189 */  immI8_rule,
  /* 1190 */  vecS_rule,
  /* 1191 */  immI8_rule,
  /* 1192 */  vecS_rule,
  /* 1193 */  immI8_rule,
  /* 1194 */  vecS_rule,
  /* 1195 */  immI8_rule,
  /* 1196 */  vecS_rule,
  /* 1197 */  immI8_rule,
  /* 1198 */  vecS_rule,
  /* 1199 */  immI8_rule,
  /* 1200 */  vecS_rule,
  /* 1201 */  vecS_rule,
  /* 1202 */  vecD_rule,
  /* 1203 */  vecD_rule,
  /* 1204 */  vecX_rule,
  /* 1205 */  vecX_rule,
  /* 1206 */  _LoadVector_memory__rule,
  /* 1207 */  vecY_rule,
  /* 1208 */  _LoadVector_memory__rule,
  /* 1209 */  vecS_rule,
  /* 1210 */  vecS_rule,
  /* 1211 */  vecD_rule,
  /* 1212 */  vecD_rule,
  /* 1213 */  vecX_rule,
  /* 1214 */  vecX_rule,
  /* 1215 */  _LoadVector_memory__rule,
  /* 1216 */  vecY_rule,
  /* 1217 */  _LoadVector_memory__rule,
  /* 1218 */  vecS_rule,
  /* 1219 */  vecS_rule,
  /* 1220 */  vecD_rule,
  /* 1221 */  vecD_rule,
  /* 1222 */  vecX_rule,
  /* 1223 */  vecX_rule,
  /* 1224 */  _LoadVector_memory__rule,
  /* 1225 */  vecY_rule,
  /* 1226 */  _LoadVector_memory__rule,
  // last instruction
  0 // no trailing comma
};

const char        *ruleName[] = {
  /*    0 */  "UNIVERSE",
  /*    1 */  "LABEL",
  /*    2 */  "SREGI",
  /*    3 */  "SREGP",
  /*    4 */  "SREGF",
  /*    5 */  "SREGD",
  /*    6 */  "SREGL",
  /*    7 */  "METHOD",
  /*    8 */  "IMMI",
  /*    9 */  "IMMI0",
  /*   10 */  "IMMI1",
  /*   11 */  "IMMI_M1",
  /*   12 */  "IMMI2",
  /*   13 */  "IMMI8",
  /*   14 */  "IMMI16",
  /*   15 */  "IMMU31",
  /*   16 */  "IMMI_32",
  /*   17 */  "IMMI_64",
  /*   18 */  "IMMP",
  /*   19 */  "IMMP0",
  /*   20 */  "IMMN",
  /*   21 */  "IMMNKLASS",
  /*   22 */  "IMMN0",
  /*   23 */  "IMMP31",
  /*   24 */  "IMML",
  /*   25 */  "IMML8",
  /*   26 */  "IMMUL32",
  /*   27 */  "IMML32",
  /*   28 */  "IMML0",
  /*   29 */  "IMML1",
  /*   30 */  "IMML_M1",
  /*   31 */  "IMML10",
  /*   32 */  "IMML_127",
  /*   33 */  "IMML_32BITS",
  /*   34 */  "IMMF0",
  /*   35 */  "IMMF",
  /*   36 */  "IMMD0",
  /*   37 */  "IMMD",
  /*   38 */  "IMMI_16",
  /*   39 */  "IMMI_24",
  /*   40 */  "IMMI_255",
  /*   41 */  "IMMI_65535",
  /*   42 */  "IMML_255",
  /*   43 */  "IMML_65535",
  /*   44 */  "RREGI",
  /*   45 */  "RAX_REGI",
  /*   46 */  "RBX_REGI",
  /*   47 */  "RCX_REGI",
  /*   48 */  "RDX_REGI",
  /*   49 */  "RDI_REGI",
  /*   50 */  "NO_RCX_REGI",
  /*   51 */  "NO_RAX_RDX_REGI",
  /*   52 */  "ANY_REGP",
  /*   53 */  "RREGP",
  /*   54 */  "RREGN",
  /*   55 */  "NO_RAX_REGP",
  /*   56 */  "NO_RBP_REGP",
  /*   57 */  "NO_RAX_RBX_REGP",
  /*   58 */  "RAX_REGP",
  /*   59 */  "RAX_REGN",
  /*   60 */  "RBX_REGP",
  /*   61 */  "RSI_REGP",
  /*   62 */  "RDI_REGP",
  /*   63 */  "R15_REGP",
  /*   64 */  "RREGL",
  /*   65 */  "NO_RAX_RDX_REGL",
  /*   66 */  "NO_RAX_REGL",
  /*   67 */  "NO_RCX_REGL",
  /*   68 */  "RAX_REGL",
  /*   69 */  "RCX_REGL",
  /*   70 */  "RDX_REGL",
  /*   71 */  "RFLAGSREG",
  /*   72 */  "RFLAGSREGU",
  /*   73 */  "RFLAGSREGUCF",
  /*   74 */  "REGF",
  /*   75 */  "REGD",
  /*   76 */  "INDIRECT",
  /*   77 */  "INDOFFSET8",
  /*   78 */  "INDOFFSET32",
  /*   79 */  "INDINDEXOFFSET",
  /*   80 */  "INDINDEX",
  /*   81 */  "INDINDEXSCALE",
  /*   82 */  "INDINDEXSCALEOFFSET",
  /*   83 */  "INDPOSINDEXSCALEOFFSET",
  /*   84 */  "INDCOMPRESSEDOOPOFFSET",
  /*   85 */  "INDIRECTNARROW",
  /*   86 */  "INDOFFSET8NARROW",
  /*   87 */  "INDOFFSET32NARROW",
  /*   88 */  "INDINDEXOFFSETNARROW",
  /*   89 */  "INDINDEXNARROW",
  /*   90 */  "INDINDEXSCALENARROW",
  /*   91 */  "INDINDEXSCALEOFFSETNARROW",
  /*   92 */  "INDPOSINDEXSCALEOFFSETNARROW",
  /*   93 */  "STACKSLOTP",
  /*   94 */  "STACKSLOTI",
  /*   95 */  "STACKSLOTF",
  /*   96 */  "STACKSLOTD",
  /*   97 */  "STACKSLOTL",
  /*   98 */  "CMPOP",
  /*   99 */  "CMPOPU",
  /*  100 */  "CMPOPUCF",
  /*  101 */  "CMPOPUCF2",
  /*  102 */  "VECS",
  /*  103 */  "VECD",
  /*  104 */  "VECX",
  /*  105 */  "VECY",
  // last operand
  /*  106 */  "MEMORY",
  // last operand class
  /*  107 */  "_AddP_any_RegP_rRegL",
  /*  108 */  "_LShiftL_rRegL_immI2",
  /*  109 */  "_AddP_any_RegP__LShiftL_rRegL_immI2",
  /*  110 */  "_ConvI2L_rRegI_",
  /*  111 */  "_LShiftL__ConvI2L_rRegI__immI2",
  /*  112 */  "_AddP_any_RegP__LShiftL__ConvI2L_rRegI__immI2",
  /*  113 */  "_DecodeN_rRegN_",
  /*  114 */  "_AddP__DecodeN_rRegN__rRegL",
  /*  115 */  "_AddP__DecodeN_rRegN___LShiftL_rRegL_immI2",
  /*  116 */  "_AddP__DecodeN_rRegN___LShiftL__ConvI2L_rRegI__immI2",
  /*  117 */  "_LoadB_memory_",
  /*  118 */  "_LoadUB_memory_",
  /*  119 */  "_AndI__LoadUB_memory__immI8",
  /*  120 */  "_LoadS_memory_",
  /*  121 */  "_LShiftI__LoadS_memory__immI_24",
  /*  122 */  "_LoadUS_memory_",
  /*  123 */  "_LShiftI__LoadUS_memory__immI_24",
  /*  124 */  "_AndI__LoadUS_memory__immI_255",
  /*  125 */  "_AndI__LoadUS_memory__immI16",
  /*  126 */  "_LoadI_memory_",
  /*  127 */  "_LShiftI__LoadI_memory__immI_24",
  /*  128 */  "_LShiftI__LoadI_memory__immI_16",
  /*  129 */  "_AndI__LoadI_memory__immI_255",
  /*  130 */  "_AndI__LoadI_memory__immI_65535",
  /*  131 */  "_AndI__LoadI_memory__immU31",
  /*  132 */  "_ConvI2L__LoadI_memory__",
  /*  133 */  "_LoadL_memory_",
  /*  134 */  "_CastP2X_rRegP_",
  /*  135 */  "_CastP2X__DecodeN_rRegN__",
  /*  136 */  "_AddL__LShiftL_rRegL_immI2_immL32",
  /*  137 */  "_Binary_cmpOp_rFlagsReg",
  /*  138 */  "_Binary_rRegI_rRegI",
  /*  139 */  "_Binary_cmpOpU_rFlagsRegU",
  /*  140 */  "_Binary_cmpOpUCF_rFlagsRegUCF",
  /*  141 */  "_Binary_rRegI__LoadI_memory_",
  /*  142 */  "_Binary_rRegN_rRegN",
  /*  143 */  "_Binary_rRegP_rRegP",
  /*  144 */  "_Binary_rRegL_rRegL",
  /*  145 */  "_Binary_rRegL__LoadL_memory_",
  /*  146 */  "_Binary_regF_regF",
  /*  147 */  "_Binary_regD_regD",
  /*  148 */  "_AddI__LoadI_memory__rRegI",
  /*  149 */  "_AddI_rRegI__LoadI_memory_",
  /*  150 */  "_AddI__LoadI_memory__immI",
  /*  151 */  "_AddI__LoadI_memory__immI1",
  /*  152 */  "_AddI__LoadI_memory__immI_M1",
  /*  153 */  "_AddL__LoadL_memory__rRegL",
  /*  154 */  "_AddL_rRegL__LoadL_memory_",
  /*  155 */  "_AddL__LoadL_memory__immL32",
  /*  156 */  "_AddL__LoadL_memory__immL1",
  /*  157 */  "_AddL__LoadL_memory__immL_M1",
  /*  158 */  "_Binary_rax_RegP_rRegP",
  /*  159 */  "_Binary_rax_RegI_rRegI",
  /*  160 */  "_Binary_rax_RegL_rRegL",
  /*  161 */  "_Binary_rax_RegN_rRegN",
  /*  162 */  "_SubI__LoadI_memory__rRegI",
  /*  163 */  "_SubI__LoadI_memory__immI",
  /*  164 */  "_SubL__LoadL_memory__rRegL",
  /*  165 */  "_SubL__LoadL_memory__immL32",
  /*  166 */  "_SubI_immI0_rRegI",
  /*  167 */  "_SubI_immI0__LoadI_memory_",
  /*  168 */  "_SubL_immL0__LoadL_memory_",
  /*  169 */  "_LShiftI__LoadI_memory__immI1",
  /*  170 */  "_LShiftI__LoadI_memory__immI8",
  /*  171 */  "_LShiftI__LoadI_memory__rcx_RegI",
  /*  172 */  "_RShiftI__LoadI_memory__immI1",
  /*  173 */  "_RShiftI__LoadI_memory__immI8",
  /*  174 */  "_RShiftI__LoadI_memory__rcx_RegI",
  /*  175 */  "_URShiftI__LoadI_memory__immI1",
  /*  176 */  "_URShiftI__LoadI_memory__immI8",
  /*  177 */  "_URShiftI__LoadI_memory__rcx_RegI",
  /*  178 */  "_LShiftL__LoadL_memory__immI1",
  /*  179 */  "_LShiftL__LoadL_memory__immI8",
  /*  180 */  "_LShiftL__LoadL_memory__rcx_RegI",
  /*  181 */  "_RShiftL__LoadL_memory__immI1",
  /*  182 */  "_RShiftL__LoadL_memory__immI8",
  /*  183 */  "_RShiftL__LoadL_memory__rcx_RegI",
  /*  184 */  "_URShiftL__LoadL_memory__immI1",
  /*  185 */  "_URShiftL__LoadL_memory__immI8",
  /*  186 */  "_URShiftL__LoadL_memory__rcx_RegI",
  /*  187 */  "_LShiftI_rRegI_immI_24",
  /*  188 */  "_LShiftI_rRegI_immI_16",
  /*  189 */  "_LShiftI_rRegI_immI1",
  /*  190 */  "_URShiftI_rRegI_immI_M1",
  /*  191 */  "_LShiftI_rRegI_immI8",
  /*  192 */  "_URShiftI_rRegI_immI8",
  /*  193 */  "_LShiftI_no_rcx_RegI_rcx_RegI",
  /*  194 */  "_SubI_immI0_rcx_RegI",
  /*  195 */  "_URShiftI_no_rcx_RegI__SubI_immI0_rcx_RegI",
  /*  196 */  "_SubI_immI_32_rcx_RegI",
  /*  197 */  "_URShiftI_no_rcx_RegI__SubI_immI_32_rcx_RegI",
  /*  198 */  "_URShiftI_rRegI_immI1",
  /*  199 */  "_LShiftI_rRegI_immI_M1",
  /*  200 */  "_URShiftI_no_rcx_RegI_rcx_RegI",
  /*  201 */  "_LShiftI_no_rcx_RegI__SubI_immI0_rcx_RegI",
  /*  202 */  "_LShiftI_no_rcx_RegI__SubI_immI_32_rcx_RegI",
  /*  203 */  "_LShiftL_rRegL_immI1",
  /*  204 */  "_URShiftL_rRegL_immI_M1",
  /*  205 */  "_LShiftL_rRegL_immI8",
  /*  206 */  "_URShiftL_rRegL_immI8",
  /*  207 */  "_LShiftL_no_rcx_RegL_rcx_RegI",
  /*  208 */  "_URShiftL_no_rcx_RegL__SubI_immI0_rcx_RegI",
  /*  209 */  "_SubI_immI_64_rcx_RegI",
  /*  210 */  "_URShiftL_no_rcx_RegL__SubI_immI_64_rcx_RegI",
  /*  211 */  "_URShiftL_rRegL_immI1",
  /*  212 */  "_LShiftL_rRegL_immI_M1",
  /*  213 */  "_URShiftL_no_rcx_RegL_rcx_RegI",
  /*  214 */  "_LShiftL_no_rcx_RegL__SubI_immI0_rcx_RegI",
  /*  215 */  "_LShiftL_no_rcx_RegL__SubI_immI_64_rcx_RegI",
  /*  216 */  "_AndI_rRegI_immI_255",
  /*  217 */  "_AndI_rRegI_immI_65535",
  /*  218 */  "_AndI__LoadI_memory__rRegI",
  /*  219 */  "_AndI_rRegI__LoadI_memory_",
  /*  220 */  "_AndI__LoadI_memory__immI",
  /*  221 */  "_XorI_rRegI_immI_M1",
  /*  222 */  "_AddI_rRegI_immI_M1",
  /*  223 */  "_OrI__LoadI_memory__rRegI",
  /*  224 */  "_OrI_rRegI__LoadI_memory_",
  /*  225 */  "_OrI__LoadI_memory__immI",
  /*  226 */  "_XorI__LoadI_memory__rRegI",
  /*  227 */  "_XorI_rRegI__LoadI_memory_",
  /*  228 */  "_XorI__LoadI_memory__immI",
  /*  229 */  "_AndL__LoadL_memory__rRegL",
  /*  230 */  "_AndL_rRegL__LoadL_memory_",
  /*  231 */  "_AndL__LoadL_memory__immL32",
  /*  232 */  "_XorL_rRegL_immL_M1",
  /*  233 */  "_SubL_immL0_rRegL",
  /*  234 */  "_AddL_rRegL_immL_M1",
  /*  235 */  "_CastP2X_any_RegP_",
  /*  236 */  "_OrL__LoadL_memory__rRegL",
  /*  237 */  "_OrL_rRegL__LoadL_memory_",
  /*  238 */  "_OrL__LoadL_memory__immL32",
  /*  239 */  "_XorL__LoadL_memory__rRegL",
  /*  240 */  "_XorL_rRegL__LoadL_memory_",
  /*  241 */  "_XorL__LoadL_memory__immL32",
  /*  242 */  "_CmpLTMask_rRegI_rRegI",
  /*  243 */  "_AndI__CmpLTMask_rRegI_rRegI_rRegI",
  /*  244 */  "_SubI_rRegI_rRegI",
  /*  245 */  "_AndI_rRegI__CmpLTMask_rRegI_rRegI",
  /*  246 */  "_LoadF_memory_",
  /*  247 */  "_LoadD_memory_",
  /*  248 */  "_Binary_rdi_RegP_rcx_RegI",
  /*  249 */  "_Binary_rsi_RegP_rdx_RegI",
  /*  250 */  "_Binary_rdi_RegP_rdx_RegI",
  /*  251 */  "_Binary_rsi_RegP_immI",
  /*  252 */  "_Binary_rsi_RegP_rax_RegI",
  /*  253 */  "_Binary_rdi_RegP_rsi_RegP",
  /*  254 */  "_AndI_rRegI_immI",
  /*  255 */  "_LoadP_memory_",
  /*  256 */  "_LoadN_memory_",
  /*  257 */  "_LoadNKlass_memory_",
  /*  258 */  "_AndL_rRegL_immL32",
  /*  259 */  "_PartialSubtypeCheck_rsi_RegP_rax_RegP",
  /*  260 */  "_ConvF2D_regF_",
  /*  261 */  "_SqrtD__ConvF2D_regF__",
  /*  262 */  "_ConvF2D__LoadF_memory__",
  /*  263 */  "_SqrtD__ConvF2D__LoadF_memory___",
  /*  264 */  "_ConvF2D_immF_",
  /*  265 */  "_SqrtD__ConvF2D_immF__",
  /*  266 */  "_LoadVector_memory_",
  // last internally defined operand
  /*  267 */  "storeSSI",
  /*  268 */  "storeSSL",
  /*  269 */  "storeSSP",
  /*  270 */  "storeSSF",
  /*  271 */  "storeSSD",
  /*  272 */  "leaP8",
  /*  273 */  "leaP32",
  /*  274 */  "leaPIdxOff",
  /*  275 */  "leaPIdxScale",
  /*  276 */  "leaPIdxScaleOff",
  /*  277 */  "leaPPosIdxScaleOff",
  /*  278 */  "leaPCompressedOopOffset",
  /*  279 */  "leaP8Narrow",
  /*  280 */  "leaP32Narrow",
  /*  281 */  "leaPIdxOffNarrow",
  /*  282 */  "leaPIdxScaleNarrow",
  /*  283 */  "leaPIdxScaleOffNarrow",
  /*  284 */  "leaPPosIdxScaleOffNarrow",
  /*  285 */  "loadConI",
  /*  286 */  "loadConI0",
  /*  287 */  "loadConL",
  /*  288 */  "loadConL0",
  /*  289 */  "loadConUL32",
  /*  290 */  "loadConL32",
  /*  291 */  "loadConP",
  /*  292 */  "loadConP0",
  /*  293 */  "loadConP31",
  /*  294 */  "loadConF",
  /*  295 */  "loadConN0",
  /*  296 */  "loadConN",
  /*  297 */  "loadConNKlass",
  /*  298 */  "loadConF0",
  /*  299 */  "loadConD",
  /*  300 */  "loadConD0",
  /*  301 */  "loadSSI",
  /*  302 */  "loadSSL",
  /*  303 */  "loadSSP",
  /*  304 */  "loadSSF",
  /*  305 */  "loadSSD",
  /*  306 */  "membar_volatile",
  /*  307 */  "castX2P",
  /*  308 */  "castP2X",
  /*  309 */  "checkCastPP",
  /*  310 */  "castPP",
  /*  311 */  "castII",
  /*  312 */  "storePConditional",
  /*  313 */  "storeIConditional",
  /*  314 */  "storeLConditional",
  /*  315 */  "cmpF_cc_reg",
  /*  316 */  "cmpF_cc_reg_CF",
  /*  317 */  "cmpF_cc_mem",
  /*  318 */  "cmpF_cc_memCF",
  /*  319 */  "cmpF_cc_imm",
  /*  320 */  "cmpF_cc_immCF",
  /*  321 */  "cmpD_cc_reg",
  /*  322 */  "cmpD_cc_reg_CF",
  /*  323 */  "cmpD_cc_mem",
  /*  324 */  "cmpD_cc_memCF",
  /*  325 */  "cmpD_cc_imm",
  /*  326 */  "cmpD_cc_immCF",
  /*  327 */  "roundFloat_nop",
  /*  328 */  "roundDouble_nop",
  /*  329 */  "MoveF2I_stack_reg",
  /*  330 */  "MoveI2F_stack_reg",
  /*  331 */  "MoveD2L_stack_reg",
  /*  332 */  "MoveL2D_stack_reg_partial",
  /*  333 */  "MoveL2D_stack_reg",
  /*  334 */  "MoveF2I_reg_reg",
  /*  335 */  "MoveD2L_reg_reg",
  /*  336 */  "MoveI2F_reg_reg",
  /*  337 */  "MoveL2D_reg_reg",
  /*  338 */  "overflowAddI_rReg",
  /*  339 */  "overflowAddI_rReg_imm",
  /*  340 */  "overflowAddL_rReg",
  /*  341 */  "overflowAddL_rReg_imm",
  /*  342 */  "overflowSubI_rReg",
  /*  343 */  "overflowSubI_rReg_imm",
  /*  344 */  "overflowSubL_rReg",
  /*  345 */  "overflowSubL_rReg_imm",
  /*  346 */  "overflowNegI_rReg",
  /*  347 */  "overflowNegL_rReg",
  /*  348 */  "overflowMulI_rReg",
  /*  349 */  "overflowMulI_rReg_imm",
  /*  350 */  "overflowMulL_rReg",
  /*  351 */  "overflowMulL_rReg_imm",
  /*  352 */  "compI_rReg",
  /*  353 */  "compI_rReg_imm",
  /*  354 */  "compI_rReg_mem",
  /*  355 */  "testI_reg",
  /*  356 */  "testI_reg_imm",
  /*  357 */  "testI_reg_mem",
  /*  358 */  "testI_reg_mem_0",
  /*  359 */  "compU_rReg",
  /*  360 */  "compU_rReg_imm",
  /*  361 */  "compU_rReg_mem",
  /*  362 */  "testU_reg",
  /*  363 */  "compP_rReg",
  /*  364 */  "compP_rReg_mem",
  /*  365 */  "compP_mem_rReg",
  /*  366 */  "testP_reg",
  /*  367 */  "testP_mem",
  /*  368 */  "testP_mem_reg0",
  /*  369 */  "compN_rReg",
  /*  370 */  "compN_rReg_mem",
  /*  371 */  "compN_rReg_imm",
  /*  372 */  "compN_mem_imm",
  /*  373 */  "compN_rReg_imm_klass",
  /*  374 */  "compN_mem_imm_klass",
  /*  375 */  "testN_reg",
  /*  376 */  "testN_mem",
  /*  377 */  "testN_mem_reg0",
  /*  378 */  "compL_rReg",
  /*  379 */  "compL_rReg_imm",
  /*  380 */  "compL_rReg_mem",
  /*  381 */  "testL_reg",
  /*  382 */  "testL_reg_imm",
  /*  383 */  "testL_reg_mem",
  /*  384 */  "testL_reg_mem_0",
  /*  385 */  "compUL_rReg",
  /*  386 */  "compUL_rReg_imm",
  /*  387 */  "compUL_rReg_mem",
  /*  388 */  "testUL_reg",
  /*  389 */  "partialSubtypeCheck_vs_Zero",
  /*  390 */  "cmpFastLockRTM",
  /*  391 */  "cmpFastLock",
  /*  392 */  "cmpFastUnlock",
  /*  393 */  "safePoint_poll",
  /*  394 */  "tlsLoadP",
  /*  395 */  "absF_reg",
  /*  396 */  "absF_reg_reg",
  /*  397 */  "absD_reg",
  /*  398 */  "absD_reg_reg",
  /*  399 */  "negF_reg",
  /*  400 */  "negF_reg_reg",
  /*  401 */  "negD_reg",
  /*  402 */  "negD_reg_reg",
  /*  403 */  "vshiftcnt",
  /*  404 */  "vshiftcnt_0",
  /*  405 */  "loadB",
  /*  406 */  "loadB2L",
  /*  407 */  "loadUB",
  /*  408 */  "loadUB2L",
  /*  409 */  "loadUB2L_immI8",
  /*  410 */  "loadS",
  /*  411 */  "loadS2B",
  /*  412 */  "loadS2L",
  /*  413 */  "loadUS",
  /*  414 */  "loadUS2B",
  /*  415 */  "loadUS2L",
  /*  416 */  "loadUS2L_immI_255",
  /*  417 */  "loadUS2L_immI16",
  /*  418 */  "loadI",
  /*  419 */  "loadI2B",
  /*  420 */  "loadI2UB",
  /*  421 */  "loadI2S",
  /*  422 */  "loadI2US",
  /*  423 */  "loadI2L",
  /*  424 */  "loadI2L_immI_255",
  /*  425 */  "loadI2L_immI_65535",
  /*  426 */  "loadI2L_immU31",
  /*  427 */  "loadUI2L",
  /*  428 */  "loadL",
  /*  429 */  "loadRange",
  /*  430 */  "loadP",
  /*  431 */  "loadN",
  /*  432 */  "loadKlass",
  /*  433 */  "loadNKlass",
  /*  434 */  "loadF",
  /*  435 */  "loadD_partial",
  /*  436 */  "loadD",
  /*  437 */  "prefetchr",
  /*  438 */  "prefetchrNTA",
  /*  439 */  "prefetchrT0",
  /*  440 */  "prefetchrT2",
  /*  441 */  "prefetchwNTA",
  /*  442 */  "prefetchAlloc",
  /*  443 */  "prefetchAllocNTA",
  /*  444 */  "prefetchAllocT0",
  /*  445 */  "prefetchAllocT2",
  /*  446 */  "storeB",
  /*  447 */  "storeC",
  /*  448 */  "storeI",
  /*  449 */  "storeL",
  /*  450 */  "storeP",
  /*  451 */  "storeImmP0",
  /*  452 */  "storeImmP",
  /*  453 */  "storeN",
  /*  454 */  "storeNKlass",
  /*  455 */  "storeImmN0",
  /*  456 */  "storeImmN",
  /*  457 */  "storeImmNKlass",
  /*  458 */  "storeImmI0",
  /*  459 */  "storeImmI",
  /*  460 */  "storeImmL0",
  /*  461 */  "storeImmL",
  /*  462 */  "storeImmC0",
  /*  463 */  "storeImmI16",
  /*  464 */  "storeImmB0",
  /*  465 */  "storeImmB",
  /*  466 */  "storeImmCM0_reg",
  /*  467 */  "storeImmCM0",
  /*  468 */  "storeF",
  /*  469 */  "storeF0",
  /*  470 */  "storeF_imm",
  /*  471 */  "storeD",
  /*  472 */  "storeD0_imm",
  /*  473 */  "storeD0",
  /*  474 */  "bytes_reverse_int",
  /*  475 */  "bytes_reverse_long",
  /*  476 */  "bytes_reverse_unsigned_short",
  /*  477 */  "bytes_reverse_short",
  /*  478 */  "countLeadingZerosI",
  /*  479 */  "countLeadingZerosI_bsr",
  /*  480 */  "countLeadingZerosL",
  /*  481 */  "countLeadingZerosL_bsr",
  /*  482 */  "countTrailingZerosI",
  /*  483 */  "countTrailingZerosI_bsf",
  /*  484 */  "countTrailingZerosL",
  /*  485 */  "countTrailingZerosL_bsf",
  /*  486 */  "popCountI",
  /*  487 */  "popCountI_mem",
  /*  488 */  "popCountL",
  /*  489 */  "popCountL_mem",
  /*  490 */  "membar_acquire",
  /*  491 */  "membar_acquire_0",
  /*  492 */  "membar_acquire_lock",
  /*  493 */  "membar_release",
  /*  494 */  "membar_release_0",
  /*  495 */  "membar_release_lock",
  /*  496 */  "unnecessary_membar_volatile",
  /*  497 */  "membar_storestore",
  /*  498 */  "convP2I",
  /*  499 */  "convN2I",
  /*  500 */  "encodeHeapOop",
  /*  501 */  "encodeHeapOop_not_null",
  /*  502 */  "decodeHeapOop",
  /*  503 */  "decodeHeapOop_not_null",
  /*  504 */  "encodeKlass_not_null",
  /*  505 */  "decodeKlass_not_null",
  /*  506 */  "jumpXtnd_offset",
  /*  507 */  "jumpXtnd_addr",
  /*  508 */  "jumpXtnd",
  /*  509 */  "cmovI_reg",
  /*  510 */  "cmovI_regU",
  /*  511 */  "cmovI_regUCF",
  /*  512 */  "cmovI_mem",
  /*  513 */  "cmovI_memU",
  /*  514 */  "cmovI_memUCF",
  /*  515 */  "cmovN_reg",
  /*  516 */  "cmovN_regU",
  /*  517 */  "cmovN_regUCF",
  /*  518 */  "cmovP_reg",
  /*  519 */  "cmovP_regU",
  /*  520 */  "cmovP_regUCF",
  /*  521 */  "cmovL_reg",
  /*  522 */  "cmovL_mem",
  /*  523 */  "cmovL_regU",
  /*  524 */  "cmovL_regUCF",
  /*  525 */  "cmovL_memU",
  /*  526 */  "cmovL_memUCF",
  /*  527 */  "cmovF_reg",
  /*  528 */  "cmovF_regU",
  /*  529 */  "cmovF_regUCF",
  /*  530 */  "cmovD_reg",
  /*  531 */  "cmovD_regU",
  /*  532 */  "cmovD_regUCF",
  /*  533 */  "addI_rReg",
  /*  534 */  "addI_rReg_imm",
  /*  535 */  "addI_rReg_mem",
  /*  536 */  "addI_rReg_mem_0",
  /*  537 */  "addI_mem_rReg",
  /*  538 */  "addI_mem_rReg_0",
  /*  539 */  "addI_mem_imm",
  /*  540 */  "incI_rReg",
  /*  541 */  "incI_mem",
  /*  542 */  "decI_rReg",
  /*  543 */  "decI_mem",
  /*  544 */  "leaI_rReg_immI",
  /*  545 */  "addL_rReg",
  /*  546 */  "addL_rReg_imm",
  /*  547 */  "addL_rReg_mem",
  /*  548 */  "addL_rReg_mem_0",
  /*  549 */  "addL_mem_rReg",
  /*  550 */  "addL_mem_rReg_0",
  /*  551 */  "addL_mem_imm",
  /*  552 */  "incL_rReg",
  /*  553 */  "incL_mem",
  /*  554 */  "decL_rReg",
  /*  555 */  "decL_mem",
  /*  556 */  "leaL_rReg_immL",
  /*  557 */  "addP_rReg",
  /*  558 */  "addP_rReg_imm",
  /*  559 */  "leaP_rReg_imm",
  /*  560 */  "loadPLocked",
  /*  561 */  "compareAndSwapP",
  /*  562 */  "compareAndSwapL",
  /*  563 */  "compareAndSwapI",
  /*  564 */  "compareAndSwapN",
  /*  565 */  "xaddI_no_res",
  /*  566 */  "xaddI",
  /*  567 */  "xaddL_no_res",
  /*  568 */  "xaddL",
  /*  569 */  "xchgI",
  /*  570 */  "xchgL",
  /*  571 */  "xchgP",
  /*  572 */  "xchgN",
  /*  573 */  "subI_rReg",
  /*  574 */  "subI_rReg_imm",
  /*  575 */  "subI_rReg_mem",
  /*  576 */  "subI_mem_rReg",
  /*  577 */  "subI_mem_imm",
  /*  578 */  "subL_rReg",
  /*  579 */  "subL_rReg_imm",
  /*  580 */  "subL_rReg_mem",
  /*  581 */  "subL_mem_rReg",
  /*  582 */  "subL_mem_imm",
  /*  583 */  "subP_rReg",
  /*  584 */  "negI_rReg",
  /*  585 */  "negI_mem",
  /*  586 */  "negL_rReg",
  /*  587 */  "negL_mem",
  /*  588 */  "mulI_rReg",
  /*  589 */  "mulI_rReg_imm",
  /*  590 */  "mulI_mem",
  /*  591 */  "mulI_mem_0",
  /*  592 */  "mulI_mem_imm",
  /*  593 */  "mulL_rReg",
  /*  594 */  "mulL_rReg_imm",
  /*  595 */  "mulL_mem",
  /*  596 */  "mulL_mem_0",
  /*  597 */  "mulL_mem_imm",
  /*  598 */  "mulHiL_rReg",
  /*  599 */  "divI_rReg",
  /*  600 */  "divL_rReg",
  /*  601 */  "divModI_rReg_divmod",
  /*  602 */  "divModL_rReg_divmod",
  /*  603 */  "loadConL_0x6666666666666667",
  /*  604 */  "mul_hi",
  /*  605 */  "sarL_rReg_63",
  /*  606 */  "sarL_rReg_2",
  /*  607 */  "divL_10",
  /*  608 */  "modI_rReg",
  /*  609 */  "modL_rReg",
  /*  610 */  "salI_rReg_1",
  /*  611 */  "salI_mem_1",
  /*  612 */  "salI_rReg_imm",
  /*  613 */  "salI_mem_imm",
  /*  614 */  "salI_rReg_CL",
  /*  615 */  "salI_mem_CL",
  /*  616 */  "sarI_rReg_1",
  /*  617 */  "sarI_mem_1",
  /*  618 */  "sarI_rReg_imm",
  /*  619 */  "sarI_mem_imm",
  /*  620 */  "sarI_rReg_CL",
  /*  621 */  "sarI_mem_CL",
  /*  622 */  "shrI_rReg_1",
  /*  623 */  "shrI_mem_1",
  /*  624 */  "shrI_rReg_imm",
  /*  625 */  "shrI_mem_imm",
  /*  626 */  "shrI_rReg_CL",
  /*  627 */  "shrI_mem_CL",
  /*  628 */  "salL_rReg_1",
  /*  629 */  "salL_mem_1",
  /*  630 */  "salL_rReg_imm",
  /*  631 */  "salL_mem_imm",
  /*  632 */  "salL_rReg_CL",
  /*  633 */  "salL_mem_CL",
  /*  634 */  "sarL_rReg_1",
  /*  635 */  "sarL_mem_1",
  /*  636 */  "sarL_rReg_imm",
  /*  637 */  "sarL_mem_imm",
  /*  638 */  "sarL_rReg_CL",
  /*  639 */  "sarL_mem_CL",
  /*  640 */  "shrL_rReg_1",
  /*  641 */  "shrL_mem_1",
  /*  642 */  "shrL_rReg_imm",
  /*  643 */  "shrL_mem_imm",
  /*  644 */  "shrL_rReg_CL",
  /*  645 */  "shrL_mem_CL",
  /*  646 */  "i2b",
  /*  647 */  "i2s",
  /*  648 */  "rolI_rReg_imm1",
  /*  649 */  "rolI_rReg_imm8",
  /*  650 */  "rolI_rReg_CL",
  /*  651 */  "rolI_rReg_i1",
  /*  652 */  "rolI_rReg_i1_0",
  /*  653 */  "rolI_rReg_i8",
  /*  654 */  "rolI_rReg_i8_0",
  /*  655 */  "rolI_rReg_Var_C0",
  /*  656 */  "rolI_rReg_Var_C0_0",
  /*  657 */  "rolI_rReg_Var_C32",
  /*  658 */  "rolI_rReg_Var_C32_0",
  /*  659 */  "rorI_rReg_imm1",
  /*  660 */  "rorI_rReg_imm8",
  /*  661 */  "rorI_rReg_CL",
  /*  662 */  "rorI_rReg_i1",
  /*  663 */  "rorI_rReg_i1_0",
  /*  664 */  "rorI_rReg_i8",
  /*  665 */  "rorI_rReg_i8_0",
  /*  666 */  "rorI_rReg_Var_C0",
  /*  667 */  "rorI_rReg_Var_C0_0",
  /*  668 */  "rorI_rReg_Var_C32",
  /*  669 */  "rorI_rReg_Var_C32_0",
  /*  670 */  "rolL_rReg_imm1",
  /*  671 */  "rolL_rReg_imm8",
  /*  672 */  "rolL_rReg_CL",
  /*  673 */  "rolL_rReg_i1",
  /*  674 */  "rolL_rReg_i1_0",
  /*  675 */  "rolL_rReg_i8",
  /*  676 */  "rolL_rReg_i8_0",
  /*  677 */  "rolL_rReg_Var_C0",
  /*  678 */  "rolL_rReg_Var_C0_0",
  /*  679 */  "rolL_rReg_Var_C64",
  /*  680 */  "rolL_rReg_Var_C64_0",
  /*  681 */  "rorL_rReg_imm1",
  /*  682 */  "rorL_rReg_imm8",
  /*  683 */  "rorL_rReg_CL",
  /*  684 */  "rorL_rReg_i1",
  /*  685 */  "rorL_rReg_i1_0",
  /*  686 */  "rorL_rReg_i8",
  /*  687 */  "rorL_rReg_i8_0",
  /*  688 */  "rorL_rReg_Var_C0",
  /*  689 */  "rorL_rReg_Var_C0_0",
  /*  690 */  "rorL_rReg_Var_C64",
  /*  691 */  "rorL_rReg_Var_C64_0",
  /*  692 */  "andI_rReg",
  /*  693 */  "andI_rReg_imm255",
  /*  694 */  "andI2L_rReg_imm255",
  /*  695 */  "andI_rReg_imm65535",
  /*  696 */  "andI2L_rReg_imm65535",
  /*  697 */  "andI_rReg_imm",
  /*  698 */  "andI_rReg_mem",
  /*  699 */  "andI_rReg_mem_0",
  /*  700 */  "andI_mem_rReg",
  /*  701 */  "andI_mem_rReg_0",
  /*  702 */  "andI_mem_imm",
  /*  703 */  "andnI_rReg_rReg_mem",
  /*  704 */  "andnI_rReg_rReg_mem_0",
  /*  705 */  "andnI_rReg_rReg_rReg",
  /*  706 */  "andnI_rReg_rReg_rReg_0",
  /*  707 */  "blsiI_rReg_rReg",
  /*  708 */  "blsiI_rReg_rReg_0",
  /*  709 */  "blsiI_rReg_mem",
  /*  710 */  "blsiI_rReg_mem_0",
  /*  711 */  "blsmskI_rReg_mem",
  /*  712 */  "blsmskI_rReg_mem_0",
  /*  713 */  "blsmskI_rReg_rReg",
  /*  714 */  "blsmskI_rReg_rReg_0",
  /*  715 */  "blsrI_rReg_rReg",
  /*  716 */  "blsrI_rReg_rReg_0",
  /*  717 */  "blsrI_rReg_mem",
  /*  718 */  "blsrI_rReg_mem_0",
  /*  719 */  "orI_rReg",
  /*  720 */  "orI_rReg_imm",
  /*  721 */  "orI_rReg_mem",
  /*  722 */  "orI_rReg_mem_0",
  /*  723 */  "orI_mem_rReg",
  /*  724 */  "orI_mem_rReg_0",
  /*  725 */  "orI_mem_imm",
  /*  726 */  "xorI_rReg",
  /*  727 */  "xorI_rReg_im1",
  /*  728 */  "xorI_rReg_imm",
  /*  729 */  "xorI_rReg_mem",
  /*  730 */  "xorI_rReg_mem_0",
  /*  731 */  "xorI_mem_rReg",
  /*  732 */  "xorI_mem_rReg_0",
  /*  733 */  "xorI_mem_imm",
  /*  734 */  "andL_rReg",
  /*  735 */  "andL_rReg_imm255",
  /*  736 */  "andL_rReg_imm65535",
  /*  737 */  "andL_rReg_imm",
  /*  738 */  "andL_rReg_mem",
  /*  739 */  "andL_rReg_mem_0",
  /*  740 */  "andL_mem_rReg",
  /*  741 */  "andL_mem_rReg_0",
  /*  742 */  "andL_mem_imm",
  /*  743 */  "andnL_rReg_rReg_mem",
  /*  744 */  "andnL_rReg_rReg_mem_0",
  /*  745 */  "andnL_rReg_rReg_rReg",
  /*  746 */  "andnL_rReg_rReg_rReg_0",
  /*  747 */  "blsiL_rReg_rReg",
  /*  748 */  "blsiL_rReg_rReg_0",
  /*  749 */  "blsiL_rReg_mem",
  /*  750 */  "blsiL_rReg_mem_0",
  /*  751 */  "blsmskL_rReg_mem",
  /*  752 */  "blsmskL_rReg_mem_0",
  /*  753 */  "blsmskL_rReg_rReg",
  /*  754 */  "blsmskL_rReg_rReg_0",
  /*  755 */  "blsrL_rReg_rReg",
  /*  756 */  "blsrL_rReg_rReg_0",
  /*  757 */  "blsrL_rReg_mem",
  /*  758 */  "blsrL_rReg_mem_0",
  /*  759 */  "orL_rReg",
  /*  760 */  "orL_rReg_castP2X",
  /*  761 */  "orL_rReg_castP2X_0",
  /*  762 */  "orL_rReg_imm",
  /*  763 */  "orL_rReg_mem",
  /*  764 */  "orL_rReg_mem_0",
  /*  765 */  "orL_mem_rReg",
  /*  766 */  "orL_mem_rReg_0",
  /*  767 */  "orL_mem_imm",
  /*  768 */  "xorL_rReg",
  /*  769 */  "xorL_rReg_im1",
  /*  770 */  "xorL_rReg_imm",
  /*  771 */  "xorL_rReg_mem",
  /*  772 */  "xorL_rReg_mem_0",
  /*  773 */  "xorL_mem_rReg",
  /*  774 */  "xorL_mem_rReg_0",
  /*  775 */  "xorL_mem_imm",
  /*  776 */  "convI2B",
  /*  777 */  "convP2B",
  /*  778 */  "cmpLTMask",
  /*  779 */  "cmpLTMask0",
  /*  780 */  "cadd_cmpLTMask",
  /*  781 */  "cadd_cmpLTMask_1",
  /*  782 */  "cadd_cmpLTMask_0",
  /*  783 */  "cadd_cmpLTMask_2",
  /*  784 */  "and_cmpLTMask",
  /*  785 */  "and_cmpLTMask_0",
  /*  786 */  "cmpF_reg",
  /*  787 */  "cmpF_mem",
  /*  788 */  "cmpF_imm",
  /*  789 */  "cmpD_reg",
  /*  790 */  "cmpD_mem",
  /*  791 */  "cmpD_imm",
  /*  792 */  "cosD_reg",
  /*  793 */  "sinD_reg",
  /*  794 */  "tanD_reg",
  /*  795 */  "log10D_reg",
  /*  796 */  "logD_reg",
  /*  797 */  "powD_reg",
  /*  798 */  "expD_reg",
  /*  799 */  "convF2D_reg_reg",
  /*  800 */  "convF2D_reg_mem",
  /*  801 */  "convD2F_reg_reg",
  /*  802 */  "convD2F_reg_mem",
  /*  803 */  "convF2I_reg_reg",
  /*  804 */  "convF2L_reg_reg",
  /*  805 */  "convD2I_reg_reg",
  /*  806 */  "convD2L_reg_reg",
  /*  807 */  "convI2F_reg_reg",
  /*  808 */  "convI2F_reg_mem",
  /*  809 */  "convI2D_reg_reg",
  /*  810 */  "convI2D_reg_mem",
  /*  811 */  "convXI2F_reg",
  /*  812 */  "convXI2D_reg",
  /*  813 */  "convL2F_reg_reg",
  /*  814 */  "convL2F_reg_mem",
  /*  815 */  "convL2D_reg_reg",
  /*  816 */  "convL2D_reg_mem",
  /*  817 */  "convI2L_reg_reg",
  /*  818 */  "convI2L_reg_reg_zex",
  /*  819 */  "convI2L_reg_mem_zex",
  /*  820 */  "zerox_long_reg_reg",
  /*  821 */  "convL2I_reg_reg",
  /*  822 */  "MoveF2I_reg_stack",
  /*  823 */  "MoveI2F_reg_stack",
  /*  824 */  "MoveD2L_reg_stack",
  /*  825 */  "MoveL2D_reg_stack",
  /*  826 */  "rep_stos",
  /*  827 */  "rep_fast_stosb",
  /*  828 */  "string_compare",
  /*  829 */  "string_indexof_con",
  /*  830 */  "string_indexof",
  /*  831 */  "string_equals",
  /*  832 */  "array_equals",
  /*  833 */  "encode_iso_array",
  /*  834 */  "cmpL3_reg_reg",
  /*  835 */  "cmovI_reg_g",
  /*  836 */  "minI_rReg",
  /*  837 */  "cmovI_reg_l",
  /*  838 */  "maxI_rReg",
  /*  839 */  "jmpDir",
  /*  840 */  "jmpCon",
  /*  841 */  "jmpLoopEnd",
  /*  842 */  "jmpLoopEndU",
  /*  843 */  "jmpLoopEndUCF",
  /*  844 */  "jmpConU",
  /*  845 */  "jmpConUCF",
  /*  846 */  "jmpConUCF2",
  /*  847 */  "partialSubtypeCheck",
  /*  848 */  "jmpDir_short",
  /*  849 */  "jmpCon_short",
  /*  850 */  "jmpLoopEnd_short",
  /*  851 */  "jmpLoopEndU_short",
  /*  852 */  "jmpLoopEndUCF_short",
  /*  853 */  "jmpConU_short",
  /*  854 */  "jmpConUCF_short",
  /*  855 */  "jmpConUCF2_short",
  /*  856 */  "safePoint_poll_far",
  /*  857 */  "CallStaticJavaDirect",
  /*  858 */  "CallDynamicJavaDirect",
  /*  859 */  "CallRuntimeDirect",
  /*  860 */  "CallLeafDirect",
  /*  861 */  "CallLeafNoFPDirect",
  /*  862 */  "Ret",
  /*  863 */  "TailCalljmpInd",
  /*  864 */  "tailjmpInd",
  /*  865 */  "CreateException",
  /*  866 */  "RethrowException",
  /*  867 */  "ShouldNotReachHere",
  /*  868 */  "addF_reg",
  /*  869 */  "addF_mem",
  /*  870 */  "addF_mem_0",
  /*  871 */  "addF_imm",
  /*  872 */  "addF_reg_reg",
  /*  873 */  "addF_reg_mem",
  /*  874 */  "addF_reg_mem_0",
  /*  875 */  "addF_reg_imm",
  /*  876 */  "addD_reg",
  /*  877 */  "addD_mem",
  /*  878 */  "addD_mem_0",
  /*  879 */  "addD_imm",
  /*  880 */  "addD_reg_reg",
  /*  881 */  "addD_reg_mem",
  /*  882 */  "addD_reg_mem_0",
  /*  883 */  "addD_reg_imm",
  /*  884 */  "subF_reg",
  /*  885 */  "subF_mem",
  /*  886 */  "subF_imm",
  /*  887 */  "subF_reg_reg",
  /*  888 */  "subF_reg_mem",
  /*  889 */  "subF_reg_imm",
  /*  890 */  "subD_reg",
  /*  891 */  "subD_mem",
  /*  892 */  "subD_imm",
  /*  893 */  "subD_reg_reg",
  /*  894 */  "subD_reg_mem",
  /*  895 */  "subD_reg_imm",
  /*  896 */  "mulF_reg",
  /*  897 */  "mulF_mem",
  /*  898 */  "mulF_mem_0",
  /*  899 */  "mulF_imm",
  /*  900 */  "mulF_reg_reg",
  /*  901 */  "mulF_reg_mem",
  /*  902 */  "mulF_reg_mem_0",
  /*  903 */  "mulF_reg_imm",
  /*  904 */  "mulD_reg",
  /*  905 */  "mulD_mem",
  /*  906 */  "mulD_mem_0",
  /*  907 */  "mulD_imm",
  /*  908 */  "mulD_reg_reg",
  /*  909 */  "mulD_reg_mem",
  /*  910 */  "mulD_reg_mem_0",
  /*  911 */  "mulD_reg_imm",
  /*  912 */  "divF_reg",
  /*  913 */  "divF_mem",
  /*  914 */  "divF_imm",
  /*  915 */  "divF_reg_reg",
  /*  916 */  "divF_reg_mem",
  /*  917 */  "divF_reg_imm",
  /*  918 */  "divD_reg",
  /*  919 */  "divD_mem",
  /*  920 */  "divD_imm",
  /*  921 */  "divD_reg_reg",
  /*  922 */  "divD_reg_mem",
  /*  923 */  "divD_reg_imm",
  /*  924 */  "sqrtF_reg",
  /*  925 */  "sqrtF_mem",
  /*  926 */  "sqrtF_imm",
  /*  927 */  "sqrtD_reg",
  /*  928 */  "sqrtD_mem",
  /*  929 */  "sqrtD_imm",
  /*  930 */  "loadV4",
  /*  931 */  "loadV8",
  /*  932 */  "loadV16",
  /*  933 */  "loadV32",
  /*  934 */  "storeV4",
  /*  935 */  "storeV8",
  /*  936 */  "storeV16",
  /*  937 */  "storeV32",
  /*  938 */  "Repl4B",
  /*  939 */  "Repl8B",
  /*  940 */  "Repl16B",
  /*  941 */  "Repl32B",
  /*  942 */  "Repl4B_imm",
  /*  943 */  "Repl8B_imm",
  /*  944 */  "Repl16B_imm",
  /*  945 */  "Repl32B_imm",
  /*  946 */  "Repl4B_zero",
  /*  947 */  "Repl8B_zero",
  /*  948 */  "Repl16B_zero",
  /*  949 */  "Repl32B_zero",
  /*  950 */  "Repl2S",
  /*  951 */  "Repl4S",
  /*  952 */  "Repl8S",
  /*  953 */  "Repl16S",
  /*  954 */  "Repl2S_imm",
  /*  955 */  "Repl4S_imm",
  /*  956 */  "Repl8S_imm",
  /*  957 */  "Repl16S_imm",
  /*  958 */  "Repl2S_zero",
  /*  959 */  "Repl4S_zero",
  /*  960 */  "Repl8S_zero",
  /*  961 */  "Repl16S_zero",
  /*  962 */  "Repl2I",
  /*  963 */  "Repl4I",
  /*  964 */  "Repl8I",
  /*  965 */  "Repl2I_imm",
  /*  966 */  "Repl4I_imm",
  /*  967 */  "Repl8I_imm",
  /*  968 */  "Repl2I_mem",
  /*  969 */  "Repl4I_mem",
  /*  970 */  "Repl8I_mem",
  /*  971 */  "Repl2I_zero",
  /*  972 */  "Repl4I_zero",
  /*  973 */  "Repl8I_zero",
  /*  974 */  "Repl2L",
  /*  975 */  "Repl4L",
  /*  976 */  "Repl2L_imm",
  /*  977 */  "Repl4L_imm",
  /*  978 */  "Repl2L_mem",
  /*  979 */  "Repl4L_mem",
  /*  980 */  "Repl2L_zero",
  /*  981 */  "Repl4L_zero",
  /*  982 */  "Repl2F",
  /*  983 */  "Repl4F",
  /*  984 */  "Repl8F",
  /*  985 */  "Repl2F_zero",
  /*  986 */  "Repl4F_zero",
  /*  987 */  "Repl8F_zero",
  /*  988 */  "Repl2D",
  /*  989 */  "Repl4D",
  /*  990 */  "Repl2D_zero",
  /*  991 */  "Repl4D_zero",
  /*  992 */  "vadd4B",
  /*  993 */  "vadd4B_reg",
  /*  994 */  "vadd8B",
  /*  995 */  "vadd8B_reg",
  /*  996 */  "vadd16B",
  /*  997 */  "vadd16B_reg",
  /*  998 */  "vadd16B_mem",
  /*  999 */  "vadd32B_reg",
  /* 1000 */  "vadd32B_mem",
  /* 1001 */  "vadd2S",
  /* 1002 */  "vadd2S_reg",
  /* 1003 */  "vadd4S",
  /* 1004 */  "vadd4S_reg",
  /* 1005 */  "vadd8S",
  /* 1006 */  "vadd8S_reg",
  /* 1007 */  "vadd8S_mem",
  /* 1008 */  "vadd16S_reg",
  /* 1009 */  "vadd16S_mem",
  /* 1010 */  "vadd2I",
  /* 1011 */  "vadd2I_reg",
  /* 1012 */  "vadd4I",
  /* 1013 */  "vadd4I_reg",
  /* 1014 */  "vadd4I_mem",
  /* 1015 */  "vadd8I_reg",
  /* 1016 */  "vadd8I_mem",
  /* 1017 */  "vadd2L",
  /* 1018 */  "vadd2L_reg",
  /* 1019 */  "vadd2L_mem",
  /* 1020 */  "vadd4L_reg",
  /* 1021 */  "vadd4L_mem",
  /* 1022 */  "vadd2F",
  /* 1023 */  "vadd2F_reg",
  /* 1024 */  "vadd4F",
  /* 1025 */  "vadd4F_reg",
  /* 1026 */  "vadd4F_mem",
  /* 1027 */  "vadd8F_reg",
  /* 1028 */  "vadd8F_mem",
  /* 1029 */  "vadd2D",
  /* 1030 */  "vadd2D_reg",
  /* 1031 */  "vadd2D_mem",
  /* 1032 */  "vadd4D_reg",
  /* 1033 */  "vadd4D_mem",
  /* 1034 */  "vsub4B",
  /* 1035 */  "vsub4B_reg",
  /* 1036 */  "vsub8B",
  /* 1037 */  "vsub8B_reg",
  /* 1038 */  "vsub16B",
  /* 1039 */  "vsub16B_reg",
  /* 1040 */  "vsub16B_mem",
  /* 1041 */  "vsub32B_reg",
  /* 1042 */  "vsub32B_mem",
  /* 1043 */  "vsub2S",
  /* 1044 */  "vsub2S_reg",
  /* 1045 */  "vsub4S",
  /* 1046 */  "vsub4S_reg",
  /* 1047 */  "vsub8S",
  /* 1048 */  "vsub8S_reg",
  /* 1049 */  "vsub8S_mem",
  /* 1050 */  "vsub16S_reg",
  /* 1051 */  "vsub16S_mem",
  /* 1052 */  "vsub2I",
  /* 1053 */  "vsub2I_reg",
  /* 1054 */  "vsub4I",
  /* 1055 */  "vsub4I_reg",
  /* 1056 */  "vsub4I_mem",
  /* 1057 */  "vsub8I_reg",
  /* 1058 */  "vsub8I_mem",
  /* 1059 */  "vsub2L",
  /* 1060 */  "vsub2L_reg",
  /* 1061 */  "vsub2L_mem",
  /* 1062 */  "vsub4L_reg",
  /* 1063 */  "vsub4L_mem",
  /* 1064 */  "vsub2F",
  /* 1065 */  "vsub2F_reg",
  /* 1066 */  "vsub4F",
  /* 1067 */  "vsub4F_reg",
  /* 1068 */  "vsub4F_mem",
  /* 1069 */  "vsub8F_reg",
  /* 1070 */  "vsub8F_mem",
  /* 1071 */  "vsub2D",
  /* 1072 */  "vsub2D_reg",
  /* 1073 */  "vsub2D_mem",
  /* 1074 */  "vsub4D_reg",
  /* 1075 */  "vsub4D_mem",
  /* 1076 */  "vmul2S",
  /* 1077 */  "vmul2S_reg",
  /* 1078 */  "vmul4S",
  /* 1079 */  "vmul4S_reg",
  /* 1080 */  "vmul8S",
  /* 1081 */  "vmul8S_reg",
  /* 1082 */  "vmul8S_mem",
  /* 1083 */  "vmul16S_reg",
  /* 1084 */  "vmul16S_mem",
  /* 1085 */  "vmul2I",
  /* 1086 */  "vmul2I_reg",
  /* 1087 */  "vmul4I",
  /* 1088 */  "vmul4I_reg",
  /* 1089 */  "vmul4I_mem",
  /* 1090 */  "vmul8I_reg",
  /* 1091 */  "vmul8I_mem",
  /* 1092 */  "vmul2F",
  /* 1093 */  "vmul2F_reg",
  /* 1094 */  "vmul4F",
  /* 1095 */  "vmul4F_reg",
  /* 1096 */  "vmul4F_mem",
  /* 1097 */  "vmul8F_reg",
  /* 1098 */  "vmul8F_mem",
  /* 1099 */  "vmul2D",
  /* 1100 */  "vmul2D_reg",
  /* 1101 */  "vmul2D_mem",
  /* 1102 */  "vmul4D_reg",
  /* 1103 */  "vmul4D_mem",
  /* 1104 */  "vdiv2F",
  /* 1105 */  "vdiv2F_reg",
  /* 1106 */  "vdiv4F",
  /* 1107 */  "vdiv4F_reg",
  /* 1108 */  "vdiv4F_mem",
  /* 1109 */  "vdiv8F_reg",
  /* 1110 */  "vdiv8F_mem",
  /* 1111 */  "vdiv2D",
  /* 1112 */  "vdiv2D_reg",
  /* 1113 */  "vdiv2D_mem",
  /* 1114 */  "vdiv4D_reg",
  /* 1115 */  "vdiv4D_mem",
  /* 1116 */  "vsll2S",
  /* 1117 */  "vsll2S_imm",
  /* 1118 */  "vsll2S_reg",
  /* 1119 */  "vsll2S_reg_imm",
  /* 1120 */  "vsll4S",
  /* 1121 */  "vsll4S_imm",
  /* 1122 */  "vsll4S_reg",
  /* 1123 */  "vsll4S_reg_imm",
  /* 1124 */  "vsll8S",
  /* 1125 */  "vsll8S_imm",
  /* 1126 */  "vsll8S_reg",
  /* 1127 */  "vsll8S_reg_imm",
  /* 1128 */  "vsll16S_reg",
  /* 1129 */  "vsll16S_reg_imm",
  /* 1130 */  "vsll2I",
  /* 1131 */  "vsll2I_imm",
  /* 1132 */  "vsll2I_reg",
  /* 1133 */  "vsll2I_reg_imm",
  /* 1134 */  "vsll4I",
  /* 1135 */  "vsll4I_imm",
  /* 1136 */  "vsll4I_reg",
  /* 1137 */  "vsll4I_reg_imm",
  /* 1138 */  "vsll8I_reg",
  /* 1139 */  "vsll8I_reg_imm",
  /* 1140 */  "vsll2L",
  /* 1141 */  "vsll2L_imm",
  /* 1142 */  "vsll2L_reg",
  /* 1143 */  "vsll2L_reg_imm",
  /* 1144 */  "vsll4L_reg",
  /* 1145 */  "vsll4L_reg_imm",
  /* 1146 */  "vsrl2S",
  /* 1147 */  "vsrl2S_imm",
  /* 1148 */  "vsrl2S_reg",
  /* 1149 */  "vsrl2S_reg_imm",
  /* 1150 */  "vsrl4S",
  /* 1151 */  "vsrl4S_imm",
  /* 1152 */  "vsrl4S_reg",
  /* 1153 */  "vsrl4S_reg_imm",
  /* 1154 */  "vsrl8S",
  /* 1155 */  "vsrl8S_imm",
  /* 1156 */  "vsrl8S_reg",
  /* 1157 */  "vsrl8S_reg_imm",
  /* 1158 */  "vsrl16S_reg",
  /* 1159 */  "vsrl16S_reg_imm",
  /* 1160 */  "vsrl2I",
  /* 1161 */  "vsrl2I_imm",
  /* 1162 */  "vsrl2I_reg",
  /* 1163 */  "vsrl2I_reg_imm",
  /* 1164 */  "vsrl4I",
  /* 1165 */  "vsrl4I_imm",
  /* 1166 */  "vsrl4I_reg",
  /* 1167 */  "vsrl4I_reg_imm",
  /* 1168 */  "vsrl8I_reg",
  /* 1169 */  "vsrl8I_reg_imm",
  /* 1170 */  "vsrl2L",
  /* 1171 */  "vsrl2L_imm",
  /* 1172 */  "vsrl2L_reg",
  /* 1173 */  "vsrl2L_reg_imm",
  /* 1174 */  "vsrl4L_reg",
  /* 1175 */  "vsrl4L_reg_imm",
  /* 1176 */  "vsra2S",
  /* 1177 */  "vsra2S_imm",
  /* 1178 */  "vsra2S_reg",
  /* 1179 */  "vsra2S_reg_imm",
  /* 1180 */  "vsra4S",
  /* 1181 */  "vsra4S_imm",
  /* 1182 */  "vsra4S_reg",
  /* 1183 */  "vsra4S_reg_imm",
  /* 1184 */  "vsra8S",
  /* 1185 */  "vsra8S_imm",
  /* 1186 */  "vsra8S_reg",
  /* 1187 */  "vsra8S_reg_imm",
  /* 1188 */  "vsra16S_reg",
  /* 1189 */  "vsra16S_reg_imm",
  /* 1190 */  "vsra2I",
  /* 1191 */  "vsra2I_imm",
  /* 1192 */  "vsra2I_reg",
  /* 1193 */  "vsra2I_reg_imm",
  /* 1194 */  "vsra4I",
  /* 1195 */  "vsra4I_imm",
  /* 1196 */  "vsra4I_reg",
  /* 1197 */  "vsra4I_reg_imm",
  /* 1198 */  "vsra8I_reg",
  /* 1199 */  "vsra8I_reg_imm",
  /* 1200 */  "vand4B",
  /* 1201 */  "vand4B_reg",
  /* 1202 */  "vand8B",
  /* 1203 */  "vand8B_reg",
  /* 1204 */  "vand16B",
  /* 1205 */  "vand16B_reg",
  /* 1206 */  "vand16B_mem",
  /* 1207 */  "vand32B_reg",
  /* 1208 */  "vand32B_mem",
  /* 1209 */  "vor4B",
  /* 1210 */  "vor4B_reg",
  /* 1211 */  "vor8B",
  /* 1212 */  "vor8B_reg",
  /* 1213 */  "vor16B",
  /* 1214 */  "vor16B_reg",
  /* 1215 */  "vor16B_mem",
  /* 1216 */  "vor32B_reg",
  /* 1217 */  "vor32B_mem",
  /* 1218 */  "vxor4B",
  /* 1219 */  "vxor4B_reg",
  /* 1220 */  "vxor8B",
  /* 1221 */  "vxor8B_reg",
  /* 1222 */  "vxor16B",
  /* 1223 */  "vxor16B_reg",
  /* 1224 */  "vxor16B_mem",
  /* 1225 */  "vxor32B_reg",
  /* 1226 */  "vxor32B_mem",
  // last instruction
  "invalid rule name" // no trailing comma
};

const        bool  swallowed[] = {
  /*    0 */  false,
  /*    1 */  false,
  /*    2 */  false,
  /*    3 */  false,
  /*    4 */  false,
  /*    5 */  false,
  /*    6 */  false,
  /*    7 */  false,
  /*    8 */  true,
  /*    9 */  true,
  /*   10 */  true,
  /*   11 */  true,
  /*   12 */  true,
  /*   13 */  true,
  /*   14 */  true,
  /*   15 */  true,
  /*   16 */  true,
  /*   17 */  true,
  /*   18 */  true,
  /*   19 */  true,
  /*   20 */  true,
  /*   21 */  true,
  /*   22 */  true,
  /*   23 */  true,
  /*   24 */  true,
  /*   25 */  true,
  /*   26 */  true,
  /*   27 */  true,
  /*   28 */  true,
  /*   29 */  true,
  /*   30 */  true,
  /*   31 */  true,
  /*   32 */  true,
  /*   33 */  true,
  /*   34 */  true,
  /*   35 */  true,
  /*   36 */  true,
  /*   37 */  true,
  /*   38 */  true,
  /*   39 */  true,
  /*   40 */  true,
  /*   41 */  true,
  /*   42 */  true,
  /*   43 */  true,
  /*   44 */  false,
  /*   45 */  false,
  /*   46 */  false,
  /*   47 */  false,
  /*   48 */  false,
  /*   49 */  false,
  /*   50 */  false,
  /*   51 */  false,
  /*   52 */  false,
  /*   53 */  false,
  /*   54 */  false,
  /*   55 */  false,
  /*   56 */  false,
  /*   57 */  false,
  /*   58 */  false,
  /*   59 */  false,
  /*   60 */  false,
  /*   61 */  false,
  /*   62 */  false,
  /*   63 */  false,
  /*   64 */  false,
  /*   65 */  false,
  /*   66 */  false,
  /*   67 */  false,
  /*   68 */  false,
  /*   69 */  false,
  /*   70 */  false,
  /*   71 */  false,
  /*   72 */  false,
  /*   73 */  false,
  /*   74 */  false,
  /*   75 */  false,
  /*   76 */  false,
  /*   77 */  false,
  /*   78 */  false,
  /*   79 */  false,
  /*   80 */  false,
  /*   81 */  false,
  /*   82 */  false,
  /*   83 */  false,
  /*   84 */  false,
  /*   85 */  false,
  /*   86 */  false,
  /*   87 */  false,
  /*   88 */  false,
  /*   89 */  false,
  /*   90 */  false,
  /*   91 */  false,
  /*   92 */  false,
  /*   93 */  false,
  /*   94 */  false,
  /*   95 */  false,
  /*   96 */  false,
  /*   97 */  false,
  /*   98 */  true,
  /*   99 */  true,
  /*  100 */  true,
  /*  101 */  true,
  /*  102 */  false,
  /*  103 */  false,
  /*  104 */  false,
  /*  105 */  false,
  // last operand
  /*  106 */  false,
  // last operand class
  /*  107 */  false,
  /*  108 */  false,
  /*  109 */  false,
  /*  110 */  false,
  /*  111 */  false,
  /*  112 */  false,
  /*  113 */  false,
  /*  114 */  false,
  /*  115 */  false,
  /*  116 */  false,
  /*  117 */  false,
  /*  118 */  false,
  /*  119 */  false,
  /*  120 */  false,
  /*  121 */  false,
  /*  122 */  false,
  /*  123 */  false,
  /*  124 */  false,
  /*  125 */  false,
  /*  126 */  false,
  /*  127 */  false,
  /*  128 */  false,
  /*  129 */  false,
  /*  130 */  false,
  /*  131 */  false,
  /*  132 */  false,
  /*  133 */  false,
  /*  134 */  false,
  /*  135 */  false,
  /*  136 */  false,
  /*  137 */  false,
  /*  138 */  false,
  /*  139 */  false,
  /*  140 */  false,
  /*  141 */  false,
  /*  142 */  false,
  /*  143 */  false,
  /*  144 */  false,
  /*  145 */  false,
  /*  146 */  false,
  /*  147 */  false,
  /*  148 */  false,
  /*  149 */  false,
  /*  150 */  false,
  /*  151 */  false,
  /*  152 */  false,
  /*  153 */  false,
  /*  154 */  false,
  /*  155 */  false,
  /*  156 */  false,
  /*  157 */  false,
  /*  158 */  false,
  /*  159 */  false,
  /*  160 */  false,
  /*  161 */  false,
  /*  162 */  false,
  /*  163 */  false,
  /*  164 */  false,
  /*  165 */  false,
  /*  166 */  false,
  /*  167 */  false,
  /*  168 */  false,
  /*  169 */  false,
  /*  170 */  false,
  /*  171 */  false,
  /*  172 */  false,
  /*  173 */  false,
  /*  174 */  false,
  /*  175 */  false,
  /*  176 */  false,
  /*  177 */  false,
  /*  178 */  false,
  /*  179 */  false,
  /*  180 */  false,
  /*  181 */  false,
  /*  182 */  false,
  /*  183 */  false,
  /*  184 */  false,
  /*  185 */  false,
  /*  186 */  false,
  /*  187 */  false,
  /*  188 */  false,
  /*  189 */  false,
  /*  190 */  false,
  /*  191 */  false,
  /*  192 */  false,
  /*  193 */  false,
  /*  194 */  false,
  /*  195 */  false,
  /*  196 */  false,
  /*  197 */  false,
  /*  198 */  false,
  /*  199 */  false,
  /*  200 */  false,
  /*  201 */  false,
  /*  202 */  false,
  /*  203 */  false,
  /*  204 */  false,
  /*  205 */  false,
  /*  206 */  false,
  /*  207 */  false,
  /*  208 */  false,
  /*  209 */  false,
  /*  210 */  false,
  /*  211 */  false,
  /*  212 */  false,
  /*  213 */  false,
  /*  214 */  false,
  /*  215 */  false,
  /*  216 */  false,
  /*  217 */  false,
  /*  218 */  false,
  /*  219 */  false,
  /*  220 */  false,
  /*  221 */  false,
  /*  222 */  false,
  /*  223 */  false,
  /*  224 */  false,
  /*  225 */  false,
  /*  226 */  false,
  /*  227 */  false,
  /*  228 */  false,
  /*  229 */  false,
  /*  230 */  false,
  /*  231 */  false,
  /*  232 */  false,
  /*  233 */  false,
  /*  234 */  false,
  /*  235 */  false,
  /*  236 */  false,
  /*  237 */  false,
  /*  238 */  false,
  /*  239 */  false,
  /*  240 */  false,
  /*  241 */  false,
  /*  242 */  false,
  /*  243 */  false,
  /*  244 */  false,
  /*  245 */  false,
  /*  246 */  false,
  /*  247 */  false,
  /*  248 */  false,
  /*  249 */  false,
  /*  250 */  false,
  /*  251 */  false,
  /*  252 */  false,
  /*  253 */  false,
  /*  254 */  false,
  /*  255 */  false,
  /*  256 */  false,
  /*  257 */  false,
  /*  258 */  false,
  /*  259 */  false,
  /*  260 */  false,
  /*  261 */  false,
  /*  262 */  false,
  /*  263 */  false,
  /*  264 */  false,
  /*  265 */  false,
  /*  266 */  false,
  // last internally defined operand
  /*  267 */  false,
  /*  268 */  false,
  /*  269 */  false,
  /*  270 */  false,
  /*  271 */  false,
  /*  272 */  false,
  /*  273 */  false,
  /*  274 */  false,
  /*  275 */  false,
  /*  276 */  false,
  /*  277 */  false,
  /*  278 */  false,
  /*  279 */  false,
  /*  280 */  false,
  /*  281 */  false,
  /*  282 */  false,
  /*  283 */  false,
  /*  284 */  false,
  /*  285 */  false,
  /*  286 */  false,
  /*  287 */  false,
  /*  288 */  false,
  /*  289 */  false,
  /*  290 */  false,
  /*  291 */  false,
  /*  292 */  false,
  /*  293 */  false,
  /*  294 */  false,
  /*  295 */  false,
  /*  296 */  false,
  /*  297 */  false,
  /*  298 */  false,
  /*  299 */  false,
  /*  300 */  false,
  /*  301 */  false,
  /*  302 */  false,
  /*  303 */  false,
  /*  304 */  false,
  /*  305 */  false,
  /*  306 */  false,
  /*  307 */  false,
  /*  308 */  false,
  /*  309 */  false,
  /*  310 */  false,
  /*  311 */  false,
  /*  312 */  false,
  /*  313 */  false,
  /*  314 */  false,
  /*  315 */  false,
  /*  316 */  false,
  /*  317 */  false,
  /*  318 */  false,
  /*  319 */  false,
  /*  320 */  false,
  /*  321 */  false,
  /*  322 */  false,
  /*  323 */  false,
  /*  324 */  false,
  /*  325 */  false,
  /*  326 */  false,
  /*  327 */  false,
  /*  328 */  false,
  /*  329 */  false,
  /*  330 */  false,
  /*  331 */  false,
  /*  332 */  false,
  /*  333 */  false,
  /*  334 */  false,
  /*  335 */  false,
  /*  336 */  false,
  /*  337 */  false,
  /*  338 */  false,
  /*  339 */  false,
  /*  340 */  false,
  /*  341 */  false,
  /*  342 */  false,
  /*  343 */  false,
  /*  344 */  false,
  /*  345 */  false,
  /*  346 */  false,
  /*  347 */  false,
  /*  348 */  false,
  /*  349 */  false,
  /*  350 */  false,
  /*  351 */  false,
  /*  352 */  false,
  /*  353 */  false,
  /*  354 */  false,
  /*  355 */  false,
  /*  356 */  false,
  /*  357 */  false,
  /*  358 */  false,
  /*  359 */  false,
  /*  360 */  false,
  /*  361 */  false,
  /*  362 */  false,
  /*  363 */  false,
  /*  364 */  false,
  /*  365 */  false,
  /*  366 */  false,
  /*  367 */  false,
  /*  368 */  false,
  /*  369 */  false,
  /*  370 */  false,
  /*  371 */  false,
  /*  372 */  false,
  /*  373 */  false,
  /*  374 */  false,
  /*  375 */  false,
  /*  376 */  false,
  /*  377 */  false,
  /*  378 */  false,
  /*  379 */  false,
  /*  380 */  false,
  /*  381 */  false,
  /*  382 */  false,
  /*  383 */  false,
  /*  384 */  false,
  /*  385 */  false,
  /*  386 */  false,
  /*  387 */  false,
  /*  388 */  false,
  /*  389 */  false,
  /*  390 */  false,
  /*  391 */  false,
  /*  392 */  false,
  /*  393 */  false,
  /*  394 */  false,
  /*  395 */  false,
  /*  396 */  false,
  /*  397 */  false,
  /*  398 */  false,
  /*  399 */  false,
  /*  400 */  false,
  /*  401 */  false,
  /*  402 */  false,
  /*  403 */  false,
  /*  404 */  false,
  /*  405 */  false,
  /*  406 */  false,
  /*  407 */  false,
  /*  408 */  false,
  /*  409 */  false,
  /*  410 */  false,
  /*  411 */  false,
  /*  412 */  false,
  /*  413 */  false,
  /*  414 */  false,
  /*  415 */  false,
  /*  416 */  false,
  /*  417 */  false,
  /*  418 */  false,
  /*  419 */  false,
  /*  420 */  false,
  /*  421 */  false,
  /*  422 */  false,
  /*  423 */  false,
  /*  424 */  false,
  /*  425 */  false,
  /*  426 */  false,
  /*  427 */  false,
  /*  428 */  false,
  /*  429 */  false,
  /*  430 */  false,
  /*  431 */  false,
  /*  432 */  false,
  /*  433 */  false,
  /*  434 */  false,
  /*  435 */  false,
  /*  436 */  false,
  /*  437 */  false,
  /*  438 */  false,
  /*  439 */  false,
  /*  440 */  false,
  /*  441 */  false,
  /*  442 */  false,
  /*  443 */  false,
  /*  444 */  false,
  /*  445 */  false,
  /*  446 */  false,
  /*  447 */  false,
  /*  448 */  false,
  /*  449 */  false,
  /*  450 */  false,
  /*  451 */  false,
  /*  452 */  false,
  /*  453 */  false,
  /*  454 */  false,
  /*  455 */  false,
  /*  456 */  false,
  /*  457 */  false,
  /*  458 */  false,
  /*  459 */  false,
  /*  460 */  false,
  /*  461 */  false,
  /*  462 */  false,
  /*  463 */  false,
  /*  464 */  false,
  /*  465 */  false,
  /*  466 */  false,
  /*  467 */  false,
  /*  468 */  false,
  /*  469 */  false,
  /*  470 */  false,
  /*  471 */  false,
  /*  472 */  false,
  /*  473 */  false,
  /*  474 */  false,
  /*  475 */  false,
  /*  476 */  false,
  /*  477 */  false,
  /*  478 */  false,
  /*  479 */  false,
  /*  480 */  false,
  /*  481 */  false,
  /*  482 */  false,
  /*  483 */  false,
  /*  484 */  false,
  /*  485 */  false,
  /*  486 */  false,
  /*  487 */  false,
  /*  488 */  false,
  /*  489 */  false,
  /*  490 */  false,
  /*  491 */  false,
  /*  492 */  false,
  /*  493 */  false,
  /*  494 */  false,
  /*  495 */  false,
  /*  496 */  false,
  /*  497 */  false,
  /*  498 */  false,
  /*  499 */  false,
  /*  500 */  false,
  /*  501 */  false,
  /*  502 */  false,
  /*  503 */  false,
  /*  504 */  false,
  /*  505 */  false,
  /*  506 */  false,
  /*  507 */  false,
  /*  508 */  false,
  /*  509 */  false,
  /*  510 */  false,
  /*  511 */  false,
  /*  512 */  false,
  /*  513 */  false,
  /*  514 */  false,
  /*  515 */  false,
  /*  516 */  false,
  /*  517 */  false,
  /*  518 */  false,
  /*  519 */  false,
  /*  520 */  false,
  /*  521 */  false,
  /*  522 */  false,
  /*  523 */  false,
  /*  524 */  false,
  /*  525 */  false,
  /*  526 */  false,
  /*  527 */  false,
  /*  528 */  false,
  /*  529 */  false,
  /*  530 */  false,
  /*  531 */  false,
  /*  532 */  false,
  /*  533 */  false,
  /*  534 */  false,
  /*  535 */  false,
  /*  536 */  false,
  /*  537 */  false,
  /*  538 */  false,
  /*  539 */  false,
  /*  540 */  false,
  /*  541 */  false,
  /*  542 */  false,
  /*  543 */  false,
  /*  544 */  false,
  /*  545 */  false,
  /*  546 */  false,
  /*  547 */  false,
  /*  548 */  false,
  /*  549 */  false,
  /*  550 */  false,
  /*  551 */  false,
  /*  552 */  false,
  /*  553 */  false,
  /*  554 */  false,
  /*  555 */  false,
  /*  556 */  false,
  /*  557 */  false,
  /*  558 */  false,
  /*  559 */  false,
  /*  560 */  false,
  /*  561 */  false,
  /*  562 */  false,
  /*  563 */  false,
  /*  564 */  false,
  /*  565 */  false,
  /*  566 */  false,
  /*  567 */  false,
  /*  568 */  false,
  /*  569 */  false,
  /*  570 */  false,
  /*  571 */  false,
  /*  572 */  false,
  /*  573 */  false,
  /*  574 */  false,
  /*  575 */  false,
  /*  576 */  false,
  /*  577 */  false,
  /*  578 */  false,
  /*  579 */  false,
  /*  580 */  false,
  /*  581 */  false,
  /*  582 */  false,
  /*  583 */  false,
  /*  584 */  false,
  /*  585 */  false,
  /*  586 */  false,
  /*  587 */  false,
  /*  588 */  false,
  /*  589 */  false,
  /*  590 */  false,
  /*  591 */  false,
  /*  592 */  false,
  /*  593 */  false,
  /*  594 */  false,
  /*  595 */  false,
  /*  596 */  false,
  /*  597 */  false,
  /*  598 */  false,
  /*  599 */  false,
  /*  600 */  false,
  /*  601 */  false,
  /*  602 */  false,
  /*  603 */  false,
  /*  604 */  false,
  /*  605 */  false,
  /*  606 */  false,
  /*  607 */  false,
  /*  608 */  false,
  /*  609 */  false,
  /*  610 */  false,
  /*  611 */  false,
  /*  612 */  false,
  /*  613 */  false,
  /*  614 */  false,
  /*  615 */  false,
  /*  616 */  false,
  /*  617 */  false,
  /*  618 */  false,
  /*  619 */  false,
  /*  620 */  false,
  /*  621 */  false,
  /*  622 */  false,
  /*  623 */  false,
  /*  624 */  false,
  /*  625 */  false,
  /*  626 */  false,
  /*  627 */  false,
  /*  628 */  false,
  /*  629 */  false,
  /*  630 */  false,
  /*  631 */  false,
  /*  632 */  false,
  /*  633 */  false,
  /*  634 */  false,
  /*  635 */  false,
  /*  636 */  false,
  /*  637 */  false,
  /*  638 */  false,
  /*  639 */  false,
  /*  640 */  false,
  /*  641 */  false,
  /*  642 */  false,
  /*  643 */  false,
  /*  644 */  false,
  /*  645 */  false,
  /*  646 */  false,
  /*  647 */  false,
  /*  648 */  false,
  /*  649 */  false,
  /*  650 */  false,
  /*  651 */  false,
  /*  652 */  false,
  /*  653 */  false,
  /*  654 */  false,
  /*  655 */  false,
  /*  656 */  false,
  /*  657 */  false,
  /*  658 */  false,
  /*  659 */  false,
  /*  660 */  false,
  /*  661 */  false,
  /*  662 */  false,
  /*  663 */  false,
  /*  664 */  false,
  /*  665 */  false,
  /*  666 */  false,
  /*  667 */  false,
  /*  668 */  false,
  /*  669 */  false,
  /*  670 */  false,
  /*  671 */  false,
  /*  672 */  false,
  /*  673 */  false,
  /*  674 */  false,
  /*  675 */  false,
  /*  676 */  false,
  /*  677 */  false,
  /*  678 */  false,
  /*  679 */  false,
  /*  680 */  false,
  /*  681 */  false,
  /*  682 */  false,
  /*  683 */  false,
  /*  684 */  false,
  /*  685 */  false,
  /*  686 */  false,
  /*  687 */  false,
  /*  688 */  false,
  /*  689 */  false,
  /*  690 */  false,
  /*  691 */  false,
  /*  692 */  false,
  /*  693 */  false,
  /*  694 */  false,
  /*  695 */  false,
  /*  696 */  false,
  /*  697 */  false,
  /*  698 */  false,
  /*  699 */  false,
  /*  700 */  false,
  /*  701 */  false,
  /*  702 */  false,
  /*  703 */  false,
  /*  704 */  false,
  /*  705 */  false,
  /*  706 */  false,
  /*  707 */  false,
  /*  708 */  false,
  /*  709 */  false,
  /*  710 */  false,
  /*  711 */  false,
  /*  712 */  false,
  /*  713 */  false,
  /*  714 */  false,
  /*  715 */  false,
  /*  716 */  false,
  /*  717 */  false,
  /*  718 */  false,
  /*  719 */  false,
  /*  720 */  false,
  /*  721 */  false,
  /*  722 */  false,
  /*  723 */  false,
  /*  724 */  false,
  /*  725 */  false,
  /*  726 */  false,
  /*  727 */  false,
  /*  728 */  false,
  /*  729 */  false,
  /*  730 */  false,
  /*  731 */  false,
  /*  732 */  false,
  /*  733 */  false,
  /*  734 */  false,
  /*  735 */  false,
  /*  736 */  false,
  /*  737 */  false,
  /*  738 */  false,
  /*  739 */  false,
  /*  740 */  false,
  /*  741 */  false,
  /*  742 */  false,
  /*  743 */  false,
  /*  744 */  false,
  /*  745 */  false,
  /*  746 */  false,
  /*  747 */  false,
  /*  748 */  false,
  /*  749 */  false,
  /*  750 */  false,
  /*  751 */  false,
  /*  752 */  false,
  /*  753 */  false,
  /*  754 */  false,
  /*  755 */  false,
  /*  756 */  false,
  /*  757 */  false,
  /*  758 */  false,
  /*  759 */  false,
  /*  760 */  false,
  /*  761 */  false,
  /*  762 */  false,
  /*  763 */  false,
  /*  764 */  false,
  /*  765 */  false,
  /*  766 */  false,
  /*  767 */  false,
  /*  768 */  false,
  /*  769 */  false,
  /*  770 */  false,
  /*  771 */  false,
  /*  772 */  false,
  /*  773 */  false,
  /*  774 */  false,
  /*  775 */  false,
  /*  776 */  false,
  /*  777 */  false,
  /*  778 */  false,
  /*  779 */  false,
  /*  780 */  false,
  /*  781 */  false,
  /*  782 */  false,
  /*  783 */  false,
  /*  784 */  false,
  /*  785 */  false,
  /*  786 */  false,
  /*  787 */  false,
  /*  788 */  false,
  /*  789 */  false,
  /*  790 */  false,
  /*  791 */  false,
  /*  792 */  false,
  /*  793 */  false,
  /*  794 */  false,
  /*  795 */  false,
  /*  796 */  false,
  /*  797 */  false,
  /*  798 */  false,
  /*  799 */  false,
  /*  800 */  false,
  /*  801 */  false,
  /*  802 */  false,
  /*  803 */  false,
  /*  804 */  false,
  /*  805 */  false,
  /*  806 */  false,
  /*  807 */  false,
  /*  808 */  false,
  /*  809 */  false,
  /*  810 */  false,
  /*  811 */  false,
  /*  812 */  false,
  /*  813 */  false,
  /*  814 */  false,
  /*  815 */  false,
  /*  816 */  false,
  /*  817 */  false,
  /*  818 */  false,
  /*  819 */  false,
  /*  820 */  false,
  /*  821 */  false,
  /*  822 */  false,
  /*  823 */  false,
  /*  824 */  false,
  /*  825 */  false,
  /*  826 */  false,
  /*  827 */  false,
  /*  828 */  false,
  /*  829 */  false,
  /*  830 */  false,
  /*  831 */  false,
  /*  832 */  false,
  /*  833 */  false,
  /*  834 */  false,
  /*  835 */  false,
  /*  836 */  false,
  /*  837 */  false,
  /*  838 */  false,
  /*  839 */  false,
  /*  840 */  false,
  /*  841 */  false,
  /*  842 */  false,
  /*  843 */  false,
  /*  844 */  false,
  /*  845 */  false,
  /*  846 */  false,
  /*  847 */  false,
  /*  848 */  false,
  /*  849 */  false,
  /*  850 */  false,
  /*  851 */  false,
  /*  852 */  false,
  /*  853 */  false,
  /*  854 */  false,
  /*  855 */  false,
  /*  856 */  false,
  /*  857 */  false,
  /*  858 */  false,
  /*  859 */  false,
  /*  860 */  false,
  /*  861 */  false,
  /*  862 */  false,
  /*  863 */  false,
  /*  864 */  false,
  /*  865 */  false,
  /*  866 */  false,
  /*  867 */  false,
  /*  868 */  false,
  /*  869 */  false,
  /*  870 */  false,
  /*  871 */  false,
  /*  872 */  false,
  /*  873 */  false,
  /*  874 */  false,
  /*  875 */  false,
  /*  876 */  false,
  /*  877 */  false,
  /*  878 */  false,
  /*  879 */  false,
  /*  880 */  false,
  /*  881 */  false,
  /*  882 */  false,
  /*  883 */  false,
  /*  884 */  false,
  /*  885 */  false,
  /*  886 */  false,
  /*  887 */  false,
  /*  888 */  false,
  /*  889 */  false,
  /*  890 */  false,
  /*  891 */  false,
  /*  892 */  false,
  /*  893 */  false,
  /*  894 */  false,
  /*  895 */  false,
  /*  896 */  false,
  /*  897 */  false,
  /*  898 */  false,
  /*  899 */  false,
  /*  900 */  false,
  /*  901 */  false,
  /*  902 */  false,
  /*  903 */  false,
  /*  904 */  false,
  /*  905 */  false,
  /*  906 */  false,
  /*  907 */  false,
  /*  908 */  false,
  /*  909 */  false,
  /*  910 */  false,
  /*  911 */  false,
  /*  912 */  false,
  /*  913 */  false,
  /*  914 */  false,
  /*  915 */  false,
  /*  916 */  false,
  /*  917 */  false,
  /*  918 */  false,
  /*  919 */  false,
  /*  920 */  false,
  /*  921 */  false,
  /*  922 */  false,
  /*  923 */  false,
  /*  924 */  false,
  /*  925 */  false,
  /*  926 */  false,
  /*  927 */  false,
  /*  928 */  false,
  /*  929 */  false,
  /*  930 */  false,
  /*  931 */  false,
  /*  932 */  false,
  /*  933 */  false,
  /*  934 */  false,
  /*  935 */  false,
  /*  936 */  false,
  /*  937 */  false,
  /*  938 */  false,
  /*  939 */  false,
  /*  940 */  false,
  /*  941 */  false,
  /*  942 */  false,
  /*  943 */  false,
  /*  944 */  false,
  /*  945 */  false,
  /*  946 */  false,
  /*  947 */  false,
  /*  948 */  false,
  /*  949 */  false,
  /*  950 */  false,
  /*  951 */  false,
  /*  952 */  false,
  /*  953 */  false,
  /*  954 */  false,
  /*  955 */  false,
  /*  956 */  false,
  /*  957 */  false,
  /*  958 */  false,
  /*  959 */  false,
  /*  960 */  false,
  /*  961 */  false,
  /*  962 */  false,
  /*  963 */  false,
  /*  964 */  false,
  /*  965 */  false,
  /*  966 */  false,
  /*  967 */  false,
  /*  968 */  false,
  /*  969 */  false,
  /*  970 */  false,
  /*  971 */  false,
  /*  972 */  false,
  /*  973 */  false,
  /*  974 */  false,
  /*  975 */  false,
  /*  976 */  false,
  /*  977 */  false,
  /*  978 */  false,
  /*  979 */  false,
  /*  980 */  false,
  /*  981 */  false,
  /*  982 */  false,
  /*  983 */  false,
  /*  984 */  false,
  /*  985 */  false,
  /*  986 */  false,
  /*  987 */  false,
  /*  988 */  false,
  /*  989 */  false,
  /*  990 */  false,
  /*  991 */  false,
  /*  992 */  false,
  /*  993 */  false,
  /*  994 */  false,
  /*  995 */  false,
  /*  996 */  false,
  /*  997 */  false,
  /*  998 */  false,
  /*  999 */  false,
  /* 1000 */  false,
  /* 1001 */  false,
  /* 1002 */  false,
  /* 1003 */  false,
  /* 1004 */  false,
  /* 1005 */  false,
  /* 1006 */  false,
  /* 1007 */  false,
  /* 1008 */  false,
  /* 1009 */  false,
  /* 1010 */  false,
  /* 1011 */  false,
  /* 1012 */  false,
  /* 1013 */  false,
  /* 1014 */  false,
  /* 1015 */  false,
  /* 1016 */  false,
  /* 1017 */  false,
  /* 1018 */  false,
  /* 1019 */  false,
  /* 1020 */  false,
  /* 1021 */  false,
  /* 1022 */  false,
  /* 1023 */  false,
  /* 1024 */  false,
  /* 1025 */  false,
  /* 1026 */  false,
  /* 1027 */  false,
  /* 1028 */  false,
  /* 1029 */  false,
  /* 1030 */  false,
  /* 1031 */  false,
  /* 1032 */  false,
  /* 1033 */  false,
  /* 1034 */  false,
  /* 1035 */  false,
  /* 1036 */  false,
  /* 1037 */  false,
  /* 1038 */  false,
  /* 1039 */  false,
  /* 1040 */  false,
  /* 1041 */  false,
  /* 1042 */  false,
  /* 1043 */  false,
  /* 1044 */  false,
  /* 1045 */  false,
  /* 1046 */  false,
  /* 1047 */  false,
  /* 1048 */  false,
  /* 1049 */  false,
  /* 1050 */  false,
  /* 1051 */  false,
  /* 1052 */  false,
  /* 1053 */  false,
  /* 1054 */  false,
  /* 1055 */  false,
  /* 1056 */  false,
  /* 1057 */  false,
  /* 1058 */  false,
  /* 1059 */  false,
  /* 1060 */  false,
  /* 1061 */  false,
  /* 1062 */  false,
  /* 1063 */  false,
  /* 1064 */  false,
  /* 1065 */  false,
  /* 1066 */  false,
  /* 1067 */  false,
  /* 1068 */  false,
  /* 1069 */  false,
  /* 1070 */  false,
  /* 1071 */  false,
  /* 1072 */  false,
  /* 1073 */  false,
  /* 1074 */  false,
  /* 1075 */  false,
  /* 1076 */  false,
  /* 1077 */  false,
  /* 1078 */  false,
  /* 1079 */  false,
  /* 1080 */  false,
  /* 1081 */  false,
  /* 1082 */  false,
  /* 1083 */  false,
  /* 1084 */  false,
  /* 1085 */  false,
  /* 1086 */  false,
  /* 1087 */  false,
  /* 1088 */  false,
  /* 1089 */  false,
  /* 1090 */  false,
  /* 1091 */  false,
  /* 1092 */  false,
  /* 1093 */  false,
  /* 1094 */  false,
  /* 1095 */  false,
  /* 1096 */  false,
  /* 1097 */  false,
  /* 1098 */  false,
  /* 1099 */  false,
  /* 1100 */  false,
  /* 1101 */  false,
  /* 1102 */  false,
  /* 1103 */  false,
  /* 1104 */  false,
  /* 1105 */  false,
  /* 1106 */  false,
  /* 1107 */  false,
  /* 1108 */  false,
  /* 1109 */  false,
  /* 1110 */  false,
  /* 1111 */  false,
  /* 1112 */  false,
  /* 1113 */  false,
  /* 1114 */  false,
  /* 1115 */  false,
  /* 1116 */  false,
  /* 1117 */  false,
  /* 1118 */  false,
  /* 1119 */  false,
  /* 1120 */  false,
  /* 1121 */  false,
  /* 1122 */  false,
  /* 1123 */  false,
  /* 1124 */  false,
  /* 1125 */  false,
  /* 1126 */  false,
  /* 1127 */  false,
  /* 1128 */  false,
  /* 1129 */  false,
  /* 1130 */  false,
  /* 1131 */  false,
  /* 1132 */  false,
  /* 1133 */  false,
  /* 1134 */  false,
  /* 1135 */  false,
  /* 1136 */  false,
  /* 1137 */  false,
  /* 1138 */  false,
  /* 1139 */  false,
  /* 1140 */  false,
  /* 1141 */  false,
  /* 1142 */  false,
  /* 1143 */  false,
  /* 1144 */  false,
  /* 1145 */  false,
  /* 1146 */  false,
  /* 1147 */  false,
  /* 1148 */  false,
  /* 1149 */  false,
  /* 1150 */  false,
  /* 1151 */  false,
  /* 1152 */  false,
  /* 1153 */  false,
  /* 1154 */  false,
  /* 1155 */  false,
  /* 1156 */  false,
  /* 1157 */  false,
  /* 1158 */  false,
  /* 1159 */  false,
  /* 1160 */  false,
  /* 1161 */  false,
  /* 1162 */  false,
  /* 1163 */  false,
  /* 1164 */  false,
  /* 1165 */  false,
  /* 1166 */  false,
  /* 1167 */  false,
  /* 1168 */  false,
  /* 1169 */  false,
  /* 1170 */  false,
  /* 1171 */  false,
  /* 1172 */  false,
  /* 1173 */  false,
  /* 1174 */  false,
  /* 1175 */  false,
  /* 1176 */  false,
  /* 1177 */  false,
  /* 1178 */  false,
  /* 1179 */  false,
  /* 1180 */  false,
  /* 1181 */  false,
  /* 1182 */  false,
  /* 1183 */  false,
  /* 1184 */  false,
  /* 1185 */  false,
  /* 1186 */  false,
  /* 1187 */  false,
  /* 1188 */  false,
  /* 1189 */  false,
  /* 1190 */  false,
  /* 1191 */  false,
  /* 1192 */  false,
  /* 1193 */  false,
  /* 1194 */  false,
  /* 1195 */  false,
  /* 1196 */  false,
  /* 1197 */  false,
  /* 1198 */  false,
  /* 1199 */  false,
  /* 1200 */  false,
  /* 1201 */  false,
  /* 1202 */  false,
  /* 1203 */  false,
  /* 1204 */  false,
  /* 1205 */  false,
  /* 1206 */  false,
  /* 1207 */  false,
  /* 1208 */  false,
  /* 1209 */  false,
  /* 1210 */  false,
  /* 1211 */  false,
  /* 1212 */  false,
  /* 1213 */  false,
  /* 1214 */  false,
  /* 1215 */  false,
  /* 1216 */  false,
  /* 1217 */  false,
  /* 1218 */  false,
  /* 1219 */  false,
  /* 1220 */  false,
  /* 1221 */  false,
  /* 1222 */  false,
  /* 1223 */  false,
  /* 1224 */  false,
  /* 1225 */  false,
  /* 1226 */  false,
  // last instruction
  false // no trailing comma
};

// Mapping from machine-independent opcode to boolean
const        char must_clone[] = {
  0, // Node: 0
  0, // Set: 1
  0, // RegN: 2
  0, // RegI: 3
  0, // RegP: 4
  0, // RegF: 5
  0, // RegD: 6
  0, // RegL: 7
  0, // RegFlags: 8
  0, // VecS: 9
  0, // VecD: 10
  0, // VecX: 11
  0, // VecY: 12
  0, // _last_machine_leaf: 13
  0, // AbsD: 14
  0, // AbsF: 15
  0, // AbsI: 16
  0, // AddD: 17
  0, // AddF: 18
  0, // AddI: 19
  0, // AddL: 20
  0, // AddP: 21
  0, // Allocate: 22
  0, // AllocateArray: 23
  0, // AndI: 24
  0, // AndL: 25
  0, // AryEq: 26
  0, // AtanD: 27
  1, // Binary: 28
  1, // Bool: 29
  0, // BoxLock: 30
  0, // ReverseBytesI: 31
  0, // ReverseBytesL: 32
  0, // ReverseBytesUS: 33
  0, // ReverseBytesS: 34
  0, // CProj: 35
  0, // CallDynamicJava: 36
  0, // CallJava: 37
  0, // CallLeaf: 38
  0, // CallLeafNoFP: 39
  0, // CallRuntime: 40
  0, // CallStaticJava: 41
  0, // CastII: 42
  0, // CastX2P: 43
  0, // CastP2X: 44
  0, // CastPP: 45
  0, // Catch: 46
  0, // CatchProj: 47
  0, // CheckCastPP: 48
  0, // ClearArray: 49
  0, // ConstraintCast: 50
  0, // CMoveD: 51
  0, // CMoveF: 52
  0, // CMoveI: 53
  0, // CMoveL: 54
  0, // CMoveP: 55
  0, // CMoveN: 56
  1, // CmpN: 57
  1, // CmpD: 58
  0, // CmpD3: 59
  1, // CmpF: 60
  0, // CmpF3: 61
  1, // CmpI: 62
  1, // CmpL: 63
  0, // CmpL3: 64
  0, // CmpLTMask: 65
  1, // CmpP: 66
  1, // CmpU: 67
  1, // CmpUL: 68
  0, // CompareAndSwapI: 69
  0, // CompareAndSwapL: 70
  0, // CompareAndSwapP: 71
  0, // CompareAndSwapN: 72
  0, // GetAndAddI: 73
  0, // GetAndAddL: 74
  0, // GetAndSetI: 75
  0, // GetAndSetL: 76
  0, // GetAndSetP: 77
  0, // GetAndSetN: 78
  0, // Con: 79
  0, // ConN: 80
  0, // ConNKlass: 81
  0, // ConD: 82
  0, // ConF: 83
  0, // ConI: 84
  0, // ConL: 85
  0, // ConP: 86
  0, // Conv2B: 87
  0, // ConvD2F: 88
  0, // ConvD2I: 89
  0, // ConvD2L: 90
  0, // ConvF2D: 91
  0, // ConvF2I: 92
  0, // ConvF2L: 93
  0, // ConvI2D: 94
  0, // ConvI2F: 95
  0, // ConvI2L: 96
  0, // ConvL2D: 97
  0, // ConvL2F: 98
  0, // ConvL2I: 99
  0, // CosD: 100
  0, // CountedLoop: 101
  0, // CountedLoopEnd: 102
  0, // CountLeadingZerosI: 103
  0, // CountLeadingZerosL: 104
  0, // CountTrailingZerosI: 105
  0, // CountTrailingZerosL: 106
  0, // CreateEx: 107
  0, // DecodeN: 108
  0, // DecodeNKlass: 109
  0, // DivD: 110
  0, // DivF: 111
  0, // DivI: 112
  0, // DivL: 113
  0, // DivMod: 114
  0, // DivModI: 115
  0, // DivModL: 116
  0, // EncodeISOArray: 117
  0, // EncodeP: 118
  0, // EncodePKlass: 119
  0, // ExpD: 120
  1, // FastLock: 121
  1, // FastUnlock: 122
  0, // Goto: 123
  0, // Halt: 124
  0, // If: 125
  0, // IfFalse: 126
  0, // IfTrue: 127
  0, // Initialize: 128
  0, // JProj: 129
  0, // Jump: 130
  0, // JumpProj: 131
  0, // LShiftI: 132
  0, // LShiftL: 133
  0, // LoadB: 134
  0, // LoadUB: 135
  0, // LoadUS: 136
  0, // LoadD: 137
  0, // LoadD_unaligned: 138
  0, // LoadF: 139
  0, // LoadI: 140
  0, // LoadKlass: 141
  0, // LoadNKlass: 142
  0, // LoadL: 143
  0, // LoadL_unaligned: 144
  0, // LoadPLocked: 145
  0, // LoadP: 146
  0, // LoadN: 147
  0, // LoadRange: 148
  0, // LoadS: 149
  0, // Lock: 150
  0, // LogD: 151
  0, // Log10D: 152
  0, // Loop: 153
  0, // LoopLimit: 154
  0, // Mach: 155
  0, // MachProj: 156
  0, // MaxI: 157
  0, // MemBarAcquire: 158
  0, // LoadFence: 159
  0, // MemBarAcquireLock: 160
  0, // MemBarCPUOrder: 161
  0, // MemBarRelease: 162
  0, // StoreFence: 163
  0, // MemBarReleaseLock: 164
  0, // MemBarVolatile: 165
  0, // MemBarStoreStore: 166
  0, // MergeMem: 167
  0, // MinI: 168
  0, // ModD: 169
  0, // ModF: 170
  0, // ModI: 171
  0, // ModL: 172
  0, // MoveI2F: 173
  0, // MoveF2I: 174
  0, // MoveL2D: 175
  0, // MoveD2L: 176
  0, // MulD: 177
  0, // MulF: 178
  0, // MulHiL: 179
  0, // MulI: 180
  0, // MulL: 181
  0, // Multi: 182
  0, // NegD: 183
  0, // NegF: 184
  0, // NeverBranch: 185
  0, // Opaque1: 186
  0, // Opaque2: 187
  0, // Opaque3: 188
  0, // ProfileBoolean: 189
  0, // OrI: 190
  0, // OrL: 191
  1, // OverflowAddI: 192
  1, // OverflowSubI: 193
  1, // OverflowMulI: 194
  1, // OverflowAddL: 195
  1, // OverflowSubL: 196
  1, // OverflowMulL: 197
  0, // PCTable: 198
  0, // Parm: 199
  0, // PartialSubtypeCheck: 200
  0, // Phi: 201
  0, // PopCountI: 202
  0, // PopCountL: 203
  0, // PowD: 204
  0, // PrefetchAllocation: 205
  0, // PrefetchRead: 206
  0, // PrefetchWrite: 207
  0, // Proj: 208
  0, // RShiftI: 209
  0, // RShiftL: 210
  0, // Region: 211
  0, // Rethrow: 212
  0, // Return: 213
  0, // Root: 214
  0, // RoundDouble: 215
  0, // RoundFloat: 216
  0, // SafePoint: 217
  0, // SafePointScalarObject: 218
  0, // SCMemProj: 219
  0, // SinD: 220
  0, // SqrtD: 221
  0, // Start: 222
  0, // StartOSR: 223
  0, // StoreB: 224
  0, // StoreC: 225
  0, // StoreCM: 226
  0, // StorePConditional: 227
  0, // StoreIConditional: 228
  0, // StoreLConditional: 229
  0, // StoreD: 230
  0, // StoreF: 231
  0, // StoreI: 232
  0, // StoreL: 233
  0, // StoreP: 234
  0, // StoreN: 235
  0, // StoreNKlass: 236
  0, // StrComp: 237
  0, // StrEquals: 238
  0, // StrIndexOf: 239
  0, // SubD: 240
  0, // SubF: 241
  0, // SubI: 242
  0, // SubL: 243
  0, // TailCall: 244
  0, // TailJump: 245
  0, // TanD: 246
  0, // ThreadLocal: 247
  0, // Unlock: 248
  0, // URShiftI: 249
  0, // URShiftL: 250
  0, // XorI: 251
  0, // XorL: 252
  0, // Vector: 253
  0, // AddVB: 254
  0, // AddVS: 255
  0, // AddVI: 256
  0, // AddVL: 257
  0, // AddVF: 258
  0, // AddVD: 259
  0, // SubVB: 260
  0, // SubVS: 261
  0, // SubVI: 262
  0, // SubVL: 263
  0, // SubVF: 264
  0, // SubVD: 265
  0, // MulVS: 266
  0, // MulVI: 267
  0, // MulVF: 268
  0, // MulVD: 269
  0, // DivVF: 270
  0, // DivVD: 271
  0, // LShiftCntV: 272
  0, // RShiftCntV: 273
  0, // LShiftVB: 274
  0, // LShiftVS: 275
  0, // LShiftVI: 276
  0, // LShiftVL: 277
  0, // RShiftVB: 278
  0, // RShiftVS: 279
  0, // RShiftVI: 280
  0, // RShiftVL: 281
  0, // URShiftVB: 282
  0, // URShiftVS: 283
  0, // URShiftVI: 284
  0, // URShiftVL: 285
  0, // AndV: 286
  0, // OrV: 287
  0, // XorV: 288
  0, // LoadVector: 289
  0, // StoreVector: 290
  0, // Pack: 291
  0, // PackB: 292
  0, // PackS: 293
  0, // PackI: 294
  0, // PackL: 295
  0, // PackF: 296
  0, // PackD: 297
  0, // Pack2L: 298
  0, // Pack2D: 299
  0, // ReplicateB: 300
  0, // ReplicateS: 301
  0, // ReplicateI: 302
  0, // ReplicateL: 303
  0, // ReplicateF: 304
  0, // ReplicateD: 305
  0, // Extract: 306
  0, // ExtractB: 307
  0, // ExtractUB: 308
  0, // ExtractC: 309
  0, // ExtractS: 310
  0, // ExtractI: 311
  0, // ExtractL: 312
  0, // ExtractF: 313
  0 // no trailing comma // ExtractD: 314
};
//  The following instructions can cisc-spill
//  popCountI can cisc-spill operand 1 to popCountI_mem
//  popCountL can cisc-spill operand 1 to popCountL_mem
//  cmovI_reg can cisc-spill operand 4 to cmovI_mem
//  cmovI_regU can cisc-spill operand 4 to cmovI_memU
//  cmovI_regUCF can cisc-spill operand 4 to cmovI_memUCF
//  cmovL_reg can cisc-spill operand 4 to cmovL_mem
//  cmovL_regU can cisc-spill operand 4 to cmovL_memU
//  cmovL_regUCF can cisc-spill operand 4 to cmovL_memUCF
//  addI_rReg can cisc-spill operand 2 to addI_rReg_mem
//  addL_rReg can cisc-spill operand 2 to addL_rReg_mem
//  subI_rReg can cisc-spill operand 2 to subI_rReg_mem
//  subL_rReg can cisc-spill operand 2 to subL_rReg_mem
//  mulI_rReg can cisc-spill operand 2 to mulI_mem
//  mulI_rReg_imm can cisc-spill operand 1 to mulI_mem_imm
//  mulL_rReg can cisc-spill operand 2 to mulL_mem
//  mulL_rReg_imm can cisc-spill operand 1 to mulL_mem_imm
//  i2b can cisc-spill operand 1 to loadI2B
//  i2s can cisc-spill operand 1 to loadI2S
//  andI_rReg can cisc-spill operand 2 to andI_rReg_mem
//  andI2L_rReg_imm255 can cisc-spill operand 1 to loadI2L_immI_255
//  andI2L_rReg_imm65535 can cisc-spill operand 1 to loadI2L_immI_65535
//  andnI_rReg_rReg_rReg can cisc-spill operand 3 to andnI_rReg_rReg_mem
//  andnI_rReg_rReg_rReg_0 can cisc-spill operand 1 to andnI_rReg_rReg_mem_0
//  orI_rReg can cisc-spill operand 2 to orI_rReg_mem
//  xorI_rReg can cisc-spill operand 2 to xorI_rReg_mem
//  andL_rReg can cisc-spill operand 2 to andL_rReg_mem
//  andnL_rReg_rReg_rReg can cisc-spill operand 3 to andnL_rReg_rReg_mem
//  andnL_rReg_rReg_rReg_0 can cisc-spill operand 1 to andnL_rReg_rReg_mem_0
//  orL_rReg can cisc-spill operand 2 to orL_rReg_mem
//  xorL_rReg can cisc-spill operand 2 to xorL_rReg_mem
//  cmpF_cc_reg can cisc-spill operand 2 to cmpF_cc_mem
//  cmpF_cc_reg_CF can cisc-spill operand 2 to cmpF_cc_memCF
//  cmpD_cc_reg can cisc-spill operand 2 to cmpD_cc_mem
//  cmpD_cc_reg_CF can cisc-spill operand 2 to cmpD_cc_memCF
//  cmpF_reg can cisc-spill operand 2 to cmpF_mem
//  cmpD_reg can cisc-spill operand 2 to cmpD_mem
//  convF2D_reg_reg can cisc-spill operand 1 to convF2D_reg_mem
//  convD2F_reg_reg can cisc-spill operand 1 to convD2F_reg_mem
//  convL2F_reg_reg can cisc-spill operand 1 to convL2F_reg_mem
//  convL2D_reg_reg can cisc-spill operand 1 to convL2D_reg_mem
//  convI2L_reg_reg can cisc-spill operand 1 to loadI2L
//  convI2L_reg_reg_zex can cisc-spill operand 1 to loadUI2L
//  MoveF2I_reg_reg can cisc-spill operand 1 to MoveF2I_stack_reg
//  MoveD2L_reg_reg can cisc-spill operand 1 to MoveD2L_stack_reg
//  MoveI2F_reg_reg can cisc-spill operand 1 to MoveI2F_stack_reg
//  compI_rReg can cisc-spill operand 2 to compI_rReg_mem
//  compU_rReg can cisc-spill operand 2 to compU_rReg_mem
//  compP_rReg can cisc-spill operand 2 to compP_rReg_mem
//  compL_rReg can cisc-spill operand 2 to compL_rReg_mem
//  compUL_rReg can cisc-spill operand 2 to compUL_rReg_mem
//  addF_reg can cisc-spill operand 2 to addF_mem
//  addF_reg_reg can cisc-spill operand 2 to addF_reg_mem
//  addD_reg can cisc-spill operand 2 to addD_mem
//  addD_reg_reg can cisc-spill operand 2 to addD_reg_mem
//  subF_reg can cisc-spill operand 2 to subF_mem
//  subF_reg_reg can cisc-spill operand 2 to subF_reg_mem
//  subD_reg can cisc-spill operand 2 to subD_mem
//  subD_reg_reg can cisc-spill operand 2 to subD_reg_mem
//  mulF_reg can cisc-spill operand 2 to mulF_mem
//  mulF_reg_reg can cisc-spill operand 2 to mulF_reg_mem
//  mulD_reg can cisc-spill operand 2 to mulD_mem
//  mulD_reg_reg can cisc-spill operand 2 to mulD_reg_mem
//  divF_reg can cisc-spill operand 2 to divF_mem
//  divF_reg_reg can cisc-spill operand 2 to divF_reg_mem
//  divD_reg can cisc-spill operand 2 to divD_mem
//  divD_reg_reg can cisc-spill operand 2 to divD_reg_mem
//  sqrtF_reg can cisc-spill operand 1 to sqrtF_mem
//  sqrtD_reg can cisc-spill operand 1 to sqrtD_mem
//  Repl2I can cisc-spill operand 1 to Repl2I_mem
//  Repl4I can cisc-spill operand 1 to Repl4I_mem
//  Repl8I can cisc-spill operand 1 to Repl8I_mem
//  Repl2L can cisc-spill operand 1 to Repl2L_mem
//  Repl4L can cisc-spill operand 1 to Repl4L_mem



// An array of character pointers to machine register names.
const char *Matcher::regName[REG_COUNT] = {
  "R10",
  "R10_H",
  "R11",
  "R11_H",
  "R8",
  "R8_H",
  "R9",
  "R9_H",
  "R12",
  "R12_H",
  "RCX",
  "RCX_H",
  "RBX",
  "RBX_H",
  "RDI",
  "RDI_H",
  "RDX",
  "RDX_H",
  "RSI",
  "RSI_H",
  "RAX",
  "RAX_H",
  "RBP",
  "RBP_H",
  "R13",
  "R13_H",
  "R14",
  "R14_H",
  "R15",
  "R15_H",
  "RSP",
  "RSP_H",
  "XMM0",
  "XMM0b",
  "XMM0c",
  "XMM0d",
  "XMM0e",
  "XMM0f",
  "XMM0g",
  "XMM0h",
  "XMM1",
  "XMM1b",
  "XMM1c",
  "XMM1d",
  "XMM1e",
  "XMM1f",
  "XMM1g",
  "XMM1h",
  "XMM2",
  "XMM2b",
  "XMM2c",
  "XMM2d",
  "XMM2e",
  "XMM2f",
  "XMM2g",
  "XMM2h",
  "XMM3",
  "XMM3b",
  "XMM3c",
  "XMM3d",
  "XMM3e",
  "XMM3f",
  "XMM3g",
  "XMM3h",
  "XMM4",
  "XMM4b",
  "XMM4c",
  "XMM4d",
  "XMM4e",
  "XMM4f",
  "XMM4g",
  "XMM4h",
  "XMM5",
  "XMM5b",
  "XMM5c",
  "XMM5d",
  "XMM5e",
  "XMM5f",
  "XMM5g",
  "XMM5h",
  "XMM6",
  "XMM6b",
  "XMM6c",
  "XMM6d",
  "XMM6e",
  "XMM6f",
  "XMM6g",
  "XMM6h",
  "XMM7",
  "XMM7b",
  "XMM7c",
  "XMM7d",
  "XMM7e",
  "XMM7f",
  "XMM7g",
  "XMM7h",
  "XMM8",
  "XMM8b",
  "XMM8c",
  "XMM8d",
  "XMM8e",
  "XMM8f",
  "XMM8g",
  "XMM8h",
  "XMM9",
  "XMM9b",
  "XMM9c",
  "XMM9d",
  "XMM9e",
  "XMM9f",
  "XMM9g",
  "XMM9h",
  "XMM10",
  "XMM10b",
  "XMM10c",
  "XMM10d",
  "XMM10e",
  "XMM10f",
  "XMM10g",
  "XMM10h",
  "XMM11",
  "XMM11b",
  "XMM11c",
  "XMM11d",
  "XMM11e",
  "XMM11f",
  "XMM11g",
  "XMM11h",
  "XMM12",
  "XMM12b",
  "XMM12c",
  "XMM12d",
  "XMM12e",
  "XMM12f",
  "XMM12g",
  "XMM12h",
  "XMM13",
  "XMM13b",
  "XMM13c",
  "XMM13d",
  "XMM13e",
  "XMM13f",
  "XMM13g",
  "XMM13h",
  "XMM14",
  "XMM14b",
  "XMM14c",
  "XMM14d",
  "XMM14e",
  "XMM14f",
  "XMM14g",
  "XMM14h",
  "XMM15",
  "XMM15b",
  "XMM15c",
  "XMM15d",
  "XMM15e",
  "XMM15f",
  "XMM15g",
  "XMM15h",
  "RFLAGS" // no trailing comma
};

// An array of character pointers to machine register names.
const VMReg OptoReg::opto2vm[REG_COUNT] = {
	r10->as_VMReg(),
	r10->as_VMReg()->next(),
	r11->as_VMReg(),
	r11->as_VMReg()->next(),
	r8->as_VMReg(),
	r8->as_VMReg()->next(),
	r9->as_VMReg(),
	r9->as_VMReg()->next(),
	r12->as_VMReg(),
	r12->as_VMReg()->next(),
	rcx->as_VMReg(),
	rcx->as_VMReg()->next(),
	rbx->as_VMReg(),
	rbx->as_VMReg()->next(),
	rdi->as_VMReg(),
	rdi->as_VMReg()->next(),
	rdx->as_VMReg(),
	rdx->as_VMReg()->next(),
	rsi->as_VMReg(),
	rsi->as_VMReg()->next(),
	rax->as_VMReg(),
	rax->as_VMReg()->next(),
	rbp->as_VMReg(),
	rbp->as_VMReg()->next(),
	r13->as_VMReg(),
	r13->as_VMReg()->next(),
	r14->as_VMReg(),
	r14->as_VMReg()->next(),
	r15->as_VMReg(),
	r15->as_VMReg()->next(),
	rsp->as_VMReg(),
	rsp->as_VMReg()->next(),
	xmm0->as_VMReg(),
	xmm0->as_VMReg()->next(1),
	xmm0->as_VMReg()->next(2),
	xmm0->as_VMReg()->next(3),
	xmm0->as_VMReg()->next(4),
	xmm0->as_VMReg()->next(5),
	xmm0->as_VMReg()->next(6),
	xmm0->as_VMReg()->next(7),
	xmm1->as_VMReg(),
	xmm1->as_VMReg()->next(1),
	xmm1->as_VMReg()->next(2),
	xmm1->as_VMReg()->next(3),
	xmm1->as_VMReg()->next(4),
	xmm1->as_VMReg()->next(5),
	xmm1->as_VMReg()->next(6),
	xmm1->as_VMReg()->next(7),
	xmm2->as_VMReg(),
	xmm2->as_VMReg()->next(1),
	xmm2->as_VMReg()->next(2),
	xmm2->as_VMReg()->next(3),
	xmm2->as_VMReg()->next(4),
	xmm2->as_VMReg()->next(5),
	xmm2->as_VMReg()->next(6),
	xmm2->as_VMReg()->next(7),
	xmm3->as_VMReg(),
	xmm3->as_VMReg()->next(1),
	xmm3->as_VMReg()->next(2),
	xmm3->as_VMReg()->next(3),
	xmm3->as_VMReg()->next(4),
	xmm3->as_VMReg()->next(5),
	xmm3->as_VMReg()->next(6),
	xmm3->as_VMReg()->next(7),
	xmm4->as_VMReg(),
	xmm4->as_VMReg()->next(1),
	xmm4->as_VMReg()->next(2),
	xmm4->as_VMReg()->next(3),
	xmm4->as_VMReg()->next(4),
	xmm4->as_VMReg()->next(5),
	xmm4->as_VMReg()->next(6),
	xmm4->as_VMReg()->next(7),
	xmm5->as_VMReg(),
	xmm5->as_VMReg()->next(1),
	xmm5->as_VMReg()->next(2),
	xmm5->as_VMReg()->next(3),
	xmm5->as_VMReg()->next(4),
	xmm5->as_VMReg()->next(5),
	xmm5->as_VMReg()->next(6),
	xmm5->as_VMReg()->next(7),
	xmm6->as_VMReg(),
	xmm6->as_VMReg()->next(1),
	xmm6->as_VMReg()->next(2),
	xmm6->as_VMReg()->next(3),
	xmm6->as_VMReg()->next(4),
	xmm6->as_VMReg()->next(5),
	xmm6->as_VMReg()->next(6),
	xmm6->as_VMReg()->next(7),
	xmm7->as_VMReg(),
	xmm7->as_VMReg()->next(1),
	xmm7->as_VMReg()->next(2),
	xmm7->as_VMReg()->next(3),
	xmm7->as_VMReg()->next(4),
	xmm7->as_VMReg()->next(5),
	xmm7->as_VMReg()->next(6),
	xmm7->as_VMReg()->next(7),
	xmm8->as_VMReg(),
	xmm8->as_VMReg()->next(1),
	xmm8->as_VMReg()->next(2),
	xmm8->as_VMReg()->next(3),
	xmm8->as_VMReg()->next(4),
	xmm8->as_VMReg()->next(5),
	xmm8->as_VMReg()->next(6),
	xmm8->as_VMReg()->next(7),
	xmm9->as_VMReg(),
	xmm9->as_VMReg()->next(1),
	xmm9->as_VMReg()->next(2),
	xmm9->as_VMReg()->next(3),
	xmm9->as_VMReg()->next(4),
	xmm9->as_VMReg()->next(5),
	xmm9->as_VMReg()->next(6),
	xmm9->as_VMReg()->next(7),
	xmm10->as_VMReg(),
	xmm10->as_VMReg()->next(1),
	xmm10->as_VMReg()->next(2),
	xmm10->as_VMReg()->next(3),
	xmm10->as_VMReg()->next(4),
	xmm10->as_VMReg()->next(5),
	xmm10->as_VMReg()->next(6),
	xmm10->as_VMReg()->next(7),
	xmm11->as_VMReg(),
	xmm11->as_VMReg()->next(1),
	xmm11->as_VMReg()->next(2),
	xmm11->as_VMReg()->next(3),
	xmm11->as_VMReg()->next(4),
	xmm11->as_VMReg()->next(5),
	xmm11->as_VMReg()->next(6),
	xmm11->as_VMReg()->next(7),
	xmm12->as_VMReg(),
	xmm12->as_VMReg()->next(1),
	xmm12->as_VMReg()->next(2),
	xmm12->as_VMReg()->next(3),
	xmm12->as_VMReg()->next(4),
	xmm12->as_VMReg()->next(5),
	xmm12->as_VMReg()->next(6),
	xmm12->as_VMReg()->next(7),
	xmm13->as_VMReg(),
	xmm13->as_VMReg()->next(1),
	xmm13->as_VMReg()->next(2),
	xmm13->as_VMReg()->next(3),
	xmm13->as_VMReg()->next(4),
	xmm13->as_VMReg()->next(5),
	xmm13->as_VMReg()->next(6),
	xmm13->as_VMReg()->next(7),
	xmm14->as_VMReg(),
	xmm14->as_VMReg()->next(1),
	xmm14->as_VMReg()->next(2),
	xmm14->as_VMReg()->next(3),
	xmm14->as_VMReg()->next(4),
	xmm14->as_VMReg()->next(5),
	xmm14->as_VMReg()->next(6),
	xmm14->as_VMReg()->next(7),
	xmm15->as_VMReg(),
	xmm15->as_VMReg()->next(1),
	xmm15->as_VMReg()->next(2),
	xmm15->as_VMReg()->next(3),
	xmm15->as_VMReg()->next(4),
	xmm15->as_VMReg()->next(5),
	xmm15->as_VMReg()->next(6),
	xmm15->as_VMReg()->next(7),
	VMRegImpl::Bad() // no trailing comma
	};

 OptoReg::Name OptoReg::vm2opto[ConcreteRegisterImpl::number_of_registers];

// An array of the machine register encode values
const unsigned char Matcher::_regEncode[REG_COUNT] = {
  (unsigned char)'\xA',  // R10
  (unsigned char)'\xA',  // R10_H
  (unsigned char)'\xB',  // R11
  (unsigned char)'\xB',  // R11_H
  (unsigned char)'\x8',  // R8
  (unsigned char)'\x8',  // R8_H
  (unsigned char)'\x9',  // R9
  (unsigned char)'\x9',  // R9_H
  (unsigned char)'\xC',  // R12
  (unsigned char)'\xC',  // R12_H
  (unsigned char)'\x1',  // RCX
  (unsigned char)'\x1',  // RCX_H
  (unsigned char)'\x3',  // RBX
  (unsigned char)'\x3',  // RBX_H
  (unsigned char)'\x7',  // RDI
  (unsigned char)'\x7',  // RDI_H
  (unsigned char)'\x2',  // RDX
  (unsigned char)'\x2',  // RDX_H
  (unsigned char)'\x6',  // RSI
  (unsigned char)'\x6',  // RSI_H
  (unsigned char)'\x0',  // RAX
  (unsigned char)'\x0',  // RAX_H
  (unsigned char)'\x5',  // RBP
  (unsigned char)'\x5',  // RBP_H
  (unsigned char)'\xD',  // R13
  (unsigned char)'\xD',  // R13_H
  (unsigned char)'\xE',  // R14
  (unsigned char)'\xE',  // R14_H
  (unsigned char)'\xF',  // R15
  (unsigned char)'\xF',  // R15_H
  (unsigned char)'\x4',  // RSP
  (unsigned char)'\x4',  // RSP_H
  (unsigned char)'\x0',  // XMM0
  (unsigned char)'\x0',  // XMM0b
  (unsigned char)'\x0',  // XMM0c
  (unsigned char)'\x0',  // XMM0d
  (unsigned char)'\x0',  // XMM0e
  (unsigned char)'\x0',  // XMM0f
  (unsigned char)'\x0',  // XMM0g
  (unsigned char)'\x0',  // XMM0h
  (unsigned char)'\x1',  // XMM1
  (unsigned char)'\x1',  // XMM1b
  (unsigned char)'\x1',  // XMM1c
  (unsigned char)'\x1',  // XMM1d
  (unsigned char)'\x1',  // XMM1e
  (unsigned char)'\x1',  // XMM1f
  (unsigned char)'\x1',  // XMM1g
  (unsigned char)'\x1',  // XMM1h
  (unsigned char)'\x2',  // XMM2
  (unsigned char)'\x2',  // XMM2b
  (unsigned char)'\x2',  // XMM2c
  (unsigned char)'\x2',  // XMM2d
  (unsigned char)'\x2',  // XMM2e
  (unsigned char)'\x2',  // XMM2f
  (unsigned char)'\x2',  // XMM2g
  (unsigned char)'\x2',  // XMM2h
  (unsigned char)'\x3',  // XMM3
  (unsigned char)'\x3',  // XMM3b
  (unsigned char)'\x3',  // XMM3c
  (unsigned char)'\x3',  // XMM3d
  (unsigned char)'\x3',  // XMM3e
  (unsigned char)'\x3',  // XMM3f
  (unsigned char)'\x3',  // XMM3g
  (unsigned char)'\x3',  // XMM3h
  (unsigned char)'\x4',  // XMM4
  (unsigned char)'\x4',  // XMM4b
  (unsigned char)'\x4',  // XMM4c
  (unsigned char)'\x4',  // XMM4d
  (unsigned char)'\x4',  // XMM4e
  (unsigned char)'\x4',  // XMM4f
  (unsigned char)'\x4',  // XMM4g
  (unsigned char)'\x4',  // XMM4h
  (unsigned char)'\x5',  // XMM5
  (unsigned char)'\x5',  // XMM5b
  (unsigned char)'\x5',  // XMM5c
  (unsigned char)'\x5',  // XMM5d
  (unsigned char)'\x5',  // XMM5e
  (unsigned char)'\x5',  // XMM5f
  (unsigned char)'\x5',  // XMM5g
  (unsigned char)'\x5',  // XMM5h
  (unsigned char)'\x6',  // XMM6
  (unsigned char)'\x6',  // XMM6b
  (unsigned char)'\x6',  // XMM6c
  (unsigned char)'\x6',  // XMM6d
  (unsigned char)'\x6',  // XMM6e
  (unsigned char)'\x6',  // XMM6f
  (unsigned char)'\x6',  // XMM6g
  (unsigned char)'\x6',  // XMM6h
  (unsigned char)'\x7',  // XMM7
  (unsigned char)'\x7',  // XMM7b
  (unsigned char)'\x7',  // XMM7c
  (unsigned char)'\x7',  // XMM7d
  (unsigned char)'\x7',  // XMM7e
  (unsigned char)'\x7',  // XMM7f
  (unsigned char)'\x7',  // XMM7g
  (unsigned char)'\x7',  // XMM7h
  (unsigned char)'\x8',  // XMM8
  (unsigned char)'\x8',  // XMM8b
  (unsigned char)'\x8',  // XMM8c
  (unsigned char)'\x8',  // XMM8d
  (unsigned char)'\x8',  // XMM8e
  (unsigned char)'\x8',  // XMM8f
  (unsigned char)'\x8',  // XMM8g
  (unsigned char)'\x8',  // XMM8h
  (unsigned char)'\x9',  // XMM9
  (unsigned char)'\x9',  // XMM9b
  (unsigned char)'\x9',  // XMM9c
  (unsigned char)'\x9',  // XMM9d
  (unsigned char)'\x9',  // XMM9e
  (unsigned char)'\x9',  // XMM9f
  (unsigned char)'\x9',  // XMM9g
  (unsigned char)'\x9',  // XMM9h
  (unsigned char)'\xA',  // XMM10
  (unsigned char)'\xA',  // XMM10b
  (unsigned char)'\xA',  // XMM10c
  (unsigned char)'\xA',  // XMM10d
  (unsigned char)'\xA',  // XMM10e
  (unsigned char)'\xA',  // XMM10f
  (unsigned char)'\xA',  // XMM10g
  (unsigned char)'\xA',  // XMM10h
  (unsigned char)'\xB',  // XMM11
  (unsigned char)'\xB',  // XMM11b
  (unsigned char)'\xB',  // XMM11c
  (unsigned char)'\xB',  // XMM11d
  (unsigned char)'\xB',  // XMM11e
  (unsigned char)'\xB',  // XMM11f
  (unsigned char)'\xB',  // XMM11g
  (unsigned char)'\xB',  // XMM11h
  (unsigned char)'\xC',  // XMM12
  (unsigned char)'\xC',  // XMM12b
  (unsigned char)'\xC',  // XMM12c
  (unsigned char)'\xC',  // XMM12d
  (unsigned char)'\xC',  // XMM12e
  (unsigned char)'\xC',  // XMM12f
  (unsigned char)'\xC',  // XMM12g
  (unsigned char)'\xC',  // XMM12h
  (unsigned char)'\xD',  // XMM13
  (unsigned char)'\xD',  // XMM13b
  (unsigned char)'\xD',  // XMM13c
  (unsigned char)'\xD',  // XMM13d
  (unsigned char)'\xD',  // XMM13e
  (unsigned char)'\xD',  // XMM13f
  (unsigned char)'\xD',  // XMM13g
  (unsigned char)'\xD',  // XMM13h
  (unsigned char)'\xE',  // XMM14
  (unsigned char)'\xE',  // XMM14b
  (unsigned char)'\xE',  // XMM14c
  (unsigned char)'\xE',  // XMM14d
  (unsigned char)'\xE',  // XMM14e
  (unsigned char)'\xE',  // XMM14f
  (unsigned char)'\xE',  // XMM14g
  (unsigned char)'\xE',  // XMM14h
  (unsigned char)'\xF',  // XMM15
  (unsigned char)'\xF',  // XMM15b
  (unsigned char)'\xF',  // XMM15c
  (unsigned char)'\xF',  // XMM15d
  (unsigned char)'\xF',  // XMM15e
  (unsigned char)'\xF',  // XMM15f
  (unsigned char)'\xF',  // XMM15g
  (unsigned char)'\xF',  // XMM15h
  (unsigned char)'\x10' // no trailing comma  // RFLAGS
};


//------------------Define classes derived from MachOper---------------------
MachOper  *labelOper::clone(Compile* C) const {
  return  new (C) labelOper(_label, _block_num);
}
uint labelOper::opcode() const { return LABEL; }

const RegMask *sRegIOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &(Compile::current()->FIRST_STACK_mask());
}

const RegMask *sRegPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &(Compile::current()->FIRST_STACK_mask());
}

const RegMask *sRegFOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &(Compile::current()->FIRST_STACK_mask());
}

const RegMask *sRegDOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &(Compile::current()->FIRST_STACK_mask());
}

const RegMask *sRegLOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &(Compile::current()->FIRST_STACK_mask());
}

MachOper  *methodOper::clone(Compile* C) const {
  return  new (C) methodOper(_method);
}
uint methodOper::opcode() const { return METHOD; }

const RegMask *rRegIOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &INT_REG_mask();
}

const RegMask *rax_RegIOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &INT_RAX_REG_mask();
}

const RegMask *rbx_RegIOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &INT_RBX_REG_mask();
}

const RegMask *rcx_RegIOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &INT_RCX_REG_mask();
}

const RegMask *rdx_RegIOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &INT_RDX_REG_mask();
}

const RegMask *rdi_RegIOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &INT_RDI_REG_mask();
}

const RegMask *no_rcx_RegIOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &INT_NO_RCX_REG_mask();
}

const RegMask *no_rax_rdx_RegIOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &INT_NO_RAX_RDX_REG_mask();
}

const RegMask *any_RegPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &ANY_REG_mask();
}

const RegMask *rRegPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PTR_REG_mask();
}

const RegMask *rRegNOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &INT_REG_mask();
}

const RegMask *no_rax_RegPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PTR_NO_RAX_REG_mask();
}

const RegMask *no_rbp_RegPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PTR_REG_NO_RBP_mask();
}

const RegMask *no_rax_rbx_RegPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PTR_NO_RAX_RBX_REG_mask();
}

const RegMask *rax_RegPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PTR_RAX_REG_mask();
}

const RegMask *rax_RegNOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &INT_RAX_REG_mask();
}

const RegMask *rbx_RegPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PTR_RBX_REG_mask();
}

const RegMask *rsi_RegPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PTR_RSI_REG_mask();
}

const RegMask *rdi_RegPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PTR_RDI_REG_mask();
}

const RegMask *r15_RegPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PTR_R15_REG_mask();
}

const RegMask *rRegLOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &LONG_REG_mask();
}

const RegMask *no_rax_rdx_RegLOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &LONG_NO_RAX_RDX_REG_mask();
}

const RegMask *no_rax_RegLOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &LONG_NO_RAX_RDX_REG_mask();
}

const RegMask *no_rcx_RegLOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &LONG_NO_RCX_REG_mask();
}

const RegMask *rax_RegLOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &LONG_RAX_REG_mask();
}

const RegMask *rcx_RegLOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &LONG_RCX_REG_mask();
}

const RegMask *rdx_RegLOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &LONG_RDX_REG_mask();
}

const RegMask *rFlagsRegOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &INT_FLAGS_mask();
}

const RegMask *rFlagsRegUOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &INT_FLAGS_mask();
}

const RegMask *rFlagsRegUCFOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &INT_FLAGS_mask();
}

const RegMask *regFOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &FLOAT_REG_mask();
}

const RegMask *regDOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &DOUBLE_REG_mask();
}

const RegMask *indirectOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PTR_REG_mask();
}

const RegMask *indOffset8Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &ANY_REG_mask();
}

const RegMask *indOffset32Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &ANY_REG_mask();
}

const RegMask *indIndexOffsetOper::in_RegMask(int index) const {
  assert(0 <= index && index < 2, "index out of range");
  switch (index) {
  case 0: return &ANY_REG_mask();
  case 1: return &LONG_REG_mask();
  }
  ShouldNotReachHere();
  return NULL;
}

const RegMask *indIndexOper::in_RegMask(int index) const {
  assert(0 <= index && index < 2, "index out of range");
  switch (index) {
  case 0: return &ANY_REG_mask();
  case 1: return &LONG_REG_mask();
  }
  ShouldNotReachHere();
  return NULL;
}

const RegMask *indIndexScaleOper::in_RegMask(int index) const {
  assert(0 <= index && index < 2, "index out of range");
  switch (index) {
  case 0: return &ANY_REG_mask();
  case 1: return &LONG_REG_mask();
  }
  ShouldNotReachHere();
  return NULL;
}

const RegMask *indIndexScaleOffsetOper::in_RegMask(int index) const {
  assert(0 <= index && index < 2, "index out of range");
  switch (index) {
  case 0: return &ANY_REG_mask();
  case 1: return &LONG_REG_mask();
  }
  ShouldNotReachHere();
  return NULL;
}

const RegMask *indPosIndexScaleOffsetOper::in_RegMask(int index) const {
  assert(0 <= index && index < 2, "index out of range");
  switch (index) {
  case 0: return &ANY_REG_mask();
  case 1: return &INT_REG_mask();
  }
  ShouldNotReachHere();
  return NULL;
}

const RegMask *indCompressedOopOffsetOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &INT_REG_mask();
}

const RegMask *indirectNarrowOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &INT_REG_mask();
}

const RegMask *indOffset8NarrowOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &INT_REG_mask();
}

const RegMask *indOffset32NarrowOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &INT_REG_mask();
}

const RegMask *indIndexOffsetNarrowOper::in_RegMask(int index) const {
  assert(0 <= index && index < 2, "index out of range");
  switch (index) {
  case 0: return &INT_REG_mask();
  case 1: return &LONG_REG_mask();
  }
  ShouldNotReachHere();
  return NULL;
}

const RegMask *indIndexNarrowOper::in_RegMask(int index) const {
  assert(0 <= index && index < 2, "index out of range");
  switch (index) {
  case 0: return &INT_REG_mask();
  case 1: return &LONG_REG_mask();
  }
  ShouldNotReachHere();
  return NULL;
}

const RegMask *indIndexScaleNarrowOper::in_RegMask(int index) const {
  assert(0 <= index && index < 2, "index out of range");
  switch (index) {
  case 0: return &INT_REG_mask();
  case 1: return &LONG_REG_mask();
  }
  ShouldNotReachHere();
  return NULL;
}

const RegMask *indIndexScaleOffsetNarrowOper::in_RegMask(int index) const {
  assert(0 <= index && index < 2, "index out of range");
  switch (index) {
  case 0: return &INT_REG_mask();
  case 1: return &LONG_REG_mask();
  }
  ShouldNotReachHere();
  return NULL;
}

const RegMask *indPosIndexScaleOffsetNarrowOper::in_RegMask(int index) const {
  assert(0 <= index && index < 2, "index out of range");
  return &INT_REG_mask();
}

const RegMask *stackSlotPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &(Compile::current()->FIRST_STACK_mask());
}

const RegMask *stackSlotIOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &(Compile::current()->FIRST_STACK_mask());
}

const RegMask *stackSlotFOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &(Compile::current()->FIRST_STACK_mask());
}

const RegMask *stackSlotDOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &(Compile::current()->FIRST_STACK_mask());
}

const RegMask *stackSlotLOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &(Compile::current()->FIRST_STACK_mask());
}

const RegMask *vecSOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &VECTORS_REG_mask();
}

const RegMask *vecDOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &VECTORD_REG_mask();
}

const RegMask *vecXOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &VECTORX_REG_mask();
}

const RegMask *vecYOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &VECTORY_REG_mask();
}

//------------------Define members for classes derived from MachNode----------

void popCountINode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_INT_REG_mask();
}

// Build CISC version of this instruction
MachNode *popCountINode::cisc_version( int offset, Compile* C ) {
  popCountI_memNode *node = new (C) popCountI_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void popCountLNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_LONG_REG_mask();
}

// Build CISC version of this instruction
MachNode *popCountLNode::cisc_version( int offset, Compile* C ) {
  popCountL_memNode *node = new (C) popCountL_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void cmovI_regNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_INT_REG_mask();
}

// Build CISC version of this instruction
MachNode *cmovI_regNode::cisc_version( int offset, Compile* C ) {
  cmovI_memNode *node = new (C) cmovI_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void cmovI_regUNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_INT_REG_mask();
}

// Build CISC version of this instruction
MachNode *cmovI_regUNode::cisc_version( int offset, Compile* C ) {
  cmovI_memUNode *node = new (C) cmovI_memUNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void cmovI_regUCFNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_INT_REG_mask();
}

// Build CISC version of this instruction
MachNode *cmovI_regUCFNode::cisc_version( int offset, Compile* C ) {
  cmovI_memUCFNode *node = new (C) cmovI_memUCFNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void cmovL_regNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_LONG_REG_mask();
}

// Build CISC version of this instruction
MachNode *cmovL_regNode::cisc_version( int offset, Compile* C ) {
  cmovL_memNode *node = new (C) cmovL_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void cmovL_regUNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_LONG_REG_mask();
}

// Build CISC version of this instruction
MachNode *cmovL_regUNode::cisc_version( int offset, Compile* C ) {
  cmovL_memUNode *node = new (C) cmovL_memUNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void cmovL_regUCFNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_LONG_REG_mask();
}

// Build CISC version of this instruction
MachNode *cmovL_regUCFNode::cisc_version( int offset, Compile* C ) {
  cmovL_memUCFNode *node = new (C) cmovL_memUCFNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void addI_rRegNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_INT_REG_mask();
}

// Build CISC version of this instruction
MachNode *addI_rRegNode::cisc_version( int offset, Compile* C ) {
  addI_rReg_memNode *node = new (C) addI_rReg_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void addL_rRegNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_LONG_REG_mask();
}

// Build CISC version of this instruction
MachNode *addL_rRegNode::cisc_version( int offset, Compile* C ) {
  addL_rReg_memNode *node = new (C) addL_rReg_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void subI_rRegNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_INT_REG_mask();
}

// Build CISC version of this instruction
MachNode *subI_rRegNode::cisc_version( int offset, Compile* C ) {
  subI_rReg_memNode *node = new (C) subI_rReg_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void subL_rRegNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_LONG_REG_mask();
}

// Build CISC version of this instruction
MachNode *subL_rRegNode::cisc_version( int offset, Compile* C ) {
  subL_rReg_memNode *node = new (C) subL_rReg_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void mulI_rRegNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_INT_REG_mask();
}

// Build CISC version of this instruction
MachNode *mulI_rRegNode::cisc_version( int offset, Compile* C ) {
  mulI_memNode *node = new (C) mulI_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void mulI_rReg_immNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_INT_REG_mask();
}

// Build CISC version of this instruction
MachNode *mulI_rReg_immNode::cisc_version( int offset, Compile* C ) {
  mulI_mem_immNode *node = new (C) mulI_mem_immNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void mulL_rRegNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_LONG_REG_mask();
}

// Build CISC version of this instruction
MachNode *mulL_rRegNode::cisc_version( int offset, Compile* C ) {
  mulL_memNode *node = new (C) mulL_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void mulL_rReg_immNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_LONG_REG_mask();
}

// Build CISC version of this instruction
MachNode *mulL_rReg_immNode::cisc_version( int offset, Compile* C ) {
  mulL_mem_immNode *node = new (C) mulL_mem_immNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void i2bNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_INT_REG_mask();
}

// Build CISC version of this instruction
MachNode *i2bNode::cisc_version( int offset, Compile* C ) {
  loadI2BNode *node = new (C) loadI2BNode();
  node->_num_opnds = 3;

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void i2sNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_INT_REG_mask();
}

// Build CISC version of this instruction
MachNode *i2sNode::cisc_version( int offset, Compile* C ) {
  loadI2SNode *node = new (C) loadI2SNode();
  node->_num_opnds = 3;

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void andI_rRegNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_INT_REG_mask();
}

// Build CISC version of this instruction
MachNode *andI_rRegNode::cisc_version( int offset, Compile* C ) {
  andI_rReg_memNode *node = new (C) andI_rReg_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void andI2L_rReg_imm255Node::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_INT_REG_mask();
}

// Build CISC version of this instruction
MachNode *andI2L_rReg_imm255Node::cisc_version( int offset, Compile* C ) {
  loadI2L_immI_255Node *node = new (C) loadI2L_immI_255Node();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void andI2L_rReg_imm65535Node::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_INT_REG_mask();
}

// Build CISC version of this instruction
MachNode *andI2L_rReg_imm65535Node::cisc_version( int offset, Compile* C ) {
  loadI2L_immI_65535Node *node = new (C) loadI2L_immI_65535Node();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void andnI_rReg_rReg_rRegNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_INT_REG_mask();
}

// Build CISC version of this instruction
MachNode *andnI_rReg_rReg_rRegNode::cisc_version( int offset, Compile* C ) {
  andnI_rReg_rReg_memNode *node = new (C) andnI_rReg_rReg_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void andnI_rReg_rReg_rReg_0Node::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_INT_REG_mask();
}

// Build CISC version of this instruction
MachNode *andnI_rReg_rReg_rReg_0Node::cisc_version( int offset, Compile* C ) {
  andnI_rReg_rReg_mem_0Node *node = new (C) andnI_rReg_rReg_mem_0Node();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void orI_rRegNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_INT_REG_mask();
}

// Build CISC version of this instruction
MachNode *orI_rRegNode::cisc_version( int offset, Compile* C ) {
  orI_rReg_memNode *node = new (C) orI_rReg_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void xorI_rRegNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_INT_REG_mask();
}

// Build CISC version of this instruction
MachNode *xorI_rRegNode::cisc_version( int offset, Compile* C ) {
  xorI_rReg_memNode *node = new (C) xorI_rReg_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void andL_rRegNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_LONG_REG_mask();
}

// Build CISC version of this instruction
MachNode *andL_rRegNode::cisc_version( int offset, Compile* C ) {
  andL_rReg_memNode *node = new (C) andL_rReg_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void andnL_rReg_rReg_rRegNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_LONG_REG_mask();
}

// Build CISC version of this instruction
MachNode *andnL_rReg_rReg_rRegNode::cisc_version( int offset, Compile* C ) {
  andnL_rReg_rReg_memNode *node = new (C) andnL_rReg_rReg_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void andnL_rReg_rReg_rReg_0Node::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_LONG_REG_mask();
}

// Build CISC version of this instruction
MachNode *andnL_rReg_rReg_rReg_0Node::cisc_version( int offset, Compile* C ) {
  andnL_rReg_rReg_mem_0Node *node = new (C) andnL_rReg_rReg_mem_0Node();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void orL_rRegNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_LONG_REG_mask();
}

// Build CISC version of this instruction
MachNode *orL_rRegNode::cisc_version( int offset, Compile* C ) {
  orL_rReg_memNode *node = new (C) orL_rReg_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void xorL_rRegNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_LONG_REG_mask();
}

// Build CISC version of this instruction
MachNode *xorL_rRegNode::cisc_version( int offset, Compile* C ) {
  xorL_rReg_memNode *node = new (C) xorL_rReg_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void cmpF_cc_regNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_FLOAT_REG_mask();
}

// Build CISC version of this instruction
MachNode *cmpF_cc_regNode::cisc_version( int offset, Compile* C ) {
  cmpF_cc_memNode *node = new (C) cmpF_cc_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void cmpF_cc_reg_CFNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_FLOAT_REG_mask();
}

// Build CISC version of this instruction
MachNode *cmpF_cc_reg_CFNode::cisc_version( int offset, Compile* C ) {
  cmpF_cc_memCFNode *node = new (C) cmpF_cc_memCFNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void cmpD_cc_regNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_DOUBLE_REG_mask();
}

// Build CISC version of this instruction
MachNode *cmpD_cc_regNode::cisc_version( int offset, Compile* C ) {
  cmpD_cc_memNode *node = new (C) cmpD_cc_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void cmpD_cc_reg_CFNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_DOUBLE_REG_mask();
}

// Build CISC version of this instruction
MachNode *cmpD_cc_reg_CFNode::cisc_version( int offset, Compile* C ) {
  cmpD_cc_memCFNode *node = new (C) cmpD_cc_memCFNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void cmpF_regNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_FLOAT_REG_mask();
}

// Build CISC version of this instruction
MachNode *cmpF_regNode::cisc_version( int offset, Compile* C ) {
  cmpF_memNode *node = new (C) cmpF_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void cmpD_regNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_DOUBLE_REG_mask();
}

// Build CISC version of this instruction
MachNode *cmpD_regNode::cisc_version( int offset, Compile* C ) {
  cmpD_memNode *node = new (C) cmpD_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void convF2D_reg_regNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_FLOAT_REG_mask();
}

// Build CISC version of this instruction
MachNode *convF2D_reg_regNode::cisc_version( int offset, Compile* C ) {
  convF2D_reg_memNode *node = new (C) convF2D_reg_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void convD2F_reg_regNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_DOUBLE_REG_mask();
}

// Build CISC version of this instruction
MachNode *convD2F_reg_regNode::cisc_version( int offset, Compile* C ) {
  convD2F_reg_memNode *node = new (C) convD2F_reg_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void convL2F_reg_regNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_LONG_REG_mask();
}

// Build CISC version of this instruction
MachNode *convL2F_reg_regNode::cisc_version( int offset, Compile* C ) {
  convL2F_reg_memNode *node = new (C) convL2F_reg_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void convL2D_reg_regNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_LONG_REG_mask();
}

// Build CISC version of this instruction
MachNode *convL2D_reg_regNode::cisc_version( int offset, Compile* C ) {
  convL2D_reg_memNode *node = new (C) convL2D_reg_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void convI2L_reg_regNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_INT_REG_mask();
}

// Build CISC version of this instruction
MachNode *convI2L_reg_regNode::cisc_version( int offset, Compile* C ) {
  loadI2LNode *node = new (C) loadI2LNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void convI2L_reg_reg_zexNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_INT_REG_mask();
}

// Build CISC version of this instruction
MachNode *convI2L_reg_reg_zexNode::cisc_version( int offset, Compile* C ) {
  loadUI2LNode *node = new (C) loadUI2LNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void MoveF2I_reg_regNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_FLOAT_REG_mask();
}

// Build CISC version of this instruction
MachNode *MoveF2I_reg_regNode::cisc_version( int offset, Compile* C ) {
  MoveF2I_stack_regNode *node = new (C) MoveF2I_stack_regNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void MoveD2L_reg_regNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_DOUBLE_REG_mask();
}

// Build CISC version of this instruction
MachNode *MoveD2L_reg_regNode::cisc_version( int offset, Compile* C ) {
  MoveD2L_stack_regNode *node = new (C) MoveD2L_stack_regNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void MoveI2F_reg_regNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_INT_REG_mask();
}

// Build CISC version of this instruction
MachNode *MoveI2F_reg_regNode::cisc_version( int offset, Compile* C ) {
  MoveI2F_stack_regNode *node = new (C) MoveI2F_stack_regNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void compI_rRegNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_INT_REG_mask();
}

// Build CISC version of this instruction
MachNode *compI_rRegNode::cisc_version( int offset, Compile* C ) {
  compI_rReg_memNode *node = new (C) compI_rReg_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void compU_rRegNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_INT_REG_mask();
}

// Build CISC version of this instruction
MachNode *compU_rRegNode::cisc_version( int offset, Compile* C ) {
  compU_rReg_memNode *node = new (C) compU_rReg_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void compP_rRegNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_PTR_REG_mask();
}

// Build CISC version of this instruction
MachNode *compP_rRegNode::cisc_version( int offset, Compile* C ) {
  compP_rReg_memNode *node = new (C) compP_rReg_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void compL_rRegNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_LONG_REG_mask();
}

// Build CISC version of this instruction
MachNode *compL_rRegNode::cisc_version( int offset, Compile* C ) {
  compL_rReg_memNode *node = new (C) compL_rReg_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void compUL_rRegNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_LONG_REG_mask();
}

// Build CISC version of this instruction
MachNode *compUL_rRegNode::cisc_version( int offset, Compile* C ) {
  compUL_rReg_memNode *node = new (C) compUL_rReg_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}

// Build short branch version of this instruction
MachNode *jmpDirNode::short_branch_version(Compile* C) {
  jmpDir_shortNode *node = new (C) jmpDir_shortNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  return node;
}

// Build short branch version of this instruction
MachNode *jmpConNode::short_branch_version(Compile* C) {
  jmpCon_shortNode *node = new (C) jmpCon_shortNode();
  node->_prob = _prob;
  node->_fcnt = _fcnt;

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  return node;
}

// Build short branch version of this instruction
MachNode *jmpLoopEndNode::short_branch_version(Compile* C) {
  jmpLoopEnd_shortNode *node = new (C) jmpLoopEnd_shortNode();
  node->_prob = _prob;
  node->_fcnt = _fcnt;

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  return node;
}

// Build short branch version of this instruction
MachNode *jmpLoopEndUNode::short_branch_version(Compile* C) {
  jmpLoopEndU_shortNode *node = new (C) jmpLoopEndU_shortNode();
  node->_prob = _prob;
  node->_fcnt = _fcnt;

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  return node;
}

// Build short branch version of this instruction
MachNode *jmpLoopEndUCFNode::short_branch_version(Compile* C) {
  jmpLoopEndUCF_shortNode *node = new (C) jmpLoopEndUCF_shortNode();
  node->_prob = _prob;
  node->_fcnt = _fcnt;

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  return node;
}

// Build short branch version of this instruction
MachNode *jmpConUNode::short_branch_version(Compile* C) {
  jmpConU_shortNode *node = new (C) jmpConU_shortNode();
  node->_prob = _prob;
  node->_fcnt = _fcnt;

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  return node;
}

// Build short branch version of this instruction
MachNode *jmpConUCFNode::short_branch_version(Compile* C) {
  jmpConUCF_shortNode *node = new (C) jmpConUCF_shortNode();
  node->_prob = _prob;
  node->_fcnt = _fcnt;

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  return node;
}

// Build short branch version of this instruction
MachNode *jmpConUCF2Node::short_branch_version(Compile* C) {
  jmpConUCF2_shortNode *node = new (C) jmpConUCF2_shortNode();
  node->_prob = _prob;
  node->_fcnt = _fcnt;

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  return node;
}


void addF_regNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_FLOAT_REG_mask();
}

// Build CISC version of this instruction
MachNode *addF_regNode::cisc_version( int offset, Compile* C ) {
  addF_memNode *node = new (C) addF_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void addF_reg_regNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_FLOAT_REG_mask();
}

// Build CISC version of this instruction
MachNode *addF_reg_regNode::cisc_version( int offset, Compile* C ) {
  addF_reg_memNode *node = new (C) addF_reg_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void addD_regNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_DOUBLE_REG_mask();
}

// Build CISC version of this instruction
MachNode *addD_regNode::cisc_version( int offset, Compile* C ) {
  addD_memNode *node = new (C) addD_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void addD_reg_regNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_DOUBLE_REG_mask();
}

// Build CISC version of this instruction
MachNode *addD_reg_regNode::cisc_version( int offset, Compile* C ) {
  addD_reg_memNode *node = new (C) addD_reg_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void subF_regNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_FLOAT_REG_mask();
}

// Build CISC version of this instruction
MachNode *subF_regNode::cisc_version( int offset, Compile* C ) {
  subF_memNode *node = new (C) subF_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void subF_reg_regNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_FLOAT_REG_mask();
}

// Build CISC version of this instruction
MachNode *subF_reg_regNode::cisc_version( int offset, Compile* C ) {
  subF_reg_memNode *node = new (C) subF_reg_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void subD_regNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_DOUBLE_REG_mask();
}

// Build CISC version of this instruction
MachNode *subD_regNode::cisc_version( int offset, Compile* C ) {
  subD_memNode *node = new (C) subD_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void subD_reg_regNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_DOUBLE_REG_mask();
}

// Build CISC version of this instruction
MachNode *subD_reg_regNode::cisc_version( int offset, Compile* C ) {
  subD_reg_memNode *node = new (C) subD_reg_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void mulF_regNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_FLOAT_REG_mask();
}

// Build CISC version of this instruction
MachNode *mulF_regNode::cisc_version( int offset, Compile* C ) {
  mulF_memNode *node = new (C) mulF_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void mulF_reg_regNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_FLOAT_REG_mask();
}

// Build CISC version of this instruction
MachNode *mulF_reg_regNode::cisc_version( int offset, Compile* C ) {
  mulF_reg_memNode *node = new (C) mulF_reg_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void mulD_regNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_DOUBLE_REG_mask();
}

// Build CISC version of this instruction
MachNode *mulD_regNode::cisc_version( int offset, Compile* C ) {
  mulD_memNode *node = new (C) mulD_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void mulD_reg_regNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_DOUBLE_REG_mask();
}

// Build CISC version of this instruction
MachNode *mulD_reg_regNode::cisc_version( int offset, Compile* C ) {
  mulD_reg_memNode *node = new (C) mulD_reg_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void divF_regNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_FLOAT_REG_mask();
}

// Build CISC version of this instruction
MachNode *divF_regNode::cisc_version( int offset, Compile* C ) {
  divF_memNode *node = new (C) divF_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void divF_reg_regNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_FLOAT_REG_mask();
}

// Build CISC version of this instruction
MachNode *divF_reg_regNode::cisc_version( int offset, Compile* C ) {
  divF_reg_memNode *node = new (C) divF_reg_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void divD_regNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_DOUBLE_REG_mask();
}

// Build CISC version of this instruction
MachNode *divD_regNode::cisc_version( int offset, Compile* C ) {
  divD_memNode *node = new (C) divD_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void divD_reg_regNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_DOUBLE_REG_mask();
}

// Build CISC version of this instruction
MachNode *divD_reg_regNode::cisc_version( int offset, Compile* C ) {
  divD_reg_memNode *node = new (C) divD_reg_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void sqrtF_regNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_FLOAT_REG_mask();
}

// Build CISC version of this instruction
MachNode *sqrtF_regNode::cisc_version( int offset, Compile* C ) {
  sqrtF_memNode *node = new (C) sqrtF_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void sqrtD_regNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_DOUBLE_REG_mask();
}

// Build CISC version of this instruction
MachNode *sqrtD_regNode::cisc_version( int offset, Compile* C ) {
  sqrtD_memNode *node = new (C) sqrtD_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void Repl2INode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_INT_REG_mask();
}

// Build CISC version of this instruction
MachNode *Repl2INode::cisc_version( int offset, Compile* C ) {
  Repl2I_memNode *node = new (C) Repl2I_memNode();
  node->_bottom_type = bottom_type();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void Repl4INode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_INT_REG_mask();
}

// Build CISC version of this instruction
MachNode *Repl4INode::cisc_version( int offset, Compile* C ) {
  Repl4I_memNode *node = new (C) Repl4I_memNode();
  node->_bottom_type = bottom_type();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void Repl8INode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_INT_REG_mask();
}

// Build CISC version of this instruction
MachNode *Repl8INode::cisc_version( int offset, Compile* C ) {
  Repl8I_memNode *node = new (C) Repl8I_memNode();
  node->_bottom_type = bottom_type();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void Repl2LNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_LONG_REG_mask();
}

// Build CISC version of this instruction
MachNode *Repl2LNode::cisc_version( int offset, Compile* C ) {
  Repl2L_memNode *node = new (C) Repl2L_memNode();
  node->_bottom_type = bottom_type();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void Repl4LNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_LONG_REG_mask();
}

// Build CISC version of this instruction
MachNode *Repl4LNode::cisc_version( int offset, Compile* C ) {
  Repl4L_memNode *node = new (C) Repl4L_memNode();
  node->_bottom_type = bottom_type();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


// Copy _idx, inputs and operands to new node
void MachNode::fill_new_machnode( MachNode* node, Compile* C) const {
  // New node must use same node index
  node->set_idx( _idx );
  // Copy machine-independent inputs
  for( uint j = 0; j < req(); j++ ) {
    node->add_req(in(j));
  }
  // Copy my operands, except for cisc position
  int nopnds = num_opnds();
  assert( node->num_opnds() == (uint)nopnds, "Must have same number of operands");
  MachOper **to = node->_opnds;
  for( int i = 0; i < nopnds; i++ ) {
    if( i != cisc_operand() ) 
      to[i] = _opnds[i]->clone(C);
  }
}

void jmpDirNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(1));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void jmpDirNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(1));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void jmpConNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void jmpConNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void jmpLoopEndNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void jmpLoopEndNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void jmpLoopEndUNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void jmpLoopEndUNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void jmpLoopEndUCFNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void jmpLoopEndUCFNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void jmpConUNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void jmpConUNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void jmpConUCFNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void jmpConUCFNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void jmpConUCF2Node::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void jmpConUCF2Node::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void jmpDir_shortNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(1));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void jmpDir_shortNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(1));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void jmpCon_shortNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void jmpCon_shortNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void jmpLoopEnd_shortNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void jmpLoopEnd_shortNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void jmpLoopEndU_shortNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void jmpLoopEndU_shortNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void jmpLoopEndUCF_shortNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void jmpLoopEndUCF_shortNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void jmpConU_shortNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void jmpConU_shortNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void jmpConUCF_shortNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void jmpConUCF_shortNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void jmpConUCF2_shortNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void jmpConUCF2_shortNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void CallStaticJavaDirectNode::method_set( intptr_t method ) {
  ((methodOper*)opnd_array(1))->_method = method;
}

void CallDynamicJavaDirectNode::method_set( intptr_t method ) {
  ((methodOper*)opnd_array(1))->_method = method;
}

void CallRuntimeDirectNode::method_set( intptr_t method ) {
  ((methodOper*)opnd_array(1))->_method = method;
}

void CallLeafDirectNode::method_set( intptr_t method ) {
  ((methodOper*)opnd_array(1))->_method = method;
}

void CallLeafNoFPDirectNode::method_set( intptr_t method ) {
  ((methodOper*)opnd_array(1))->_method = method;
}

int loadBNode::reloc() const {
  return 1;
}

int loadB2LNode::reloc() const {
  return 1;
}

int loadUBNode::reloc() const {
  return 1;
}

int loadUB2LNode::reloc() const {
  return 1;
}

int loadUB2L_immI8Node::reloc() const {
  return 1;
}

int loadSNode::reloc() const {
  return 1;
}

int loadS2BNode::reloc() const {
  return 1;
}

int loadS2LNode::reloc() const {
  return 1;
}

int loadUSNode::reloc() const {
  return 1;
}

int loadUS2BNode::reloc() const {
  return 1;
}

int loadUS2LNode::reloc() const {
  return 1;
}

int loadUS2L_immI_255Node::reloc() const {
  return 1;
}

int loadUS2L_immI16Node::reloc() const {
  return 1;
}

int loadINode::reloc() const {
  return 1;
}

int loadI2BNode::reloc() const {
  return 1;
}

int loadI2UBNode::reloc() const {
  return 1;
}

int loadI2SNode::reloc() const {
  return 1;
}

int loadI2USNode::reloc() const {
  return 1;
}

int loadI2LNode::reloc() const {
  return 1;
}

int loadI2L_immI_255Node::reloc() const {
  return 1;
}

int loadI2L_immI_65535Node::reloc() const {
  return 1;
}

int loadI2L_immU31Node::reloc() const {
  return 1;
}

int loadUI2LNode::reloc() const {
  return 1;
}

int loadLNode::reloc() const {
  return 1;
}

int loadRangeNode::reloc() const {
  return 1;
}

int loadPNode::reloc() const {
  return 1;
}

int loadNNode::reloc() const {
  return 1;
}

int loadKlassNode::reloc() const {
  return 1;
}

int loadNKlassNode::reloc() const {
  return 1;
}

int loadFNode::reloc() const {
  return 1;
}

int loadD_partialNode::reloc() const {
  return 1;
}

int loadDNode::reloc() const {
  return 1;
}

int loadConPNode::reloc() const {
  return 1;
}

int loadConP0Node::reloc() const {
  return 1;
}

int loadConP31Node::reloc() const {
  return 1;
}

int loadConFNode::reloc() const {
  return 2;
}

int loadConF0Node::reloc() const {
  return 2;
}

int loadConDNode::reloc() const {
  return 2;
}

int loadConD0Node::reloc() const {
  return 2;
}

int prefetchrNode::reloc() const {
  return 1;
}

int prefetchrNTANode::reloc() const {
  return 1;
}

int prefetchrT0Node::reloc() const {
  return 1;
}

int prefetchrT2Node::reloc() const {
  return 1;
}

int prefetchwNTANode::reloc() const {
  return 1;
}

int prefetchAllocNode::reloc() const {
  return 1;
}

int prefetchAllocNTANode::reloc() const {
  return 1;
}

int prefetchAllocT0Node::reloc() const {
  return 1;
}

int prefetchAllocT2Node::reloc() const {
  return 1;
}

int storeBNode::reloc() const {
  return 2;
}

int storeCNode::reloc() const {
  return 2;
}

int storeINode::reloc() const {
  return 2;
}

int storeLNode::reloc() const {
  return 2;
}

int storePNode::reloc() const {
  return 2;
}

int storeImmP0Node::reloc() const {
  return 3;
}

int storeImmPNode::reloc() const {
  return 3;
}

int storeNNode::reloc() const {
  return 2;
}

int storeNKlassNode::reloc() const {
  return 2;
}

int storeImmN0Node::reloc() const {
  return 2;
}

int storeImmNNode::reloc() const {
  return 2;
}

int storeImmNKlassNode::reloc() const {
  return 2;
}

int storeImmI0Node::reloc() const {
  return 2;
}

int storeImmINode::reloc() const {
  return 2;
}

int storeImmL0Node::reloc() const {
  return 2;
}

int storeImmLNode::reloc() const {
  return 2;
}

int storeImmC0Node::reloc() const {
  return 2;
}

int storeImmI16Node::reloc() const {
  return 2;
}

int storeImmB0Node::reloc() const {
  return 2;
}

int storeImmBNode::reloc() const {
  return 2;
}

int storeImmCM0_regNode::reloc() const {
  return 2;
}

int storeImmCM0Node::reloc() const {
  return 2;
}

int storeFNode::reloc() const {
  return 2;
}

int storeF0Node::reloc() const {
  return 3;
}

int storeF_immNode::reloc() const {
  return 3;
}

int storeDNode::reloc() const {
  return 2;
}

int storeD0_immNode::reloc() const {
  return 3;
}

int storeD0Node::reloc() const {
  return 3;
}

int popCountI_memNode::reloc() const {
  return 1;
}

int popCountL_memNode::reloc() const {
  return 1;
}

int cmovI_memNode::reloc() const {
  return 1;
}

int cmovI_memUNode::reloc() const {
  return 1;
}

int cmovI_memUCFNode::reloc() const {
  return 1;
}

int cmovL_memNode::reloc() const {
  return 1;
}

int cmovL_memUNode::reloc() const {
  return 1;
}

int cmovL_memUCFNode::reloc() const {
  return 1;
}

int addI_rReg_memNode::reloc() const {
  return 1;
}

int addI_rReg_mem_0Node::reloc() const {
  return 1;
}

int addI_mem_rRegNode::reloc() const {
  return 3;
}

int addI_mem_rReg_0Node::reloc() const {
  return 3;
}

int addI_mem_immNode::reloc() const {
  return 3;
}

int incI_memNode::reloc() const {
  return 3;
}

int decI_memNode::reloc() const {
  return 3;
}

int addL_rReg_memNode::reloc() const {
  return 1;
}

int addL_rReg_mem_0Node::reloc() const {
  return 1;
}

int addL_mem_rRegNode::reloc() const {
  return 3;
}

int addL_mem_rReg_0Node::reloc() const {
  return 3;
}

int addL_mem_immNode::reloc() const {
  return 3;
}

int incL_memNode::reloc() const {
  return 3;
}

int decL_memNode::reloc() const {
  return 3;
}

int loadPLockedNode::reloc() const {
  return 1;
}

int storePConditionalNode::reloc() const {
  return 1;
}

int storeIConditionalNode::reloc() const {
  return 1;
}

int storeLConditionalNode::reloc() const {
  return 1;
}

int compareAndSwapPNode::reloc() const {
  return 1;
}

int compareAndSwapLNode::reloc() const {
  return 1;
}

int compareAndSwapINode::reloc() const {
  return 1;
}

int compareAndSwapNNode::reloc() const {
  return 1;
}

int xaddI_no_resNode::reloc() const {
  return 1;
}

int xaddINode::reloc() const {
  return 1;
}

int xaddL_no_resNode::reloc() const {
  return 1;
}

int xaddLNode::reloc() const {
  return 1;
}

int xchgINode::reloc() const {
  return 1;
}

int xchgLNode::reloc() const {
  return 1;
}

int xchgPNode::reloc() const {
  return 1;
}

int xchgNNode::reloc() const {
  return 1;
}

int subI_rReg_memNode::reloc() const {
  return 1;
}

int subI_mem_rRegNode::reloc() const {
  return 3;
}

int subI_mem_immNode::reloc() const {
  return 3;
}

int subL_rReg_memNode::reloc() const {
  return 1;
}

int subL_mem_rRegNode::reloc() const {
  return 3;
}

int subL_mem_immNode::reloc() const {
  return 3;
}

int negI_memNode::reloc() const {
  return 3;
}

int negL_memNode::reloc() const {
  return 3;
}

int mulI_memNode::reloc() const {
  return 1;
}

int mulI_mem_0Node::reloc() const {
  return 1;
}

int mulI_mem_immNode::reloc() const {
  return 1;
}

int mulL_memNode::reloc() const {
  return 1;
}

int mulL_mem_0Node::reloc() const {
  return 1;
}

int mulL_mem_immNode::reloc() const {
  return 1;
}

int salI_mem_1Node::reloc() const {
  return 3;
}

int salI_mem_immNode::reloc() const {
  return 3;
}

int salI_mem_CLNode::reloc() const {
  return 3;
}

int sarI_mem_1Node::reloc() const {
  return 3;
}

int sarI_mem_immNode::reloc() const {
  return 3;
}

int sarI_mem_CLNode::reloc() const {
  return 3;
}

int shrI_mem_1Node::reloc() const {
  return 3;
}

int shrI_mem_immNode::reloc() const {
  return 3;
}

int shrI_mem_CLNode::reloc() const {
  return 3;
}

int salL_mem_1Node::reloc() const {
  return 3;
}

int salL_mem_immNode::reloc() const {
  return 3;
}

int salL_mem_CLNode::reloc() const {
  return 3;
}

int sarL_mem_1Node::reloc() const {
  return 3;
}

int sarL_mem_immNode::reloc() const {
  return 3;
}

int sarL_mem_CLNode::reloc() const {
  return 3;
}

int shrL_mem_1Node::reloc() const {
  return 3;
}

int shrL_mem_immNode::reloc() const {
  return 3;
}

int shrL_mem_CLNode::reloc() const {
  return 3;
}

int andI_rReg_memNode::reloc() const {
  return 1;
}

int andI_rReg_mem_0Node::reloc() const {
  return 1;
}

int andI_mem_rRegNode::reloc() const {
  return 3;
}

int andI_mem_rReg_0Node::reloc() const {
  return 3;
}

int andI_mem_immNode::reloc() const {
  return 3;
}

int andnI_rReg_rReg_memNode::reloc() const {
  return 1;
}

int andnI_rReg_rReg_mem_0Node::reloc() const {
  return 1;
}

int blsiI_rReg_memNode::reloc() const {
  return 2;
}

int blsiI_rReg_mem_0Node::reloc() const {
  return 2;
}

int blsmskI_rReg_memNode::reloc() const {
  return 2;
}

int blsmskI_rReg_mem_0Node::reloc() const {
  return 2;
}

int blsrI_rReg_memNode::reloc() const {
  return 2;
}

int blsrI_rReg_mem_0Node::reloc() const {
  return 2;
}

int orI_rReg_memNode::reloc() const {
  return 1;
}

int orI_rReg_mem_0Node::reloc() const {
  return 1;
}

int orI_mem_rRegNode::reloc() const {
  return 3;
}

int orI_mem_rReg_0Node::reloc() const {
  return 3;
}

int orI_mem_immNode::reloc() const {
  return 3;
}

int xorI_rReg_memNode::reloc() const {
  return 1;
}

int xorI_rReg_mem_0Node::reloc() const {
  return 1;
}

int xorI_mem_rRegNode::reloc() const {
  return 3;
}

int xorI_mem_rReg_0Node::reloc() const {
  return 3;
}

int xorI_mem_immNode::reloc() const {
  return 3;
}

int andL_rReg_memNode::reloc() const {
  return 1;
}

int andL_rReg_mem_0Node::reloc() const {
  return 1;
}

int andL_mem_rRegNode::reloc() const {
  return 3;
}

int andL_mem_rReg_0Node::reloc() const {
  return 3;
}

int andL_mem_immNode::reloc() const {
  return 3;
}

int andnL_rReg_rReg_memNode::reloc() const {
  return 1;
}

int andnL_rReg_rReg_mem_0Node::reloc() const {
  return 1;
}

int blsiL_rReg_memNode::reloc() const {
  return 2;
}

int blsiL_rReg_mem_0Node::reloc() const {
  return 2;
}

int blsmskL_rReg_memNode::reloc() const {
  return 2;
}

int blsmskL_rReg_mem_0Node::reloc() const {
  return 2;
}

int blsrL_rReg_memNode::reloc() const {
  return 2;
}

int blsrL_rReg_mem_0Node::reloc() const {
  return 2;
}

int orL_rReg_memNode::reloc() const {
  return 1;
}

int orL_rReg_mem_0Node::reloc() const {
  return 1;
}

int orL_mem_rRegNode::reloc() const {
  return 3;
}

int orL_mem_rReg_0Node::reloc() const {
  return 3;
}

int orL_mem_immNode::reloc() const {
  return 3;
}

int xorL_rReg_memNode::reloc() const {
  return 1;
}

int xorL_rReg_mem_0Node::reloc() const {
  return 1;
}

int xorL_mem_rRegNode::reloc() const {
  return 3;
}

int xorL_mem_rReg_0Node::reloc() const {
  return 3;
}

int xorL_mem_immNode::reloc() const {
  return 3;
}

int cmpF_cc_memNode::reloc() const {
  return 1;
}

int cmpF_cc_memCFNode::reloc() const {
  return 1;
}

int cmpF_cc_immNode::reloc() const {
  return 1;
}

int cmpF_cc_immCFNode::reloc() const {
  return 1;
}

int cmpD_cc_memNode::reloc() const {
  return 1;
}

int cmpD_cc_memCFNode::reloc() const {
  return 1;
}

int cmpD_cc_immNode::reloc() const {
  return 1;
}

int cmpD_cc_immCFNode::reloc() const {
  return 1;
}

int cmpF_memNode::reloc() const {
  return 1;
}

int cmpF_immNode::reloc() const {
  return 1;
}

int cmpD_memNode::reloc() const {
  return 1;
}

int cmpD_immNode::reloc() const {
  return 1;
}

int convF2D_reg_memNode::reloc() const {
  return 1;
}

int convD2F_reg_memNode::reloc() const {
  return 1;
}

int convI2F_reg_memNode::reloc() const {
  return 1;
}

int convI2D_reg_memNode::reloc() const {
  return 1;
}

int convL2F_reg_memNode::reloc() const {
  return 1;
}

int convL2D_reg_memNode::reloc() const {
  return 1;
}

int convI2L_reg_mem_zexNode::reloc() const {
  return 1;
}

int compI_rReg_memNode::reloc() const {
  return 1;
}

int testI_reg_memNode::reloc() const {
  return 1;
}

int testI_reg_mem_0Node::reloc() const {
  return 1;
}

int compU_rReg_memNode::reloc() const {
  return 1;
}

int compP_rReg_memNode::reloc() const {
  return 1;
}

int compP_mem_rRegNode::reloc() const {
  return 1;
}

int testP_regNode::reloc() const {
  return 1;
}

int testP_memNode::reloc() const {
  return 2;
}

int testP_mem_reg0Node::reloc() const {
  return 2;
}

int compN_rReg_memNode::reloc() const {
  return 1;
}

int compN_mem_immNode::reloc() const {
  return 1;
}

int compN_mem_imm_klassNode::reloc() const {
  return 1;
}

int testN_memNode::reloc() const {
  return 1;
}

int testN_mem_reg0Node::reloc() const {
  return 1;
}

int compL_rReg_memNode::reloc() const {
  return 1;
}

int testL_reg_memNode::reloc() const {
  return 1;
}

int testL_reg_mem_0Node::reloc() const {
  return 1;
}

int compUL_rReg_memNode::reloc() const {
  return 1;
}

int partialSubtypeCheck_vs_ZeroNode::reloc() const {
  return 1;
}

int safePoint_pollNode::reloc() const {
  return 1;
}

int safePoint_poll_farNode::reloc() const {
  return 1;
}

int CallStaticJavaDirectNode::reloc() const {
  return 1;
}

int CallDynamicJavaDirectNode::reloc() const {
  return 1;
}

int CallRuntimeDirectNode::reloc() const {
  return 1;
}

int CallLeafDirectNode::reloc() const {
  return 1;
}

int CallLeafNoFPDirectNode::reloc() const {
  return 1;
}

int RetNode::reloc() const {
  return 1;
}

int TailCalljmpIndNode::reloc() const {
  return 1;
}

int tailjmpIndNode::reloc() const {
  return 1;
}

int RethrowExceptionNode::reloc() const {
  return 1;
}

int addF_memNode::reloc() const {
  return 1;
}

int addF_mem_0Node::reloc() const {
  return 1;
}

int addF_immNode::reloc() const {
  return 1;
}

int addF_reg_memNode::reloc() const {
  return 1;
}

int addF_reg_mem_0Node::reloc() const {
  return 1;
}

int addF_reg_immNode::reloc() const {
  return 1;
}

int addD_memNode::reloc() const {
  return 1;
}

int addD_mem_0Node::reloc() const {
  return 1;
}

int addD_immNode::reloc() const {
  return 1;
}

int addD_reg_memNode::reloc() const {
  return 1;
}

int addD_reg_mem_0Node::reloc() const {
  return 1;
}

int addD_reg_immNode::reloc() const {
  return 1;
}

int subF_memNode::reloc() const {
  return 1;
}

int subF_immNode::reloc() const {
  return 1;
}

int subF_reg_memNode::reloc() const {
  return 1;
}

int subF_reg_immNode::reloc() const {
  return 1;
}

int subD_memNode::reloc() const {
  return 1;
}

int subD_immNode::reloc() const {
  return 1;
}

int subD_reg_memNode::reloc() const {
  return 1;
}

int subD_reg_immNode::reloc() const {
  return 1;
}

int mulF_memNode::reloc() const {
  return 1;
}

int mulF_mem_0Node::reloc() const {
  return 1;
}

int mulF_immNode::reloc() const {
  return 1;
}

int mulF_reg_memNode::reloc() const {
  return 1;
}

int mulF_reg_mem_0Node::reloc() const {
  return 1;
}

int mulF_reg_immNode::reloc() const {
  return 1;
}

int mulD_memNode::reloc() const {
  return 1;
}

int mulD_mem_0Node::reloc() const {
  return 1;
}

int mulD_immNode::reloc() const {
  return 1;
}

int mulD_reg_memNode::reloc() const {
  return 1;
}

int mulD_reg_mem_0Node::reloc() const {
  return 1;
}

int mulD_reg_immNode::reloc() const {
  return 1;
}

int divF_memNode::reloc() const {
  return 1;
}

int divF_immNode::reloc() const {
  return 1;
}

int divF_reg_memNode::reloc() const {
  return 1;
}

int divF_reg_immNode::reloc() const {
  return 1;
}

int divD_memNode::reloc() const {
  return 1;
}

int divD_immNode::reloc() const {
  return 1;
}

int divD_reg_memNode::reloc() const {
  return 1;
}

int divD_reg_immNode::reloc() const {
  return 1;
}

int sqrtF_memNode::reloc() const {
  return 1;
}

int sqrtF_immNode::reloc() const {
  return 1;
}

int sqrtD_memNode::reloc() const {
  return 1;
}

int sqrtD_immNode::reloc() const {
  return 1;
}

int loadV4Node::reloc() const {
  return 1;
}

int loadV8Node::reloc() const {
  return 1;
}

int loadV16Node::reloc() const {
  return 1;
}

int loadV32Node::reloc() const {
  return 1;
}

int storeV4Node::reloc() const {
  return 2;
}

int storeV8Node::reloc() const {
  return 2;
}

int storeV16Node::reloc() const {
  return 2;
}

int storeV32Node::reloc() const {
  return 2;
}

int Repl2I_memNode::reloc() const {
  return 1;
}

int Repl4I_memNode::reloc() const {
  return 1;
}

int Repl8I_memNode::reloc() const {
  return 1;
}

int Repl2L_memNode::reloc() const {
  return 1;
}

int Repl4L_memNode::reloc() const {
  return 1;
}

int Repl2F_zeroNode::reloc() const {
  return 1;
}

int Repl4F_zeroNode::reloc() const {
  return 1;
}

int Repl8F_zeroNode::reloc() const {
  return 1;
}

int Repl2D_zeroNode::reloc() const {
  return 1;
}

int Repl4D_zeroNode::reloc() const {
  return 1;
}

int vadd16B_memNode::reloc() const {
  return 1;
}

int vadd32B_memNode::reloc() const {
  return 1;
}

int vadd8S_memNode::reloc() const {
  return 1;
}

int vadd16S_memNode::reloc() const {
  return 1;
}

int vadd4I_memNode::reloc() const {
  return 1;
}

int vadd8I_memNode::reloc() const {
  return 1;
}

int vadd2L_memNode::reloc() const {
  return 1;
}

int vadd4L_memNode::reloc() const {
  return 1;
}

int vadd4F_memNode::reloc() const {
  return 1;
}

int vadd8F_memNode::reloc() const {
  return 1;
}

int vadd2D_memNode::reloc() const {
  return 1;
}

int vadd4D_memNode::reloc() const {
  return 1;
}

int vsub16B_memNode::reloc() const {
  return 1;
}

int vsub32B_memNode::reloc() const {
  return 1;
}

int vsub8S_memNode::reloc() const {
  return 1;
}

int vsub16S_memNode::reloc() const {
  return 1;
}

int vsub4I_memNode::reloc() const {
  return 1;
}

int vsub8I_memNode::reloc() const {
  return 1;
}

int vsub2L_memNode::reloc() const {
  return 1;
}

int vsub4L_memNode::reloc() const {
  return 1;
}

int vsub4F_memNode::reloc() const {
  return 1;
}

int vsub8F_memNode::reloc() const {
  return 1;
}

int vsub2D_memNode::reloc() const {
  return 1;
}

int vsub4D_memNode::reloc() const {
  return 1;
}

int vmul8S_memNode::reloc() const {
  return 1;
}

int vmul16S_memNode::reloc() const {
  return 1;
}

int vmul4I_memNode::reloc() const {
  return 1;
}

int vmul8I_memNode::reloc() const {
  return 1;
}

int vmul4F_memNode::reloc() const {
  return 1;
}

int vmul8F_memNode::reloc() const {
  return 1;
}

int vmul2D_memNode::reloc() const {
  return 1;
}

int vmul4D_memNode::reloc() const {
  return 1;
}

int vdiv4F_memNode::reloc() const {
  return 1;
}

int vdiv8F_memNode::reloc() const {
  return 1;
}

int vdiv2D_memNode::reloc() const {
  return 1;
}

int vdiv4D_memNode::reloc() const {
  return 1;
}

int vand16B_memNode::reloc() const {
  return 1;
}

int vand32B_memNode::reloc() const {
  return 1;
}

int vor16B_memNode::reloc() const {
  return 1;
}

int vor32B_memNode::reloc() const {
  return 1;
}

int vxor16B_memNode::reloc() const {
  return 1;
}

int vxor32B_memNode::reloc() const {
  return 1;
}


void loadBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 4631 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ movsbl(opnd_array(0)->as_Register(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
  
#line 12521 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void loadB2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 4646 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ movsbq(opnd_array(0)->as_Register(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
  
#line 12537 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void loadUBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 4661 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ movzbl(opnd_array(0)->as_Register(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
  
#line 12553 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void loadUB2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 4676 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ movzbq(opnd_array(0)->as_Register(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
  
#line 12569 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void loadUB2L_immI8Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  {
    MacroAssembler _masm(&cbuf);

#line 4690 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    Register Rdst = opnd_array(0)->as_Register(ra_,this)/* dst */;
    __ movzbq(Rdst, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
    __ andl(Rdst, opnd_array(2)->constant());
  
#line 12588 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void loadSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 4706 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ movswl(opnd_array(0)->as_Register(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
  
#line 12604 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void loadS2BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// twentyfour
  {
    MacroAssembler _masm(&cbuf);

#line 4719 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ movsbl(opnd_array(0)->as_Register(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
  
#line 12621 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void loadS2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 4733 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ movswq(opnd_array(0)->as_Register(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
  
#line 12637 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void loadUSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 4748 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ movzwl(opnd_array(0)->as_Register(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
  
#line 12653 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void loadUS2BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// twentyfour
  {
    MacroAssembler _masm(&cbuf);

#line 4761 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ movsbl(opnd_array(0)->as_Register(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
  
#line 12670 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void loadUS2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 4775 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ movzwq(opnd_array(0)->as_Register(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
  
#line 12686 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void loadUS2L_immI_255Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  {
    MacroAssembler _masm(&cbuf);

#line 4787 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ movzbq(opnd_array(0)->as_Register(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
  
#line 12703 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void loadUS2L_immI16Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  {
    MacroAssembler _masm(&cbuf);

#line 4800 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    Register Rdst = opnd_array(0)->as_Register(ra_,this)/* dst */;
    __ movzwq(Rdst, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
    __ andl(Rdst, opnd_array(2)->constant());
  
#line 12722 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void loadINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 4816 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ movl(opnd_array(0)->as_Register(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
  
#line 12738 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void loadI2BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// twentyfour
  {
    MacroAssembler _masm(&cbuf);

#line 4829 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ movsbl(opnd_array(0)->as_Register(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
  
#line 12755 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void loadI2UBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  {
    MacroAssembler _masm(&cbuf);

#line 4841 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ movzbl(opnd_array(0)->as_Register(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
  
#line 12772 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void loadI2SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// sixteen
  {
    MacroAssembler _masm(&cbuf);

#line 4853 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ movswl(opnd_array(0)->as_Register(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
  
#line 12789 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void loadI2USNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  {
    MacroAssembler _masm(&cbuf);

#line 4865 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ movzwl(opnd_array(0)->as_Register(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
  
#line 12806 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void loadI2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 4879 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ movslq(opnd_array(0)->as_Register(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
  
#line 12822 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void loadI2L_immI_255Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  {
    MacroAssembler _masm(&cbuf);

#line 4891 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ movzbq(opnd_array(0)->as_Register(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
  
#line 12839 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void loadI2L_immI_65535Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  {
    MacroAssembler _masm(&cbuf);

#line 4902 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ movzwq(opnd_array(0)->as_Register(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
  
#line 12856 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void loadI2L_immU31Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  {
    MacroAssembler _masm(&cbuf);

#line 4915 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    Register Rdst = opnd_array(0)->as_Register(ra_,this)/* dst */;
    __ movl(Rdst, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
    __ andl(Rdst, opnd_array(2)->constant());
  
#line 12875 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void loadUI2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  {
    MacroAssembler _masm(&cbuf);

#line 4931 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ movl(opnd_array(0)->as_Register(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
  
#line 12892 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void loadLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 4946 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ movq(opnd_array(0)->as_Register(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
  
#line 12908 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void loadRangeNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2447 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(0)->reg(ra_,this)/* dst */ < 8) {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) >= 8) {
          emit_opcode(cbuf, Assembler::REX_X);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_B);
        } else {
          emit_opcode(cbuf, Assembler::REX_XB);
        }
      }
    } else {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_R);
        } else {
          emit_opcode(cbuf, Assembler::REX_RX);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_RB);
        } else {
          emit_opcode(cbuf, Assembler::REX_RXB);
        }
      }
    }
  
#line 12949 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x8B /*primary()*/));
  
#line 12957 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2511 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // High registers handle in encode_RegMem
    int reg = opnd_array(0)->reg(ra_,this)/* dst */;
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int disp = opnd_array(1)->disp(ra_,this,idx1);
    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();

    encode_RegMem(cbuf, reg, base, index, scale, disp, disp_reloc);
  
#line 12973 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void loadPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2478 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(0)->reg(ra_,this)/* dst */ < 8) {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_W);
        } else {
          emit_opcode(cbuf, Assembler::REX_WX);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WXB);
        }
      }
    } else {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WR);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRX);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WRB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRXB);
        }
      }
    }
  
#line 13016 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x8B /*primary()*/));
  
#line 13024 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2511 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // High registers handle in encode_RegMem
    int reg = opnd_array(0)->reg(ra_,this)/* dst */;
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int disp = opnd_array(1)->disp(ra_,this,idx1);
    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();

    encode_RegMem(cbuf, reg, base, index, scale, disp, disp_reloc);
  
#line 13040 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void loadNNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 4984 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

     __ movl(opnd_array(0)->as_Register(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
   
#line 13056 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void loadKlassNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2478 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(0)->reg(ra_,this)/* dst */ < 8) {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_W);
        } else {
          emit_opcode(cbuf, Assembler::REX_WX);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WXB);
        }
      }
    } else {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WR);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRX);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WRB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRXB);
        }
      }
    }
  
#line 13099 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x8B /*primary()*/));
  
#line 13107 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2511 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // High registers handle in encode_RegMem
    int reg = opnd_array(0)->reg(ra_,this)/* dst */;
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int disp = opnd_array(1)->disp(ra_,this,idx1);
    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();

    encode_RegMem(cbuf, reg, base, index, scale, disp, disp_reloc);
  
#line 13123 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void loadNKlassNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 5010 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ movl(opnd_array(0)->as_Register(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
  
#line 13139 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void loadFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 5023 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ movflt(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
  
#line 13155 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void loadD_partialNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 5037 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ movdbl(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
  
#line 13171 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void loadDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 5050 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ movdbl(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
  
#line 13187 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void leaP8Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2478 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(0)->reg(ra_,this)/* dst */ < 8) {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_W);
        } else {
          emit_opcode(cbuf, Assembler::REX_WX);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WXB);
        }
      }
    } else {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WR);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRX);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WRB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRXB);
        }
      }
    }
  
#line 13230 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x8D /*primary()*/));
  
#line 13238 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2511 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // High registers handle in encode_RegMem
    int reg = opnd_array(0)->reg(ra_,this)/* dst */;
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int disp = opnd_array(1)->disp(ra_,this,idx1);
    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();

    encode_RegMem(cbuf, reg, base, index, scale, disp, disp_reloc);
  
#line 13254 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void leaP32Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2478 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(0)->reg(ra_,this)/* dst */ < 8) {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_W);
        } else {
          emit_opcode(cbuf, Assembler::REX_WX);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WXB);
        }
      }
    } else {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WR);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRX);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WRB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRXB);
        }
      }
    }
  
#line 13297 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x8D /*primary()*/));
  
#line 13305 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2511 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // High registers handle in encode_RegMem
    int reg = opnd_array(0)->reg(ra_,this)/* dst */;
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int disp = opnd_array(1)->disp(ra_,this,idx1);
    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();

    encode_RegMem(cbuf, reg, base, index, scale, disp, disp_reloc);
  
#line 13321 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void leaPIdxOffNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2478 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(0)->reg(ra_,this)/* dst */ < 8) {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_W);
        } else {
          emit_opcode(cbuf, Assembler::REX_WX);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WXB);
        }
      }
    } else {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WR);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRX);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WRB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRXB);
        }
      }
    }
  
#line 13364 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x8D /*primary()*/));
  
#line 13372 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2511 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // High registers handle in encode_RegMem
    int reg = opnd_array(0)->reg(ra_,this)/* dst */;
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int disp = opnd_array(1)->disp(ra_,this,idx1);
    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();

    encode_RegMem(cbuf, reg, base, index, scale, disp, disp_reloc);
  
#line 13388 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void leaPIdxScaleNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2478 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(0)->reg(ra_,this)/* dst */ < 8) {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_W);
        } else {
          emit_opcode(cbuf, Assembler::REX_WX);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WXB);
        }
      }
    } else {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WR);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRX);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WRB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRXB);
        }
      }
    }
  
#line 13431 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x8D /*primary()*/));
  
#line 13439 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2511 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // High registers handle in encode_RegMem
    int reg = opnd_array(0)->reg(ra_,this)/* dst */;
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int disp = opnd_array(1)->disp(ra_,this,idx1);
    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();

    encode_RegMem(cbuf, reg, base, index, scale, disp, disp_reloc);
  
#line 13455 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void leaPIdxScaleOffNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2478 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(0)->reg(ra_,this)/* dst */ < 8) {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_W);
        } else {
          emit_opcode(cbuf, Assembler::REX_WX);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WXB);
        }
      }
    } else {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WR);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRX);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WRB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRXB);
        }
      }
    }
  
#line 13498 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x8D /*primary()*/));
  
#line 13506 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2511 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // High registers handle in encode_RegMem
    int reg = opnd_array(0)->reg(ra_,this)/* dst */;
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int disp = opnd_array(1)->disp(ra_,this,idx1);
    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();

    encode_RegMem(cbuf, reg, base, index, scale, disp, disp_reloc);
  
#line 13522 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void leaPPosIdxScaleOffNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2478 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(0)->reg(ra_,this)/* dst */ < 8) {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_W);
        } else {
          emit_opcode(cbuf, Assembler::REX_WX);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WXB);
        }
      }
    } else {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WR);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRX);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WRB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRXB);
        }
      }
    }
  
#line 13565 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x8D /*primary()*/));
  
#line 13573 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2511 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // High registers handle in encode_RegMem
    int reg = opnd_array(0)->reg(ra_,this)/* dst */;
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int disp = opnd_array(1)->disp(ra_,this,idx1);
    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();

    encode_RegMem(cbuf, reg, base, index, scale, disp, disp_reloc);
  
#line 13589 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void leaPCompressedOopOffsetNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2478 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(0)->reg(ra_,this)/* dst */ < 8) {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_W);
        } else {
          emit_opcode(cbuf, Assembler::REX_WX);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WXB);
        }
      }
    } else {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WR);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRX);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WRB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRXB);
        }
      }
    }
  
#line 13632 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x8D /*primary()*/));
  
#line 13640 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2511 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // High registers handle in encode_RegMem
    int reg = opnd_array(0)->reg(ra_,this)/* dst */;
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int disp = opnd_array(1)->disp(ra_,this,idx1);
    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();

    encode_RegMem(cbuf, reg, base, index, scale, disp, disp_reloc);
  
#line 13656 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void leaP8NarrowNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2478 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(0)->reg(ra_,this)/* dst */ < 8) {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_W);
        } else {
          emit_opcode(cbuf, Assembler::REX_WX);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WXB);
        }
      }
    } else {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WR);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRX);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WRB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRXB);
        }
      }
    }
  
#line 13699 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x8D /*primary()*/));
  
#line 13707 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2511 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // High registers handle in encode_RegMem
    int reg = opnd_array(0)->reg(ra_,this)/* dst */;
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int disp = opnd_array(1)->disp(ra_,this,idx1);
    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();

    encode_RegMem(cbuf, reg, base, index, scale, disp, disp_reloc);
  
#line 13723 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void leaP32NarrowNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2478 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(0)->reg(ra_,this)/* dst */ < 8) {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_W);
        } else {
          emit_opcode(cbuf, Assembler::REX_WX);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WXB);
        }
      }
    } else {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WR);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRX);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WRB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRXB);
        }
      }
    }
  
#line 13766 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x8D /*primary()*/));
  
#line 13774 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2511 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // High registers handle in encode_RegMem
    int reg = opnd_array(0)->reg(ra_,this)/* dst */;
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int disp = opnd_array(1)->disp(ra_,this,idx1);
    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();

    encode_RegMem(cbuf, reg, base, index, scale, disp, disp_reloc);
  
#line 13790 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void leaPIdxOffNarrowNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2478 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(0)->reg(ra_,this)/* dst */ < 8) {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_W);
        } else {
          emit_opcode(cbuf, Assembler::REX_WX);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WXB);
        }
      }
    } else {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WR);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRX);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WRB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRXB);
        }
      }
    }
  
#line 13833 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x8D /*primary()*/));
  
#line 13841 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2511 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // High registers handle in encode_RegMem
    int reg = opnd_array(0)->reg(ra_,this)/* dst */;
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int disp = opnd_array(1)->disp(ra_,this,idx1);
    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();

    encode_RegMem(cbuf, reg, base, index, scale, disp, disp_reloc);
  
#line 13857 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void leaPIdxScaleNarrowNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2478 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(0)->reg(ra_,this)/* dst */ < 8) {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_W);
        } else {
          emit_opcode(cbuf, Assembler::REX_WX);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WXB);
        }
      }
    } else {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WR);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRX);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WRB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRXB);
        }
      }
    }
  
#line 13900 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x8D /*primary()*/));
  
#line 13908 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2511 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // High registers handle in encode_RegMem
    int reg = opnd_array(0)->reg(ra_,this)/* dst */;
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int disp = opnd_array(1)->disp(ra_,this,idx1);
    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();

    encode_RegMem(cbuf, reg, base, index, scale, disp, disp_reloc);
  
#line 13924 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void leaPIdxScaleOffNarrowNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2478 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(0)->reg(ra_,this)/* dst */ < 8) {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_W);
        } else {
          emit_opcode(cbuf, Assembler::REX_WX);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WXB);
        }
      }
    } else {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WR);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRX);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WRB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRXB);
        }
      }
    }
  
#line 13967 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x8D /*primary()*/));
  
#line 13975 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2511 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // High registers handle in encode_RegMem
    int reg = opnd_array(0)->reg(ra_,this)/* dst */;
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int disp = opnd_array(1)->disp(ra_,this,idx1);
    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();

    encode_RegMem(cbuf, reg, base, index, scale, disp, disp_reloc);
  
#line 13991 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void leaPPosIdxScaleOffNarrowNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2478 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(0)->reg(ra_,this)/* dst */ < 8) {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_W);
        } else {
          emit_opcode(cbuf, Assembler::REX_WX);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WXB);
        }
      }
    } else {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WR);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRX);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WRB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRXB);
        }
      }
    }
  
#line 14034 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x8D /*primary()*/));
  
#line 14042 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2511 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // High registers handle in encode_RegMem
    int reg = opnd_array(0)->reg(ra_,this)/* dst */;
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int disp = opnd_array(1)->disp(ra_,this,idx1);
    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();

    encode_RegMem(cbuf, reg, base, index, scale, disp, disp_reloc);
  
#line 14058 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void loadConINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {

#line 2190 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    int dstenc = opnd_array(0)->reg(ra_,this)/* dst */;
    if (dstenc >= 8) {
      emit_opcode(cbuf, Assembler::REX_B);
      dstenc -= 8;
    }
    emit_opcode(cbuf, 0xB8 | dstenc);
    emit_d32(cbuf, opnd_array(1)->constant());
  
#line 14079 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void loadConI0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {

#line 2415 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(0)->reg(ra_,this)/* dst */ < 8) {
      if (opnd_array(0)->reg(ra_,this)/* dst */ >= 8) {
        emit_opcode(cbuf, Assembler::REX_B);
      }
    } else {
      if (opnd_array(0)->reg(ra_,this)/* dst */ < 8) {
        emit_opcode(cbuf, Assembler::REX_R);
      } else {
        emit_opcode(cbuf, Assembler::REX_RB);
      }
    }
  
#line 14104 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x33 /*primary()*/));
  
#line 14112 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1815 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_rm(cbuf, 0x3, opnd_array(0)->reg(ra_,this)/* dst */ & 7, opnd_array(0)->reg(ra_,this)/* dst */ & 7);
  
#line 14120 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void loadConLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {

#line 2201 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    int dstenc = opnd_array(0)->reg(ra_,this)/* dst */;
    if (dstenc < 8) {
      emit_opcode(cbuf, Assembler::REX_W);
    } else {
      emit_opcode(cbuf, Assembler::REX_WB);
      dstenc -= 8;
    }
    emit_opcode(cbuf, 0xB8 | dstenc);
    emit_d64(cbuf, opnd_array(1)->constantL());
  
#line 14143 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void loadConL0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {

#line 2415 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(0)->reg(ra_,this)/* dst */ < 8) {
      if (opnd_array(0)->reg(ra_,this)/* dst */ >= 8) {
        emit_opcode(cbuf, Assembler::REX_B);
      }
    } else {
      if (opnd_array(0)->reg(ra_,this)/* dst */ < 8) {
        emit_opcode(cbuf, Assembler::REX_R);
      } else {
        emit_opcode(cbuf, Assembler::REX_RB);
      }
    }
  
#line 14168 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x33 /*primary()*/));
  
#line 14176 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1815 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_rm(cbuf, 0x3, opnd_array(0)->reg(ra_,this)/* dst */ & 7, opnd_array(0)->reg(ra_,this)/* dst */ & 7);
  
#line 14184 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void loadConUL32Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {

#line 2214 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // same as load_immI, but this time we care about zeroes in the high word
    int dstenc = opnd_array(0)->reg(ra_,this)/* dst */;
    if (dstenc >= 8) {
      emit_opcode(cbuf, Assembler::REX_B);
      dstenc -= 8;
    }
    emit_opcode(cbuf, 0xB8 | dstenc);
    emit_d32(cbuf, opnd_array(1)->constantL());
  
#line 14206 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void loadConL32Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {

#line 2226 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    int dstenc = opnd_array(0)->reg(ra_,this)/* dst */;
    if (dstenc < 8) {
      emit_opcode(cbuf, Assembler::REX_W);
    } else {
      emit_opcode(cbuf, Assembler::REX_WB);
      dstenc -= 8;
    }
    emit_opcode(cbuf, 0xC7);
    emit_rm(cbuf, 0x03, 0x00, dstenc);
    emit_d32(cbuf, opnd_array(1)->constantL());
  
#line 14230 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void loadConPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {

#line 2252 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    int dstenc = opnd_array(0)->reg(ra_,this)/* dst */;
    if (dstenc < 8) {
      emit_opcode(cbuf, Assembler::REX_W);
    } else {
      emit_opcode(cbuf, Assembler::REX_WB);
      dstenc -= 8;
    }
    emit_opcode(cbuf, 0xB8 | dstenc);
    // This next line should be generated from ADLC
    if (opnd_array(1)->constant_reloc() != relocInfo::none) {
      emit_d64_reloc(cbuf, opnd_array(1)->constant(), opnd_array(1)->constant_reloc(), RELOC_IMM64);
    } else {
      emit_d64(cbuf, opnd_array(1)->constant());
    }
  
#line 14258 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void loadConP0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {

#line 2415 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(0)->reg(ra_,this)/* dst */ < 8) {
      if (opnd_array(0)->reg(ra_,this)/* dst */ >= 8) {
        emit_opcode(cbuf, Assembler::REX_B);
      }
    } else {
      if (opnd_array(0)->reg(ra_,this)/* dst */ < 8) {
        emit_opcode(cbuf, Assembler::REX_R);
      } else {
        emit_opcode(cbuf, Assembler::REX_RB);
      }
    }
  
#line 14283 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x33 /*primary()*/));
  
#line 14291 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1815 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_rm(cbuf, 0x3, opnd_array(0)->reg(ra_,this)/* dst */ & 7, opnd_array(0)->reg(ra_,this)/* dst */ & 7);
  
#line 14299 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void loadConP31Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {

#line 2240 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // same as load_immI, but this time we care about zeroes in the high word
    int dstenc = opnd_array(0)->reg(ra_,this)/* dst */;
    if (dstenc >= 8) {
      emit_opcode(cbuf, Assembler::REX_B);
      dstenc -= 8;
    }
    emit_opcode(cbuf, 0xB8 | dstenc);
    
if ( opnd_array(1)->constant_reloc() != relocInfo::none ) {
  emit_d32_reloc(cbuf, opnd_array(1)->constant(), opnd_array(1)->constant_reloc(), 0);
} else {
  emit_d32(cbuf, opnd_array(1)->constant());
};
  
#line 14326 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void loadConFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 5317 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ movflt(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, InternalAddress(__ code()->consts()->start() + constant_offset()));
  
#line 14342 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void loadConFNode::eval_constant(Compile* C) {
  {

#line 5318 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"
    _constant = C->constant_table().add(this, opnd_array(1));
#line 14351 "../generated/adfiles/ad_x86_64.cpp"
  }
}
void loadConN0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 5327 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ xorq(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(0)->as_Register(ra_,this)/* dst */);
  
#line 14366 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void loadConNNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 5338 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    address con = (address)opnd_array(1)->constant();
    if (con == NULL) {
      ShouldNotReachHere();
    } else {
      __ set_narrow_oop(opnd_array(0)->as_Register(ra_,this)/* dst */, (jobject)opnd_array(1)->constant());
    }
  
#line 14387 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void loadConNKlassNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 5354 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    address con = (address)opnd_array(1)->constant();
    if (con == NULL) {
      ShouldNotReachHere();
    } else {
      __ set_narrow_klass(opnd_array(0)->as_Register(ra_,this)/* dst */, (Klass*)opnd_array(1)->constant());
    }
  
#line 14408 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void loadConF0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 5371 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ xorps(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */);
  
#line 14424 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void loadConDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 5382 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ movdbl(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, InternalAddress(__ code()->consts()->start() + constant_offset()));
  
#line 14440 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void loadConDNode::eval_constant(Compile* C) {
  {

#line 5383 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"
    _constant = C->constant_table().add(this, opnd_array(1));
#line 14449 "../generated/adfiles/ad_x86_64.cpp"
  }
}
void loadConD0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 5394 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ xorpd (opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */);
  
#line 14464 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void loadSSINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {

#line 2447 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(0)->reg(ra_,this)/* dst */ < 8) {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) >= 8) {
          emit_opcode(cbuf, Assembler::REX_X);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_B);
        } else {
          emit_opcode(cbuf, Assembler::REX_XB);
        }
      }
    } else {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_R);
        } else {
          emit_opcode(cbuf, Assembler::REX_RX);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_RB);
        } else {
          emit_opcode(cbuf, Assembler::REX_RXB);
        }
      }
    }
  
#line 14505 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x8B /*primary()*/));
  
#line 14513 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2511 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // High registers handle in encode_RegMem
    int reg = opnd_array(0)->reg(ra_,this)/* dst */;
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int disp = opnd_array(1)->disp(ra_,this,idx1);
    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();

    encode_RegMem(cbuf, reg, base, index, scale, disp, disp_reloc);
  
#line 14529 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void loadSSLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {

#line 2478 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(0)->reg(ra_,this)/* dst */ < 8) {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_W);
        } else {
          emit_opcode(cbuf, Assembler::REX_WX);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WXB);
        }
      }
    } else {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WR);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRX);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WRB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRXB);
        }
      }
    }
  
#line 14572 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x8B /*primary()*/));
  
#line 14580 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2511 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // High registers handle in encode_RegMem
    int reg = opnd_array(0)->reg(ra_,this)/* dst */;
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int disp = opnd_array(1)->disp(ra_,this,idx1);
    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();

    encode_RegMem(cbuf, reg, base, index, scale, disp, disp_reloc);
  
#line 14596 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void loadSSPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {

#line 2478 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(0)->reg(ra_,this)/* dst */ < 8) {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_W);
        } else {
          emit_opcode(cbuf, Assembler::REX_WX);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WXB);
        }
      }
    } else {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WR);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRX);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WRB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRXB);
        }
      }
    }
  
#line 14639 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x8B /*primary()*/));
  
#line 14647 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2511 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // High registers handle in encode_RegMem
    int reg = opnd_array(0)->reg(ra_,this)/* dst */;
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int disp = opnd_array(1)->disp(ra_,this,idx1);
    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();

    encode_RegMem(cbuf, reg, base, index, scale, disp, disp_reloc);
  
#line 14663 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void loadSSFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 5439 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ movflt(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, Address(rsp, opnd_array(1)->disp(ra_,this,idx1)));
  
#line 14679 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void loadSSDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 5452 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ movdbl(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, Address(rsp, opnd_array(1)->disp(ra_,this,idx1)));
  
#line 14695 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void prefetchrNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 5467 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ prefetchr(Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
  
#line 14711 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void prefetchrNTANode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 5479 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ prefetchnta(Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
  
#line 14727 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void prefetchrT0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 5491 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ prefetcht0(Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
  
#line 14743 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void prefetchrT2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 5503 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ prefetcht2(Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
  
#line 14759 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void prefetchwNTANode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 5514 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ prefetchnta(Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
  
#line 14775 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void prefetchAllocNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 5528 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ prefetchw(Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
  
#line 14791 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void prefetchAllocNTANode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 5540 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ prefetchnta(Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
  
#line 14807 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void prefetchAllocT0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 5552 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ prefetcht0(Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
  
#line 14823 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void prefetchAllocT2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 5564 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ prefetcht2(Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
  
#line 14839 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void storeBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2366 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(2)->reg(ra_,this,idx2)/* src */ < 8) {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) >= 8) {
          emit_opcode(cbuf, Assembler::REX_X);
        } else if (opnd_array(2)->reg(ra_,this,idx2)/* src */ >= 4) {
          emit_opcode(cbuf, Assembler::REX);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_B);
        } else {
          emit_opcode(cbuf, Assembler::REX_XB);
        }
      }
    } else {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_R);
        } else {
          emit_opcode(cbuf, Assembler::REX_RX);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_RB);
        } else {
          emit_opcode(cbuf, Assembler::REX_RXB);
        }
      }
    }
  
#line 14883 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x88 /*primary()*/));
  
#line 14891 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2511 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // High registers handle in encode_RegMem
    int reg = opnd_array(2)->reg(ra_,this,idx2)/* src */;
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int disp = opnd_array(1)->disp(ra_,this,idx1);
    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();

    encode_RegMem(cbuf, reg, base, index, scale, disp, disp_reloc);
  
#line 14907 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void storeCNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 1805 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, 0x66);
  
#line 14923 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2447 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(2)->reg(ra_,this,idx2)/* src */ < 8) {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) >= 8) {
          emit_opcode(cbuf, Assembler::REX_X);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_B);
        } else {
          emit_opcode(cbuf, Assembler::REX_XB);
        }
      }
    } else {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_R);
        } else {
          emit_opcode(cbuf, Assembler::REX_RX);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_RB);
        } else {
          emit_opcode(cbuf, Assembler::REX_RXB);
        }
      }
    }
  
#line 14957 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x89 /*primary()*/));
  
#line 14965 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2511 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // High registers handle in encode_RegMem
    int reg = opnd_array(2)->reg(ra_,this,idx2)/* src */;
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int disp = opnd_array(1)->disp(ra_,this,idx1);
    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();

    encode_RegMem(cbuf, reg, base, index, scale, disp, disp_reloc);
  
#line 14981 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void storeINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2447 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(2)->reg(ra_,this,idx2)/* src */ < 8) {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) >= 8) {
          emit_opcode(cbuf, Assembler::REX_X);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_B);
        } else {
          emit_opcode(cbuf, Assembler::REX_XB);
        }
      }
    } else {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_R);
        } else {
          emit_opcode(cbuf, Assembler::REX_RX);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_RB);
        } else {
          emit_opcode(cbuf, Assembler::REX_RXB);
        }
      }
    }
  
#line 15023 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x89 /*primary()*/));
  
#line 15031 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2511 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // High registers handle in encode_RegMem
    int reg = opnd_array(2)->reg(ra_,this,idx2)/* src */;
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int disp = opnd_array(1)->disp(ra_,this,idx1);
    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();

    encode_RegMem(cbuf, reg, base, index, scale, disp, disp_reloc);
  
#line 15047 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void storeLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2478 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(2)->reg(ra_,this,idx2)/* src */ < 8) {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_W);
        } else {
          emit_opcode(cbuf, Assembler::REX_WX);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WXB);
        }
      }
    } else {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WR);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRX);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WRB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRXB);
        }
      }
    }
  
#line 15091 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x89 /*primary()*/));
  
#line 15099 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2511 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // High registers handle in encode_RegMem
    int reg = opnd_array(2)->reg(ra_,this,idx2)/* src */;
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int disp = opnd_array(1)->disp(ra_,this,idx1);
    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();

    encode_RegMem(cbuf, reg, base, index, scale, disp, disp_reloc);
  
#line 15115 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void storePNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2478 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(2)->reg(ra_,this,idx2)/* src */ < 8) {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_W);
        } else {
          emit_opcode(cbuf, Assembler::REX_WX);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WXB);
        }
      }
    } else {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WR);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRX);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WRB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRXB);
        }
      }
    }
  
#line 15159 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x89 /*primary()*/));
  
#line 15167 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2511 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // High registers handle in encode_RegMem
    int reg = opnd_array(2)->reg(ra_,this,idx2)/* src */;
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int disp = opnd_array(1)->disp(ra_,this,idx1);
    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();

    encode_RegMem(cbuf, reg, base, index, scale, disp, disp_reloc);
  
#line 15183 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void storeImmP0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {
    MacroAssembler _masm(&cbuf);

#line 5639 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ movq(Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()), r12);
  
#line 15200 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void storeImmPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2324 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->base(ra_,this,idx1) >= 8) {
      if (opnd_array(1)->index(ra_,this,idx1) < 8) {
        emit_opcode(cbuf, Assembler::REX_WB);
      } else {
        emit_opcode(cbuf, Assembler::REX_WXB);
      }
    } else {
      if (opnd_array(1)->index(ra_,this,idx1) < 8) {
        emit_opcode(cbuf, Assembler::REX_W);
      } else {
        emit_opcode(cbuf, Assembler::REX_WX);
      }
    }
  
#line 15228 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xC7 /*primary()*/));
  
#line 15236 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2524 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    int rm_byte_opcode = (0x00);

    // High registers handle in encode_RegMem
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);

    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();       // disp-as-oop when
                                            // working with static
                                            // globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace,
                  disp_reloc);
  
#line 15256 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2270 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // Output immediate
    
if ( opnd_array(2)->constant_reloc() != relocInfo::none ) {
  emit_d32_reloc(cbuf, opnd_array(2)->constant(), opnd_array(2)->constant_reloc(), 0);
} else {
  emit_d32(cbuf, opnd_array(2)->constant());
};
  
#line 15270 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void storeNNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 5664 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ movl(Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()), opnd_array(2)->as_Register(ra_,this,idx2)/* src */);
  
#line 15287 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void storeNKlassNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 5676 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ movl(Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()), opnd_array(2)->as_Register(ra_,this,idx2)/* src */);
  
#line 15304 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void storeImmN0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {
    MacroAssembler _masm(&cbuf);

#line 5689 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ movl(Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()), r12);
  
#line 15321 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void storeImmNNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 5701 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    address con = (address)opnd_array(2)->constant();
    if (con == NULL) {
      __ movl(Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()), (int32_t)0);
    } else {
      __ set_narrow_oop(Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()), (jobject)opnd_array(2)->constant());
    }
  
#line 15343 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void storeImmNKlassNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 5718 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ set_narrow_klass(Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()), (Klass*)opnd_array(2)->constant());
  
#line 15360 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void storeImmI0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {
    MacroAssembler _masm(&cbuf);

#line 5732 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ movl(Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()), r12);
  
#line 15377 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void storeImmINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2309 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->base(ra_,this,idx1) >= 8) {
      if (opnd_array(1)->index(ra_,this,idx1) < 8) {
        emit_opcode(cbuf, Assembler::REX_B);
      } else {
        emit_opcode(cbuf, Assembler::REX_XB);
      }
    } else {
      if (opnd_array(1)->index(ra_,this,idx1) >= 8) {
        emit_opcode(cbuf, Assembler::REX_X);
      }
    }
  
#line 15403 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xC7 /*primary()*/));
  
#line 15411 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2524 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    int rm_byte_opcode = (0x00);

    // High registers handle in encode_RegMem
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);

    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();       // disp-as-oop when
                                            // working with static
                                            // globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace,
                  disp_reloc);
  
#line 15431 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2270 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // Output immediate
    emit_d32(cbuf, opnd_array(2)->constant());
  
#line 15440 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void storeImmL0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {
    MacroAssembler _masm(&cbuf);

#line 5757 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ movq(Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()), r12);
  
#line 15457 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void storeImmLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2324 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->base(ra_,this,idx1) >= 8) {
      if (opnd_array(1)->index(ra_,this,idx1) < 8) {
        emit_opcode(cbuf, Assembler::REX_WB);
      } else {
        emit_opcode(cbuf, Assembler::REX_WXB);
      }
    } else {
      if (opnd_array(1)->index(ra_,this,idx1) < 8) {
        emit_opcode(cbuf, Assembler::REX_W);
      } else {
        emit_opcode(cbuf, Assembler::REX_WX);
      }
    }
  
#line 15485 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xC7 /*primary()*/));
  
#line 15493 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2524 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    int rm_byte_opcode = (0x00);

    // High registers handle in encode_RegMem
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);

    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();       // disp-as-oop when
                                            // working with static
                                            // globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace,
                  disp_reloc);
  
#line 15513 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2270 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // Output immediate
    emit_d32(cbuf, opnd_array(2)->constantL());
  
#line 15522 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void storeImmC0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {
    MacroAssembler _masm(&cbuf);

#line 5782 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ movw(Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()), r12);
  
#line 15539 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void storeImmI16Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 1805 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, 0x66);
  
#line 15555 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2309 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->base(ra_,this,idx1) >= 8) {
      if (opnd_array(1)->index(ra_,this,idx1) < 8) {
        emit_opcode(cbuf, Assembler::REX_B);
      } else {
        emit_opcode(cbuf, Assembler::REX_XB);
      }
    } else {
      if (opnd_array(1)->index(ra_,this,idx1) >= 8) {
        emit_opcode(cbuf, Assembler::REX_X);
      }
    }
  
#line 15573 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xC7 /*primary()*/));
  
#line 15581 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2524 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    int rm_byte_opcode = (0x00);

    // High registers handle in encode_RegMem
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);

    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();       // disp-as-oop when
                                            // working with static
                                            // globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace,
                  disp_reloc);
  
#line 15601 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2284 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // Output immediate
    emit_d16(cbuf, opnd_array(2)->constant());
  
#line 15610 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void storeImmB0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {
    MacroAssembler _masm(&cbuf);

#line 5808 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ movb(Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()), r12);
  
#line 15627 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void storeImmBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2309 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->base(ra_,this,idx1) >= 8) {
      if (opnd_array(1)->index(ra_,this,idx1) < 8) {
        emit_opcode(cbuf, Assembler::REX_B);
      } else {
        emit_opcode(cbuf, Assembler::REX_XB);
      }
    } else {
      if (opnd_array(1)->index(ra_,this,idx1) >= 8) {
        emit_opcode(cbuf, Assembler::REX_X);
      }
    }
  
#line 15653 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xC6 /*primary()*/));
  
#line 15661 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2524 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    int rm_byte_opcode = (0x00);

    // High registers handle in encode_RegMem
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);

    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();       // disp-as-oop when
                                            // working with static
                                            // globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace,
                  disp_reloc);
  
#line 15681 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2016 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // Check for 8-bit immediate, and set sign extend bit in opcode
    if (-0x80 <= opnd_array(2)->constant() && opnd_array(2)->constant() < 0x80) {
      emit_d8(cbuf, opnd_array(2)->constant());
    } else {
      // 32-bit immediate
      emit_d32(cbuf, opnd_array(2)->constant());
    }
  
#line 15695 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void storeImmCM0_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {
    MacroAssembler _masm(&cbuf);

#line 5833 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ movb(Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()), r12);
  
#line 15712 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void storeImmCM0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2309 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->base(ra_,this,idx1) >= 8) {
      if (opnd_array(1)->index(ra_,this,idx1) < 8) {
        emit_opcode(cbuf, Assembler::REX_B);
      } else {
        emit_opcode(cbuf, Assembler::REX_XB);
      }
    } else {
      if (opnd_array(1)->index(ra_,this,idx1) >= 8) {
        emit_opcode(cbuf, Assembler::REX_X);
      }
    }
  
#line 15738 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xC6 /*primary()*/));
  
#line 15746 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2524 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    int rm_byte_opcode = (0x00);

    // High registers handle in encode_RegMem
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);

    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();       // disp-as-oop when
                                            // working with static
                                            // globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace,
                  disp_reloc);
  
#line 15766 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2016 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // Check for 8-bit immediate, and set sign extend bit in opcode
    if (-0x80 <= opnd_array(2)->constant() && opnd_array(2)->constant() < 0x80) {
      emit_d8(cbuf, opnd_array(2)->constant());
    } else {
      // 32-bit immediate
      emit_d32(cbuf, opnd_array(2)->constant());
    }
  
#line 15780 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void storeFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 5857 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ movflt(Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()), opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 15797 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void storeF0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {
    MacroAssembler _masm(&cbuf);

#line 5871 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ movl(Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()), r12);
  
#line 15814 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void storeF_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2309 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->base(ra_,this,idx1) >= 8) {
      if (opnd_array(1)->index(ra_,this,idx1) < 8) {
        emit_opcode(cbuf, Assembler::REX_B);
      } else {
        emit_opcode(cbuf, Assembler::REX_XB);
      }
    } else {
      if (opnd_array(1)->index(ra_,this,idx1) >= 8) {
        emit_opcode(cbuf, Assembler::REX_X);
      }
    }
  
#line 15840 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xC7 /*primary()*/));
  
#line 15848 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2524 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    int rm_byte_opcode = (0x00);

    // High registers handle in encode_RegMem
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);

    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();       // disp-as-oop when
                                            // working with static
                                            // globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace,
                  disp_reloc);
  
#line 15868 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2276 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // Output Float immediate bits
    jfloat jf = opnd_array(2)->constantF();
    jint jf_as_bits = jint_cast(jf);
    emit_d32(cbuf, jf_as_bits);
  
#line 15879 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void storeDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 5895 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ movdbl(Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()), opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 15896 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void storeD0_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2324 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->base(ra_,this,idx1) >= 8) {
      if (opnd_array(1)->index(ra_,this,idx1) < 8) {
        emit_opcode(cbuf, Assembler::REX_WB);
      } else {
        emit_opcode(cbuf, Assembler::REX_WXB);
      }
    } else {
      if (opnd_array(1)->index(ra_,this,idx1) < 8) {
        emit_opcode(cbuf, Assembler::REX_W);
      } else {
        emit_opcode(cbuf, Assembler::REX_WX);
      }
    }
  
#line 15924 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xC7 /*primary()*/));
  
#line 15932 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2524 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    int rm_byte_opcode = (0x00);

    // High registers handle in encode_RegMem
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);

    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();       // disp-as-oop when
                                            // working with static
                                            // globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace,
                  disp_reloc);
  
#line 15952 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2276 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // Output Float immediate bits
    jfloat jf = opnd_array(2)->constantD();
    jint jf_as_bits = jint_cast(jf);
    emit_d32(cbuf, jf_as_bits);
  
#line 15963 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void storeD0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {
    MacroAssembler _masm(&cbuf);

#line 5921 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ movq(Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()), r12);
  
#line 15980 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void storeSSINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {

#line 2447 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->reg(ra_,this,idx1)/* src */ < 8) {
      if (opnd_array(0)->base(ra_,this,idx0) < 8) {
        if (opnd_array(0)->index(ra_,this,idx0) >= 8) {
          emit_opcode(cbuf, Assembler::REX_X);
        }
      } else {
        if (opnd_array(0)->index(ra_,this,idx0) < 8) {
          emit_opcode(cbuf, Assembler::REX_B);
        } else {
          emit_opcode(cbuf, Assembler::REX_XB);
        }
      }
    } else {
      if (opnd_array(0)->base(ra_,this,idx0) < 8) {
        if (opnd_array(0)->index(ra_,this,idx0) < 8) {
          emit_opcode(cbuf, Assembler::REX_R);
        } else {
          emit_opcode(cbuf, Assembler::REX_RX);
        }
      } else {
        if (opnd_array(0)->index(ra_,this,idx0) < 8) {
          emit_opcode(cbuf, Assembler::REX_RB);
        } else {
          emit_opcode(cbuf, Assembler::REX_RXB);
        }
      }
    }
  
#line 16021 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x89 /*primary()*/));
  
#line 16029 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2511 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // High registers handle in encode_RegMem
    int reg = opnd_array(1)->reg(ra_,this,idx1)/* src */;
    int base = opnd_array(0)->base(ra_,this,idx0);
    int index = opnd_array(0)->index(ra_,this,idx0);
    int scale = opnd_array(0)->scale();
    int disp = opnd_array(0)->disp(ra_,this,0);
    relocInfo::relocType disp_reloc = opnd_array(0)->disp_reloc();

    encode_RegMem(cbuf, reg, base, index, scale, disp, disp_reloc);
  
#line 16045 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void storeSSLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {

#line 2478 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->reg(ra_,this,idx1)/* src */ < 8) {
      if (opnd_array(0)->base(ra_,this,idx0) < 8) {
        if (opnd_array(0)->index(ra_,this,idx0) < 8) {
          emit_opcode(cbuf, Assembler::REX_W);
        } else {
          emit_opcode(cbuf, Assembler::REX_WX);
        }
      } else {
        if (opnd_array(0)->index(ra_,this,idx0) < 8) {
          emit_opcode(cbuf, Assembler::REX_WB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WXB);
        }
      }
    } else {
      if (opnd_array(0)->base(ra_,this,idx0) < 8) {
        if (opnd_array(0)->index(ra_,this,idx0) < 8) {
          emit_opcode(cbuf, Assembler::REX_WR);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRX);
        }
      } else {
        if (opnd_array(0)->index(ra_,this,idx0) < 8) {
          emit_opcode(cbuf, Assembler::REX_WRB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRXB);
        }
      }
    }
  
#line 16088 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x89 /*primary()*/));
  
#line 16096 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2511 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // High registers handle in encode_RegMem
    int reg = opnd_array(1)->reg(ra_,this,idx1)/* src */;
    int base = opnd_array(0)->base(ra_,this,idx0);
    int index = opnd_array(0)->index(ra_,this,idx0);
    int scale = opnd_array(0)->scale();
    int disp = opnd_array(0)->disp(ra_,this,0);
    relocInfo::relocType disp_reloc = opnd_array(0)->disp_reloc();

    encode_RegMem(cbuf, reg, base, index, scale, disp, disp_reloc);
  
#line 16112 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void storeSSPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {

#line 2478 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->reg(ra_,this,idx1)/* src */ < 8) {
      if (opnd_array(0)->base(ra_,this,idx0) < 8) {
        if (opnd_array(0)->index(ra_,this,idx0) < 8) {
          emit_opcode(cbuf, Assembler::REX_W);
        } else {
          emit_opcode(cbuf, Assembler::REX_WX);
        }
      } else {
        if (opnd_array(0)->index(ra_,this,idx0) < 8) {
          emit_opcode(cbuf, Assembler::REX_WB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WXB);
        }
      }
    } else {
      if (opnd_array(0)->base(ra_,this,idx0) < 8) {
        if (opnd_array(0)->index(ra_,this,idx0) < 8) {
          emit_opcode(cbuf, Assembler::REX_WR);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRX);
        }
      } else {
        if (opnd_array(0)->index(ra_,this,idx0) < 8) {
          emit_opcode(cbuf, Assembler::REX_WRB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRXB);
        }
      }
    }
  
#line 16155 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x89 /*primary()*/));
  
#line 16163 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2511 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // High registers handle in encode_RegMem
    int reg = opnd_array(1)->reg(ra_,this,idx1)/* src */;
    int base = opnd_array(0)->base(ra_,this,idx0);
    int index = opnd_array(0)->index(ra_,this,idx0);
    int scale = opnd_array(0)->scale();
    int disp = opnd_array(0)->disp(ra_,this,0);
    relocInfo::relocType disp_reloc = opnd_array(0)->disp_reloc();

    encode_RegMem(cbuf, reg, base, index, scale, disp, disp_reloc);
  
#line 16179 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void storeSSFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 5966 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ movflt(Address(rsp, opnd_array(0)->disp(ra_,this,0)), opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */);
  
#line 16195 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void storeSSDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 5978 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ movdbl(Address(rsp, opnd_array(0)->disp(ra_,this,0)), opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */);
  
#line 16211 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void bytes_reverse_intNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  {

#line 2399 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->reg(ra_,this,idx1)/* dst */ >= 8) {
      emit_opcode(cbuf, Assembler::REX_B);
    }
  
#line 16228 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x0F /*primary()*/));
  
#line 16236 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2027 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // BSWAP
    emit_cc(cbuf, (0xC8 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1)/* dst */);
  
#line 16245 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void bytes_reverse_longNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  {

#line 2406 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->reg(ra_,this,idx1)/* dst */ < 8) {
      emit_opcode(cbuf, Assembler::REX_W);
    } else {
      emit_opcode(cbuf, Assembler::REX_WB);
    }
  
#line 16264 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x0F /*primary()*/));
  
#line 16272 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2027 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // BSWAP
    emit_cc(cbuf, (0xC8 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1)/* dst */);
  
#line 16281 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void bytes_reverse_unsigned_shortNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  {
    MacroAssembler _masm(&cbuf);

#line 6009 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ bswapl(opnd_array(1)->as_Register(ra_,this,idx1)/* dst */);
    __ shrl(opnd_array(1)->as_Register(ra_,this,idx1)/* dst */, 16);
  
#line 16298 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void bytes_reverse_shortNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  {
    MacroAssembler _masm(&cbuf);

#line 6022 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ bswapl(opnd_array(1)->as_Register(ra_,this,idx1)/* dst */);
    __ sarl(opnd_array(1)->as_Register(ra_,this,idx1)/* dst */, 16);
  
#line 16315 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void countLeadingZerosINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 6037 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ lzcntl(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
  
#line 16331 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void countLeadingZerosI_bsrNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 6054 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    Register Rdst = opnd_array(0)->as_Register(ra_,this)/* dst */;
    Register Rsrc = opnd_array(1)->as_Register(ra_,this,idx1)/* src */;
    Label skip;
    __ bsrl(Rdst, Rsrc);
    __ jccb(Assembler::notZero, skip);
    __ movl(Rdst, -1);
    __ bind(skip);
    __ negl(Rdst);
    __ addl(Rdst, BitsPerInt - 1);
  
#line 16355 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void countLeadingZerosLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 6074 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ lzcntq(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
  
#line 16371 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void countLeadingZerosL_bsrNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 6091 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    Register Rdst = opnd_array(0)->as_Register(ra_,this)/* dst */;
    Register Rsrc = opnd_array(1)->as_Register(ra_,this,idx1)/* src */;
    Label skip;
    __ bsrq(Rdst, Rsrc);
    __ jccb(Assembler::notZero, skip);
    __ movl(Rdst, -1);
    __ bind(skip);
    __ negl(Rdst);
    __ addl(Rdst, BitsPerLong - 1);
  
#line 16395 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void countTrailingZerosINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 6111 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ tzcntl(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
  
#line 16411 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void countTrailingZerosI_bsfNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 6126 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    Register Rdst = opnd_array(0)->as_Register(ra_,this)/* dst */;
    Label done;
    __ bsfl(Rdst, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
    __ jccb(Assembler::notZero, done);
    __ movl(Rdst, BitsPerInt);
    __ bind(done);
  
#line 16432 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void countTrailingZerosLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 6143 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ tzcntq(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
  
#line 16448 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void countTrailingZerosL_bsfNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 6158 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    Register Rdst = opnd_array(0)->as_Register(ra_,this)/* dst */;
    Label done;
    __ bsfq(Rdst, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
    __ jccb(Assembler::notZero, done);
    __ movl(Rdst, BitsPerLong);
    __ bind(done);
  
#line 16469 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void popCountINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 6178 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ popcntl(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
  
#line 16485 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void popCountI_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 6190 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ popcntl(opnd_array(0)->as_Register(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
  
#line 16501 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void popCountLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 6203 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ popcntq(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
  
#line 16517 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void popCountL_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 6216 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ popcntq(opnd_array(0)->as_Register(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
  
#line 16533 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void membar_acquireNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  // User did not define which encode class to use.
}

uint membar_acquireNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 0);
}

void membar_acquire_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  // User did not define which encode class to use.
}

uint membar_acquire_0Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 0);
}

void membar_acquire_lockNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  // User did not define which encode class to use.
}

uint membar_acquire_lockNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 0);
}

void membar_releaseNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  // User did not define which encode class to use.
}

uint membar_releaseNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 0);
}

void membar_release_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  // User did not define which encode class to use.
}

uint membar_release_0Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 0);
}

void membar_release_lockNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  // User did not define which encode class to use.
}

uint membar_release_lockNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 0);
}

void membar_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 6285 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ membar(Assembler::StoreLoad);
  
#line 16627 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void unnecessary_membar_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  // User did not define which encode class to use.
}

uint unnecessary_membar_volatileNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 0);
}

void membar_storestoreNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  // User did not define which encode class to use.
}

uint membar_storestoreNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 0);
}

void castX2PNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 6320 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(0)->reg(ra_,this)/* dst */!= opnd_array(1)->reg(ra_,this,idx1)/* src */) {
      __ movptr(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
    }
  
#line 16671 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void castP2XNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 6333 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(0)->reg(ra_,this)/* dst */!= opnd_array(1)->reg(ra_,this,idx1)/* src */) {
      __ movptr(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
    }
  
#line 16689 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void convP2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 6347 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ movl(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
  
#line 16705 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void convN2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 6361 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ movl(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
  
#line 16721 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void encodeHeapOopNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 6373 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    Register s = opnd_array(1)->as_Register(ra_,this,idx1)/* src */;
    Register d = opnd_array(0)->as_Register(ra_,this)/* dst */;
    if (s != d) {
      __ movq(d, s);
    }
    __ encode_heap_oop(d);
  
#line 16742 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void encodeHeapOop_not_nullNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 6389 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ encode_heap_oop_not_null(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
  
#line 16758 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void decodeHeapOopNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 6401 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    Register s = opnd_array(1)->as_Register(ra_,this,idx1)/* src */;
    Register d = opnd_array(0)->as_Register(ra_,this)/* dst */;
    if (s != d) {
      __ movq(d, s);
    }
    __ decode_heap_oop(d);
  
#line 16779 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void decodeHeapOop_not_nullNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 6418 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    Register s = opnd_array(1)->as_Register(ra_,this,idx1)/* src */;
    Register d = opnd_array(0)->as_Register(ra_,this)/* dst */;
    if (s != d) {
      __ decode_heap_oop_not_null(d, s);
    } else {
      __ decode_heap_oop_not_null(d);
    }
  
#line 16801 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void encodeKlass_not_nullNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 6434 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ encode_klass_not_null(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
  
#line 16817 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void decodeKlass_not_nullNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 6444 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    Register s = opnd_array(1)->as_Register(ra_,this,idx1)/* src */;
    Register d = opnd_array(0)->as_Register(ra_,this)/* dst */;
    if (s != d) {
      __ decode_klass_not_null(d, s);
    } else {
      __ decode_klass_not_null(d);
    }
  
#line 16839 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void jumpXtnd_offsetNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  ra_->C->constant_table().fill_jump_table(cbuf, (MachConstantNode*) this, _index2label);
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// shift
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dest
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 6468 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // We could use jump(ArrayAddress) except that the macro assembler needs to use r10
    // to do that and the compiler is using that register as one it can allocate.
    // So we build it all by hand.
    // Address index(noreg, switch_reg, (Address::ScaleFactor)$shift$$constant);
    // ArrayAddress dispatch(table, index);
    Address dispatch(opnd_array(3)->as_Register(ra_,this,idx3)/* dest */, opnd_array(1)->as_Register(ra_,this,idx1)/* switch_val */, (Address::ScaleFactor) opnd_array(2)->constant());
    __ lea(opnd_array(3)->as_Register(ra_,this,idx3)/* dest */, InternalAddress(__ code()->consts()->start() + constant_offset()));
    __ jmp(dispatch);
  
#line 16865 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void jumpXtnd_offsetNode::eval_constant(Compile* C) {
  _constant = C->constant_table().add_jump_table(this);
  // User did not define an encode section.
}
void jumpXtnd_addrNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  ra_->C->constant_table().fill_jump_table(cbuf, (MachConstantNode*) this, _index2label);
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// shift
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// offset
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dest
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 6488 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // We could use jump(ArrayAddress) except that the macro assembler needs to use r10
    // to do that and the compiler is using that register as one it can allocate.
    // So we build it all by hand.
    // Address index(noreg, switch_reg, (Address::ScaleFactor) $shift$$constant, (int) $offset$$constant);
    // ArrayAddress dispatch(table, index);
    Address dispatch(opnd_array(4)->as_Register(ra_,this,idx4)/* dest */, opnd_array(1)->as_Register(ra_,this,idx1)/* switch_val */, (Address::ScaleFactor) opnd_array(2)->constant(), (int) opnd_array(3)->constantL());
    __ lea(opnd_array(4)->as_Register(ra_,this,idx4)/* dest */, InternalAddress(__ code()->consts()->start() + constant_offset()));
    __ jmp(dispatch);
  
#line 16896 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void jumpXtnd_addrNode::eval_constant(Compile* C) {
  _constant = C->constant_table().add_jump_table(this);
  // User did not define an encode section.
}
void jumpXtndNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  ra_->C->constant_table().fill_jump_table(cbuf, (MachConstantNode*) this, _index2label);
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dest
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 6508 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // We could use jump(ArrayAddress) except that the macro assembler needs to use r10
    // to do that and the compiler is using that register as one it can allocate.
    // So we build it all by hand.
    // Address index(noreg, switch_reg, Address::times_1);
    // ArrayAddress dispatch(table, index);
    Address dispatch(opnd_array(2)->as_Register(ra_,this,idx2)/* dest */, opnd_array(1)->as_Register(ra_,this,idx1)/* switch_val */, Address::times_1);
    __ lea(opnd_array(2)->as_Register(ra_,this,idx2)/* dest */, InternalAddress(__ code()->consts()->start() + constant_offset()));
    __ jmp(dispatch);
  
#line 16925 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void jumpXtndNode::eval_constant(Compile* C) {
  _constant = C->constant_table().add_jump_table(this);
  // User did not define an encode section.
}
void cmovI_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cop
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {

#line 2415 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(3)->reg(ra_,this,idx3)/* dst */ < 8) {
      if (opnd_array(4)->reg(ra_,this,idx4)/* src */ >= 8) {
        emit_opcode(cbuf, Assembler::REX_B);
      }
    } else {
      if (opnd_array(4)->reg(ra_,this,idx4)/* src */ < 8) {
        emit_opcode(cbuf, Assembler::REX_R);
      } else {
        emit_opcode(cbuf, Assembler::REX_RB);
      }
    }
  
#line 16957 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2045 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // CMOV
    emit_d8(cbuf, (0x0F /*primary()*/));
    emit_cc(cbuf, (0x40 /*secondary()*/), opnd_array(1)->ccode());
  
#line 16967 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1815 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_rm(cbuf, 0x3, opnd_array(3)->reg(ra_,this,idx3)/* dst */ & 7, opnd_array(4)->reg(ra_,this,idx4)/* src */ & 7);
  
#line 16975 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void cmovI_regUNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cop
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {

#line 2415 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(3)->reg(ra_,this,idx3)/* dst */ < 8) {
      if (opnd_array(4)->reg(ra_,this,idx4)/* src */ >= 8) {
        emit_opcode(cbuf, Assembler::REX_B);
      }
    } else {
      if (opnd_array(4)->reg(ra_,this,idx4)/* src */ < 8) {
        emit_opcode(cbuf, Assembler::REX_R);
      } else {
        emit_opcode(cbuf, Assembler::REX_RB);
      }
    }
  
#line 17003 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2045 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // CMOV
    emit_d8(cbuf, (0x0F /*primary()*/));
    emit_cc(cbuf, (0x40 /*secondary()*/), opnd_array(1)->ccode());
  
#line 17013 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1815 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_rm(cbuf, 0x3, opnd_array(3)->reg(ra_,this,idx3)/* dst */ & 7, opnd_array(4)->reg(ra_,this,idx4)/* src */ & 7);
  
#line 17021 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void cmovI_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// cop
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {

#line 2447 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(3)->reg(ra_,this,idx3)/* dst */ < 8) {
      if (opnd_array(4)->base(ra_,this,idx4) < 8) {
        if (opnd_array(4)->index(ra_,this,idx4) >= 8) {
          emit_opcode(cbuf, Assembler::REX_X);
        }
      } else {
        if (opnd_array(4)->index(ra_,this,idx4) < 8) {
          emit_opcode(cbuf, Assembler::REX_B);
        } else {
          emit_opcode(cbuf, Assembler::REX_XB);
        }
      }
    } else {
      if (opnd_array(4)->base(ra_,this,idx4) < 8) {
        if (opnd_array(4)->index(ra_,this,idx4) < 8) {
          emit_opcode(cbuf, Assembler::REX_R);
        } else {
          emit_opcode(cbuf, Assembler::REX_RX);
        }
      } else {
        if (opnd_array(4)->index(ra_,this,idx4) < 8) {
          emit_opcode(cbuf, Assembler::REX_RB);
        } else {
          emit_opcode(cbuf, Assembler::REX_RXB);
        }
      }
    }
  
#line 17065 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2045 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // CMOV
    emit_d8(cbuf, (0x0F /*primary()*/));
    emit_cc(cbuf, (0x40 /*secondary()*/), opnd_array(1)->ccode());
  
#line 17075 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2511 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // High registers handle in encode_RegMem
    int reg = opnd_array(3)->reg(ra_,this,idx3)/* dst */;
    int base = opnd_array(4)->base(ra_,this,idx4);
    int index = opnd_array(4)->index(ra_,this,idx4);
    int scale = opnd_array(4)->scale();
    int disp = opnd_array(4)->disp(ra_,this,idx4);
    relocInfo::relocType disp_reloc = opnd_array(4)->disp_reloc();

    encode_RegMem(cbuf, reg, base, index, scale, disp, disp_reloc);
  
#line 17091 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void cmovI_memUNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// cop
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {

#line 2447 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(3)->reg(ra_,this,idx3)/* dst */ < 8) {
      if (opnd_array(4)->base(ra_,this,idx4) < 8) {
        if (opnd_array(4)->index(ra_,this,idx4) >= 8) {
          emit_opcode(cbuf, Assembler::REX_X);
        }
      } else {
        if (opnd_array(4)->index(ra_,this,idx4) < 8) {
          emit_opcode(cbuf, Assembler::REX_B);
        } else {
          emit_opcode(cbuf, Assembler::REX_XB);
        }
      }
    } else {
      if (opnd_array(4)->base(ra_,this,idx4) < 8) {
        if (opnd_array(4)->index(ra_,this,idx4) < 8) {
          emit_opcode(cbuf, Assembler::REX_R);
        } else {
          emit_opcode(cbuf, Assembler::REX_RX);
        }
      } else {
        if (opnd_array(4)->index(ra_,this,idx4) < 8) {
          emit_opcode(cbuf, Assembler::REX_RB);
        } else {
          emit_opcode(cbuf, Assembler::REX_RXB);
        }
      }
    }
  
#line 17135 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2045 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // CMOV
    emit_d8(cbuf, (0x0F /*primary()*/));
    emit_cc(cbuf, (0x40 /*secondary()*/), opnd_array(1)->ccode());
  
#line 17145 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2511 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // High registers handle in encode_RegMem
    int reg = opnd_array(3)->reg(ra_,this,idx3)/* dst */;
    int base = opnd_array(4)->base(ra_,this,idx4);
    int index = opnd_array(4)->index(ra_,this,idx4);
    int scale = opnd_array(4)->scale();
    int disp = opnd_array(4)->disp(ra_,this,idx4);
    relocInfo::relocType disp_reloc = opnd_array(4)->disp_reloc();

    encode_RegMem(cbuf, reg, base, index, scale, disp, disp_reloc);
  
#line 17161 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void cmovN_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cop
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {

#line 2415 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(3)->reg(ra_,this,idx3)/* dst */ < 8) {
      if (opnd_array(4)->reg(ra_,this,idx4)/* src */ >= 8) {
        emit_opcode(cbuf, Assembler::REX_B);
      }
    } else {
      if (opnd_array(4)->reg(ra_,this,idx4)/* src */ < 8) {
        emit_opcode(cbuf, Assembler::REX_R);
      } else {
        emit_opcode(cbuf, Assembler::REX_RB);
      }
    }
  
#line 17189 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2045 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // CMOV
    emit_d8(cbuf, (0x0F /*primary()*/));
    emit_cc(cbuf, (0x40 /*secondary()*/), opnd_array(1)->ccode());
  
#line 17199 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1815 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_rm(cbuf, 0x3, opnd_array(3)->reg(ra_,this,idx3)/* dst */ & 7, opnd_array(4)->reg(ra_,this,idx4)/* src */ & 7);
  
#line 17207 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void cmovN_regUNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cop
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {

#line 2415 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(3)->reg(ra_,this,idx3)/* dst */ < 8) {
      if (opnd_array(4)->reg(ra_,this,idx4)/* src */ >= 8) {
        emit_opcode(cbuf, Assembler::REX_B);
      }
    } else {
      if (opnd_array(4)->reg(ra_,this,idx4)/* src */ < 8) {
        emit_opcode(cbuf, Assembler::REX_R);
      } else {
        emit_opcode(cbuf, Assembler::REX_RB);
      }
    }
  
#line 17235 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2045 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // CMOV
    emit_d8(cbuf, (0x0F /*primary()*/));
    emit_cc(cbuf, (0x40 /*secondary()*/), opnd_array(1)->ccode());
  
#line 17245 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1815 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_rm(cbuf, 0x3, opnd_array(3)->reg(ra_,this,idx3)/* dst */ & 7, opnd_array(4)->reg(ra_,this,idx4)/* src */ & 7);
  
#line 17253 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void cmovP_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cop
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {

#line 2430 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(3)->reg(ra_,this,idx3)/* dst */ < 8) {
      if (opnd_array(4)->reg(ra_,this,idx4)/* src */ < 8) {
        emit_opcode(cbuf, Assembler::REX_W);
      } else {
        emit_opcode(cbuf, Assembler::REX_WB);
      }
    } else {
      if (opnd_array(4)->reg(ra_,this,idx4)/* src */ < 8) {
        emit_opcode(cbuf, Assembler::REX_WR);
      } else {
        emit_opcode(cbuf, Assembler::REX_WRB);
      }
    }
  
#line 17283 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2045 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // CMOV
    emit_d8(cbuf, (0x0F /*primary()*/));
    emit_cc(cbuf, (0x40 /*secondary()*/), opnd_array(1)->ccode());
  
#line 17293 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1815 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_rm(cbuf, 0x3, opnd_array(3)->reg(ra_,this,idx3)/* dst */ & 7, opnd_array(4)->reg(ra_,this,idx4)/* src */ & 7);
  
#line 17301 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void cmovP_regUNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cop
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {

#line 2430 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(3)->reg(ra_,this,idx3)/* dst */ < 8) {
      if (opnd_array(4)->reg(ra_,this,idx4)/* src */ < 8) {
        emit_opcode(cbuf, Assembler::REX_W);
      } else {
        emit_opcode(cbuf, Assembler::REX_WB);
      }
    } else {
      if (opnd_array(4)->reg(ra_,this,idx4)/* src */ < 8) {
        emit_opcode(cbuf, Assembler::REX_WR);
      } else {
        emit_opcode(cbuf, Assembler::REX_WRB);
      }
    }
  
#line 17331 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2045 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // CMOV
    emit_d8(cbuf, (0x0F /*primary()*/));
    emit_cc(cbuf, (0x40 /*secondary()*/), opnd_array(1)->ccode());
  
#line 17341 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1815 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_rm(cbuf, 0x3, opnd_array(3)->reg(ra_,this,idx3)/* dst */ & 7, opnd_array(4)->reg(ra_,this,idx4)/* src */ & 7);
  
#line 17349 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void cmovL_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cop
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {

#line 2430 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(3)->reg(ra_,this,idx3)/* dst */ < 8) {
      if (opnd_array(4)->reg(ra_,this,idx4)/* src */ < 8) {
        emit_opcode(cbuf, Assembler::REX_W);
      } else {
        emit_opcode(cbuf, Assembler::REX_WB);
      }
    } else {
      if (opnd_array(4)->reg(ra_,this,idx4)/* src */ < 8) {
        emit_opcode(cbuf, Assembler::REX_WR);
      } else {
        emit_opcode(cbuf, Assembler::REX_WRB);
      }
    }
  
#line 17379 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2045 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // CMOV
    emit_d8(cbuf, (0x0F /*primary()*/));
    emit_cc(cbuf, (0x40 /*secondary()*/), opnd_array(1)->ccode());
  
#line 17389 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1815 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_rm(cbuf, 0x3, opnd_array(3)->reg(ra_,this,idx3)/* dst */ & 7, opnd_array(4)->reg(ra_,this,idx4)/* src */ & 7);
  
#line 17397 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void cmovL_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// cop
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {

#line 2478 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(3)->reg(ra_,this,idx3)/* dst */ < 8) {
      if (opnd_array(4)->base(ra_,this,idx4) < 8) {
        if (opnd_array(4)->index(ra_,this,idx4) < 8) {
          emit_opcode(cbuf, Assembler::REX_W);
        } else {
          emit_opcode(cbuf, Assembler::REX_WX);
        }
      } else {
        if (opnd_array(4)->index(ra_,this,idx4) < 8) {
          emit_opcode(cbuf, Assembler::REX_WB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WXB);
        }
      }
    } else {
      if (opnd_array(4)->base(ra_,this,idx4) < 8) {
        if (opnd_array(4)->index(ra_,this,idx4) < 8) {
          emit_opcode(cbuf, Assembler::REX_WR);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRX);
        }
      } else {
        if (opnd_array(4)->index(ra_,this,idx4) < 8) {
          emit_opcode(cbuf, Assembler::REX_WRB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRXB);
        }
      }
    }
  
#line 17443 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2045 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // CMOV
    emit_d8(cbuf, (0x0F /*primary()*/));
    emit_cc(cbuf, (0x40 /*secondary()*/), opnd_array(1)->ccode());
  
#line 17453 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2511 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // High registers handle in encode_RegMem
    int reg = opnd_array(3)->reg(ra_,this,idx3)/* dst */;
    int base = opnd_array(4)->base(ra_,this,idx4);
    int index = opnd_array(4)->index(ra_,this,idx4);
    int scale = opnd_array(4)->scale();
    int disp = opnd_array(4)->disp(ra_,this,idx4);
    relocInfo::relocType disp_reloc = opnd_array(4)->disp_reloc();

    encode_RegMem(cbuf, reg, base, index, scale, disp, disp_reloc);
  
#line 17469 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void cmovL_regUNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cop
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {

#line 2430 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(3)->reg(ra_,this,idx3)/* dst */ < 8) {
      if (opnd_array(4)->reg(ra_,this,idx4)/* src */ < 8) {
        emit_opcode(cbuf, Assembler::REX_W);
      } else {
        emit_opcode(cbuf, Assembler::REX_WB);
      }
    } else {
      if (opnd_array(4)->reg(ra_,this,idx4)/* src */ < 8) {
        emit_opcode(cbuf, Assembler::REX_WR);
      } else {
        emit_opcode(cbuf, Assembler::REX_WRB);
      }
    }
  
#line 17499 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2045 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // CMOV
    emit_d8(cbuf, (0x0F /*primary()*/));
    emit_cc(cbuf, (0x40 /*secondary()*/), opnd_array(1)->ccode());
  
#line 17509 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1815 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_rm(cbuf, 0x3, opnd_array(3)->reg(ra_,this,idx3)/* dst */ & 7, opnd_array(4)->reg(ra_,this,idx4)/* src */ & 7);
  
#line 17517 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void cmovL_memUNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// cop
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {

#line 2478 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(3)->reg(ra_,this,idx3)/* dst */ < 8) {
      if (opnd_array(4)->base(ra_,this,idx4) < 8) {
        if (opnd_array(4)->index(ra_,this,idx4) < 8) {
          emit_opcode(cbuf, Assembler::REX_W);
        } else {
          emit_opcode(cbuf, Assembler::REX_WX);
        }
      } else {
        if (opnd_array(4)->index(ra_,this,idx4) < 8) {
          emit_opcode(cbuf, Assembler::REX_WB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WXB);
        }
      }
    } else {
      if (opnd_array(4)->base(ra_,this,idx4) < 8) {
        if (opnd_array(4)->index(ra_,this,idx4) < 8) {
          emit_opcode(cbuf, Assembler::REX_WR);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRX);
        }
      } else {
        if (opnd_array(4)->index(ra_,this,idx4) < 8) {
          emit_opcode(cbuf, Assembler::REX_WRB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRXB);
        }
      }
    }
  
#line 17563 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2045 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // CMOV
    emit_d8(cbuf, (0x0F /*primary()*/));
    emit_cc(cbuf, (0x40 /*secondary()*/), opnd_array(1)->ccode());
  
#line 17573 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2511 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // High registers handle in encode_RegMem
    int reg = opnd_array(3)->reg(ra_,this,idx3)/* dst */;
    int base = opnd_array(4)->base(ra_,this,idx4);
    int index = opnd_array(4)->index(ra_,this,idx4);
    int scale = opnd_array(4)->scale();
    int disp = opnd_array(4)->disp(ra_,this,idx4);
    relocInfo::relocType disp_reloc = opnd_array(4)->disp_reloc();

    encode_RegMem(cbuf, reg, base, index, scale, disp, disp_reloc);
  
#line 17589 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void cmovF_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cop
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 6741 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    Label Lskip;
    // Invert sense of branch from sense of CMOV
    __ jccb((Assembler::Condition)(opnd_array(1)->ccode()^1), Lskip);
    __ movflt(opnd_array(3)->as_XMMRegister(ra_,this,idx3)/* dst */, opnd_array(4)->as_XMMRegister(ra_,this,idx4)/* src */);
    __ bind(Lskip);
  
#line 17612 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void cmovF_regUNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cop
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 6771 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    Label Lskip;
    // Invert sense of branch from sense of CMOV
    __ jccb((Assembler::Condition)(opnd_array(1)->ccode()^1), Lskip);
    __ movflt(opnd_array(3)->as_XMMRegister(ra_,this,idx3)/* dst */, opnd_array(4)->as_XMMRegister(ra_,this,idx4)/* src */);
    __ bind(Lskip);
  
#line 17635 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void cmovD_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cop
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 6797 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    Label Lskip;
    // Invert sense of branch from sense of CMOV
    __ jccb((Assembler::Condition)(opnd_array(1)->ccode()^1), Lskip);
    __ movdbl(opnd_array(3)->as_XMMRegister(ra_,this,idx3)/* dst */, opnd_array(4)->as_XMMRegister(ra_,this,idx4)/* src */);
    __ bind(Lskip);
  
#line 17658 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void cmovD_regUNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cop
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 6815 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    Label Lskip;
    // Invert sense of branch from sense of CMOV
    __ jccb((Assembler::Condition)(opnd_array(1)->ccode()^1), Lskip);
    __ movdbl(opnd_array(3)->as_XMMRegister(ra_,this,idx3)/* dst */, opnd_array(4)->as_XMMRegister(ra_,this,idx4)/* src */);
    __ bind(Lskip);
  
#line 17681 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void addI_rRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2415 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->reg(ra_,this,idx1)/* dst */ < 8) {
      if (opnd_array(2)->reg(ra_,this,idx2)/* src */ >= 8) {
        emit_opcode(cbuf, Assembler::REX_B);
      }
    } else {
      if (opnd_array(2)->reg(ra_,this,idx2)/* src */ < 8) {
        emit_opcode(cbuf, Assembler::REX_R);
      } else {
        emit_opcode(cbuf, Assembler::REX_RB);
      }
    }
  
#line 17707 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x03 /*primary()*/));
  
#line 17715 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1815 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1)/* dst */ & 7, opnd_array(2)->reg(ra_,this,idx2)/* src */ & 7);
  
#line 17723 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void addI_rReg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 1974 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // OpcSEr/m
    int dstenc = opnd_array(1)->reg(ra_,this,idx1)/* dst */;
    if (dstenc >= 8) {
      emit_opcode(cbuf, Assembler::REX_B);
      dstenc -= 8;
    }
    // Emit primary opcode and set sign-extend bit
    // Check for 8-bit immediate, and set sign extend bit in opcode
    if (-0x80 <= opnd_array(2)->constant() && opnd_array(2)->constant() < 0x80) {
      emit_opcode(cbuf, (0x81 /*primary()*/) | 0x02);
    } else {
      // 32-bit immediate
      emit_opcode(cbuf, (0x81 /*primary()*/));
    }
    // Emit r/m byte with secondary opcode, after primary opcode.
    emit_rm(cbuf, 0x3, (0x00 /*secondary()*/), dstenc);
  
#line 17754 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2016 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // Check for 8-bit immediate, and set sign extend bit in opcode
    if (-0x80 <= opnd_array(2)->constant() && opnd_array(2)->constant() < 0x80) {
      emit_d8(cbuf, opnd_array(2)->constant());
    } else {
      // 32-bit immediate
      emit_d32(cbuf, opnd_array(2)->constant());
    }
  
#line 17768 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void addI_rReg_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2447 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->reg(ra_,this,idx1)/* dst */ < 8) {
      if (opnd_array(2)->base(ra_,this,idx2) < 8) {
        if (opnd_array(2)->index(ra_,this,idx2) >= 8) {
          emit_opcode(cbuf, Assembler::REX_X);
        }
      } else {
        if (opnd_array(2)->index(ra_,this,idx2) < 8) {
          emit_opcode(cbuf, Assembler::REX_B);
        } else {
          emit_opcode(cbuf, Assembler::REX_XB);
        }
      }
    } else {
      if (opnd_array(2)->base(ra_,this,idx2) < 8) {
        if (opnd_array(2)->index(ra_,this,idx2) < 8) {
          emit_opcode(cbuf, Assembler::REX_R);
        } else {
          emit_opcode(cbuf, Assembler::REX_RX);
        }
      } else {
        if (opnd_array(2)->index(ra_,this,idx2) < 8) {
          emit_opcode(cbuf, Assembler::REX_RB);
        } else {
          emit_opcode(cbuf, Assembler::REX_RXB);
        }
      }
    }
  
#line 17810 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x03 /*primary()*/));
  
#line 17818 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2511 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // High registers handle in encode_RegMem
    int reg = opnd_array(1)->reg(ra_,this,idx1)/* dst */;
    int base = opnd_array(2)->base(ra_,this,idx2);
    int index = opnd_array(2)->index(ra_,this,idx2);
    int scale = opnd_array(2)->scale();
    int disp = opnd_array(2)->disp(ra_,this,idx2);
    relocInfo::relocType disp_reloc = opnd_array(2)->disp_reloc();

    encode_RegMem(cbuf, reg, base, index, scale, disp, disp_reloc);
  
#line 17834 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void addI_rReg_mem_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  {

#line 2447 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(2)->reg(ra_,this,idx2)/* dst */ < 8) {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) >= 8) {
          emit_opcode(cbuf, Assembler::REX_X);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_B);
        } else {
          emit_opcode(cbuf, Assembler::REX_XB);
        }
      }
    } else {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_R);
        } else {
          emit_opcode(cbuf, Assembler::REX_RX);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_RB);
        } else {
          emit_opcode(cbuf, Assembler::REX_RXB);
        }
      }
    }
  
#line 17876 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x03 /*primary()*/));
  
#line 17884 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2511 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // High registers handle in encode_RegMem
    int reg = opnd_array(2)->reg(ra_,this,idx2)/* dst */;
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int disp = opnd_array(1)->disp(ra_,this,idx1);
    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();

    encode_RegMem(cbuf, reg, base, index, scale, disp, disp_reloc);
  
#line 17900 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void addI_mem_rRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2447 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(2)->reg(ra_,this,idx2)/* src */ < 8) {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) >= 8) {
          emit_opcode(cbuf, Assembler::REX_X);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_B);
        } else {
          emit_opcode(cbuf, Assembler::REX_XB);
        }
      }
    } else {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_R);
        } else {
          emit_opcode(cbuf, Assembler::REX_RX);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_RB);
        } else {
          emit_opcode(cbuf, Assembler::REX_RXB);
        }
      }
    }
  
#line 17942 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x01 /*primary()*/));
  
#line 17950 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2511 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // High registers handle in encode_RegMem
    int reg = opnd_array(2)->reg(ra_,this,idx2)/* src */;
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int disp = opnd_array(1)->disp(ra_,this,idx1);
    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();

    encode_RegMem(cbuf, reg, base, index, scale, disp, disp_reloc);
  
#line 17966 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void addI_mem_rReg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2447 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(2)->reg(ra_,this,idx2)/* src */ < 8) {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) >= 8) {
          emit_opcode(cbuf, Assembler::REX_X);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_B);
        } else {
          emit_opcode(cbuf, Assembler::REX_XB);
        }
      }
    } else {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_R);
        } else {
          emit_opcode(cbuf, Assembler::REX_RX);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_RB);
        } else {
          emit_opcode(cbuf, Assembler::REX_RXB);
        }
      }
    }
  
#line 18008 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x01 /*primary()*/));
  
#line 18016 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2511 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // High registers handle in encode_RegMem
    int reg = opnd_array(2)->reg(ra_,this,idx2)/* src */;
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int disp = opnd_array(1)->disp(ra_,this,idx1);
    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();

    encode_RegMem(cbuf, reg, base, index, scale, disp, disp_reloc);
  
#line 18032 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void addI_mem_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2309 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->base(ra_,this,idx1) >= 8) {
      if (opnd_array(1)->index(ra_,this,idx1) < 8) {
        emit_opcode(cbuf, Assembler::REX_B);
      } else {
        emit_opcode(cbuf, Assembler::REX_XB);
      }
    } else {
      if (opnd_array(1)->index(ra_,this,idx1) >= 8) {
        emit_opcode(cbuf, Assembler::REX_X);
      }
    }
  
#line 18058 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1962 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // Emit primary opcode and set sign-extend bit
    // Check for 8-bit immediate, and set sign extend bit in opcode
    if (-0x80 <= opnd_array(2)->constant() && opnd_array(2)->constant() < 0x80) {
      emit_opcode(cbuf, (0x81 /*primary()*/) | 0x02);
    } else {
      // 32-bit immediate
      emit_opcode(cbuf, (0x81 /*primary()*/));
    }
  
#line 18073 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2524 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    int rm_byte_opcode = (0x00);

    // High registers handle in encode_RegMem
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);

    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();       // disp-as-oop when
                                            // working with static
                                            // globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace,
                  disp_reloc);
  
#line 18093 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2016 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // Check for 8-bit immediate, and set sign extend bit in opcode
    if (-0x80 <= opnd_array(2)->constant() && opnd_array(2)->constant() < 0x80) {
      emit_d8(cbuf, opnd_array(2)->constant());
    } else {
      // 32-bit immediate
      emit_d32(cbuf, opnd_array(2)->constant());
    }
  
#line 18107 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void incI_rRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2399 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->reg(ra_,this,idx1)/* dst */ >= 8) {
      emit_opcode(cbuf, Assembler::REX_B);
    }
  
#line 18125 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xFF /*primary()*/));
  
#line 18133 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2039 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // INC, DEC, IDIV, IMOD, JMP indirect, ...
    emit_rm(cbuf, 0x3, (0x00 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1)/* dst */ & 7);
  
#line 18142 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void incI_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2309 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->base(ra_,this,idx1) >= 8) {
      if (opnd_array(1)->index(ra_,this,idx1) < 8) {
        emit_opcode(cbuf, Assembler::REX_B);
      } else {
        emit_opcode(cbuf, Assembler::REX_XB);
      }
    } else {
      if (opnd_array(1)->index(ra_,this,idx1) >= 8) {
        emit_opcode(cbuf, Assembler::REX_X);
      }
    }
  
#line 18168 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xFF /*primary()*/));
  
#line 18176 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2524 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    int rm_byte_opcode = (0x00);

    // High registers handle in encode_RegMem
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);

    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();       // disp-as-oop when
                                            // working with static
                                            // globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace,
                  disp_reloc);
  
#line 18196 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void decI_rRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2399 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->reg(ra_,this,idx1)/* dst */ >= 8) {
      emit_opcode(cbuf, Assembler::REX_B);
    }
  
#line 18214 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xFF /*primary()*/));
  
#line 18222 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2039 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // INC, DEC, IDIV, IMOD, JMP indirect, ...
    emit_rm(cbuf, 0x3, (0x01 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1)/* dst */ & 7);
  
#line 18231 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void decI_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2309 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->base(ra_,this,idx1) >= 8) {
      if (opnd_array(1)->index(ra_,this,idx1) < 8) {
        emit_opcode(cbuf, Assembler::REX_B);
      } else {
        emit_opcode(cbuf, Assembler::REX_XB);
      }
    } else {
      if (opnd_array(1)->index(ra_,this,idx1) >= 8) {
        emit_opcode(cbuf, Assembler::REX_X);
      }
    }
  
#line 18257 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xFF /*primary()*/));
  
#line 18265 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2524 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    int rm_byte_opcode = (0x01);

    // High registers handle in encode_RegMem
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);

    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();       // disp-as-oop when
                                            // working with static
                                            // globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace,
                  disp_reloc);
  
#line 18285 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void leaI_rReg_immINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src0
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  {

#line 1799 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x67));
  
#line 18301 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2415 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(0)->reg(ra_,this)/* dst */ < 8) {
      if (opnd_array(1)->reg(ra_,this,idx1)/* src0 */ >= 8) {
        emit_opcode(cbuf, Assembler::REX_B);
      }
    } else {
      if (opnd_array(1)->reg(ra_,this,idx1)/* src0 */ < 8) {
        emit_opcode(cbuf, Assembler::REX_R);
      } else {
        emit_opcode(cbuf, Assembler::REX_RB);
      }
    }
  
#line 18319 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x8D /*primary()*/));
  
#line 18327 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2541 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    int reg_encoding = opnd_array(0)->reg(ra_,this)/* dst */;
    int base         = opnd_array(1)->reg(ra_,this,idx1)/* src0 */;      // 0xFFFFFFFF indicates no base
    int index        = 0x04;            // 0x04 indicates no index
    int scale        = 0x00;            // 0x00 indicates no scale
    int displace     = opnd_array(2)->constant(); // 0x00 indicates no displacement
    relocInfo::relocType disp_reloc = relocInfo::none;
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace,
                  disp_reloc);
  
#line 18342 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void addL_rRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2430 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->reg(ra_,this,idx1)/* dst */ < 8) {
      if (opnd_array(2)->reg(ra_,this,idx2)/* src */ < 8) {
        emit_opcode(cbuf, Assembler::REX_W);
      } else {
        emit_opcode(cbuf, Assembler::REX_WB);
      }
    } else {
      if (opnd_array(2)->reg(ra_,this,idx2)/* src */ < 8) {
        emit_opcode(cbuf, Assembler::REX_WR);
      } else {
        emit_opcode(cbuf, Assembler::REX_WRB);
      }
    }
  
#line 18370 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x03 /*primary()*/));
  
#line 18378 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1815 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1)/* dst */ & 7, opnd_array(2)->reg(ra_,this,idx2)/* src */ & 7);
  
#line 18386 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void addL_rReg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 1994 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // OpcSEr/m
    int dstenc = opnd_array(1)->reg(ra_,this,idx1)/* dst */;
    if (dstenc < 8) {
      emit_opcode(cbuf, Assembler::REX_W);
    } else {
      emit_opcode(cbuf, Assembler::REX_WB);
      dstenc -= 8;
    }
    // Emit primary opcode and set sign-extend bit
    // Check for 8-bit immediate, and set sign extend bit in opcode
    if (-0x80 <= opnd_array(2)->constantL() && opnd_array(2)->constantL() < 0x80) {
      emit_opcode(cbuf, (0x81 /*primary()*/) | 0x02);
    } else {
      // 32-bit immediate
      emit_opcode(cbuf, (0x81 /*primary()*/));
    }
    // Emit r/m byte with secondary opcode, after primary opcode.
    emit_rm(cbuf, 0x3, (0x00 /*secondary()*/), dstenc);
  
#line 18419 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2016 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // Check for 8-bit immediate, and set sign extend bit in opcode
    if (-0x80 <= opnd_array(2)->constantL() && opnd_array(2)->constantL() < 0x80) {
      emit_d8(cbuf, opnd_array(2)->constantL());
    } else {
      // 32-bit immediate
      emit_d32(cbuf, opnd_array(2)->constantL());
    }
  
#line 18433 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void addL_rReg_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2478 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->reg(ra_,this,idx1)/* dst */ < 8) {
      if (opnd_array(2)->base(ra_,this,idx2) < 8) {
        if (opnd_array(2)->index(ra_,this,idx2) < 8) {
          emit_opcode(cbuf, Assembler::REX_W);
        } else {
          emit_opcode(cbuf, Assembler::REX_WX);
        }
      } else {
        if (opnd_array(2)->index(ra_,this,idx2) < 8) {
          emit_opcode(cbuf, Assembler::REX_WB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WXB);
        }
      }
    } else {
      if (opnd_array(2)->base(ra_,this,idx2) < 8) {
        if (opnd_array(2)->index(ra_,this,idx2) < 8) {
          emit_opcode(cbuf, Assembler::REX_WR);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRX);
        }
      } else {
        if (opnd_array(2)->index(ra_,this,idx2) < 8) {
          emit_opcode(cbuf, Assembler::REX_WRB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRXB);
        }
      }
    }
  
#line 18477 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x03 /*primary()*/));
  
#line 18485 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2511 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // High registers handle in encode_RegMem
    int reg = opnd_array(1)->reg(ra_,this,idx1)/* dst */;
    int base = opnd_array(2)->base(ra_,this,idx2);
    int index = opnd_array(2)->index(ra_,this,idx2);
    int scale = opnd_array(2)->scale();
    int disp = opnd_array(2)->disp(ra_,this,idx2);
    relocInfo::relocType disp_reloc = opnd_array(2)->disp_reloc();

    encode_RegMem(cbuf, reg, base, index, scale, disp, disp_reloc);
  
#line 18501 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void addL_rReg_mem_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  {

#line 2478 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(2)->reg(ra_,this,idx2)/* dst */ < 8) {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_W);
        } else {
          emit_opcode(cbuf, Assembler::REX_WX);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WXB);
        }
      }
    } else {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WR);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRX);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WRB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRXB);
        }
      }
    }
  
#line 18545 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x03 /*primary()*/));
  
#line 18553 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2511 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // High registers handle in encode_RegMem
    int reg = opnd_array(2)->reg(ra_,this,idx2)/* dst */;
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int disp = opnd_array(1)->disp(ra_,this,idx1);
    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();

    encode_RegMem(cbuf, reg, base, index, scale, disp, disp_reloc);
  
#line 18569 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void addL_mem_rRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2478 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(2)->reg(ra_,this,idx2)/* src */ < 8) {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_W);
        } else {
          emit_opcode(cbuf, Assembler::REX_WX);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WXB);
        }
      }
    } else {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WR);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRX);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WRB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRXB);
        }
      }
    }
  
#line 18613 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x01 /*primary()*/));
  
#line 18621 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2511 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // High registers handle in encode_RegMem
    int reg = opnd_array(2)->reg(ra_,this,idx2)/* src */;
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int disp = opnd_array(1)->disp(ra_,this,idx1);
    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();

    encode_RegMem(cbuf, reg, base, index, scale, disp, disp_reloc);
  
#line 18637 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void addL_mem_rReg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2478 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(2)->reg(ra_,this,idx2)/* src */ < 8) {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_W);
        } else {
          emit_opcode(cbuf, Assembler::REX_WX);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WXB);
        }
      }
    } else {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WR);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRX);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WRB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRXB);
        }
      }
    }
  
#line 18681 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x01 /*primary()*/));
  
#line 18689 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2511 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // High registers handle in encode_RegMem
    int reg = opnd_array(2)->reg(ra_,this,idx2)/* src */;
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int disp = opnd_array(1)->disp(ra_,this,idx1);
    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();

    encode_RegMem(cbuf, reg, base, index, scale, disp, disp_reloc);
  
#line 18705 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void addL_mem_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2324 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->base(ra_,this,idx1) >= 8) {
      if (opnd_array(1)->index(ra_,this,idx1) < 8) {
        emit_opcode(cbuf, Assembler::REX_WB);
      } else {
        emit_opcode(cbuf, Assembler::REX_WXB);
      }
    } else {
      if (opnd_array(1)->index(ra_,this,idx1) < 8) {
        emit_opcode(cbuf, Assembler::REX_W);
      } else {
        emit_opcode(cbuf, Assembler::REX_WX);
      }
    }
  
#line 18733 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1962 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // Emit primary opcode and set sign-extend bit
    // Check for 8-bit immediate, and set sign extend bit in opcode
    if (-0x80 <= opnd_array(2)->constantL() && opnd_array(2)->constantL() < 0x80) {
      emit_opcode(cbuf, (0x81 /*primary()*/) | 0x02);
    } else {
      // 32-bit immediate
      emit_opcode(cbuf, (0x81 /*primary()*/));
    }
  
#line 18748 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2524 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    int rm_byte_opcode = (0x00);

    // High registers handle in encode_RegMem
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);

    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();       // disp-as-oop when
                                            // working with static
                                            // globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace,
                  disp_reloc);
  
#line 18768 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2016 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // Check for 8-bit immediate, and set sign extend bit in opcode
    if (-0x80 <= opnd_array(2)->constantL() && opnd_array(2)->constantL() < 0x80) {
      emit_d8(cbuf, opnd_array(2)->constantL());
    } else {
      // 32-bit immediate
      emit_d32(cbuf, opnd_array(2)->constantL());
    }
  
#line 18782 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void incL_rRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2406 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->reg(ra_,this,idx1)/* dst */ < 8) {
      emit_opcode(cbuf, Assembler::REX_W);
    } else {
      emit_opcode(cbuf, Assembler::REX_WB);
    }
  
#line 18802 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xFF /*primary()*/));
  
#line 18810 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2039 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // INC, DEC, IDIV, IMOD, JMP indirect, ...
    emit_rm(cbuf, 0x3, (0x00 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1)/* dst */ & 7);
  
#line 18819 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void incL_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2324 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->base(ra_,this,idx1) >= 8) {
      if (opnd_array(1)->index(ra_,this,idx1) < 8) {
        emit_opcode(cbuf, Assembler::REX_WB);
      } else {
        emit_opcode(cbuf, Assembler::REX_WXB);
      }
    } else {
      if (opnd_array(1)->index(ra_,this,idx1) < 8) {
        emit_opcode(cbuf, Assembler::REX_W);
      } else {
        emit_opcode(cbuf, Assembler::REX_WX);
      }
    }
  
#line 18847 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xFF /*primary()*/));
  
#line 18855 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2524 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    int rm_byte_opcode = (0x00);

    // High registers handle in encode_RegMem
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);

    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();       // disp-as-oop when
                                            // working with static
                                            // globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace,
                  disp_reloc);
  
#line 18875 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void decL_rRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2406 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->reg(ra_,this,idx1)/* dst */ < 8) {
      emit_opcode(cbuf, Assembler::REX_W);
    } else {
      emit_opcode(cbuf, Assembler::REX_WB);
    }
  
#line 18895 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xFF /*primary()*/));
  
#line 18903 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2039 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // INC, DEC, IDIV, IMOD, JMP indirect, ...
    emit_rm(cbuf, 0x3, (0x01 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1)/* dst */ & 7);
  
#line 18912 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void decL_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2324 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->base(ra_,this,idx1) >= 8) {
      if (opnd_array(1)->index(ra_,this,idx1) < 8) {
        emit_opcode(cbuf, Assembler::REX_WB);
      } else {
        emit_opcode(cbuf, Assembler::REX_WXB);
      }
    } else {
      if (opnd_array(1)->index(ra_,this,idx1) < 8) {
        emit_opcode(cbuf, Assembler::REX_W);
      } else {
        emit_opcode(cbuf, Assembler::REX_WX);
      }
    }
  
#line 18940 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xFF /*primary()*/));
  
#line 18948 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2524 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    int rm_byte_opcode = (0x01);

    // High registers handle in encode_RegMem
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);

    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();       // disp-as-oop when
                                            // working with static
                                            // globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace,
                  disp_reloc);
  
#line 18968 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void leaL_rReg_immLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src0
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  {

#line 2430 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(0)->reg(ra_,this)/* dst */ < 8) {
      if (opnd_array(1)->reg(ra_,this,idx1)/* src0 */ < 8) {
        emit_opcode(cbuf, Assembler::REX_W);
      } else {
        emit_opcode(cbuf, Assembler::REX_WB);
      }
    } else {
      if (opnd_array(1)->reg(ra_,this,idx1)/* src0 */ < 8) {
        emit_opcode(cbuf, Assembler::REX_WR);
      } else {
        emit_opcode(cbuf, Assembler::REX_WRB);
      }
    }
  
#line 18996 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x8D /*primary()*/));
  
#line 19004 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2541 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    int reg_encoding = opnd_array(0)->reg(ra_,this)/* dst */;
    int base         = opnd_array(1)->reg(ra_,this,idx1)/* src0 */;      // 0xFFFFFFFF indicates no base
    int index        = 0x04;            // 0x04 indicates no index
    int scale        = 0x00;            // 0x00 indicates no scale
    int displace     = opnd_array(2)->constantL(); // 0x00 indicates no displacement
    relocInfo::relocType disp_reloc = relocInfo::none;
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace,
                  disp_reloc);
  
#line 19019 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void addP_rRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2430 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->reg(ra_,this,idx1)/* dst */ < 8) {
      if (opnd_array(2)->reg(ra_,this,idx2)/* src */ < 8) {
        emit_opcode(cbuf, Assembler::REX_W);
      } else {
        emit_opcode(cbuf, Assembler::REX_WB);
      }
    } else {
      if (opnd_array(2)->reg(ra_,this,idx2)/* src */ < 8) {
        emit_opcode(cbuf, Assembler::REX_WR);
      } else {
        emit_opcode(cbuf, Assembler::REX_WRB);
      }
    }
  
#line 19047 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x03 /*primary()*/));
  
#line 19055 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1815 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1)/* dst */ & 7, opnd_array(2)->reg(ra_,this,idx2)/* src */ & 7);
  
#line 19063 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void addP_rReg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 1994 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // OpcSEr/m
    int dstenc = opnd_array(1)->reg(ra_,this,idx1)/* dst */;
    if (dstenc < 8) {
      emit_opcode(cbuf, Assembler::REX_W);
    } else {
      emit_opcode(cbuf, Assembler::REX_WB);
      dstenc -= 8;
    }
    // Emit primary opcode and set sign-extend bit
    // Check for 8-bit immediate, and set sign extend bit in opcode
    if (-0x80 <= opnd_array(2)->constantL() && opnd_array(2)->constantL() < 0x80) {
      emit_opcode(cbuf, (0x81 /*primary()*/) | 0x02);
    } else {
      // 32-bit immediate
      emit_opcode(cbuf, (0x81 /*primary()*/));
    }
    // Emit r/m byte with secondary opcode, after primary opcode.
    emit_rm(cbuf, 0x3, (0x00 /*secondary()*/), dstenc);
  
#line 19096 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2016 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // Check for 8-bit immediate, and set sign extend bit in opcode
    if (-0x80 <= opnd_array(2)->constantL() && opnd_array(2)->constantL() < 0x80) {
      emit_d8(cbuf, opnd_array(2)->constantL());
    } else {
      // 32-bit immediate
      emit_d32(cbuf, opnd_array(2)->constantL());
    }
  
#line 19110 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void leaP_rReg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src0
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  {

#line 2430 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(0)->reg(ra_,this)/* dst */ < 8) {
      if (opnd_array(1)->reg(ra_,this,idx1)/* src0 */ < 8) {
        emit_opcode(cbuf, Assembler::REX_W);
      } else {
        emit_opcode(cbuf, Assembler::REX_WB);
      }
    } else {
      if (opnd_array(1)->reg(ra_,this,idx1)/* src0 */ < 8) {
        emit_opcode(cbuf, Assembler::REX_WR);
      } else {
        emit_opcode(cbuf, Assembler::REX_WRB);
      }
    }
  
#line 19138 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x8D /*primary()*/));
  
#line 19146 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2541 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    int reg_encoding = opnd_array(0)->reg(ra_,this)/* dst */;
    int base         = opnd_array(1)->reg(ra_,this,idx1)/* src0 */;      // 0xFFFFFFFF indicates no base
    int index        = 0x04;            // 0x04 indicates no index
    int scale        = 0x00;            // 0x00 indicates no scale
    int displace     = opnd_array(2)->constantL(); // 0x00 indicates no displacement
    relocInfo::relocType disp_reloc = relocInfo::none;
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace,
                  disp_reloc);
  
#line 19161 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void checkCastPPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  // User did not define which encode class to use.
}

uint checkCastPPNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 0);
}

void castPPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  // User did not define which encode class to use.
}

uint castPPNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 0);
}

void castIINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  // User did not define which encode class to use.
}

uint castIINode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 0);
}

void loadPLockedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2478 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(0)->reg(ra_,this)/* dst */ < 8) {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_W);
        } else {
          emit_opcode(cbuf, Assembler::REX_WX);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WXB);
        }
      }
    } else {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WR);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRX);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WRB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRXB);
        }
      }
    }
  
#line 19243 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x8B /*primary()*/));
  
#line 19251 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2511 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // High registers handle in encode_RegMem
    int reg = opnd_array(0)->reg(ra_,this)/* dst */;
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int disp = opnd_array(1)->disp(ra_,this,idx1);
    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();

    encode_RegMem(cbuf, reg, base, index, scale, disp, disp_reloc);
  
#line 19267 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void storePConditionalNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// heap_top_ptr
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {

#line 2302 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (os::is_MP()) {
      emit_opcode(cbuf, 0xF0); // lock
    }
  
#line 19286 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2478 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(3)->reg(ra_,this,idx3)/* newval */ < 8) {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_W);
        } else {
          emit_opcode(cbuf, Assembler::REX_WX);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WXB);
        }
      }
    } else {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WR);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRX);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WRB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRXB);
        }
      }
    }
  
#line 19322 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x0F /*primary()*/));
  
#line 19330 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1787 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xB1 /*secondary()*/));
  
#line 19338 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2511 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // High registers handle in encode_RegMem
    int reg = opnd_array(3)->reg(ra_,this,idx3)/* newval */;
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int disp = opnd_array(1)->disp(ra_,this,idx1);
    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();

    encode_RegMem(cbuf, reg, base, index, scale, disp, disp_reloc);
  
#line 19354 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void storeIConditionalNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {

#line 2302 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (os::is_MP()) {
      emit_opcode(cbuf, 0xF0); // lock
    }
  
#line 19373 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2447 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(3)->reg(ra_,this,idx3)/* newval */ < 8) {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) >= 8) {
          emit_opcode(cbuf, Assembler::REX_X);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_B);
        } else {
          emit_opcode(cbuf, Assembler::REX_XB);
        }
      }
    } else {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_R);
        } else {
          emit_opcode(cbuf, Assembler::REX_RX);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_RB);
        } else {
          emit_opcode(cbuf, Assembler::REX_RXB);
        }
      }
    }
  
#line 19407 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x0F /*primary()*/));
  
#line 19415 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1787 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xB1 /*secondary()*/));
  
#line 19423 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2511 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // High registers handle in encode_RegMem
    int reg = opnd_array(3)->reg(ra_,this,idx3)/* newval */;
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int disp = opnd_array(1)->disp(ra_,this,idx1);
    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();

    encode_RegMem(cbuf, reg, base, index, scale, disp, disp_reloc);
  
#line 19439 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void storeLConditionalNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {

#line 2302 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (os::is_MP()) {
      emit_opcode(cbuf, 0xF0); // lock
    }
  
#line 19458 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2478 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(3)->reg(ra_,this,idx3)/* newval */ < 8) {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_W);
        } else {
          emit_opcode(cbuf, Assembler::REX_WX);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WXB);
        }
      }
    } else {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WR);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRX);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WRB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRXB);
        }
      }
    }
  
#line 19494 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x0F /*primary()*/));
  
#line 19502 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1787 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xB1 /*secondary()*/));
  
#line 19510 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2511 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // High registers handle in encode_RegMem
    int reg = opnd_array(3)->reg(ra_,this,idx3)/* newval */;
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int disp = opnd_array(1)->disp(ra_,this,idx1);
    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();

    encode_RegMem(cbuf, reg, base, index, scale, disp, disp_reloc);
  
#line 19526 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void compareAndSwapPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem_ptr
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {

#line 2302 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (os::is_MP()) {
      emit_opcode(cbuf, 0xF0); // lock
    }
  
#line 19545 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2478 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(3)->reg(ra_,this,idx3)/* newval */ < 8) {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_W);
        } else {
          emit_opcode(cbuf, Assembler::REX_WX);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WXB);
        }
      }
    } else {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WR);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRX);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WRB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRXB);
        }
      }
    }
  
#line 19581 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x0F /*primary()*/));
  
#line 19589 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1787 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xB1 /*secondary()*/));
  
#line 19597 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2511 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // High registers handle in encode_RegMem
    int reg = opnd_array(3)->reg(ra_,this,idx3)/* newval */;
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int disp = opnd_array(1)->disp(ra_,this,idx1);
    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();

    encode_RegMem(cbuf, reg, base, index, scale, disp, disp_reloc);
  
#line 19613 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2342 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(0)->reg(ra_,this)/* res */ >= 4) {
      emit_opcode(cbuf, opnd_array(0)->reg(ra_,this)/* res */ < 8 ? Assembler::REX : Assembler::REX_B);
    }
  
#line 19623 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1799 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x0F));
  
#line 19631 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1799 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x94));
  
#line 19639 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1810 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_rm(cbuf, 0x3, 0, opnd_array(0)->reg(ra_,this)/* res */ & 7);
  
#line 19647 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2350 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(0)->reg(ra_,this)/* res */ < 8) {
      if (opnd_array(0)->reg(ra_,this)/* res */ >= 4) {
        emit_opcode(cbuf, opnd_array(0)->reg(ra_,this)/* res */ < 8 ? Assembler::REX : Assembler::REX_B);
      }
    } else {
      if (opnd_array(0)->reg(ra_,this)/* res */ < 8) {
        emit_opcode(cbuf, Assembler::REX_R);
      } else {
        emit_opcode(cbuf, Assembler::REX_RB);
      }
    }
  
#line 19665 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1799 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xF));
  
#line 19673 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1799 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xB6));
  
#line 19681 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1815 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_rm(cbuf, 0x3, opnd_array(0)->reg(ra_,this)/* res */ & 7, opnd_array(0)->reg(ra_,this)/* res */ & 7);
  
#line 19689 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void compareAndSwapLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem_ptr
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {

#line 2302 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (os::is_MP()) {
      emit_opcode(cbuf, 0xF0); // lock
    }
  
#line 19708 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2478 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(3)->reg(ra_,this,idx3)/* newval */ < 8) {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_W);
        } else {
          emit_opcode(cbuf, Assembler::REX_WX);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WXB);
        }
      }
    } else {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WR);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRX);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WRB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRXB);
        }
      }
    }
  
#line 19744 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x0F /*primary()*/));
  
#line 19752 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1787 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xB1 /*secondary()*/));
  
#line 19760 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2511 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // High registers handle in encode_RegMem
    int reg = opnd_array(3)->reg(ra_,this,idx3)/* newval */;
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int disp = opnd_array(1)->disp(ra_,this,idx1);
    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();

    encode_RegMem(cbuf, reg, base, index, scale, disp, disp_reloc);
  
#line 19776 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2342 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(0)->reg(ra_,this)/* res */ >= 4) {
      emit_opcode(cbuf, opnd_array(0)->reg(ra_,this)/* res */ < 8 ? Assembler::REX : Assembler::REX_B);
    }
  
#line 19786 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1799 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x0F));
  
#line 19794 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1799 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x94));
  
#line 19802 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1810 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_rm(cbuf, 0x3, 0, opnd_array(0)->reg(ra_,this)/* res */ & 7);
  
#line 19810 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2350 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(0)->reg(ra_,this)/* res */ < 8) {
      if (opnd_array(0)->reg(ra_,this)/* res */ >= 4) {
        emit_opcode(cbuf, opnd_array(0)->reg(ra_,this)/* res */ < 8 ? Assembler::REX : Assembler::REX_B);
      }
    } else {
      if (opnd_array(0)->reg(ra_,this)/* res */ < 8) {
        emit_opcode(cbuf, Assembler::REX_R);
      } else {
        emit_opcode(cbuf, Assembler::REX_RB);
      }
    }
  
#line 19828 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1799 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xF));
  
#line 19836 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1799 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xB6));
  
#line 19844 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1815 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_rm(cbuf, 0x3, opnd_array(0)->reg(ra_,this)/* res */ & 7, opnd_array(0)->reg(ra_,this)/* res */ & 7);
  
#line 19852 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void compareAndSwapINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem_ptr
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {

#line 2302 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (os::is_MP()) {
      emit_opcode(cbuf, 0xF0); // lock
    }
  
#line 19871 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2447 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(3)->reg(ra_,this,idx3)/* newval */ < 8) {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) >= 8) {
          emit_opcode(cbuf, Assembler::REX_X);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_B);
        } else {
          emit_opcode(cbuf, Assembler::REX_XB);
        }
      }
    } else {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_R);
        } else {
          emit_opcode(cbuf, Assembler::REX_RX);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_RB);
        } else {
          emit_opcode(cbuf, Assembler::REX_RXB);
        }
      }
    }
  
#line 19905 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x0F /*primary()*/));
  
#line 19913 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1787 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xB1 /*secondary()*/));
  
#line 19921 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2511 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // High registers handle in encode_RegMem
    int reg = opnd_array(3)->reg(ra_,this,idx3)/* newval */;
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int disp = opnd_array(1)->disp(ra_,this,idx1);
    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();

    encode_RegMem(cbuf, reg, base, index, scale, disp, disp_reloc);
  
#line 19937 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2342 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(0)->reg(ra_,this)/* res */ >= 4) {
      emit_opcode(cbuf, opnd_array(0)->reg(ra_,this)/* res */ < 8 ? Assembler::REX : Assembler::REX_B);
    }
  
#line 19947 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1799 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x0F));
  
#line 19955 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1799 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x94));
  
#line 19963 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1810 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_rm(cbuf, 0x3, 0, opnd_array(0)->reg(ra_,this)/* res */ & 7);
  
#line 19971 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2350 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(0)->reg(ra_,this)/* res */ < 8) {
      if (opnd_array(0)->reg(ra_,this)/* res */ >= 4) {
        emit_opcode(cbuf, opnd_array(0)->reg(ra_,this)/* res */ < 8 ? Assembler::REX : Assembler::REX_B);
      }
    } else {
      if (opnd_array(0)->reg(ra_,this)/* res */ < 8) {
        emit_opcode(cbuf, Assembler::REX_R);
      } else {
        emit_opcode(cbuf, Assembler::REX_RB);
      }
    }
  
#line 19989 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1799 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xF));
  
#line 19997 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1799 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xB6));
  
#line 20005 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1815 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_rm(cbuf, 0x3, opnd_array(0)->reg(ra_,this)/* res */ & 7, opnd_array(0)->reg(ra_,this)/* res */ & 7);
  
#line 20013 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void compareAndSwapNNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem_ptr
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {

#line 2302 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (os::is_MP()) {
      emit_opcode(cbuf, 0xF0); // lock
    }
  
#line 20032 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2447 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(3)->reg(ra_,this,idx3)/* newval */ < 8) {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) >= 8) {
          emit_opcode(cbuf, Assembler::REX_X);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_B);
        } else {
          emit_opcode(cbuf, Assembler::REX_XB);
        }
      }
    } else {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_R);
        } else {
          emit_opcode(cbuf, Assembler::REX_RX);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_RB);
        } else {
          emit_opcode(cbuf, Assembler::REX_RXB);
        }
      }
    }
  
#line 20066 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x0F /*primary()*/));
  
#line 20074 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1787 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xB1 /*secondary()*/));
  
#line 20082 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2511 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // High registers handle in encode_RegMem
    int reg = opnd_array(3)->reg(ra_,this,idx3)/* newval */;
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int disp = opnd_array(1)->disp(ra_,this,idx1);
    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();

    encode_RegMem(cbuf, reg, base, index, scale, disp, disp_reloc);
  
#line 20098 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2342 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(0)->reg(ra_,this)/* res */ >= 4) {
      emit_opcode(cbuf, opnd_array(0)->reg(ra_,this)/* res */ < 8 ? Assembler::REX : Assembler::REX_B);
    }
  
#line 20108 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1799 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x0F));
  
#line 20116 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1799 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x94));
  
#line 20124 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1810 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_rm(cbuf, 0x3, 0, opnd_array(0)->reg(ra_,this)/* res */ & 7);
  
#line 20132 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2350 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(0)->reg(ra_,this)/* res */ < 8) {
      if (opnd_array(0)->reg(ra_,this)/* res */ >= 4) {
        emit_opcode(cbuf, opnd_array(0)->reg(ra_,this)/* res */ < 8 ? Assembler::REX : Assembler::REX_B);
      }
    } else {
      if (opnd_array(0)->reg(ra_,this)/* res */ < 8) {
        emit_opcode(cbuf, Assembler::REX_R);
      } else {
        emit_opcode(cbuf, Assembler::REX_RB);
      }
    }
  
#line 20150 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1799 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xF));
  
#line 20158 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1799 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xB6));
  
#line 20166 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1815 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_rm(cbuf, 0x3, opnd_array(0)->reg(ra_,this)/* res */ & 7, opnd_array(0)->reg(ra_,this)/* res */ & 7);
  
#line 20174 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void xaddI_no_resNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// add
  {
    MacroAssembler _masm(&cbuf);

#line 7310 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (os::is_MP()) { __ lock(); }
    __ addl(Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()), opnd_array(2)->constant());
  
#line 20192 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void xaddINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// newval
  {
    MacroAssembler _masm(&cbuf);

#line 7321 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (os::is_MP()) { __ lock(); }
    __ xaddl(Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()), opnd_array(2)->as_Register(ra_,this,idx2)/* newval */);
  
#line 20210 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void xaddL_no_resNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// add
  {
    MacroAssembler _masm(&cbuf);

#line 7333 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (os::is_MP()) { __ lock(); }
    __ addq(Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()), opnd_array(2)->constantL());
  
#line 20228 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void xaddLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// newval
  {
    MacroAssembler _masm(&cbuf);

#line 7344 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (os::is_MP()) { __ lock(); }
    __ xaddq(Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()), opnd_array(2)->as_Register(ra_,this,idx2)/* newval */);
  
#line 20246 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void xchgINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// newval
  {
    MacroAssembler _masm(&cbuf);

#line 7354 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ xchgl(opnd_array(2)->as_Register(ra_,this,idx2)/* newval */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
  
#line 20263 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void xchgLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// newval
  {
    MacroAssembler _masm(&cbuf);

#line 7363 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ xchgq(opnd_array(2)->as_Register(ra_,this,idx2)/* newval */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
  
#line 20280 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void xchgPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// newval
  {
    MacroAssembler _masm(&cbuf);

#line 7372 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ xchgq(opnd_array(2)->as_Register(ra_,this,idx2)/* newval */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
  
#line 20297 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void xchgNNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// newval
  {
    MacroAssembler _masm(&cbuf);

#line 7381 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ xchgl(opnd_array(2)->as_Register(ra_,this,idx2)/* newval */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
  
#line 20314 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void subI_rRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2415 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->reg(ra_,this,idx1)/* dst */ < 8) {
      if (opnd_array(2)->reg(ra_,this,idx2)/* src */ >= 8) {
        emit_opcode(cbuf, Assembler::REX_B);
      }
    } else {
      if (opnd_array(2)->reg(ra_,this,idx2)/* src */ < 8) {
        emit_opcode(cbuf, Assembler::REX_R);
      } else {
        emit_opcode(cbuf, Assembler::REX_RB);
      }
    }
  
#line 20340 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x2B /*primary()*/));
  
#line 20348 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1815 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1)/* dst */ & 7, opnd_array(2)->reg(ra_,this,idx2)/* src */ & 7);
  
#line 20356 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void subI_rReg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 1974 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // OpcSEr/m
    int dstenc = opnd_array(1)->reg(ra_,this,idx1)/* dst */;
    if (dstenc >= 8) {
      emit_opcode(cbuf, Assembler::REX_B);
      dstenc -= 8;
    }
    // Emit primary opcode and set sign-extend bit
    // Check for 8-bit immediate, and set sign extend bit in opcode
    if (-0x80 <= opnd_array(2)->constant() && opnd_array(2)->constant() < 0x80) {
      emit_opcode(cbuf, (0x81 /*primary()*/) | 0x02);
    } else {
      // 32-bit immediate
      emit_opcode(cbuf, (0x81 /*primary()*/));
    }
    // Emit r/m byte with secondary opcode, after primary opcode.
    emit_rm(cbuf, 0x3, (0x05 /*secondary()*/), dstenc);
  
#line 20387 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2016 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // Check for 8-bit immediate, and set sign extend bit in opcode
    if (-0x80 <= opnd_array(2)->constant() && opnd_array(2)->constant() < 0x80) {
      emit_d8(cbuf, opnd_array(2)->constant());
    } else {
      // 32-bit immediate
      emit_d32(cbuf, opnd_array(2)->constant());
    }
  
#line 20401 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void subI_rReg_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2447 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->reg(ra_,this,idx1)/* dst */ < 8) {
      if (opnd_array(2)->base(ra_,this,idx2) < 8) {
        if (opnd_array(2)->index(ra_,this,idx2) >= 8) {
          emit_opcode(cbuf, Assembler::REX_X);
        }
      } else {
        if (opnd_array(2)->index(ra_,this,idx2) < 8) {
          emit_opcode(cbuf, Assembler::REX_B);
        } else {
          emit_opcode(cbuf, Assembler::REX_XB);
        }
      }
    } else {
      if (opnd_array(2)->base(ra_,this,idx2) < 8) {
        if (opnd_array(2)->index(ra_,this,idx2) < 8) {
          emit_opcode(cbuf, Assembler::REX_R);
        } else {
          emit_opcode(cbuf, Assembler::REX_RX);
        }
      } else {
        if (opnd_array(2)->index(ra_,this,idx2) < 8) {
          emit_opcode(cbuf, Assembler::REX_RB);
        } else {
          emit_opcode(cbuf, Assembler::REX_RXB);
        }
      }
    }
  
#line 20443 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x2B /*primary()*/));
  
#line 20451 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2511 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // High registers handle in encode_RegMem
    int reg = opnd_array(1)->reg(ra_,this,idx1)/* dst */;
    int base = opnd_array(2)->base(ra_,this,idx2);
    int index = opnd_array(2)->index(ra_,this,idx2);
    int scale = opnd_array(2)->scale();
    int disp = opnd_array(2)->disp(ra_,this,idx2);
    relocInfo::relocType disp_reloc = opnd_array(2)->disp_reloc();

    encode_RegMem(cbuf, reg, base, index, scale, disp, disp_reloc);
  
#line 20467 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void subI_mem_rRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2447 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(2)->reg(ra_,this,idx2)/* src */ < 8) {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) >= 8) {
          emit_opcode(cbuf, Assembler::REX_X);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_B);
        } else {
          emit_opcode(cbuf, Assembler::REX_XB);
        }
      }
    } else {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_R);
        } else {
          emit_opcode(cbuf, Assembler::REX_RX);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_RB);
        } else {
          emit_opcode(cbuf, Assembler::REX_RXB);
        }
      }
    }
  
#line 20509 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x29 /*primary()*/));
  
#line 20517 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2511 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // High registers handle in encode_RegMem
    int reg = opnd_array(2)->reg(ra_,this,idx2)/* src */;
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int disp = opnd_array(1)->disp(ra_,this,idx1);
    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();

    encode_RegMem(cbuf, reg, base, index, scale, disp, disp_reloc);
  
#line 20533 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void subI_mem_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2309 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->base(ra_,this,idx1) >= 8) {
      if (opnd_array(1)->index(ra_,this,idx1) < 8) {
        emit_opcode(cbuf, Assembler::REX_B);
      } else {
        emit_opcode(cbuf, Assembler::REX_XB);
      }
    } else {
      if (opnd_array(1)->index(ra_,this,idx1) >= 8) {
        emit_opcode(cbuf, Assembler::REX_X);
      }
    }
  
#line 20559 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1962 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // Emit primary opcode and set sign-extend bit
    // Check for 8-bit immediate, and set sign extend bit in opcode
    if (-0x80 <= opnd_array(2)->constant() && opnd_array(2)->constant() < 0x80) {
      emit_opcode(cbuf, (0x81 /*primary()*/) | 0x02);
    } else {
      // 32-bit immediate
      emit_opcode(cbuf, (0x81 /*primary()*/));
    }
  
#line 20574 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2524 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    int rm_byte_opcode = (0x05);

    // High registers handle in encode_RegMem
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);

    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();       // disp-as-oop when
                                            // working with static
                                            // globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace,
                  disp_reloc);
  
#line 20594 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2016 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // Check for 8-bit immediate, and set sign extend bit in opcode
    if (-0x80 <= opnd_array(2)->constant() && opnd_array(2)->constant() < 0x80) {
      emit_d8(cbuf, opnd_array(2)->constant());
    } else {
      // 32-bit immediate
      emit_d32(cbuf, opnd_array(2)->constant());
    }
  
#line 20608 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void subL_rRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2430 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->reg(ra_,this,idx1)/* dst */ < 8) {
      if (opnd_array(2)->reg(ra_,this,idx2)/* src */ < 8) {
        emit_opcode(cbuf, Assembler::REX_W);
      } else {
        emit_opcode(cbuf, Assembler::REX_WB);
      }
    } else {
      if (opnd_array(2)->reg(ra_,this,idx2)/* src */ < 8) {
        emit_opcode(cbuf, Assembler::REX_WR);
      } else {
        emit_opcode(cbuf, Assembler::REX_WRB);
      }
    }
  
#line 20636 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x2B /*primary()*/));
  
#line 20644 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1815 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1)/* dst */ & 7, opnd_array(2)->reg(ra_,this,idx2)/* src */ & 7);
  
#line 20652 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void subL_rReg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 1994 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // OpcSEr/m
    int dstenc = opnd_array(1)->reg(ra_,this,idx1)/* dst */;
    if (dstenc < 8) {
      emit_opcode(cbuf, Assembler::REX_W);
    } else {
      emit_opcode(cbuf, Assembler::REX_WB);
      dstenc -= 8;
    }
    // Emit primary opcode and set sign-extend bit
    // Check for 8-bit immediate, and set sign extend bit in opcode
    if (-0x80 <= opnd_array(2)->constantL() && opnd_array(2)->constantL() < 0x80) {
      emit_opcode(cbuf, (0x81 /*primary()*/) | 0x02);
    } else {
      // 32-bit immediate
      emit_opcode(cbuf, (0x81 /*primary()*/));
    }
    // Emit r/m byte with secondary opcode, after primary opcode.
    emit_rm(cbuf, 0x3, (0x05 /*secondary()*/), dstenc);
  
#line 20685 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2016 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // Check for 8-bit immediate, and set sign extend bit in opcode
    if (-0x80 <= opnd_array(2)->constantL() && opnd_array(2)->constantL() < 0x80) {
      emit_d8(cbuf, opnd_array(2)->constantL());
    } else {
      // 32-bit immediate
      emit_d32(cbuf, opnd_array(2)->constantL());
    }
  
#line 20699 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void subL_rReg_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2478 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->reg(ra_,this,idx1)/* dst */ < 8) {
      if (opnd_array(2)->base(ra_,this,idx2) < 8) {
        if (opnd_array(2)->index(ra_,this,idx2) < 8) {
          emit_opcode(cbuf, Assembler::REX_W);
        } else {
          emit_opcode(cbuf, Assembler::REX_WX);
        }
      } else {
        if (opnd_array(2)->index(ra_,this,idx2) < 8) {
          emit_opcode(cbuf, Assembler::REX_WB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WXB);
        }
      }
    } else {
      if (opnd_array(2)->base(ra_,this,idx2) < 8) {
        if (opnd_array(2)->index(ra_,this,idx2) < 8) {
          emit_opcode(cbuf, Assembler::REX_WR);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRX);
        }
      } else {
        if (opnd_array(2)->index(ra_,this,idx2) < 8) {
          emit_opcode(cbuf, Assembler::REX_WRB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRXB);
        }
      }
    }
  
#line 20743 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x2B /*primary()*/));
  
#line 20751 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2511 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // High registers handle in encode_RegMem
    int reg = opnd_array(1)->reg(ra_,this,idx1)/* dst */;
    int base = opnd_array(2)->base(ra_,this,idx2);
    int index = opnd_array(2)->index(ra_,this,idx2);
    int scale = opnd_array(2)->scale();
    int disp = opnd_array(2)->disp(ra_,this,idx2);
    relocInfo::relocType disp_reloc = opnd_array(2)->disp_reloc();

    encode_RegMem(cbuf, reg, base, index, scale, disp, disp_reloc);
  
#line 20767 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void subL_mem_rRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2478 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(2)->reg(ra_,this,idx2)/* src */ < 8) {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_W);
        } else {
          emit_opcode(cbuf, Assembler::REX_WX);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WXB);
        }
      }
    } else {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WR);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRX);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WRB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRXB);
        }
      }
    }
  
#line 20811 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x29 /*primary()*/));
  
#line 20819 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2511 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // High registers handle in encode_RegMem
    int reg = opnd_array(2)->reg(ra_,this,idx2)/* src */;
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int disp = opnd_array(1)->disp(ra_,this,idx1);
    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();

    encode_RegMem(cbuf, reg, base, index, scale, disp, disp_reloc);
  
#line 20835 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void subL_mem_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2324 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->base(ra_,this,idx1) >= 8) {
      if (opnd_array(1)->index(ra_,this,idx1) < 8) {
        emit_opcode(cbuf, Assembler::REX_WB);
      } else {
        emit_opcode(cbuf, Assembler::REX_WXB);
      }
    } else {
      if (opnd_array(1)->index(ra_,this,idx1) < 8) {
        emit_opcode(cbuf, Assembler::REX_W);
      } else {
        emit_opcode(cbuf, Assembler::REX_WX);
      }
    }
  
#line 20863 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1962 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // Emit primary opcode and set sign-extend bit
    // Check for 8-bit immediate, and set sign extend bit in opcode
    if (-0x80 <= opnd_array(2)->constantL() && opnd_array(2)->constantL() < 0x80) {
      emit_opcode(cbuf, (0x81 /*primary()*/) | 0x02);
    } else {
      // 32-bit immediate
      emit_opcode(cbuf, (0x81 /*primary()*/));
    }
  
#line 20878 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2524 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    int rm_byte_opcode = (0x05);

    // High registers handle in encode_RegMem
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);

    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();       // disp-as-oop when
                                            // working with static
                                            // globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace,
                  disp_reloc);
  
#line 20898 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2016 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // Check for 8-bit immediate, and set sign extend bit in opcode
    if (-0x80 <= opnd_array(2)->constantL() && opnd_array(2)->constantL() < 0x80) {
      emit_d8(cbuf, opnd_array(2)->constantL());
    } else {
      // 32-bit immediate
      emit_d32(cbuf, opnd_array(2)->constantL());
    }
  
#line 20912 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void subP_rRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src
  {

#line 2430 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->reg(ra_,this,idx1)/* dst */ < 8) {
      if (opnd_array(3)->reg(ra_,this,idx3)/* src */ < 8) {
        emit_opcode(cbuf, Assembler::REX_W);
      } else {
        emit_opcode(cbuf, Assembler::REX_WB);
      }
    } else {
      if (opnd_array(3)->reg(ra_,this,idx3)/* src */ < 8) {
        emit_opcode(cbuf, Assembler::REX_WR);
      } else {
        emit_opcode(cbuf, Assembler::REX_WRB);
      }
    }
  
#line 20941 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x2B /*primary()*/));
  
#line 20949 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1815 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1)/* dst */ & 7, opnd_array(3)->reg(ra_,this,idx3)/* src */ & 7);
  
#line 20957 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void negI_rRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  {

#line 2399 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(2)->reg(ra_,this,idx2)/* dst */ >= 8) {
      emit_opcode(cbuf, Assembler::REX_B);
    }
  
#line 20975 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xF7 /*primary()*/));
  
#line 20983 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2039 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // INC, DEC, IDIV, IMOD, JMP indirect, ...
    emit_rm(cbuf, 0x3, (0x03 /*secondary()*/), opnd_array(2)->reg(ra_,this,idx2)/* dst */ & 7);
  
#line 20992 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void negI_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 2309 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->base(ra_,this,idx1) >= 8) {
      if (opnd_array(1)->index(ra_,this,idx1) < 8) {
        emit_opcode(cbuf, Assembler::REX_B);
      } else {
        emit_opcode(cbuf, Assembler::REX_XB);
      }
    } else {
      if (opnd_array(1)->index(ra_,this,idx1) >= 8) {
        emit_opcode(cbuf, Assembler::REX_X);
      }
    }
  
#line 21018 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xF7 /*primary()*/));
  
#line 21026 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2524 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    int rm_byte_opcode = (0x03 /*secondary()*/);

    // High registers handle in encode_RegMem
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);

    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();       // disp-as-oop when
                                            // working with static
                                            // globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace,
                  disp_reloc);
  
#line 21046 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void negL_rRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  {

#line 2406 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(2)->reg(ra_,this,idx2)/* dst */ < 8) {
      emit_opcode(cbuf, Assembler::REX_W);
    } else {
      emit_opcode(cbuf, Assembler::REX_WB);
    }
  
#line 21066 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xF7 /*primary()*/));
  
#line 21074 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2039 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // INC, DEC, IDIV, IMOD, JMP indirect, ...
    emit_rm(cbuf, 0x3, (0x03 /*secondary()*/), opnd_array(2)->reg(ra_,this,idx2)/* dst */ & 7);
  
#line 21083 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void negL_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 2324 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->base(ra_,this,idx1) >= 8) {
      if (opnd_array(1)->index(ra_,this,idx1) < 8) {
        emit_opcode(cbuf, Assembler::REX_WB);
      } else {
        emit_opcode(cbuf, Assembler::REX_WXB);
      }
    } else {
      if (opnd_array(1)->index(ra_,this,idx1) < 8) {
        emit_opcode(cbuf, Assembler::REX_W);
      } else {
        emit_opcode(cbuf, Assembler::REX_WX);
      }
    }
  
#line 21111 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xF7 /*primary()*/));
  
#line 21119 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2524 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    int rm_byte_opcode = (0x03 /*secondary()*/);

    // High registers handle in encode_RegMem
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);

    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();       // disp-as-oop when
                                            // working with static
                                            // globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace,
                  disp_reloc);
  
#line 21139 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void mulI_rRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2415 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->reg(ra_,this,idx1)/* dst */ < 8) {
      if (opnd_array(2)->reg(ra_,this,idx2)/* src */ >= 8) {
        emit_opcode(cbuf, Assembler::REX_B);
      }
    } else {
      if (opnd_array(2)->reg(ra_,this,idx2)/* src */ < 8) {
        emit_opcode(cbuf, Assembler::REX_R);
      } else {
        emit_opcode(cbuf, Assembler::REX_RB);
      }
    }
  
#line 21165 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x0F /*primary()*/));
  
#line 21173 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1787 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xAF /*secondary()*/));
  
#line 21181 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1815 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1)/* dst */ & 7, opnd_array(2)->reg(ra_,this,idx2)/* src */ & 7);
  
#line 21189 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void mulI_rReg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// imm
  {

#line 2415 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(0)->reg(ra_,this)/* dst */ < 8) {
      if (opnd_array(1)->reg(ra_,this,idx1)/* src */ >= 8) {
        emit_opcode(cbuf, Assembler::REX_B);
      }
    } else {
      if (opnd_array(1)->reg(ra_,this,idx1)/* src */ < 8) {
        emit_opcode(cbuf, Assembler::REX_R);
      } else {
        emit_opcode(cbuf, Assembler::REX_RB);
      }
    }
  
#line 21215 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1962 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // Emit primary opcode and set sign-extend bit
    // Check for 8-bit immediate, and set sign extend bit in opcode
    if (-0x80 <= opnd_array(2)->constant() && opnd_array(2)->constant() < 0x80) {
      emit_opcode(cbuf, (0x69 /*primary()*/) | 0x02);
    } else {
      // 32-bit immediate
      emit_opcode(cbuf, (0x69 /*primary()*/));
    }
  
#line 21230 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1815 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_rm(cbuf, 0x3, opnd_array(0)->reg(ra_,this)/* dst */ & 7, opnd_array(1)->reg(ra_,this,idx1)/* src */ & 7);
  
#line 21238 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2016 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // Check for 8-bit immediate, and set sign extend bit in opcode
    if (-0x80 <= opnd_array(2)->constant() && opnd_array(2)->constant() < 0x80) {
      emit_d8(cbuf, opnd_array(2)->constant());
    } else {
      // 32-bit immediate
      emit_d32(cbuf, opnd_array(2)->constant());
    }
  
#line 21252 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void mulI_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2447 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->reg(ra_,this,idx1)/* dst */ < 8) {
      if (opnd_array(2)->base(ra_,this,idx2) < 8) {
        if (opnd_array(2)->index(ra_,this,idx2) >= 8) {
          emit_opcode(cbuf, Assembler::REX_X);
        }
      } else {
        if (opnd_array(2)->index(ra_,this,idx2) < 8) {
          emit_opcode(cbuf, Assembler::REX_B);
        } else {
          emit_opcode(cbuf, Assembler::REX_XB);
        }
      }
    } else {
      if (opnd_array(2)->base(ra_,this,idx2) < 8) {
        if (opnd_array(2)->index(ra_,this,idx2) < 8) {
          emit_opcode(cbuf, Assembler::REX_R);
        } else {
          emit_opcode(cbuf, Assembler::REX_RX);
        }
      } else {
        if (opnd_array(2)->index(ra_,this,idx2) < 8) {
          emit_opcode(cbuf, Assembler::REX_RB);
        } else {
          emit_opcode(cbuf, Assembler::REX_RXB);
        }
      }
    }
  
#line 21294 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x0F /*primary()*/));
  
#line 21302 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1787 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xAF /*secondary()*/));
  
#line 21310 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2511 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // High registers handle in encode_RegMem
    int reg = opnd_array(1)->reg(ra_,this,idx1)/* dst */;
    int base = opnd_array(2)->base(ra_,this,idx2);
    int index = opnd_array(2)->index(ra_,this,idx2);
    int scale = opnd_array(2)->scale();
    int disp = opnd_array(2)->disp(ra_,this,idx2);
    relocInfo::relocType disp_reloc = opnd_array(2)->disp_reloc();

    encode_RegMem(cbuf, reg, base, index, scale, disp, disp_reloc);
  
#line 21326 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void mulI_mem_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  {

#line 2447 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(2)->reg(ra_,this,idx2)/* dst */ < 8) {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) >= 8) {
          emit_opcode(cbuf, Assembler::REX_X);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_B);
        } else {
          emit_opcode(cbuf, Assembler::REX_XB);
        }
      }
    } else {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_R);
        } else {
          emit_opcode(cbuf, Assembler::REX_RX);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_RB);
        } else {
          emit_opcode(cbuf, Assembler::REX_RXB);
        }
      }
    }
  
#line 21368 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x0F /*primary()*/));
  
#line 21376 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1787 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xAF /*secondary()*/));
  
#line 21384 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2511 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // High registers handle in encode_RegMem
    int reg = opnd_array(2)->reg(ra_,this,idx2)/* dst */;
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int disp = opnd_array(1)->disp(ra_,this,idx1);
    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();

    encode_RegMem(cbuf, reg, base, index, scale, disp, disp_reloc);
  
#line 21400 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void mulI_mem_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// imm
  {

#line 2447 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(0)->reg(ra_,this)/* dst */ < 8) {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) >= 8) {
          emit_opcode(cbuf, Assembler::REX_X);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_B);
        } else {
          emit_opcode(cbuf, Assembler::REX_XB);
        }
      }
    } else {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_R);
        } else {
          emit_opcode(cbuf, Assembler::REX_RX);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_RB);
        } else {
          emit_opcode(cbuf, Assembler::REX_RXB);
        }
      }
    }
  
#line 21442 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1962 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // Emit primary opcode and set sign-extend bit
    // Check for 8-bit immediate, and set sign extend bit in opcode
    if (-0x80 <= opnd_array(2)->constant() && opnd_array(2)->constant() < 0x80) {
      emit_opcode(cbuf, (0x69 /*primary()*/) | 0x02);
    } else {
      // 32-bit immediate
      emit_opcode(cbuf, (0x69 /*primary()*/));
    }
  
#line 21457 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2511 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // High registers handle in encode_RegMem
    int reg = opnd_array(0)->reg(ra_,this)/* dst */;
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int disp = opnd_array(1)->disp(ra_,this,idx1);
    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();

    encode_RegMem(cbuf, reg, base, index, scale, disp, disp_reloc);
  
#line 21473 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2016 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // Check for 8-bit immediate, and set sign extend bit in opcode
    if (-0x80 <= opnd_array(2)->constant() && opnd_array(2)->constant() < 0x80) {
      emit_d8(cbuf, opnd_array(2)->constant());
    } else {
      // 32-bit immediate
      emit_d32(cbuf, opnd_array(2)->constant());
    }
  
#line 21487 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void mulL_rRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2430 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->reg(ra_,this,idx1)/* dst */ < 8) {
      if (opnd_array(2)->reg(ra_,this,idx2)/* src */ < 8) {
        emit_opcode(cbuf, Assembler::REX_W);
      } else {
        emit_opcode(cbuf, Assembler::REX_WB);
      }
    } else {
      if (opnd_array(2)->reg(ra_,this,idx2)/* src */ < 8) {
        emit_opcode(cbuf, Assembler::REX_WR);
      } else {
        emit_opcode(cbuf, Assembler::REX_WRB);
      }
    }
  
#line 21515 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x0F /*primary()*/));
  
#line 21523 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1787 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xAF /*secondary()*/));
  
#line 21531 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1815 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1)/* dst */ & 7, opnd_array(2)->reg(ra_,this,idx2)/* src */ & 7);
  
#line 21539 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void mulL_rReg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// imm
  {

#line 2430 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(0)->reg(ra_,this)/* dst */ < 8) {
      if (opnd_array(1)->reg(ra_,this,idx1)/* src */ < 8) {
        emit_opcode(cbuf, Assembler::REX_W);
      } else {
        emit_opcode(cbuf, Assembler::REX_WB);
      }
    } else {
      if (opnd_array(1)->reg(ra_,this,idx1)/* src */ < 8) {
        emit_opcode(cbuf, Assembler::REX_WR);
      } else {
        emit_opcode(cbuf, Assembler::REX_WRB);
      }
    }
  
#line 21567 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1962 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // Emit primary opcode and set sign-extend bit
    // Check for 8-bit immediate, and set sign extend bit in opcode
    if (-0x80 <= opnd_array(2)->constantL() && opnd_array(2)->constantL() < 0x80) {
      emit_opcode(cbuf, (0x69 /*primary()*/) | 0x02);
    } else {
      // 32-bit immediate
      emit_opcode(cbuf, (0x69 /*primary()*/));
    }
  
#line 21582 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1815 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_rm(cbuf, 0x3, opnd_array(0)->reg(ra_,this)/* dst */ & 7, opnd_array(1)->reg(ra_,this,idx1)/* src */ & 7);
  
#line 21590 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2016 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // Check for 8-bit immediate, and set sign extend bit in opcode
    if (-0x80 <= opnd_array(2)->constantL() && opnd_array(2)->constantL() < 0x80) {
      emit_d8(cbuf, opnd_array(2)->constantL());
    } else {
      // 32-bit immediate
      emit_d32(cbuf, opnd_array(2)->constantL());
    }
  
#line 21604 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void mulL_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2478 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->reg(ra_,this,idx1)/* dst */ < 8) {
      if (opnd_array(2)->base(ra_,this,idx2) < 8) {
        if (opnd_array(2)->index(ra_,this,idx2) < 8) {
          emit_opcode(cbuf, Assembler::REX_W);
        } else {
          emit_opcode(cbuf, Assembler::REX_WX);
        }
      } else {
        if (opnd_array(2)->index(ra_,this,idx2) < 8) {
          emit_opcode(cbuf, Assembler::REX_WB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WXB);
        }
      }
    } else {
      if (opnd_array(2)->base(ra_,this,idx2) < 8) {
        if (opnd_array(2)->index(ra_,this,idx2) < 8) {
          emit_opcode(cbuf, Assembler::REX_WR);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRX);
        }
      } else {
        if (opnd_array(2)->index(ra_,this,idx2) < 8) {
          emit_opcode(cbuf, Assembler::REX_WRB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRXB);
        }
      }
    }
  
#line 21648 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x0F /*primary()*/));
  
#line 21656 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1787 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xAF /*secondary()*/));
  
#line 21664 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2511 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // High registers handle in encode_RegMem
    int reg = opnd_array(1)->reg(ra_,this,idx1)/* dst */;
    int base = opnd_array(2)->base(ra_,this,idx2);
    int index = opnd_array(2)->index(ra_,this,idx2);
    int scale = opnd_array(2)->scale();
    int disp = opnd_array(2)->disp(ra_,this,idx2);
    relocInfo::relocType disp_reloc = opnd_array(2)->disp_reloc();

    encode_RegMem(cbuf, reg, base, index, scale, disp, disp_reloc);
  
#line 21680 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void mulL_mem_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  {

#line 2478 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(2)->reg(ra_,this,idx2)/* dst */ < 8) {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_W);
        } else {
          emit_opcode(cbuf, Assembler::REX_WX);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WXB);
        }
      }
    } else {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WR);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRX);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WRB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRXB);
        }
      }
    }
  
#line 21724 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x0F /*primary()*/));
  
#line 21732 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1787 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xAF /*secondary()*/));
  
#line 21740 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2511 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // High registers handle in encode_RegMem
    int reg = opnd_array(2)->reg(ra_,this,idx2)/* dst */;
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int disp = opnd_array(1)->disp(ra_,this,idx1);
    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();

    encode_RegMem(cbuf, reg, base, index, scale, disp, disp_reloc);
  
#line 21756 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void mulL_mem_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// imm
  {

#line 2478 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(0)->reg(ra_,this)/* dst */ < 8) {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_W);
        } else {
          emit_opcode(cbuf, Assembler::REX_WX);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WXB);
        }
      }
    } else {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WR);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRX);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WRB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRXB);
        }
      }
    }
  
#line 21800 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1962 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // Emit primary opcode and set sign-extend bit
    // Check for 8-bit immediate, and set sign extend bit in opcode
    if (-0x80 <= opnd_array(2)->constantL() && opnd_array(2)->constantL() < 0x80) {
      emit_opcode(cbuf, (0x69 /*primary()*/) | 0x02);
    } else {
      // 32-bit immediate
      emit_opcode(cbuf, (0x69 /*primary()*/));
    }
  
#line 21815 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2511 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // High registers handle in encode_RegMem
    int reg = opnd_array(0)->reg(ra_,this)/* dst */;
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int disp = opnd_array(1)->disp(ra_,this,idx1);
    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();

    encode_RegMem(cbuf, reg, base, index, scale, disp, disp_reloc);
  
#line 21831 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2016 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // Check for 8-bit immediate, and set sign extend bit in opcode
    if (-0x80 <= opnd_array(2)->constantL() && opnd_array(2)->constantL() < 0x80) {
      emit_d8(cbuf, opnd_array(2)->constantL());
    } else {
      // 32-bit immediate
      emit_d32(cbuf, opnd_array(2)->constantL());
    }
  
#line 21845 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void mulHiL_rRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// rax
  {

#line 2406 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->reg(ra_,this,idx1)/* src */ < 8) {
      emit_opcode(cbuf, Assembler::REX_W);
    } else {
      emit_opcode(cbuf, Assembler::REX_WB);
    }
  
#line 21865 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xF7 /*primary()*/));
  
#line 21873 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2039 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // INC, DEC, IDIV, IMOD, JMP indirect, ...
    emit_rm(cbuf, 0x3, (0x5 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1)/* src */ & 7);
  
#line 21882 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void divI_rRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// rax
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// div
  {

#line 1826 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // Full implementation of Java idiv and irem; checks for
    // special case as described in JVM spec., p.243 & p.271.
    //
    //         normal case                           special case
    //
    // input : rax: dividend                         min_int
    //         reg: divisor                          -1
    //
    // output: rax: quotient  (= rax idiv reg)       min_int
    //         rdx: remainder (= rax irem reg)       0
    //
    //  Code sequnce:
    //
    //    0:   3d 00 00 00 80          cmp    $0x80000000,%eax
    //    5:   75 07/08                jne    e <normal>
    //    7:   33 d2                   xor    %edx,%edx
    //  [div >= 8 -> offset + 1]
    //  [REX_B]
    //    9:   83 f9 ff                cmp    $0xffffffffffffffff,$div
    //    c:   74 03/04                je     11 <done>
    // 000000000000000e <normal>:
    //    e:   99                      cltd
    //  [div >= 8 -> offset + 1]
    //  [REX_B]
    //    f:   f7 f9                   idiv   $div
    // 0000000000000011 <done>:

    // cmp    $0x80000000,%eax
    emit_opcode(cbuf, 0x3d);
    emit_d8(cbuf, 0x00);
    emit_d8(cbuf, 0x00);
    emit_d8(cbuf, 0x00);
    emit_d8(cbuf, 0x80);

    // jne    e <normal>
    emit_opcode(cbuf, 0x75);
    emit_d8(cbuf, opnd_array(2)->reg(ra_,this,idx2)/* div */ < 8 ? 0x07 : 0x08);

    // xor    %edx,%edx
    emit_opcode(cbuf, 0x33);
    emit_d8(cbuf, 0xD2);

    // cmp    $0xffffffffffffffff,%ecx
    if (opnd_array(2)->reg(ra_,this,idx2)/* div */ >= 8) {
      emit_opcode(cbuf, Assembler::REX_B);
    }
    emit_opcode(cbuf, 0x83);
    emit_rm(cbuf, 0x3, 0x7, opnd_array(2)->reg(ra_,this,idx2)/* div */ & 7);
    emit_d8(cbuf, 0xFF);

    // je     11 <done>
    emit_opcode(cbuf, 0x74);
    emit_d8(cbuf, opnd_array(2)->reg(ra_,this,idx2)/* div */ < 8 ? 0x03 : 0x04);

    // <normal>
    // cltd
    emit_opcode(cbuf, 0x99);

    // idivl (note: must be emitted by the user of this rule)
    // <done>
  
#line 21957 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2399 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(2)->reg(ra_,this,idx2)/* div */ >= 8) {
      emit_opcode(cbuf, Assembler::REX_B);
    }
  
#line 21967 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xF7 /*primary()*/));
  
#line 21975 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2039 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // INC, DEC, IDIV, IMOD, JMP indirect, ...
    emit_rm(cbuf, 0x3, (0x7 /*secondary()*/), opnd_array(2)->reg(ra_,this,idx2)/* div */ & 7);
  
#line 21984 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void divL_rRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// rax
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// div
  {

#line 1890 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // Full implementation of Java ldiv and lrem; checks for
    // special case as described in JVM spec., p.243 & p.271.
    //
    //         normal case                           special case
    //
    // input : rax: dividend                         min_long
    //         reg: divisor                          -1
    //
    // output: rax: quotient  (= rax idiv reg)       min_long
    //         rdx: remainder (= rax irem reg)       0
    //
    //  Code sequnce:
    //
    //    0:   48 ba 00 00 00 00 00    mov    $0x8000000000000000,%rdx
    //    7:   00 00 80
    //    a:   48 39 d0                cmp    %rdx,%rax
    //    d:   75 08                   jne    17 <normal>
    //    f:   33 d2                   xor    %edx,%edx
    //   11:   48 83 f9 ff             cmp    $0xffffffffffffffff,$div
    //   15:   74 05                   je     1c <done>
    // 0000000000000017 <normal>:
    //   17:   48 99                   cqto
    //   19:   48 f7 f9                idiv   $div
    // 000000000000001c <done>:

    // mov    $0x8000000000000000,%rdx
    emit_opcode(cbuf, Assembler::REX_W);
    emit_opcode(cbuf, 0xBA);
    emit_d8(cbuf, 0x00);
    emit_d8(cbuf, 0x00);
    emit_d8(cbuf, 0x00);
    emit_d8(cbuf, 0x00);
    emit_d8(cbuf, 0x00);
    emit_d8(cbuf, 0x00);
    emit_d8(cbuf, 0x00);
    emit_d8(cbuf, 0x80);

    // cmp    %rdx,%rax
    emit_opcode(cbuf, Assembler::REX_W);
    emit_opcode(cbuf, 0x39);
    emit_d8(cbuf, 0xD0);

    // jne    17 <normal>
    emit_opcode(cbuf, 0x75);
    emit_d8(cbuf, 0x08);

    // xor    %edx,%edx
    emit_opcode(cbuf, 0x33);
    emit_d8(cbuf, 0xD2);

    // cmp    $0xffffffffffffffff,$div
    emit_opcode(cbuf, opnd_array(2)->reg(ra_,this,idx2)/* div */ < 8 ? Assembler::REX_W : Assembler::REX_WB);
    emit_opcode(cbuf, 0x83);
    emit_rm(cbuf, 0x3, 0x7, opnd_array(2)->reg(ra_,this,idx2)/* div */ & 7);
    emit_d8(cbuf, 0xFF);

    // je     1e <done>
    emit_opcode(cbuf, 0x74);
    emit_d8(cbuf, 0x05);

    // <normal>
    // cqto
    emit_opcode(cbuf, Assembler::REX_W);
    emit_opcode(cbuf, 0x99);

    // idivq (note: must be emitted by the user of this rule)
    // <done>
  
#line 22066 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2406 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(2)->reg(ra_,this,idx2)/* div */ < 8) {
      emit_opcode(cbuf, Assembler::REX_W);
    } else {
      emit_opcode(cbuf, Assembler::REX_WB);
    }
  
#line 22078 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xF7 /*primary()*/));
  
#line 22086 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2039 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // INC, DEC, IDIV, IMOD, JMP indirect, ...
    emit_rm(cbuf, 0x3, (0x7 /*secondary()*/), opnd_array(2)->reg(ra_,this,idx2)/* div */ & 7);
  
#line 22095 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void divModI_rReg_divmodNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// div
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// rdx
  {

#line 1826 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // Full implementation of Java idiv and irem; checks for
    // special case as described in JVM spec., p.243 & p.271.
    //
    //         normal case                           special case
    //
    // input : rax: dividend                         min_int
    //         reg: divisor                          -1
    //
    // output: rax: quotient  (= rax idiv reg)       min_int
    //         rdx: remainder (= rax irem reg)       0
    //
    //  Code sequnce:
    //
    //    0:   3d 00 00 00 80          cmp    $0x80000000,%eax
    //    5:   75 07/08                jne    e <normal>
    //    7:   33 d2                   xor    %edx,%edx
    //  [div >= 8 -> offset + 1]
    //  [REX_B]
    //    9:   83 f9 ff                cmp    $0xffffffffffffffff,$div
    //    c:   74 03/04                je     11 <done>
    // 000000000000000e <normal>:
    //    e:   99                      cltd
    //  [div >= 8 -> offset + 1]
    //  [REX_B]
    //    f:   f7 f9                   idiv   $div
    // 0000000000000011 <done>:

    // cmp    $0x80000000,%eax
    emit_opcode(cbuf, 0x3d);
    emit_d8(cbuf, 0x00);
    emit_d8(cbuf, 0x00);
    emit_d8(cbuf, 0x00);
    emit_d8(cbuf, 0x80);

    // jne    e <normal>
    emit_opcode(cbuf, 0x75);
    emit_d8(cbuf, opnd_array(2)->reg(ra_,this,idx2)/* div */ < 8 ? 0x07 : 0x08);

    // xor    %edx,%edx
    emit_opcode(cbuf, 0x33);
    emit_d8(cbuf, 0xD2);

    // cmp    $0xffffffffffffffff,%ecx
    if (opnd_array(2)->reg(ra_,this,idx2)/* div */ >= 8) {
      emit_opcode(cbuf, Assembler::REX_B);
    }
    emit_opcode(cbuf, 0x83);
    emit_rm(cbuf, 0x3, 0x7, opnd_array(2)->reg(ra_,this,idx2)/* div */ & 7);
    emit_d8(cbuf, 0xFF);

    // je     11 <done>
    emit_opcode(cbuf, 0x74);
    emit_d8(cbuf, opnd_array(2)->reg(ra_,this,idx2)/* div */ < 8 ? 0x03 : 0x04);

    // <normal>
    // cltd
    emit_opcode(cbuf, 0x99);

    // idivl (note: must be emitted by the user of this rule)
    // <done>
  
#line 22170 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2399 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(2)->reg(ra_,this,idx2)/* div */ >= 8) {
      emit_opcode(cbuf, Assembler::REX_B);
    }
  
#line 22180 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xF7 /*primary()*/));
  
#line 22188 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2039 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // INC, DEC, IDIV, IMOD, JMP indirect, ...
    emit_rm(cbuf, 0x3, (0x7 /*secondary()*/), opnd_array(2)->reg(ra_,this,idx2)/* div */ & 7);
  
#line 22197 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void divModL_rReg_divmodNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// div
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// rdx
  {

#line 1890 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // Full implementation of Java ldiv and lrem; checks for
    // special case as described in JVM spec., p.243 & p.271.
    //
    //         normal case                           special case
    //
    // input : rax: dividend                         min_long
    //         reg: divisor                          -1
    //
    // output: rax: quotient  (= rax idiv reg)       min_long
    //         rdx: remainder (= rax irem reg)       0
    //
    //  Code sequnce:
    //
    //    0:   48 ba 00 00 00 00 00    mov    $0x8000000000000000,%rdx
    //    7:   00 00 80
    //    a:   48 39 d0                cmp    %rdx,%rax
    //    d:   75 08                   jne    17 <normal>
    //    f:   33 d2                   xor    %edx,%edx
    //   11:   48 83 f9 ff             cmp    $0xffffffffffffffff,$div
    //   15:   74 05                   je     1c <done>
    // 0000000000000017 <normal>:
    //   17:   48 99                   cqto
    //   19:   48 f7 f9                idiv   $div
    // 000000000000001c <done>:

    // mov    $0x8000000000000000,%rdx
    emit_opcode(cbuf, Assembler::REX_W);
    emit_opcode(cbuf, 0xBA);
    emit_d8(cbuf, 0x00);
    emit_d8(cbuf, 0x00);
    emit_d8(cbuf, 0x00);
    emit_d8(cbuf, 0x00);
    emit_d8(cbuf, 0x00);
    emit_d8(cbuf, 0x00);
    emit_d8(cbuf, 0x00);
    emit_d8(cbuf, 0x80);

    // cmp    %rdx,%rax
    emit_opcode(cbuf, Assembler::REX_W);
    emit_opcode(cbuf, 0x39);
    emit_d8(cbuf, 0xD0);

    // jne    17 <normal>
    emit_opcode(cbuf, 0x75);
    emit_d8(cbuf, 0x08);

    // xor    %edx,%edx
    emit_opcode(cbuf, 0x33);
    emit_d8(cbuf, 0xD2);

    // cmp    $0xffffffffffffffff,$div
    emit_opcode(cbuf, opnd_array(2)->reg(ra_,this,idx2)/* div */ < 8 ? Assembler::REX_W : Assembler::REX_WB);
    emit_opcode(cbuf, 0x83);
    emit_rm(cbuf, 0x3, 0x7, opnd_array(2)->reg(ra_,this,idx2)/* div */ & 7);
    emit_d8(cbuf, 0xFF);

    // je     1e <done>
    emit_opcode(cbuf, 0x74);
    emit_d8(cbuf, 0x05);

    // <normal>
    // cqto
    emit_opcode(cbuf, Assembler::REX_W);
    emit_opcode(cbuf, 0x99);

    // idivq (note: must be emitted by the user of this rule)
    // <done>
  
#line 22279 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2406 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(2)->reg(ra_,this,idx2)/* div */ < 8) {
      emit_opcode(cbuf, Assembler::REX_W);
    } else {
      emit_opcode(cbuf, Assembler::REX_WB);
    }
  
#line 22291 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xF7 /*primary()*/));
  
#line 22299 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2039 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // INC, DEC, IDIV, IMOD, JMP indirect, ...
    emit_rm(cbuf, 0x3, (0x7 /*secondary()*/), opnd_array(2)->reg(ra_,this,idx2)/* div */ & 7);
  
#line 22308 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void loadConL_0x6666666666666667Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {

#line 2201 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    int dstenc = opnd_array(0)->reg(ra_,this)/* dst */;
    if (dstenc < 8) {
      emit_opcode(cbuf, Assembler::REX_W);
    } else {
      emit_opcode(cbuf, Assembler::REX_WB);
      dstenc -= 8;
    }
    emit_opcode(cbuf, 0xB8 | dstenc);
    emit_d64(cbuf, (0x6666666666666667));
  
#line 22331 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void mul_hiNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// rax
  {

#line 2406 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->reg(ra_,this,idx1)/* src */ < 8) {
      emit_opcode(cbuf, Assembler::REX_W);
    } else {
      emit_opcode(cbuf, Assembler::REX_WB);
    }
  
#line 22351 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xF7 /*primary()*/));
  
#line 22359 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2039 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // INC, DEC, IDIV, IMOD, JMP indirect, ...
    emit_rm(cbuf, 0x3, (0x5 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1)/* src */ & 7);
  
#line 22368 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void sarL_rReg_63Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cr
  {

#line 2175 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // SAL, SAR, SHR
    int dstenc = opnd_array(1)->reg(ra_,this,idx1)/* dst */;
    if (dstenc < 8) {
      emit_opcode(cbuf, Assembler::REX_W);
    } else {
      emit_opcode(cbuf, Assembler::REX_WB);
      dstenc -= 8;
    }
    emit_d8(cbuf, (0xC1 /*primary()*/));
    emit_rm(cbuf, 0x3, (0x7 /*secondary()*/), dstenc);
    emit_d8(cbuf, (0x3F));
  
#line 22393 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void sarL_rReg_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cr
  {

#line 2175 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // SAL, SAR, SHR
    int dstenc = opnd_array(1)->reg(ra_,this,idx1)/* dst */;
    if (dstenc < 8) {
      emit_opcode(cbuf, Assembler::REX_W);
    } else {
      emit_opcode(cbuf, Assembler::REX_WB);
      dstenc -= 8;
    }
    emit_d8(cbuf, (0xC1 /*primary()*/));
    emit_rm(cbuf, 0x3, (0x7 /*secondary()*/), dstenc);
    emit_d8(cbuf, (0x2));
  
#line 22418 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void modI_rRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// rax
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// div
  {

#line 1826 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // Full implementation of Java idiv and irem; checks for
    // special case as described in JVM spec., p.243 & p.271.
    //
    //         normal case                           special case
    //
    // input : rax: dividend                         min_int
    //         reg: divisor                          -1
    //
    // output: rax: quotient  (= rax idiv reg)       min_int
    //         rdx: remainder (= rax irem reg)       0
    //
    //  Code sequnce:
    //
    //    0:   3d 00 00 00 80          cmp    $0x80000000,%eax
    //    5:   75 07/08                jne    e <normal>
    //    7:   33 d2                   xor    %edx,%edx
    //  [div >= 8 -> offset + 1]
    //  [REX_B]
    //    9:   83 f9 ff                cmp    $0xffffffffffffffff,$div
    //    c:   74 03/04                je     11 <done>
    // 000000000000000e <normal>:
    //    e:   99                      cltd
    //  [div >= 8 -> offset + 1]
    //  [REX_B]
    //    f:   f7 f9                   idiv   $div
    // 0000000000000011 <done>:

    // cmp    $0x80000000,%eax
    emit_opcode(cbuf, 0x3d);
    emit_d8(cbuf, 0x00);
    emit_d8(cbuf, 0x00);
    emit_d8(cbuf, 0x00);
    emit_d8(cbuf, 0x80);

    // jne    e <normal>
    emit_opcode(cbuf, 0x75);
    emit_d8(cbuf, opnd_array(2)->reg(ra_,this,idx2)/* div */ < 8 ? 0x07 : 0x08);

    // xor    %edx,%edx
    emit_opcode(cbuf, 0x33);
    emit_d8(cbuf, 0xD2);

    // cmp    $0xffffffffffffffff,%ecx
    if (opnd_array(2)->reg(ra_,this,idx2)/* div */ >= 8) {
      emit_opcode(cbuf, Assembler::REX_B);
    }
    emit_opcode(cbuf, 0x83);
    emit_rm(cbuf, 0x3, 0x7, opnd_array(2)->reg(ra_,this,idx2)/* div */ & 7);
    emit_d8(cbuf, 0xFF);

    // je     11 <done>
    emit_opcode(cbuf, 0x74);
    emit_d8(cbuf, opnd_array(2)->reg(ra_,this,idx2)/* div */ < 8 ? 0x03 : 0x04);

    // <normal>
    // cltd
    emit_opcode(cbuf, 0x99);

    // idivl (note: must be emitted by the user of this rule)
    // <done>
  
#line 22493 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2399 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(2)->reg(ra_,this,idx2)/* div */ >= 8) {
      emit_opcode(cbuf, Assembler::REX_B);
    }
  
#line 22503 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xF7 /*primary()*/));
  
#line 22511 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2039 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // INC, DEC, IDIV, IMOD, JMP indirect, ...
    emit_rm(cbuf, 0x3, (0x7 /*secondary()*/), opnd_array(2)->reg(ra_,this,idx2)/* div */ & 7);
  
#line 22520 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void modL_rRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// rax
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// div
  {

#line 1890 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // Full implementation of Java ldiv and lrem; checks for
    // special case as described in JVM spec., p.243 & p.271.
    //
    //         normal case                           special case
    //
    // input : rax: dividend                         min_long
    //         reg: divisor                          -1
    //
    // output: rax: quotient  (= rax idiv reg)       min_long
    //         rdx: remainder (= rax irem reg)       0
    //
    //  Code sequnce:
    //
    //    0:   48 ba 00 00 00 00 00    mov    $0x8000000000000000,%rdx
    //    7:   00 00 80
    //    a:   48 39 d0                cmp    %rdx,%rax
    //    d:   75 08                   jne    17 <normal>
    //    f:   33 d2                   xor    %edx,%edx
    //   11:   48 83 f9 ff             cmp    $0xffffffffffffffff,$div
    //   15:   74 05                   je     1c <done>
    // 0000000000000017 <normal>:
    //   17:   48 99                   cqto
    //   19:   48 f7 f9                idiv   $div
    // 000000000000001c <done>:

    // mov    $0x8000000000000000,%rdx
    emit_opcode(cbuf, Assembler::REX_W);
    emit_opcode(cbuf, 0xBA);
    emit_d8(cbuf, 0x00);
    emit_d8(cbuf, 0x00);
    emit_d8(cbuf, 0x00);
    emit_d8(cbuf, 0x00);
    emit_d8(cbuf, 0x00);
    emit_d8(cbuf, 0x00);
    emit_d8(cbuf, 0x00);
    emit_d8(cbuf, 0x80);

    // cmp    %rdx,%rax
    emit_opcode(cbuf, Assembler::REX_W);
    emit_opcode(cbuf, 0x39);
    emit_d8(cbuf, 0xD0);

    // jne    17 <normal>
    emit_opcode(cbuf, 0x75);
    emit_d8(cbuf, 0x08);

    // xor    %edx,%edx
    emit_opcode(cbuf, 0x33);
    emit_d8(cbuf, 0xD2);

    // cmp    $0xffffffffffffffff,$div
    emit_opcode(cbuf, opnd_array(2)->reg(ra_,this,idx2)/* div */ < 8 ? Assembler::REX_W : Assembler::REX_WB);
    emit_opcode(cbuf, 0x83);
    emit_rm(cbuf, 0x3, 0x7, opnd_array(2)->reg(ra_,this,idx2)/* div */ & 7);
    emit_d8(cbuf, 0xFF);

    // je     1e <done>
    emit_opcode(cbuf, 0x74);
    emit_d8(cbuf, 0x05);

    // <normal>
    // cqto
    emit_opcode(cbuf, Assembler::REX_W);
    emit_opcode(cbuf, 0x99);

    // idivq (note: must be emitted by the user of this rule)
    // <done>
  
#line 22602 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2406 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(2)->reg(ra_,this,idx2)/* div */ < 8) {
      emit_opcode(cbuf, Assembler::REX_W);
    } else {
      emit_opcode(cbuf, Assembler::REX_WB);
    }
  
#line 22614 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xF7 /*primary()*/));
  
#line 22622 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2039 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // INC, DEC, IDIV, IMOD, JMP indirect, ...
    emit_rm(cbuf, 0x3, (0x7 /*secondary()*/), opnd_array(2)->reg(ra_,this,idx2)/* div */ & 7);
  
#line 22631 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void salI_rReg_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {

#line 2399 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->reg(ra_,this,idx1)/* dst */ >= 8) {
      emit_opcode(cbuf, Assembler::REX_B);
    }
  
#line 22649 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xD1 /*primary()*/));
  
#line 22657 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2039 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // INC, DEC, IDIV, IMOD, JMP indirect, ...
    emit_rm(cbuf, 0x3, (0x4 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1)/* dst */ & 7);
  
#line 22666 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void salI_mem_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {

#line 2309 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->base(ra_,this,idx1) >= 8) {
      if (opnd_array(1)->index(ra_,this,idx1) < 8) {
        emit_opcode(cbuf, Assembler::REX_B);
      } else {
        emit_opcode(cbuf, Assembler::REX_XB);
      }
    } else {
      if (opnd_array(1)->index(ra_,this,idx1) >= 8) {
        emit_opcode(cbuf, Assembler::REX_X);
      }
    }
  
#line 22692 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xD1 /*primary()*/));
  
#line 22700 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2524 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    int rm_byte_opcode = (0x4 /*secondary()*/);

    // High registers handle in encode_RegMem
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);

    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();       // disp-as-oop when
                                            // working with static
                                            // globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace,
                  disp_reloc);
  
#line 22720 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void salI_rReg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {

#line 2162 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // SAL, SAR, SHR
    int dstenc = opnd_array(1)->reg(ra_,this,idx1)/* dst */;
    if (dstenc >= 8) {
      emit_opcode(cbuf, Assembler::REX_B);
      dstenc -= 8;
    }
    emit_d8(cbuf, (0xC1 /*primary()*/));
    emit_rm(cbuf, 0x3, (0x4 /*secondary()*/), dstenc);
    emit_d8(cbuf, opnd_array(2)->constant());
  
#line 22744 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void salI_mem_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {

#line 2309 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->base(ra_,this,idx1) >= 8) {
      if (opnd_array(1)->index(ra_,this,idx1) < 8) {
        emit_opcode(cbuf, Assembler::REX_B);
      } else {
        emit_opcode(cbuf, Assembler::REX_XB);
      }
    } else {
      if (opnd_array(1)->index(ra_,this,idx1) >= 8) {
        emit_opcode(cbuf, Assembler::REX_X);
      }
    }
  
#line 22770 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xC1 /*primary()*/));
  
#line 22778 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2524 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    int rm_byte_opcode = (0x4 /*secondary()*/);

    // High registers handle in encode_RegMem
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);

    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();       // disp-as-oop when
                                            // working with static
                                            // globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace,
                  disp_reloc);
  
#line 22798 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2016 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // Check for 8-bit immediate, and set sign extend bit in opcode
    if (-0x80 <= opnd_array(2)->constant() && opnd_array(2)->constant() < 0x80) {
      emit_d8(cbuf, opnd_array(2)->constant());
    } else {
      // 32-bit immediate
      emit_d32(cbuf, opnd_array(2)->constant());
    }
  
#line 22812 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void salI_rReg_CLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {

#line 2399 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->reg(ra_,this,idx1)/* dst */ >= 8) {
      emit_opcode(cbuf, Assembler::REX_B);
    }
  
#line 22830 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xD3 /*primary()*/));
  
#line 22838 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2039 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // INC, DEC, IDIV, IMOD, JMP indirect, ...
    emit_rm(cbuf, 0x3, (0x4 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1)/* dst */ & 7);
  
#line 22847 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void salI_mem_CLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {

#line 2309 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->base(ra_,this,idx1) >= 8) {
      if (opnd_array(1)->index(ra_,this,idx1) < 8) {
        emit_opcode(cbuf, Assembler::REX_B);
      } else {
        emit_opcode(cbuf, Assembler::REX_XB);
      }
    } else {
      if (opnd_array(1)->index(ra_,this,idx1) >= 8) {
        emit_opcode(cbuf, Assembler::REX_X);
      }
    }
  
#line 22873 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xD3 /*primary()*/));
  
#line 22881 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2524 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    int rm_byte_opcode = (0x4 /*secondary()*/);

    // High registers handle in encode_RegMem
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);

    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();       // disp-as-oop when
                                            // working with static
                                            // globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace,
                  disp_reloc);
  
#line 22901 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void sarI_rReg_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {

#line 2399 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->reg(ra_,this,idx1)/* dst */ >= 8) {
      emit_opcode(cbuf, Assembler::REX_B);
    }
  
#line 22919 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xD1 /*primary()*/));
  
#line 22927 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2039 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // INC, DEC, IDIV, IMOD, JMP indirect, ...
    emit_rm(cbuf, 0x3, (0x7 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1)/* dst */ & 7);
  
#line 22936 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void sarI_mem_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {

#line 2309 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->base(ra_,this,idx1) >= 8) {
      if (opnd_array(1)->index(ra_,this,idx1) < 8) {
        emit_opcode(cbuf, Assembler::REX_B);
      } else {
        emit_opcode(cbuf, Assembler::REX_XB);
      }
    } else {
      if (opnd_array(1)->index(ra_,this,idx1) >= 8) {
        emit_opcode(cbuf, Assembler::REX_X);
      }
    }
  
#line 22962 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xD1 /*primary()*/));
  
#line 22970 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2524 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    int rm_byte_opcode = (0x7 /*secondary()*/);

    // High registers handle in encode_RegMem
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);

    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();       // disp-as-oop when
                                            // working with static
                                            // globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace,
                  disp_reloc);
  
#line 22990 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void sarI_rReg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {

#line 2162 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // SAL, SAR, SHR
    int dstenc = opnd_array(1)->reg(ra_,this,idx1)/* dst */;
    if (dstenc >= 8) {
      emit_opcode(cbuf, Assembler::REX_B);
      dstenc -= 8;
    }
    emit_d8(cbuf, (0xC1 /*primary()*/));
    emit_rm(cbuf, 0x3, (0x7 /*secondary()*/), dstenc);
    emit_d8(cbuf, opnd_array(2)->constant());
  
#line 23014 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void sarI_mem_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {

#line 2309 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->base(ra_,this,idx1) >= 8) {
      if (opnd_array(1)->index(ra_,this,idx1) < 8) {
        emit_opcode(cbuf, Assembler::REX_B);
      } else {
        emit_opcode(cbuf, Assembler::REX_XB);
      }
    } else {
      if (opnd_array(1)->index(ra_,this,idx1) >= 8) {
        emit_opcode(cbuf, Assembler::REX_X);
      }
    }
  
#line 23040 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xC1 /*primary()*/));
  
#line 23048 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2524 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    int rm_byte_opcode = (0x7 /*secondary()*/);

    // High registers handle in encode_RegMem
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);

    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();       // disp-as-oop when
                                            // working with static
                                            // globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace,
                  disp_reloc);
  
#line 23068 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2016 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // Check for 8-bit immediate, and set sign extend bit in opcode
    if (-0x80 <= opnd_array(2)->constant() && opnd_array(2)->constant() < 0x80) {
      emit_d8(cbuf, opnd_array(2)->constant());
    } else {
      // 32-bit immediate
      emit_d32(cbuf, opnd_array(2)->constant());
    }
  
#line 23082 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void sarI_rReg_CLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {

#line 2399 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->reg(ra_,this,idx1)/* dst */ >= 8) {
      emit_opcode(cbuf, Assembler::REX_B);
    }
  
#line 23100 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xD3 /*primary()*/));
  
#line 23108 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2039 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // INC, DEC, IDIV, IMOD, JMP indirect, ...
    emit_rm(cbuf, 0x3, (0x7 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1)/* dst */ & 7);
  
#line 23117 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void sarI_mem_CLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {

#line 2309 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->base(ra_,this,idx1) >= 8) {
      if (opnd_array(1)->index(ra_,this,idx1) < 8) {
        emit_opcode(cbuf, Assembler::REX_B);
      } else {
        emit_opcode(cbuf, Assembler::REX_XB);
      }
    } else {
      if (opnd_array(1)->index(ra_,this,idx1) >= 8) {
        emit_opcode(cbuf, Assembler::REX_X);
      }
    }
  
#line 23143 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xD3 /*primary()*/));
  
#line 23151 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2524 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    int rm_byte_opcode = (0x7 /*secondary()*/);

    // High registers handle in encode_RegMem
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);

    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();       // disp-as-oop when
                                            // working with static
                                            // globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace,
                  disp_reloc);
  
#line 23171 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void shrI_rReg_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {

#line 2399 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->reg(ra_,this,idx1)/* dst */ >= 8) {
      emit_opcode(cbuf, Assembler::REX_B);
    }
  
#line 23189 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xD1 /*primary()*/));
  
#line 23197 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2039 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // INC, DEC, IDIV, IMOD, JMP indirect, ...
    emit_rm(cbuf, 0x3, (0x5 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1)/* dst */ & 7);
  
#line 23206 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void shrI_mem_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {

#line 2309 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->base(ra_,this,idx1) >= 8) {
      if (opnd_array(1)->index(ra_,this,idx1) < 8) {
        emit_opcode(cbuf, Assembler::REX_B);
      } else {
        emit_opcode(cbuf, Assembler::REX_XB);
      }
    } else {
      if (opnd_array(1)->index(ra_,this,idx1) >= 8) {
        emit_opcode(cbuf, Assembler::REX_X);
      }
    }
  
#line 23232 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xD1 /*primary()*/));
  
#line 23240 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2524 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    int rm_byte_opcode = (0x5 /*secondary()*/);

    // High registers handle in encode_RegMem
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);

    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();       // disp-as-oop when
                                            // working with static
                                            // globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace,
                  disp_reloc);
  
#line 23260 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void shrI_rReg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {

#line 2162 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // SAL, SAR, SHR
    int dstenc = opnd_array(1)->reg(ra_,this,idx1)/* dst */;
    if (dstenc >= 8) {
      emit_opcode(cbuf, Assembler::REX_B);
      dstenc -= 8;
    }
    emit_d8(cbuf, (0xC1 /*primary()*/));
    emit_rm(cbuf, 0x3, (0x5 /*secondary()*/), dstenc);
    emit_d8(cbuf, opnd_array(2)->constant());
  
#line 23284 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void shrI_mem_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {

#line 2309 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->base(ra_,this,idx1) >= 8) {
      if (opnd_array(1)->index(ra_,this,idx1) < 8) {
        emit_opcode(cbuf, Assembler::REX_B);
      } else {
        emit_opcode(cbuf, Assembler::REX_XB);
      }
    } else {
      if (opnd_array(1)->index(ra_,this,idx1) >= 8) {
        emit_opcode(cbuf, Assembler::REX_X);
      }
    }
  
#line 23310 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xC1 /*primary()*/));
  
#line 23318 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2524 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    int rm_byte_opcode = (0x5 /*secondary()*/);

    // High registers handle in encode_RegMem
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);

    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();       // disp-as-oop when
                                            // working with static
                                            // globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace,
                  disp_reloc);
  
#line 23338 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2016 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // Check for 8-bit immediate, and set sign extend bit in opcode
    if (-0x80 <= opnd_array(2)->constant() && opnd_array(2)->constant() < 0x80) {
      emit_d8(cbuf, opnd_array(2)->constant());
    } else {
      // 32-bit immediate
      emit_d32(cbuf, opnd_array(2)->constant());
    }
  
#line 23352 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void shrI_rReg_CLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {

#line 2399 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->reg(ra_,this,idx1)/* dst */ >= 8) {
      emit_opcode(cbuf, Assembler::REX_B);
    }
  
#line 23370 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xD3 /*primary()*/));
  
#line 23378 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2039 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // INC, DEC, IDIV, IMOD, JMP indirect, ...
    emit_rm(cbuf, 0x3, (0x5 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1)/* dst */ & 7);
  
#line 23387 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void shrI_mem_CLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {

#line 2309 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->base(ra_,this,idx1) >= 8) {
      if (opnd_array(1)->index(ra_,this,idx1) < 8) {
        emit_opcode(cbuf, Assembler::REX_B);
      } else {
        emit_opcode(cbuf, Assembler::REX_XB);
      }
    } else {
      if (opnd_array(1)->index(ra_,this,idx1) >= 8) {
        emit_opcode(cbuf, Assembler::REX_X);
      }
    }
  
#line 23413 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xD3 /*primary()*/));
  
#line 23421 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2524 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    int rm_byte_opcode = (0x5 /*secondary()*/);

    // High registers handle in encode_RegMem
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);

    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();       // disp-as-oop when
                                            // working with static
                                            // globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace,
                  disp_reloc);
  
#line 23441 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void salL_rReg_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {

#line 2406 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->reg(ra_,this,idx1)/* dst */ < 8) {
      emit_opcode(cbuf, Assembler::REX_W);
    } else {
      emit_opcode(cbuf, Assembler::REX_WB);
    }
  
#line 23461 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xD1 /*primary()*/));
  
#line 23469 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2039 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // INC, DEC, IDIV, IMOD, JMP indirect, ...
    emit_rm(cbuf, 0x3, (0x4 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1)/* dst */ & 7);
  
#line 23478 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void salL_mem_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {

#line 2324 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->base(ra_,this,idx1) >= 8) {
      if (opnd_array(1)->index(ra_,this,idx1) < 8) {
        emit_opcode(cbuf, Assembler::REX_WB);
      } else {
        emit_opcode(cbuf, Assembler::REX_WXB);
      }
    } else {
      if (opnd_array(1)->index(ra_,this,idx1) < 8) {
        emit_opcode(cbuf, Assembler::REX_W);
      } else {
        emit_opcode(cbuf, Assembler::REX_WX);
      }
    }
  
#line 23506 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xD1 /*primary()*/));
  
#line 23514 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2524 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    int rm_byte_opcode = (0x4 /*secondary()*/);

    // High registers handle in encode_RegMem
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);

    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();       // disp-as-oop when
                                            // working with static
                                            // globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace,
                  disp_reloc);
  
#line 23534 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void salL_rReg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {

#line 2175 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // SAL, SAR, SHR
    int dstenc = opnd_array(1)->reg(ra_,this,idx1)/* dst */;
    if (dstenc < 8) {
      emit_opcode(cbuf, Assembler::REX_W);
    } else {
      emit_opcode(cbuf, Assembler::REX_WB);
      dstenc -= 8;
    }
    emit_d8(cbuf, (0xC1 /*primary()*/));
    emit_rm(cbuf, 0x3, (0x4 /*secondary()*/), dstenc);
    emit_d8(cbuf, opnd_array(2)->constant());
  
#line 23560 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void salL_mem_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {

#line 2324 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->base(ra_,this,idx1) >= 8) {
      if (opnd_array(1)->index(ra_,this,idx1) < 8) {
        emit_opcode(cbuf, Assembler::REX_WB);
      } else {
        emit_opcode(cbuf, Assembler::REX_WXB);
      }
    } else {
      if (opnd_array(1)->index(ra_,this,idx1) < 8) {
        emit_opcode(cbuf, Assembler::REX_W);
      } else {
        emit_opcode(cbuf, Assembler::REX_WX);
      }
    }
  
#line 23588 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xC1 /*primary()*/));
  
#line 23596 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2524 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    int rm_byte_opcode = (0x4 /*secondary()*/);

    // High registers handle in encode_RegMem
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);

    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();       // disp-as-oop when
                                            // working with static
                                            // globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace,
                  disp_reloc);
  
#line 23616 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2016 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // Check for 8-bit immediate, and set sign extend bit in opcode
    if (-0x80 <= opnd_array(2)->constant() && opnd_array(2)->constant() < 0x80) {
      emit_d8(cbuf, opnd_array(2)->constant());
    } else {
      // 32-bit immediate
      emit_d32(cbuf, opnd_array(2)->constant());
    }
  
#line 23630 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void salL_rReg_CLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {

#line 2406 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->reg(ra_,this,idx1)/* dst */ < 8) {
      emit_opcode(cbuf, Assembler::REX_W);
    } else {
      emit_opcode(cbuf, Assembler::REX_WB);
    }
  
#line 23650 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xD3 /*primary()*/));
  
#line 23658 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2039 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // INC, DEC, IDIV, IMOD, JMP indirect, ...
    emit_rm(cbuf, 0x3, (0x4 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1)/* dst */ & 7);
  
#line 23667 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void salL_mem_CLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {

#line 2324 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->base(ra_,this,idx1) >= 8) {
      if (opnd_array(1)->index(ra_,this,idx1) < 8) {
        emit_opcode(cbuf, Assembler::REX_WB);
      } else {
        emit_opcode(cbuf, Assembler::REX_WXB);
      }
    } else {
      if (opnd_array(1)->index(ra_,this,idx1) < 8) {
        emit_opcode(cbuf, Assembler::REX_W);
      } else {
        emit_opcode(cbuf, Assembler::REX_WX);
      }
    }
  
#line 23695 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xD3 /*primary()*/));
  
#line 23703 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2524 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    int rm_byte_opcode = (0x4 /*secondary()*/);

    // High registers handle in encode_RegMem
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);

    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();       // disp-as-oop when
                                            // working with static
                                            // globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace,
                  disp_reloc);
  
#line 23723 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void sarL_rReg_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {

#line 2406 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->reg(ra_,this,idx1)/* dst */ < 8) {
      emit_opcode(cbuf, Assembler::REX_W);
    } else {
      emit_opcode(cbuf, Assembler::REX_WB);
    }
  
#line 23743 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xD1 /*primary()*/));
  
#line 23751 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2039 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // INC, DEC, IDIV, IMOD, JMP indirect, ...
    emit_rm(cbuf, 0x3, (0x7 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1)/* dst */ & 7);
  
#line 23760 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void sarL_mem_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {

#line 2324 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->base(ra_,this,idx1) >= 8) {
      if (opnd_array(1)->index(ra_,this,idx1) < 8) {
        emit_opcode(cbuf, Assembler::REX_WB);
      } else {
        emit_opcode(cbuf, Assembler::REX_WXB);
      }
    } else {
      if (opnd_array(1)->index(ra_,this,idx1) < 8) {
        emit_opcode(cbuf, Assembler::REX_W);
      } else {
        emit_opcode(cbuf, Assembler::REX_WX);
      }
    }
  
#line 23788 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xD1 /*primary()*/));
  
#line 23796 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2524 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    int rm_byte_opcode = (0x7 /*secondary()*/);

    // High registers handle in encode_RegMem
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);

    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();       // disp-as-oop when
                                            // working with static
                                            // globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace,
                  disp_reloc);
  
#line 23816 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void sarL_rReg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {

#line 2175 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // SAL, SAR, SHR
    int dstenc = opnd_array(1)->reg(ra_,this,idx1)/* dst */;
    if (dstenc < 8) {
      emit_opcode(cbuf, Assembler::REX_W);
    } else {
      emit_opcode(cbuf, Assembler::REX_WB);
      dstenc -= 8;
    }
    emit_d8(cbuf, (0xC1 /*primary()*/));
    emit_rm(cbuf, 0x3, (0x7 /*secondary()*/), dstenc);
    emit_d8(cbuf, opnd_array(2)->constant());
  
#line 23842 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void sarL_mem_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {

#line 2324 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->base(ra_,this,idx1) >= 8) {
      if (opnd_array(1)->index(ra_,this,idx1) < 8) {
        emit_opcode(cbuf, Assembler::REX_WB);
      } else {
        emit_opcode(cbuf, Assembler::REX_WXB);
      }
    } else {
      if (opnd_array(1)->index(ra_,this,idx1) < 8) {
        emit_opcode(cbuf, Assembler::REX_W);
      } else {
        emit_opcode(cbuf, Assembler::REX_WX);
      }
    }
  
#line 23870 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xC1 /*primary()*/));
  
#line 23878 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2524 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    int rm_byte_opcode = (0x7 /*secondary()*/);

    // High registers handle in encode_RegMem
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);

    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();       // disp-as-oop when
                                            // working with static
                                            // globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace,
                  disp_reloc);
  
#line 23898 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2016 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // Check for 8-bit immediate, and set sign extend bit in opcode
    if (-0x80 <= opnd_array(2)->constant() && opnd_array(2)->constant() < 0x80) {
      emit_d8(cbuf, opnd_array(2)->constant());
    } else {
      // 32-bit immediate
      emit_d32(cbuf, opnd_array(2)->constant());
    }
  
#line 23912 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void sarL_rReg_CLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {

#line 2406 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->reg(ra_,this,idx1)/* dst */ < 8) {
      emit_opcode(cbuf, Assembler::REX_W);
    } else {
      emit_opcode(cbuf, Assembler::REX_WB);
    }
  
#line 23932 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xD3 /*primary()*/));
  
#line 23940 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2039 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // INC, DEC, IDIV, IMOD, JMP indirect, ...
    emit_rm(cbuf, 0x3, (0x7 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1)/* dst */ & 7);
  
#line 23949 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void sarL_mem_CLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {

#line 2324 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->base(ra_,this,idx1) >= 8) {
      if (opnd_array(1)->index(ra_,this,idx1) < 8) {
        emit_opcode(cbuf, Assembler::REX_WB);
      } else {
        emit_opcode(cbuf, Assembler::REX_WXB);
      }
    } else {
      if (opnd_array(1)->index(ra_,this,idx1) < 8) {
        emit_opcode(cbuf, Assembler::REX_W);
      } else {
        emit_opcode(cbuf, Assembler::REX_WX);
      }
    }
  
#line 23977 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xD3 /*primary()*/));
  
#line 23985 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2524 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    int rm_byte_opcode = (0x7 /*secondary()*/);

    // High registers handle in encode_RegMem
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);

    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();       // disp-as-oop when
                                            // working with static
                                            // globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace,
                  disp_reloc);
  
#line 24005 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void shrL_rReg_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {

#line 2406 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->reg(ra_,this,idx1)/* dst */ < 8) {
      emit_opcode(cbuf, Assembler::REX_W);
    } else {
      emit_opcode(cbuf, Assembler::REX_WB);
    }
  
#line 24025 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xD1 /*primary()*/));
  
#line 24033 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2039 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // INC, DEC, IDIV, IMOD, JMP indirect, ...
    emit_rm(cbuf, 0x3, (0x5 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1)/* dst */ & 7);
  
#line 24042 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void shrL_mem_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {

#line 2324 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->base(ra_,this,idx1) >= 8) {
      if (opnd_array(1)->index(ra_,this,idx1) < 8) {
        emit_opcode(cbuf, Assembler::REX_WB);
      } else {
        emit_opcode(cbuf, Assembler::REX_WXB);
      }
    } else {
      if (opnd_array(1)->index(ra_,this,idx1) < 8) {
        emit_opcode(cbuf, Assembler::REX_W);
      } else {
        emit_opcode(cbuf, Assembler::REX_WX);
      }
    }
  
#line 24070 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xD1 /*primary()*/));
  
#line 24078 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2524 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    int rm_byte_opcode = (0x5 /*secondary()*/);

    // High registers handle in encode_RegMem
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);

    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();       // disp-as-oop when
                                            // working with static
                                            // globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace,
                  disp_reloc);
  
#line 24098 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void shrL_rReg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {

#line 2175 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // SAL, SAR, SHR
    int dstenc = opnd_array(1)->reg(ra_,this,idx1)/* dst */;
    if (dstenc < 8) {
      emit_opcode(cbuf, Assembler::REX_W);
    } else {
      emit_opcode(cbuf, Assembler::REX_WB);
      dstenc -= 8;
    }
    emit_d8(cbuf, (0xC1 /*primary()*/));
    emit_rm(cbuf, 0x3, (0x5 /*secondary()*/), dstenc);
    emit_d8(cbuf, opnd_array(2)->constant());
  
#line 24124 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void shrL_mem_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {

#line 2324 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->base(ra_,this,idx1) >= 8) {
      if (opnd_array(1)->index(ra_,this,idx1) < 8) {
        emit_opcode(cbuf, Assembler::REX_WB);
      } else {
        emit_opcode(cbuf, Assembler::REX_WXB);
      }
    } else {
      if (opnd_array(1)->index(ra_,this,idx1) < 8) {
        emit_opcode(cbuf, Assembler::REX_W);
      } else {
        emit_opcode(cbuf, Assembler::REX_WX);
      }
    }
  
#line 24152 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xC1 /*primary()*/));
  
#line 24160 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2524 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    int rm_byte_opcode = (0x5 /*secondary()*/);

    // High registers handle in encode_RegMem
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);

    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();       // disp-as-oop when
                                            // working with static
                                            // globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace,
                  disp_reloc);
  
#line 24180 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2016 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // Check for 8-bit immediate, and set sign extend bit in opcode
    if (-0x80 <= opnd_array(2)->constant() && opnd_array(2)->constant() < 0x80) {
      emit_d8(cbuf, opnd_array(2)->constant());
    } else {
      // 32-bit immediate
      emit_d32(cbuf, opnd_array(2)->constant());
    }
  
#line 24194 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void shrL_rReg_CLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {

#line 2406 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->reg(ra_,this,idx1)/* dst */ < 8) {
      emit_opcode(cbuf, Assembler::REX_W);
    } else {
      emit_opcode(cbuf, Assembler::REX_WB);
    }
  
#line 24214 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xD3 /*primary()*/));
  
#line 24222 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2039 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // INC, DEC, IDIV, IMOD, JMP indirect, ...
    emit_rm(cbuf, 0x3, (0x5 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1)/* dst */ & 7);
  
#line 24231 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void shrL_mem_CLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {

#line 2324 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->base(ra_,this,idx1) >= 8) {
      if (opnd_array(1)->index(ra_,this,idx1) < 8) {
        emit_opcode(cbuf, Assembler::REX_WB);
      } else {
        emit_opcode(cbuf, Assembler::REX_WXB);
      }
    } else {
      if (opnd_array(1)->index(ra_,this,idx1) < 8) {
        emit_opcode(cbuf, Assembler::REX_W);
      } else {
        emit_opcode(cbuf, Assembler::REX_WX);
      }
    }
  
#line 24259 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xD3 /*primary()*/));
  
#line 24267 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2524 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    int rm_byte_opcode = (0x5 /*secondary()*/);

    // High registers handle in encode_RegMem
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);

    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();       // disp-as-oop when
                                            // working with static
                                            // globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace,
                  disp_reloc);
  
#line 24287 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void i2bNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// twentyfour
  {

#line 2350 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(0)->reg(ra_,this)/* dst */ < 8) {
      if (opnd_array(1)->reg(ra_,this,idx1)/* src */ >= 4) {
        emit_opcode(cbuf, opnd_array(1)->reg(ra_,this,idx1)/* src */ < 8 ? Assembler::REX : Assembler::REX_B);
      }
    } else {
      if (opnd_array(1)->reg(ra_,this,idx1)/* src */ < 8) {
        emit_opcode(cbuf, Assembler::REX_R);
      } else {
        emit_opcode(cbuf, Assembler::REX_RB);
      }
    }
  
#line 24313 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x0F /*primary()*/));
  
#line 24321 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1787 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xBE /*secondary()*/));
  
#line 24329 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1815 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_rm(cbuf, 0x3, opnd_array(0)->reg(ra_,this)/* dst */ & 7, opnd_array(1)->reg(ra_,this,idx1)/* src */ & 7);
  
#line 24337 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void i2sNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// sixteen
  {

#line 2415 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(0)->reg(ra_,this)/* dst */ < 8) {
      if (opnd_array(1)->reg(ra_,this,idx1)/* src */ >= 8) {
        emit_opcode(cbuf, Assembler::REX_B);
      }
    } else {
      if (opnd_array(1)->reg(ra_,this,idx1)/* src */ < 8) {
        emit_opcode(cbuf, Assembler::REX_R);
      } else {
        emit_opcode(cbuf, Assembler::REX_RB);
      }
    }
  
#line 24363 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x0F /*primary()*/));
  
#line 24371 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1787 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xBF /*secondary()*/));
  
#line 24379 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1815 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_rm(cbuf, 0x3, opnd_array(0)->reg(ra_,this)/* dst */ & 7, opnd_array(1)->reg(ra_,this,idx1)/* src */ & 7);
  
#line 24387 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void rolI_rReg_imm1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cr
  {

#line 2399 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->reg(ra_,this,idx1)/* dst */ >= 8) {
      emit_opcode(cbuf, Assembler::REX_B);
    }
  
#line 24404 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xD1 /*primary()*/));
  
#line 24412 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2039 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // INC, DEC, IDIV, IMOD, JMP indirect, ...
    emit_rm(cbuf, 0x3, (0x0 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1)/* dst */ & 7);
  
#line 24421 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void rolI_rReg_imm8Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// shift
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  {

#line 2162 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // SAL, SAR, SHR
    int dstenc = opnd_array(1)->reg(ra_,this,idx1)/* dst */;
    if (dstenc >= 8) {
      emit_opcode(cbuf, Assembler::REX_B);
      dstenc -= 8;
    }
    emit_d8(cbuf, (0xC1 /*primary()*/));
    emit_rm(cbuf, 0x3, (0x0 /*secondary()*/), dstenc);
    emit_d8(cbuf, opnd_array(2)->constant());
  
#line 24445 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void rolI_rReg_CLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// shift
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  {

#line 2399 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->reg(ra_,this,idx1)/* dst */ >= 8) {
      emit_opcode(cbuf, Assembler::REX_B);
    }
  
#line 24463 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xD3 /*primary()*/));
  
#line 24471 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2039 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // INC, DEC, IDIV, IMOD, JMP indirect, ...
    emit_rm(cbuf, 0x3, (0x0 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1)/* dst */ & 7);
  
#line 24480 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void rorI_rReg_imm1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cr
  {

#line 2399 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->reg(ra_,this,idx1)/* dst */ >= 8) {
      emit_opcode(cbuf, Assembler::REX_B);
    }
  
#line 24497 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xD1 /*primary()*/));
  
#line 24505 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2039 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // INC, DEC, IDIV, IMOD, JMP indirect, ...
    emit_rm(cbuf, 0x3, (0x1 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1)/* dst */ & 7);
  
#line 24514 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void rorI_rReg_imm8Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// shift
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  {

#line 2162 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // SAL, SAR, SHR
    int dstenc = opnd_array(1)->reg(ra_,this,idx1)/* dst */;
    if (dstenc >= 8) {
      emit_opcode(cbuf, Assembler::REX_B);
      dstenc -= 8;
    }
    emit_d8(cbuf, (0xC1 /*primary()*/));
    emit_rm(cbuf, 0x3, (0x1 /*secondary()*/), dstenc);
    emit_d8(cbuf, opnd_array(2)->constant());
  
#line 24538 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void rorI_rReg_CLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// shift
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  {

#line 2399 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->reg(ra_,this,idx1)/* dst */ >= 8) {
      emit_opcode(cbuf, Assembler::REX_B);
    }
  
#line 24556 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xD3 /*primary()*/));
  
#line 24564 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2039 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // INC, DEC, IDIV, IMOD, JMP indirect, ...
    emit_rm(cbuf, 0x3, (0x1 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1)/* dst */ & 7);
  
#line 24573 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void rolL_rReg_imm1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cr
  {

#line 2406 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->reg(ra_,this,idx1)/* dst */ < 8) {
      emit_opcode(cbuf, Assembler::REX_W);
    } else {
      emit_opcode(cbuf, Assembler::REX_WB);
    }
  
#line 24592 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xD1 /*primary()*/));
  
#line 24600 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2039 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // INC, DEC, IDIV, IMOD, JMP indirect, ...
    emit_rm(cbuf, 0x3, (0x0 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1)/* dst */ & 7);
  
#line 24609 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void rolL_rReg_imm8Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// shift
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  {

#line 2175 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // SAL, SAR, SHR
    int dstenc = opnd_array(1)->reg(ra_,this,idx1)/* dst */;
    if (dstenc < 8) {
      emit_opcode(cbuf, Assembler::REX_W);
    } else {
      emit_opcode(cbuf, Assembler::REX_WB);
      dstenc -= 8;
    }
    emit_d8(cbuf, (0xC1 /*primary()*/));
    emit_rm(cbuf, 0x3, (0x0 /*secondary()*/), dstenc);
    emit_d8(cbuf, opnd_array(2)->constant());
  
#line 24635 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void rolL_rReg_CLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// shift
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  {

#line 2406 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->reg(ra_,this,idx1)/* dst */ < 8) {
      emit_opcode(cbuf, Assembler::REX_W);
    } else {
      emit_opcode(cbuf, Assembler::REX_WB);
    }
  
#line 24655 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xD3 /*primary()*/));
  
#line 24663 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2039 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // INC, DEC, IDIV, IMOD, JMP indirect, ...
    emit_rm(cbuf, 0x3, (0x0 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1)/* dst */ & 7);
  
#line 24672 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void rorL_rReg_imm1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cr
  {

#line 2406 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->reg(ra_,this,idx1)/* dst */ < 8) {
      emit_opcode(cbuf, Assembler::REX_W);
    } else {
      emit_opcode(cbuf, Assembler::REX_WB);
    }
  
#line 24691 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xD1 /*primary()*/));
  
#line 24699 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2039 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // INC, DEC, IDIV, IMOD, JMP indirect, ...
    emit_rm(cbuf, 0x3, (0x1 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1)/* dst */ & 7);
  
#line 24708 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void rorL_rReg_imm8Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// shift
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  {

#line 2175 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // SAL, SAR, SHR
    int dstenc = opnd_array(1)->reg(ra_,this,idx1)/* dst */;
    if (dstenc < 8) {
      emit_opcode(cbuf, Assembler::REX_W);
    } else {
      emit_opcode(cbuf, Assembler::REX_WB);
      dstenc -= 8;
    }
    emit_d8(cbuf, (0xC1 /*primary()*/));
    emit_rm(cbuf, 0x3, (0x1 /*secondary()*/), dstenc);
    emit_d8(cbuf, opnd_array(2)->constant());
  
#line 24734 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void rorL_rReg_CLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// shift
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  {

#line 2406 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->reg(ra_,this,idx1)/* dst */ < 8) {
      emit_opcode(cbuf, Assembler::REX_W);
    } else {
      emit_opcode(cbuf, Assembler::REX_WB);
    }
  
#line 24754 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xD3 /*primary()*/));
  
#line 24762 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2039 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // INC, DEC, IDIV, IMOD, JMP indirect, ...
    emit_rm(cbuf, 0x3, (0x1 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1)/* dst */ & 7);
  
#line 24771 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void andI_rRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2415 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->reg(ra_,this,idx1)/* dst */ < 8) {
      if (opnd_array(2)->reg(ra_,this,idx2)/* src */ >= 8) {
        emit_opcode(cbuf, Assembler::REX_B);
      }
    } else {
      if (opnd_array(2)->reg(ra_,this,idx2)/* src */ < 8) {
        emit_opcode(cbuf, Assembler::REX_R);
      } else {
        emit_opcode(cbuf, Assembler::REX_RB);
      }
    }
  
#line 24797 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x23 /*primary()*/));
  
#line 24805 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1815 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1)/* dst */ & 7, opnd_array(2)->reg(ra_,this,idx2)/* src */ & 7);
  
#line 24813 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void andI_rReg_imm255Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2350 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->reg(ra_,this,idx1)/* dst */ < 8) {
      if (opnd_array(1)->reg(ra_,this,idx1)/* dst */ >= 4) {
        emit_opcode(cbuf, opnd_array(1)->reg(ra_,this,idx1)/* dst */ < 8 ? Assembler::REX : Assembler::REX_B);
      }
    } else {
      if (opnd_array(1)->reg(ra_,this,idx1)/* dst */ < 8) {
        emit_opcode(cbuf, Assembler::REX_R);
      } else {
        emit_opcode(cbuf, Assembler::REX_RB);
      }
    }
  
#line 24839 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x0F /*primary()*/));
  
#line 24847 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1787 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xB6 /*secondary()*/));
  
#line 24855 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1815 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1)/* dst */ & 7, opnd_array(1)->reg(ra_,this,idx1)/* dst */ & 7);
  
#line 24863 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void andI2L_rReg_imm255Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  {

#line 2350 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(0)->reg(ra_,this)/* dst */ < 8) {
      if (opnd_array(1)->reg(ra_,this,idx1)/* src */ >= 4) {
        emit_opcode(cbuf, opnd_array(1)->reg(ra_,this,idx1)/* src */ < 8 ? Assembler::REX : Assembler::REX_B);
      }
    } else {
      if (opnd_array(1)->reg(ra_,this,idx1)/* src */ < 8) {
        emit_opcode(cbuf, Assembler::REX_R);
      } else {
        emit_opcode(cbuf, Assembler::REX_RB);
      }
    }
  
#line 24889 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x0F /*primary()*/));
  
#line 24897 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1787 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xB6 /*secondary()*/));
  
#line 24905 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1815 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_rm(cbuf, 0x3, opnd_array(0)->reg(ra_,this)/* dst */ & 7, opnd_array(1)->reg(ra_,this,idx1)/* src */ & 7);
  
#line 24913 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void andI_rReg_imm65535Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2415 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->reg(ra_,this,idx1)/* dst */ < 8) {
      if (opnd_array(1)->reg(ra_,this,idx1)/* dst */ >= 8) {
        emit_opcode(cbuf, Assembler::REX_B);
      }
    } else {
      if (opnd_array(1)->reg(ra_,this,idx1)/* dst */ < 8) {
        emit_opcode(cbuf, Assembler::REX_R);
      } else {
        emit_opcode(cbuf, Assembler::REX_RB);
      }
    }
  
#line 24939 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x0F /*primary()*/));
  
#line 24947 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1787 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xB7 /*secondary()*/));
  
#line 24955 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1815 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1)/* dst */ & 7, opnd_array(1)->reg(ra_,this,idx1)/* dst */ & 7);
  
#line 24963 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void andI2L_rReg_imm65535Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  {

#line 2415 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(0)->reg(ra_,this)/* dst */ < 8) {
      if (opnd_array(1)->reg(ra_,this,idx1)/* src */ >= 8) {
        emit_opcode(cbuf, Assembler::REX_B);
      }
    } else {
      if (opnd_array(1)->reg(ra_,this,idx1)/* src */ < 8) {
        emit_opcode(cbuf, Assembler::REX_R);
      } else {
        emit_opcode(cbuf, Assembler::REX_RB);
      }
    }
  
#line 24989 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x0F /*primary()*/));
  
#line 24997 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1787 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xB7 /*secondary()*/));
  
#line 25005 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1815 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_rm(cbuf, 0x3, opnd_array(0)->reg(ra_,this)/* dst */ & 7, opnd_array(1)->reg(ra_,this,idx1)/* src */ & 7);
  
#line 25013 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void andI_rReg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 1974 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // OpcSEr/m
    int dstenc = opnd_array(1)->reg(ra_,this,idx1)/* dst */;
    if (dstenc >= 8) {
      emit_opcode(cbuf, Assembler::REX_B);
      dstenc -= 8;
    }
    // Emit primary opcode and set sign-extend bit
    // Check for 8-bit immediate, and set sign extend bit in opcode
    if (-0x80 <= opnd_array(2)->constant() && opnd_array(2)->constant() < 0x80) {
      emit_opcode(cbuf, (0x81 /*primary()*/) | 0x02);
    } else {
      // 32-bit immediate
      emit_opcode(cbuf, (0x81 /*primary()*/));
    }
    // Emit r/m byte with secondary opcode, after primary opcode.
    emit_rm(cbuf, 0x3, (0x04 /*secondary()*/), dstenc);
  
#line 25044 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2016 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // Check for 8-bit immediate, and set sign extend bit in opcode
    if (-0x80 <= opnd_array(2)->constant() && opnd_array(2)->constant() < 0x80) {
      emit_d8(cbuf, opnd_array(2)->constant());
    } else {
      // 32-bit immediate
      emit_d32(cbuf, opnd_array(2)->constant());
    }
  
#line 25058 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void andI_rReg_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2447 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->reg(ra_,this,idx1)/* dst */ < 8) {
      if (opnd_array(2)->base(ra_,this,idx2) < 8) {
        if (opnd_array(2)->index(ra_,this,idx2) >= 8) {
          emit_opcode(cbuf, Assembler::REX_X);
        }
      } else {
        if (opnd_array(2)->index(ra_,this,idx2) < 8) {
          emit_opcode(cbuf, Assembler::REX_B);
        } else {
          emit_opcode(cbuf, Assembler::REX_XB);
        }
      }
    } else {
      if (opnd_array(2)->base(ra_,this,idx2) < 8) {
        if (opnd_array(2)->index(ra_,this,idx2) < 8) {
          emit_opcode(cbuf, Assembler::REX_R);
        } else {
          emit_opcode(cbuf, Assembler::REX_RX);
        }
      } else {
        if (opnd_array(2)->index(ra_,this,idx2) < 8) {
          emit_opcode(cbuf, Assembler::REX_RB);
        } else {
          emit_opcode(cbuf, Assembler::REX_RXB);
        }
      }
    }
  
#line 25100 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x23 /*primary()*/));
  
#line 25108 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2511 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // High registers handle in encode_RegMem
    int reg = opnd_array(1)->reg(ra_,this,idx1)/* dst */;
    int base = opnd_array(2)->base(ra_,this,idx2);
    int index = opnd_array(2)->index(ra_,this,idx2);
    int scale = opnd_array(2)->scale();
    int disp = opnd_array(2)->disp(ra_,this,idx2);
    relocInfo::relocType disp_reloc = opnd_array(2)->disp_reloc();

    encode_RegMem(cbuf, reg, base, index, scale, disp, disp_reloc);
  
#line 25124 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void andI_rReg_mem_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  {

#line 2447 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(2)->reg(ra_,this,idx2)/* dst */ < 8) {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) >= 8) {
          emit_opcode(cbuf, Assembler::REX_X);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_B);
        } else {
          emit_opcode(cbuf, Assembler::REX_XB);
        }
      }
    } else {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_R);
        } else {
          emit_opcode(cbuf, Assembler::REX_RX);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_RB);
        } else {
          emit_opcode(cbuf, Assembler::REX_RXB);
        }
      }
    }
  
#line 25166 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x23 /*primary()*/));
  
#line 25174 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2511 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // High registers handle in encode_RegMem
    int reg = opnd_array(2)->reg(ra_,this,idx2)/* dst */;
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int disp = opnd_array(1)->disp(ra_,this,idx1);
    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();

    encode_RegMem(cbuf, reg, base, index, scale, disp, disp_reloc);
  
#line 25190 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void andI_mem_rRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2447 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(2)->reg(ra_,this,idx2)/* src */ < 8) {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) >= 8) {
          emit_opcode(cbuf, Assembler::REX_X);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_B);
        } else {
          emit_opcode(cbuf, Assembler::REX_XB);
        }
      }
    } else {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_R);
        } else {
          emit_opcode(cbuf, Assembler::REX_RX);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_RB);
        } else {
          emit_opcode(cbuf, Assembler::REX_RXB);
        }
      }
    }
  
#line 25232 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x21 /*primary()*/));
  
#line 25240 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2511 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // High registers handle in encode_RegMem
    int reg = opnd_array(2)->reg(ra_,this,idx2)/* src */;
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int disp = opnd_array(1)->disp(ra_,this,idx1);
    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();

    encode_RegMem(cbuf, reg, base, index, scale, disp, disp_reloc);
  
#line 25256 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void andI_mem_rReg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2447 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(2)->reg(ra_,this,idx2)/* src */ < 8) {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) >= 8) {
          emit_opcode(cbuf, Assembler::REX_X);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_B);
        } else {
          emit_opcode(cbuf, Assembler::REX_XB);
        }
      }
    } else {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_R);
        } else {
          emit_opcode(cbuf, Assembler::REX_RX);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_RB);
        } else {
          emit_opcode(cbuf, Assembler::REX_RXB);
        }
      }
    }
  
#line 25298 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x21 /*primary()*/));
  
#line 25306 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2511 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // High registers handle in encode_RegMem
    int reg = opnd_array(2)->reg(ra_,this,idx2)/* src */;
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int disp = opnd_array(1)->disp(ra_,this,idx1);
    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();

    encode_RegMem(cbuf, reg, base, index, scale, disp, disp_reloc);
  
#line 25322 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void andI_mem_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2309 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->base(ra_,this,idx1) >= 8) {
      if (opnd_array(1)->index(ra_,this,idx1) < 8) {
        emit_opcode(cbuf, Assembler::REX_B);
      } else {
        emit_opcode(cbuf, Assembler::REX_XB);
      }
    } else {
      if (opnd_array(1)->index(ra_,this,idx1) >= 8) {
        emit_opcode(cbuf, Assembler::REX_X);
      }
    }
  
#line 25348 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1962 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // Emit primary opcode and set sign-extend bit
    // Check for 8-bit immediate, and set sign extend bit in opcode
    if (-0x80 <= opnd_array(2)->constant() && opnd_array(2)->constant() < 0x80) {
      emit_opcode(cbuf, (0x81 /*primary()*/) | 0x02);
    } else {
      // 32-bit immediate
      emit_opcode(cbuf, (0x81 /*primary()*/));
    }
  
#line 25363 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2524 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    int rm_byte_opcode = (0x4 /*secondary()*/);

    // High registers handle in encode_RegMem
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);

    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();       // disp-as-oop when
                                            // working with static
                                            // globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace,
                  disp_reloc);
  
#line 25383 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2016 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // Check for 8-bit immediate, and set sign extend bit in opcode
    if (-0x80 <= opnd_array(2)->constant() && opnd_array(2)->constant() < 0x80) {
      emit_d8(cbuf, opnd_array(2)->constant());
    } else {
      // 32-bit immediate
      emit_d32(cbuf, opnd_array(2)->constant());
    }
  
#line 25397 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void andnI_rReg_rReg_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// minus_1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 8741 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ andnl(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, Address::make_raw(opnd_array(3)->base(ra_,this,idx3), opnd_array(3)->index(ra_,this,idx3), opnd_array(3)->scale(), opnd_array(3)->disp(ra_,this,idx3), opnd_array(3)->disp_reloc()));
  
#line 25415 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void andnI_rReg_rReg_mem_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// minus_1
  {
    MacroAssembler _masm(&cbuf);

#line 8741 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ andnl(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(2)->as_Register(ra_,this,idx2)/* src1 */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
  
#line 25433 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void andnI_rReg_rReg_rRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// minus_1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 8754 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ andnl(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* src2 */);
  
#line 25451 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void andnI_rReg_rReg_rReg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// minus_1
  {
    MacroAssembler _masm(&cbuf);

#line 8754 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ andnl(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(2)->as_Register(ra_,this,idx2)/* src1 */, opnd_array(1)->as_Register(ra_,this,idx1)/* src2 */);
  
#line 25469 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void blsiI_rReg_rRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// imm_zero
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 8767 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ blsil(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(2)->as_Register(ra_,this,idx2)/* src */);
  
#line 25486 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void blsiI_rReg_rReg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// imm_zero
  {
    MacroAssembler _masm(&cbuf);

#line 8767 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ blsil(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
  
#line 25503 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void blsiI_rReg_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// imm_zero
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 8781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ blsil(opnd_array(0)->as_Register(ra_,this)/* dst */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_reloc()));
  
#line 25520 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void blsiI_rReg_mem_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// imm_zero
  {
    MacroAssembler _masm(&cbuf);

#line 8781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ blsil(opnd_array(0)->as_Register(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
  
#line 25537 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void blsmskI_rReg_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// minus_1
  {
    MacroAssembler _masm(&cbuf);

#line 8796 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ blsmskl(opnd_array(0)->as_Register(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
  
#line 25554 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void blsmskI_rReg_mem_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// minus_1
  {
    MacroAssembler _masm(&cbuf);

#line 8796 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ blsmskl(opnd_array(0)->as_Register(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
  
#line 25571 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void blsmskI_rReg_rRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// minus_1
  {
    MacroAssembler _masm(&cbuf);

#line 8810 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ blsmskl(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
  
#line 25588 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void blsmskI_rReg_rReg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// minus_1
  {
    MacroAssembler _masm(&cbuf);

#line 8810 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ blsmskl(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
  
#line 25605 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void blsrI_rReg_rRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// minus_1
  {
    MacroAssembler _masm(&cbuf);

#line 8825 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ blsrl(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
  
#line 25622 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void blsrI_rReg_rReg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// minus_1
  {
    MacroAssembler _masm(&cbuf);

#line 8825 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ blsrl(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
  
#line 25639 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void blsrI_rReg_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// minus_1
  {
    MacroAssembler _masm(&cbuf);

#line 8841 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ blsrl(opnd_array(0)->as_Register(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
  
#line 25656 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void blsrI_rReg_mem_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// minus_1
  {
    MacroAssembler _masm(&cbuf);

#line 8841 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ blsrl(opnd_array(0)->as_Register(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
  
#line 25673 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void orI_rRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2415 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->reg(ra_,this,idx1)/* dst */ < 8) {
      if (opnd_array(2)->reg(ra_,this,idx2)/* src */ >= 8) {
        emit_opcode(cbuf, Assembler::REX_B);
      }
    } else {
      if (opnd_array(2)->reg(ra_,this,idx2)/* src */ < 8) {
        emit_opcode(cbuf, Assembler::REX_R);
      } else {
        emit_opcode(cbuf, Assembler::REX_RB);
      }
    }
  
#line 25699 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x0B /*primary()*/));
  
#line 25707 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1815 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1)/* dst */ & 7, opnd_array(2)->reg(ra_,this,idx2)/* src */ & 7);
  
#line 25715 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void orI_rReg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 1974 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // OpcSEr/m
    int dstenc = opnd_array(1)->reg(ra_,this,idx1)/* dst */;
    if (dstenc >= 8) {
      emit_opcode(cbuf, Assembler::REX_B);
      dstenc -= 8;
    }
    // Emit primary opcode and set sign-extend bit
    // Check for 8-bit immediate, and set sign extend bit in opcode
    if (-0x80 <= opnd_array(2)->constant() && opnd_array(2)->constant() < 0x80) {
      emit_opcode(cbuf, (0x81 /*primary()*/) | 0x02);
    } else {
      // 32-bit immediate
      emit_opcode(cbuf, (0x81 /*primary()*/));
    }
    // Emit r/m byte with secondary opcode, after primary opcode.
    emit_rm(cbuf, 0x3, (0x01 /*secondary()*/), dstenc);
  
#line 25746 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2016 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // Check for 8-bit immediate, and set sign extend bit in opcode
    if (-0x80 <= opnd_array(2)->constant() && opnd_array(2)->constant() < 0x80) {
      emit_d8(cbuf, opnd_array(2)->constant());
    } else {
      // 32-bit immediate
      emit_d32(cbuf, opnd_array(2)->constant());
    }
  
#line 25760 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void orI_rReg_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2447 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->reg(ra_,this,idx1)/* dst */ < 8) {
      if (opnd_array(2)->base(ra_,this,idx2) < 8) {
        if (opnd_array(2)->index(ra_,this,idx2) >= 8) {
          emit_opcode(cbuf, Assembler::REX_X);
        }
      } else {
        if (opnd_array(2)->index(ra_,this,idx2) < 8) {
          emit_opcode(cbuf, Assembler::REX_B);
        } else {
          emit_opcode(cbuf, Assembler::REX_XB);
        }
      }
    } else {
      if (opnd_array(2)->base(ra_,this,idx2) < 8) {
        if (opnd_array(2)->index(ra_,this,idx2) < 8) {
          emit_opcode(cbuf, Assembler::REX_R);
        } else {
          emit_opcode(cbuf, Assembler::REX_RX);
        }
      } else {
        if (opnd_array(2)->index(ra_,this,idx2) < 8) {
          emit_opcode(cbuf, Assembler::REX_RB);
        } else {
          emit_opcode(cbuf, Assembler::REX_RXB);
        }
      }
    }
  
#line 25802 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x0B /*primary()*/));
  
#line 25810 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2511 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // High registers handle in encode_RegMem
    int reg = opnd_array(1)->reg(ra_,this,idx1)/* dst */;
    int base = opnd_array(2)->base(ra_,this,idx2);
    int index = opnd_array(2)->index(ra_,this,idx2);
    int scale = opnd_array(2)->scale();
    int disp = opnd_array(2)->disp(ra_,this,idx2);
    relocInfo::relocType disp_reloc = opnd_array(2)->disp_reloc();

    encode_RegMem(cbuf, reg, base, index, scale, disp, disp_reloc);
  
#line 25826 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void orI_rReg_mem_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  {

#line 2447 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(2)->reg(ra_,this,idx2)/* dst */ < 8) {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) >= 8) {
          emit_opcode(cbuf, Assembler::REX_X);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_B);
        } else {
          emit_opcode(cbuf, Assembler::REX_XB);
        }
      }
    } else {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_R);
        } else {
          emit_opcode(cbuf, Assembler::REX_RX);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_RB);
        } else {
          emit_opcode(cbuf, Assembler::REX_RXB);
        }
      }
    }
  
#line 25868 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x0B /*primary()*/));
  
#line 25876 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2511 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // High registers handle in encode_RegMem
    int reg = opnd_array(2)->reg(ra_,this,idx2)/* dst */;
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int disp = opnd_array(1)->disp(ra_,this,idx1);
    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();

    encode_RegMem(cbuf, reg, base, index, scale, disp, disp_reloc);
  
#line 25892 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void orI_mem_rRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2447 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(2)->reg(ra_,this,idx2)/* src */ < 8) {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) >= 8) {
          emit_opcode(cbuf, Assembler::REX_X);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_B);
        } else {
          emit_opcode(cbuf, Assembler::REX_XB);
        }
      }
    } else {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_R);
        } else {
          emit_opcode(cbuf, Assembler::REX_RX);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_RB);
        } else {
          emit_opcode(cbuf, Assembler::REX_RXB);
        }
      }
    }
  
#line 25934 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x09 /*primary()*/));
  
#line 25942 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2511 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // High registers handle in encode_RegMem
    int reg = opnd_array(2)->reg(ra_,this,idx2)/* src */;
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int disp = opnd_array(1)->disp(ra_,this,idx1);
    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();

    encode_RegMem(cbuf, reg, base, index, scale, disp, disp_reloc);
  
#line 25958 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void orI_mem_rReg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2447 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(2)->reg(ra_,this,idx2)/* src */ < 8) {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) >= 8) {
          emit_opcode(cbuf, Assembler::REX_X);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_B);
        } else {
          emit_opcode(cbuf, Assembler::REX_XB);
        }
      }
    } else {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_R);
        } else {
          emit_opcode(cbuf, Assembler::REX_RX);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_RB);
        } else {
          emit_opcode(cbuf, Assembler::REX_RXB);
        }
      }
    }
  
#line 26000 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x09 /*primary()*/));
  
#line 26008 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2511 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // High registers handle in encode_RegMem
    int reg = opnd_array(2)->reg(ra_,this,idx2)/* src */;
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int disp = opnd_array(1)->disp(ra_,this,idx1);
    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();

    encode_RegMem(cbuf, reg, base, index, scale, disp, disp_reloc);
  
#line 26024 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void orI_mem_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2309 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->base(ra_,this,idx1) >= 8) {
      if (opnd_array(1)->index(ra_,this,idx1) < 8) {
        emit_opcode(cbuf, Assembler::REX_B);
      } else {
        emit_opcode(cbuf, Assembler::REX_XB);
      }
    } else {
      if (opnd_array(1)->index(ra_,this,idx1) >= 8) {
        emit_opcode(cbuf, Assembler::REX_X);
      }
    }
  
#line 26050 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1962 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // Emit primary opcode and set sign-extend bit
    // Check for 8-bit immediate, and set sign extend bit in opcode
    if (-0x80 <= opnd_array(2)->constant() && opnd_array(2)->constant() < 0x80) {
      emit_opcode(cbuf, (0x81 /*primary()*/) | 0x02);
    } else {
      // 32-bit immediate
      emit_opcode(cbuf, (0x81 /*primary()*/));
    }
  
#line 26065 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2524 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    int rm_byte_opcode = (0x1 /*secondary()*/);

    // High registers handle in encode_RegMem
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);

    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();       // disp-as-oop when
                                            // working with static
                                            // globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace,
                  disp_reloc);
  
#line 26085 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2016 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // Check for 8-bit immediate, and set sign extend bit in opcode
    if (-0x80 <= opnd_array(2)->constant() && opnd_array(2)->constant() < 0x80) {
      emit_d8(cbuf, opnd_array(2)->constant());
    } else {
      // 32-bit immediate
      emit_d32(cbuf, opnd_array(2)->constant());
    }
  
#line 26099 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void xorI_rRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2415 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->reg(ra_,this,idx1)/* dst */ < 8) {
      if (opnd_array(2)->reg(ra_,this,idx2)/* src */ >= 8) {
        emit_opcode(cbuf, Assembler::REX_B);
      }
    } else {
      if (opnd_array(2)->reg(ra_,this,idx2)/* src */ < 8) {
        emit_opcode(cbuf, Assembler::REX_R);
      } else {
        emit_opcode(cbuf, Assembler::REX_RB);
      }
    }
  
#line 26125 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x33 /*primary()*/));
  
#line 26133 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1815 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1)/* dst */ & 7, opnd_array(2)->reg(ra_,this,idx2)/* src */ & 7);
  
#line 26141 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void xorI_rReg_im1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// imm
  {
    MacroAssembler _masm(&cbuf);

#line 8931 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

     __ notl(opnd_array(1)->as_Register(ra_,this,idx1)/* dst */);
  
#line 26158 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void xorI_rReg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 1974 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // OpcSEr/m
    int dstenc = opnd_array(1)->reg(ra_,this,idx1)/* dst */;
    if (dstenc >= 8) {
      emit_opcode(cbuf, Assembler::REX_B);
      dstenc -= 8;
    }
    // Emit primary opcode and set sign-extend bit
    // Check for 8-bit immediate, and set sign extend bit in opcode
    if (-0x80 <= opnd_array(2)->constant() && opnd_array(2)->constant() < 0x80) {
      emit_opcode(cbuf, (0x81 /*primary()*/) | 0x02);
    } else {
      // 32-bit immediate
      emit_opcode(cbuf, (0x81 /*primary()*/));
    }
    // Emit r/m byte with secondary opcode, after primary opcode.
    emit_rm(cbuf, 0x3, (0x06 /*secondary()*/), dstenc);
  
#line 26189 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2016 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // Check for 8-bit immediate, and set sign extend bit in opcode
    if (-0x80 <= opnd_array(2)->constant() && opnd_array(2)->constant() < 0x80) {
      emit_d8(cbuf, opnd_array(2)->constant());
    } else {
      // 32-bit immediate
      emit_d32(cbuf, opnd_array(2)->constant());
    }
  
#line 26203 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void xorI_rReg_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2447 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->reg(ra_,this,idx1)/* dst */ < 8) {
      if (opnd_array(2)->base(ra_,this,idx2) < 8) {
        if (opnd_array(2)->index(ra_,this,idx2) >= 8) {
          emit_opcode(cbuf, Assembler::REX_X);
        }
      } else {
        if (opnd_array(2)->index(ra_,this,idx2) < 8) {
          emit_opcode(cbuf, Assembler::REX_B);
        } else {
          emit_opcode(cbuf, Assembler::REX_XB);
        }
      }
    } else {
      if (opnd_array(2)->base(ra_,this,idx2) < 8) {
        if (opnd_array(2)->index(ra_,this,idx2) < 8) {
          emit_opcode(cbuf, Assembler::REX_R);
        } else {
          emit_opcode(cbuf, Assembler::REX_RX);
        }
      } else {
        if (opnd_array(2)->index(ra_,this,idx2) < 8) {
          emit_opcode(cbuf, Assembler::REX_RB);
        } else {
          emit_opcode(cbuf, Assembler::REX_RXB);
        }
      }
    }
  
#line 26245 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x33 /*primary()*/));
  
#line 26253 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2511 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // High registers handle in encode_RegMem
    int reg = opnd_array(1)->reg(ra_,this,idx1)/* dst */;
    int base = opnd_array(2)->base(ra_,this,idx2);
    int index = opnd_array(2)->index(ra_,this,idx2);
    int scale = opnd_array(2)->scale();
    int disp = opnd_array(2)->disp(ra_,this,idx2);
    relocInfo::relocType disp_reloc = opnd_array(2)->disp_reloc();

    encode_RegMem(cbuf, reg, base, index, scale, disp, disp_reloc);
  
#line 26269 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void xorI_rReg_mem_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  {

#line 2447 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(2)->reg(ra_,this,idx2)/* dst */ < 8) {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) >= 8) {
          emit_opcode(cbuf, Assembler::REX_X);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_B);
        } else {
          emit_opcode(cbuf, Assembler::REX_XB);
        }
      }
    } else {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_R);
        } else {
          emit_opcode(cbuf, Assembler::REX_RX);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_RB);
        } else {
          emit_opcode(cbuf, Assembler::REX_RXB);
        }
      }
    }
  
#line 26311 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x33 /*primary()*/));
  
#line 26319 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2511 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // High registers handle in encode_RegMem
    int reg = opnd_array(2)->reg(ra_,this,idx2)/* dst */;
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int disp = opnd_array(1)->disp(ra_,this,idx1);
    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();

    encode_RegMem(cbuf, reg, base, index, scale, disp, disp_reloc);
  
#line 26335 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void xorI_mem_rRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2447 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(2)->reg(ra_,this,idx2)/* src */ < 8) {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) >= 8) {
          emit_opcode(cbuf, Assembler::REX_X);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_B);
        } else {
          emit_opcode(cbuf, Assembler::REX_XB);
        }
      }
    } else {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_R);
        } else {
          emit_opcode(cbuf, Assembler::REX_RX);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_RB);
        } else {
          emit_opcode(cbuf, Assembler::REX_RXB);
        }
      }
    }
  
#line 26377 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x31 /*primary()*/));
  
#line 26385 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2511 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // High registers handle in encode_RegMem
    int reg = opnd_array(2)->reg(ra_,this,idx2)/* src */;
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int disp = opnd_array(1)->disp(ra_,this,idx1);
    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();

    encode_RegMem(cbuf, reg, base, index, scale, disp, disp_reloc);
  
#line 26401 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void xorI_mem_rReg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2447 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(2)->reg(ra_,this,idx2)/* src */ < 8) {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) >= 8) {
          emit_opcode(cbuf, Assembler::REX_X);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_B);
        } else {
          emit_opcode(cbuf, Assembler::REX_XB);
        }
      }
    } else {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_R);
        } else {
          emit_opcode(cbuf, Assembler::REX_RX);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_RB);
        } else {
          emit_opcode(cbuf, Assembler::REX_RXB);
        }
      }
    }
  
#line 26443 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x31 /*primary()*/));
  
#line 26451 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2511 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // High registers handle in encode_RegMem
    int reg = opnd_array(2)->reg(ra_,this,idx2)/* src */;
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int disp = opnd_array(1)->disp(ra_,this,idx1);
    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();

    encode_RegMem(cbuf, reg, base, index, scale, disp, disp_reloc);
  
#line 26467 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void xorI_mem_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2309 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->base(ra_,this,idx1) >= 8) {
      if (opnd_array(1)->index(ra_,this,idx1) < 8) {
        emit_opcode(cbuf, Assembler::REX_B);
      } else {
        emit_opcode(cbuf, Assembler::REX_XB);
      }
    } else {
      if (opnd_array(1)->index(ra_,this,idx1) >= 8) {
        emit_opcode(cbuf, Assembler::REX_X);
      }
    }
  
#line 26493 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1962 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // Emit primary opcode and set sign-extend bit
    // Check for 8-bit immediate, and set sign extend bit in opcode
    if (-0x80 <= opnd_array(2)->constant() && opnd_array(2)->constant() < 0x80) {
      emit_opcode(cbuf, (0x81 /*primary()*/) | 0x02);
    } else {
      // 32-bit immediate
      emit_opcode(cbuf, (0x81 /*primary()*/));
    }
  
#line 26508 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2524 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    int rm_byte_opcode = (0x6 /*secondary()*/);

    // High registers handle in encode_RegMem
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);

    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();       // disp-as-oop when
                                            // working with static
                                            // globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace,
                  disp_reloc);
  
#line 26528 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2016 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // Check for 8-bit immediate, and set sign extend bit in opcode
    if (-0x80 <= opnd_array(2)->constant() && opnd_array(2)->constant() < 0x80) {
      emit_d8(cbuf, opnd_array(2)->constant());
    } else {
      // 32-bit immediate
      emit_d32(cbuf, opnd_array(2)->constant());
    }
  
#line 26542 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void andL_rRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2430 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->reg(ra_,this,idx1)/* dst */ < 8) {
      if (opnd_array(2)->reg(ra_,this,idx2)/* src */ < 8) {
        emit_opcode(cbuf, Assembler::REX_W);
      } else {
        emit_opcode(cbuf, Assembler::REX_WB);
      }
    } else {
      if (opnd_array(2)->reg(ra_,this,idx2)/* src */ < 8) {
        emit_opcode(cbuf, Assembler::REX_WR);
      } else {
        emit_opcode(cbuf, Assembler::REX_WRB);
      }
    }
  
#line 26570 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x23 /*primary()*/));
  
#line 26578 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1815 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1)/* dst */ & 7, opnd_array(2)->reg(ra_,this,idx2)/* src */ & 7);
  
#line 26586 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void andL_rReg_imm255Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2430 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->reg(ra_,this,idx1)/* dst */ < 8) {
      if (opnd_array(1)->reg(ra_,this,idx1)/* dst */ < 8) {
        emit_opcode(cbuf, Assembler::REX_W);
      } else {
        emit_opcode(cbuf, Assembler::REX_WB);
      }
    } else {
      if (opnd_array(1)->reg(ra_,this,idx1)/* dst */ < 8) {
        emit_opcode(cbuf, Assembler::REX_WR);
      } else {
        emit_opcode(cbuf, Assembler::REX_WRB);
      }
    }
  
#line 26614 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x0F /*primary()*/));
  
#line 26622 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1787 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xB6 /*secondary()*/));
  
#line 26630 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1815 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1)/* dst */ & 7, opnd_array(1)->reg(ra_,this,idx1)/* dst */ & 7);
  
#line 26638 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void andL_rReg_imm65535Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2430 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->reg(ra_,this,idx1)/* dst */ < 8) {
      if (opnd_array(1)->reg(ra_,this,idx1)/* dst */ < 8) {
        emit_opcode(cbuf, Assembler::REX_W);
      } else {
        emit_opcode(cbuf, Assembler::REX_WB);
      }
    } else {
      if (opnd_array(1)->reg(ra_,this,idx1)/* dst */ < 8) {
        emit_opcode(cbuf, Assembler::REX_WR);
      } else {
        emit_opcode(cbuf, Assembler::REX_WRB);
      }
    }
  
#line 26666 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x0F /*primary()*/));
  
#line 26674 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1787 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xB7 /*secondary()*/));
  
#line 26682 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1815 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1)/* dst */ & 7, opnd_array(1)->reg(ra_,this,idx1)/* dst */ & 7);
  
#line 26690 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void andL_rReg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 1994 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // OpcSEr/m
    int dstenc = opnd_array(1)->reg(ra_,this,idx1)/* dst */;
    if (dstenc < 8) {
      emit_opcode(cbuf, Assembler::REX_W);
    } else {
      emit_opcode(cbuf, Assembler::REX_WB);
      dstenc -= 8;
    }
    // Emit primary opcode and set sign-extend bit
    // Check for 8-bit immediate, and set sign extend bit in opcode
    if (-0x80 <= opnd_array(2)->constantL() && opnd_array(2)->constantL() < 0x80) {
      emit_opcode(cbuf, (0x81 /*primary()*/) | 0x02);
    } else {
      // 32-bit immediate
      emit_opcode(cbuf, (0x81 /*primary()*/));
    }
    // Emit r/m byte with secondary opcode, after primary opcode.
    emit_rm(cbuf, 0x3, (0x04 /*secondary()*/), dstenc);
  
#line 26723 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2016 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // Check for 8-bit immediate, and set sign extend bit in opcode
    if (-0x80 <= opnd_array(2)->constantL() && opnd_array(2)->constantL() < 0x80) {
      emit_d8(cbuf, opnd_array(2)->constantL());
    } else {
      // 32-bit immediate
      emit_d32(cbuf, opnd_array(2)->constantL());
    }
  
#line 26737 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void andL_rReg_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2478 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->reg(ra_,this,idx1)/* dst */ < 8) {
      if (opnd_array(2)->base(ra_,this,idx2) < 8) {
        if (opnd_array(2)->index(ra_,this,idx2) < 8) {
          emit_opcode(cbuf, Assembler::REX_W);
        } else {
          emit_opcode(cbuf, Assembler::REX_WX);
        }
      } else {
        if (opnd_array(2)->index(ra_,this,idx2) < 8) {
          emit_opcode(cbuf, Assembler::REX_WB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WXB);
        }
      }
    } else {
      if (opnd_array(2)->base(ra_,this,idx2) < 8) {
        if (opnd_array(2)->index(ra_,this,idx2) < 8) {
          emit_opcode(cbuf, Assembler::REX_WR);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRX);
        }
      } else {
        if (opnd_array(2)->index(ra_,this,idx2) < 8) {
          emit_opcode(cbuf, Assembler::REX_WRB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRXB);
        }
      }
    }
  
#line 26781 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x23 /*primary()*/));
  
#line 26789 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2511 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // High registers handle in encode_RegMem
    int reg = opnd_array(1)->reg(ra_,this,idx1)/* dst */;
    int base = opnd_array(2)->base(ra_,this,idx2);
    int index = opnd_array(2)->index(ra_,this,idx2);
    int scale = opnd_array(2)->scale();
    int disp = opnd_array(2)->disp(ra_,this,idx2);
    relocInfo::relocType disp_reloc = opnd_array(2)->disp_reloc();

    encode_RegMem(cbuf, reg, base, index, scale, disp, disp_reloc);
  
#line 26805 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void andL_rReg_mem_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  {

#line 2478 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(2)->reg(ra_,this,idx2)/* dst */ < 8) {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_W);
        } else {
          emit_opcode(cbuf, Assembler::REX_WX);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WXB);
        }
      }
    } else {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WR);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRX);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WRB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRXB);
        }
      }
    }
  
#line 26849 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x23 /*primary()*/));
  
#line 26857 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2511 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // High registers handle in encode_RegMem
    int reg = opnd_array(2)->reg(ra_,this,idx2)/* dst */;
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int disp = opnd_array(1)->disp(ra_,this,idx1);
    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();

    encode_RegMem(cbuf, reg, base, index, scale, disp, disp_reloc);
  
#line 26873 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void andL_mem_rRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2478 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(2)->reg(ra_,this,idx2)/* src */ < 8) {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_W);
        } else {
          emit_opcode(cbuf, Assembler::REX_WX);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WXB);
        }
      }
    } else {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WR);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRX);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WRB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRXB);
        }
      }
    }
  
#line 26917 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x21 /*primary()*/));
  
#line 26925 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2511 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // High registers handle in encode_RegMem
    int reg = opnd_array(2)->reg(ra_,this,idx2)/* src */;
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int disp = opnd_array(1)->disp(ra_,this,idx1);
    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();

    encode_RegMem(cbuf, reg, base, index, scale, disp, disp_reloc);
  
#line 26941 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void andL_mem_rReg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2478 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(2)->reg(ra_,this,idx2)/* src */ < 8) {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_W);
        } else {
          emit_opcode(cbuf, Assembler::REX_WX);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WXB);
        }
      }
    } else {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WR);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRX);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WRB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRXB);
        }
      }
    }
  
#line 26985 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x21 /*primary()*/));
  
#line 26993 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2511 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // High registers handle in encode_RegMem
    int reg = opnd_array(2)->reg(ra_,this,idx2)/* src */;
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int disp = opnd_array(1)->disp(ra_,this,idx1);
    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();

    encode_RegMem(cbuf, reg, base, index, scale, disp, disp_reloc);
  
#line 27009 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void andL_mem_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2324 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->base(ra_,this,idx1) >= 8) {
      if (opnd_array(1)->index(ra_,this,idx1) < 8) {
        emit_opcode(cbuf, Assembler::REX_WB);
      } else {
        emit_opcode(cbuf, Assembler::REX_WXB);
      }
    } else {
      if (opnd_array(1)->index(ra_,this,idx1) < 8) {
        emit_opcode(cbuf, Assembler::REX_W);
      } else {
        emit_opcode(cbuf, Assembler::REX_WX);
      }
    }
  
#line 27037 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1962 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // Emit primary opcode and set sign-extend bit
    // Check for 8-bit immediate, and set sign extend bit in opcode
    if (-0x80 <= opnd_array(2)->constantL() && opnd_array(2)->constantL() < 0x80) {
      emit_opcode(cbuf, (0x81 /*primary()*/) | 0x02);
    } else {
      // 32-bit immediate
      emit_opcode(cbuf, (0x81 /*primary()*/));
    }
  
#line 27052 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2524 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    int rm_byte_opcode = (0x4 /*secondary()*/);

    // High registers handle in encode_RegMem
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);

    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();       // disp-as-oop when
                                            // working with static
                                            // globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace,
                  disp_reloc);
  
#line 27072 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2016 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // Check for 8-bit immediate, and set sign extend bit in opcode
    if (-0x80 <= opnd_array(2)->constantL() && opnd_array(2)->constantL() < 0x80) {
      emit_d8(cbuf, opnd_array(2)->constantL());
    } else {
      // 32-bit immediate
      emit_d32(cbuf, opnd_array(2)->constantL());
    }
  
#line 27086 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void andnL_rReg_rReg_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// minus_1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 9088 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ andnq(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, Address::make_raw(opnd_array(3)->base(ra_,this,idx3), opnd_array(3)->index(ra_,this,idx3), opnd_array(3)->scale(), opnd_array(3)->disp(ra_,this,idx3), opnd_array(3)->disp_reloc()));
  
#line 27104 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void andnL_rReg_rReg_mem_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// minus_1
  {
    MacroAssembler _masm(&cbuf);

#line 9088 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ andnq(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(2)->as_Register(ra_,this,idx2)/* src1 */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
  
#line 27122 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void andnL_rReg_rReg_rRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// minus_1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 9101 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

  __ andnq(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* src2 */);
  
#line 27140 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void andnL_rReg_rReg_rReg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// minus_1
  {
    MacroAssembler _masm(&cbuf);

#line 9101 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

  __ andnq(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(2)->as_Register(ra_,this,idx2)/* src1 */, opnd_array(1)->as_Register(ra_,this,idx1)/* src2 */);
  
#line 27158 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void blsiL_rReg_rRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// imm_zero
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 9114 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ blsiq(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(2)->as_Register(ra_,this,idx2)/* src */);
  
#line 27175 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void blsiL_rReg_rReg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// imm_zero
  {
    MacroAssembler _masm(&cbuf);

#line 9114 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ blsiq(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
  
#line 27192 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void blsiL_rReg_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// imm_zero
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 9128 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ blsiq(opnd_array(0)->as_Register(ra_,this)/* dst */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_reloc()));
  
#line 27209 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void blsiL_rReg_mem_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// imm_zero
  {
    MacroAssembler _masm(&cbuf);

#line 9128 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ blsiq(opnd_array(0)->as_Register(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
  
#line 27226 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void blsmskL_rReg_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// minus_1
  {
    MacroAssembler _masm(&cbuf);

#line 9143 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ blsmskq(opnd_array(0)->as_Register(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
  
#line 27243 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void blsmskL_rReg_mem_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// minus_1
  {
    MacroAssembler _masm(&cbuf);

#line 9143 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ blsmskq(opnd_array(0)->as_Register(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
  
#line 27260 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void blsmskL_rReg_rRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// minus_1
  {
    MacroAssembler _masm(&cbuf);

#line 9157 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ blsmskq(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
  
#line 27277 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void blsmskL_rReg_rReg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// minus_1
  {
    MacroAssembler _masm(&cbuf);

#line 9157 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ blsmskq(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
  
#line 27294 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void blsrL_rReg_rRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// minus_1
  {
    MacroAssembler _masm(&cbuf);

#line 9172 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ blsrq(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
  
#line 27311 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void blsrL_rReg_rReg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// minus_1
  {
    MacroAssembler _masm(&cbuf);

#line 9172 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ blsrq(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
  
#line 27328 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void blsrL_rReg_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// minus_1
  {
    MacroAssembler _masm(&cbuf);

#line 9188 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ blsrq(opnd_array(0)->as_Register(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
  
#line 27345 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void blsrL_rReg_mem_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// minus_1
  {
    MacroAssembler _masm(&cbuf);

#line 9188 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ blsrq(opnd_array(0)->as_Register(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
  
#line 27362 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void orL_rRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2430 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->reg(ra_,this,idx1)/* dst */ < 8) {
      if (opnd_array(2)->reg(ra_,this,idx2)/* src */ < 8) {
        emit_opcode(cbuf, Assembler::REX_W);
      } else {
        emit_opcode(cbuf, Assembler::REX_WB);
      }
    } else {
      if (opnd_array(2)->reg(ra_,this,idx2)/* src */ < 8) {
        emit_opcode(cbuf, Assembler::REX_WR);
      } else {
        emit_opcode(cbuf, Assembler::REX_WRB);
      }
    }
  
#line 27390 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x0B /*primary()*/));
  
#line 27398 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1815 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1)/* dst */ & 7, opnd_array(2)->reg(ra_,this,idx2)/* src */ & 7);
  
#line 27406 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void orL_rReg_castP2XNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2430 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->reg(ra_,this,idx1)/* dst */ < 8) {
      if (opnd_array(2)->reg(ra_,this,idx2)/* src */ < 8) {
        emit_opcode(cbuf, Assembler::REX_W);
      } else {
        emit_opcode(cbuf, Assembler::REX_WB);
      }
    } else {
      if (opnd_array(2)->reg(ra_,this,idx2)/* src */ < 8) {
        emit_opcode(cbuf, Assembler::REX_WR);
      } else {
        emit_opcode(cbuf, Assembler::REX_WRB);
      }
    }
  
#line 27434 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x0B /*primary()*/));
  
#line 27442 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1815 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1)/* dst */ & 7, opnd_array(2)->reg(ra_,this,idx2)/* src */ & 7);
  
#line 27450 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void orL_rReg_castP2X_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  {

#line 2430 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(2)->reg(ra_,this,idx2)/* dst */ < 8) {
      if (opnd_array(1)->reg(ra_,this,idx1)/* src */ < 8) {
        emit_opcode(cbuf, Assembler::REX_W);
      } else {
        emit_opcode(cbuf, Assembler::REX_WB);
      }
    } else {
      if (opnd_array(1)->reg(ra_,this,idx1)/* src */ < 8) {
        emit_opcode(cbuf, Assembler::REX_WR);
      } else {
        emit_opcode(cbuf, Assembler::REX_WRB);
      }
    }
  
#line 27478 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x0B /*primary()*/));
  
#line 27486 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1815 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_rm(cbuf, 0x3, opnd_array(2)->reg(ra_,this,idx2)/* dst */ & 7, opnd_array(1)->reg(ra_,this,idx1)/* src */ & 7);
  
#line 27494 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void orL_rReg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 1994 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // OpcSEr/m
    int dstenc = opnd_array(1)->reg(ra_,this,idx1)/* dst */;
    if (dstenc < 8) {
      emit_opcode(cbuf, Assembler::REX_W);
    } else {
      emit_opcode(cbuf, Assembler::REX_WB);
      dstenc -= 8;
    }
    // Emit primary opcode and set sign-extend bit
    // Check for 8-bit immediate, and set sign extend bit in opcode
    if (-0x80 <= opnd_array(2)->constantL() && opnd_array(2)->constantL() < 0x80) {
      emit_opcode(cbuf, (0x81 /*primary()*/) | 0x02);
    } else {
      // 32-bit immediate
      emit_opcode(cbuf, (0x81 /*primary()*/));
    }
    // Emit r/m byte with secondary opcode, after primary opcode.
    emit_rm(cbuf, 0x3, (0x01 /*secondary()*/), dstenc);
  
#line 27527 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2016 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // Check for 8-bit immediate, and set sign extend bit in opcode
    if (-0x80 <= opnd_array(2)->constantL() && opnd_array(2)->constantL() < 0x80) {
      emit_d8(cbuf, opnd_array(2)->constantL());
    } else {
      // 32-bit immediate
      emit_d32(cbuf, opnd_array(2)->constantL());
    }
  
#line 27541 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void orL_rReg_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2478 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->reg(ra_,this,idx1)/* dst */ < 8) {
      if (opnd_array(2)->base(ra_,this,idx2) < 8) {
        if (opnd_array(2)->index(ra_,this,idx2) < 8) {
          emit_opcode(cbuf, Assembler::REX_W);
        } else {
          emit_opcode(cbuf, Assembler::REX_WX);
        }
      } else {
        if (opnd_array(2)->index(ra_,this,idx2) < 8) {
          emit_opcode(cbuf, Assembler::REX_WB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WXB);
        }
      }
    } else {
      if (opnd_array(2)->base(ra_,this,idx2) < 8) {
        if (opnd_array(2)->index(ra_,this,idx2) < 8) {
          emit_opcode(cbuf, Assembler::REX_WR);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRX);
        }
      } else {
        if (opnd_array(2)->index(ra_,this,idx2) < 8) {
          emit_opcode(cbuf, Assembler::REX_WRB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRXB);
        }
      }
    }
  
#line 27585 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x0B /*primary()*/));
  
#line 27593 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2511 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // High registers handle in encode_RegMem
    int reg = opnd_array(1)->reg(ra_,this,idx1)/* dst */;
    int base = opnd_array(2)->base(ra_,this,idx2);
    int index = opnd_array(2)->index(ra_,this,idx2);
    int scale = opnd_array(2)->scale();
    int disp = opnd_array(2)->disp(ra_,this,idx2);
    relocInfo::relocType disp_reloc = opnd_array(2)->disp_reloc();

    encode_RegMem(cbuf, reg, base, index, scale, disp, disp_reloc);
  
#line 27609 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void orL_rReg_mem_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  {

#line 2478 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(2)->reg(ra_,this,idx2)/* dst */ < 8) {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_W);
        } else {
          emit_opcode(cbuf, Assembler::REX_WX);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WXB);
        }
      }
    } else {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WR);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRX);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WRB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRXB);
        }
      }
    }
  
#line 27653 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x0B /*primary()*/));
  
#line 27661 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2511 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // High registers handle in encode_RegMem
    int reg = opnd_array(2)->reg(ra_,this,idx2)/* dst */;
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int disp = opnd_array(1)->disp(ra_,this,idx1);
    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();

    encode_RegMem(cbuf, reg, base, index, scale, disp, disp_reloc);
  
#line 27677 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void orL_mem_rRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2478 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(2)->reg(ra_,this,idx2)/* src */ < 8) {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_W);
        } else {
          emit_opcode(cbuf, Assembler::REX_WX);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WXB);
        }
      }
    } else {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WR);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRX);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WRB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRXB);
        }
      }
    }
  
#line 27721 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x09 /*primary()*/));
  
#line 27729 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2511 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // High registers handle in encode_RegMem
    int reg = opnd_array(2)->reg(ra_,this,idx2)/* src */;
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int disp = opnd_array(1)->disp(ra_,this,idx1);
    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();

    encode_RegMem(cbuf, reg, base, index, scale, disp, disp_reloc);
  
#line 27745 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void orL_mem_rReg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2478 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(2)->reg(ra_,this,idx2)/* src */ < 8) {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_W);
        } else {
          emit_opcode(cbuf, Assembler::REX_WX);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WXB);
        }
      }
    } else {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WR);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRX);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WRB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRXB);
        }
      }
    }
  
#line 27789 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x09 /*primary()*/));
  
#line 27797 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2511 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // High registers handle in encode_RegMem
    int reg = opnd_array(2)->reg(ra_,this,idx2)/* src */;
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int disp = opnd_array(1)->disp(ra_,this,idx1);
    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();

    encode_RegMem(cbuf, reg, base, index, scale, disp, disp_reloc);
  
#line 27813 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void orL_mem_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2324 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->base(ra_,this,idx1) >= 8) {
      if (opnd_array(1)->index(ra_,this,idx1) < 8) {
        emit_opcode(cbuf, Assembler::REX_WB);
      } else {
        emit_opcode(cbuf, Assembler::REX_WXB);
      }
    } else {
      if (opnd_array(1)->index(ra_,this,idx1) < 8) {
        emit_opcode(cbuf, Assembler::REX_W);
      } else {
        emit_opcode(cbuf, Assembler::REX_WX);
      }
    }
  
#line 27841 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1962 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // Emit primary opcode and set sign-extend bit
    // Check for 8-bit immediate, and set sign extend bit in opcode
    if (-0x80 <= opnd_array(2)->constantL() && opnd_array(2)->constantL() < 0x80) {
      emit_opcode(cbuf, (0x81 /*primary()*/) | 0x02);
    } else {
      // 32-bit immediate
      emit_opcode(cbuf, (0x81 /*primary()*/));
    }
  
#line 27856 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2524 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    int rm_byte_opcode = (0x1 /*secondary()*/);

    // High registers handle in encode_RegMem
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);

    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();       // disp-as-oop when
                                            // working with static
                                            // globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace,
                  disp_reloc);
  
#line 27876 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2016 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // Check for 8-bit immediate, and set sign extend bit in opcode
    if (-0x80 <= opnd_array(2)->constantL() && opnd_array(2)->constantL() < 0x80) {
      emit_d8(cbuf, opnd_array(2)->constantL());
    } else {
      // 32-bit immediate
      emit_d32(cbuf, opnd_array(2)->constantL());
    }
  
#line 27890 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void xorL_rRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2430 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->reg(ra_,this,idx1)/* dst */ < 8) {
      if (opnd_array(2)->reg(ra_,this,idx2)/* src */ < 8) {
        emit_opcode(cbuf, Assembler::REX_W);
      } else {
        emit_opcode(cbuf, Assembler::REX_WB);
      }
    } else {
      if (opnd_array(2)->reg(ra_,this,idx2)/* src */ < 8) {
        emit_opcode(cbuf, Assembler::REX_WR);
      } else {
        emit_opcode(cbuf, Assembler::REX_WRB);
      }
    }
  
#line 27918 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x33 /*primary()*/));
  
#line 27926 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1815 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1)/* dst */ & 7, opnd_array(2)->reg(ra_,this,idx2)/* src */ & 7);
  
#line 27934 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void xorL_rReg_im1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// imm
  {
    MacroAssembler _masm(&cbuf);

#line 9290 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

     __ notq(opnd_array(1)->as_Register(ra_,this,idx1)/* dst */);
  
#line 27951 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void xorL_rReg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 1994 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // OpcSEr/m
    int dstenc = opnd_array(1)->reg(ra_,this,idx1)/* dst */;
    if (dstenc < 8) {
      emit_opcode(cbuf, Assembler::REX_W);
    } else {
      emit_opcode(cbuf, Assembler::REX_WB);
      dstenc -= 8;
    }
    // Emit primary opcode and set sign-extend bit
    // Check for 8-bit immediate, and set sign extend bit in opcode
    if (-0x80 <= opnd_array(2)->constantL() && opnd_array(2)->constantL() < 0x80) {
      emit_opcode(cbuf, (0x81 /*primary()*/) | 0x02);
    } else {
      // 32-bit immediate
      emit_opcode(cbuf, (0x81 /*primary()*/));
    }
    // Emit r/m byte with secondary opcode, after primary opcode.
    emit_rm(cbuf, 0x3, (0x06 /*secondary()*/), dstenc);
  
#line 27984 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2016 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // Check for 8-bit immediate, and set sign extend bit in opcode
    if (-0x80 <= opnd_array(2)->constantL() && opnd_array(2)->constantL() < 0x80) {
      emit_d8(cbuf, opnd_array(2)->constantL());
    } else {
      // 32-bit immediate
      emit_d32(cbuf, opnd_array(2)->constantL());
    }
  
#line 27998 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void xorL_rReg_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2478 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->reg(ra_,this,idx1)/* dst */ < 8) {
      if (opnd_array(2)->base(ra_,this,idx2) < 8) {
        if (opnd_array(2)->index(ra_,this,idx2) < 8) {
          emit_opcode(cbuf, Assembler::REX_W);
        } else {
          emit_opcode(cbuf, Assembler::REX_WX);
        }
      } else {
        if (opnd_array(2)->index(ra_,this,idx2) < 8) {
          emit_opcode(cbuf, Assembler::REX_WB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WXB);
        }
      }
    } else {
      if (opnd_array(2)->base(ra_,this,idx2) < 8) {
        if (opnd_array(2)->index(ra_,this,idx2) < 8) {
          emit_opcode(cbuf, Assembler::REX_WR);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRX);
        }
      } else {
        if (opnd_array(2)->index(ra_,this,idx2) < 8) {
          emit_opcode(cbuf, Assembler::REX_WRB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRXB);
        }
      }
    }
  
#line 28042 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x33 /*primary()*/));
  
#line 28050 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2511 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // High registers handle in encode_RegMem
    int reg = opnd_array(1)->reg(ra_,this,idx1)/* dst */;
    int base = opnd_array(2)->base(ra_,this,idx2);
    int index = opnd_array(2)->index(ra_,this,idx2);
    int scale = opnd_array(2)->scale();
    int disp = opnd_array(2)->disp(ra_,this,idx2);
    relocInfo::relocType disp_reloc = opnd_array(2)->disp_reloc();

    encode_RegMem(cbuf, reg, base, index, scale, disp, disp_reloc);
  
#line 28066 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void xorL_rReg_mem_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  {

#line 2478 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(2)->reg(ra_,this,idx2)/* dst */ < 8) {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_W);
        } else {
          emit_opcode(cbuf, Assembler::REX_WX);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WXB);
        }
      }
    } else {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WR);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRX);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WRB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRXB);
        }
      }
    }
  
#line 28110 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x33 /*primary()*/));
  
#line 28118 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2511 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // High registers handle in encode_RegMem
    int reg = opnd_array(2)->reg(ra_,this,idx2)/* dst */;
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int disp = opnd_array(1)->disp(ra_,this,idx1);
    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();

    encode_RegMem(cbuf, reg, base, index, scale, disp, disp_reloc);
  
#line 28134 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void xorL_mem_rRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2478 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(2)->reg(ra_,this,idx2)/* src */ < 8) {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_W);
        } else {
          emit_opcode(cbuf, Assembler::REX_WX);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WXB);
        }
      }
    } else {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WR);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRX);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WRB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRXB);
        }
      }
    }
  
#line 28178 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x31 /*primary()*/));
  
#line 28186 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2511 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // High registers handle in encode_RegMem
    int reg = opnd_array(2)->reg(ra_,this,idx2)/* src */;
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int disp = opnd_array(1)->disp(ra_,this,idx1);
    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();

    encode_RegMem(cbuf, reg, base, index, scale, disp, disp_reloc);
  
#line 28202 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void xorL_mem_rReg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2478 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(2)->reg(ra_,this,idx2)/* src */ < 8) {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_W);
        } else {
          emit_opcode(cbuf, Assembler::REX_WX);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WXB);
        }
      }
    } else {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WR);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRX);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WRB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRXB);
        }
      }
    }
  
#line 28246 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x31 /*primary()*/));
  
#line 28254 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2511 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // High registers handle in encode_RegMem
    int reg = opnd_array(2)->reg(ra_,this,idx2)/* src */;
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int disp = opnd_array(1)->disp(ra_,this,idx1);
    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();

    encode_RegMem(cbuf, reg, base, index, scale, disp, disp_reloc);
  
#line 28270 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void xorL_mem_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2324 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->base(ra_,this,idx1) >= 8) {
      if (opnd_array(1)->index(ra_,this,idx1) < 8) {
        emit_opcode(cbuf, Assembler::REX_WB);
      } else {
        emit_opcode(cbuf, Assembler::REX_WXB);
      }
    } else {
      if (opnd_array(1)->index(ra_,this,idx1) < 8) {
        emit_opcode(cbuf, Assembler::REX_W);
      } else {
        emit_opcode(cbuf, Assembler::REX_WX);
      }
    }
  
#line 28298 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1962 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // Emit primary opcode and set sign-extend bit
    // Check for 8-bit immediate, and set sign extend bit in opcode
    if (-0x80 <= opnd_array(2)->constantL() && opnd_array(2)->constantL() < 0x80) {
      emit_opcode(cbuf, (0x81 /*primary()*/) | 0x02);
    } else {
      // 32-bit immediate
      emit_opcode(cbuf, (0x81 /*primary()*/));
    }
  
#line 28313 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2524 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    int rm_byte_opcode = (0x6 /*secondary()*/);

    // High registers handle in encode_RegMem
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);

    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();       // disp-as-oop when
                                            // working with static
                                            // globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace,
                  disp_reloc);
  
#line 28333 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2016 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // Check for 8-bit immediate, and set sign extend bit in opcode
    if (-0x80 <= opnd_array(2)->constantL() && opnd_array(2)->constantL() < 0x80) {
      emit_d8(cbuf, opnd_array(2)->constantL());
    } else {
      // 32-bit immediate
      emit_d32(cbuf, opnd_array(2)->constantL());
    }
  
#line 28347 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void convI2BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {

#line 2415 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->reg(ra_,this,idx1)/* src */ < 8) {
      if (opnd_array(1)->reg(ra_,this,idx1)/* src */ >= 8) {
        emit_opcode(cbuf, Assembler::REX_B);
      }
    } else {
      if (opnd_array(1)->reg(ra_,this,idx1)/* src */ < 8) {
        emit_opcode(cbuf, Assembler::REX_R);
      } else {
        emit_opcode(cbuf, Assembler::REX_RB);
      }
    }
  
#line 28372 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1820 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x85));
    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1)/* src */ & 7, opnd_array(1)->reg(ra_,this,idx1)/* src */ & 7);
  
#line 28381 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2594 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    int dstenc = opnd_array(0)->reg(ra_,this)/* dst */;
    if (dstenc >= 8) {
      emit_opcode(cbuf, Assembler::REX_B);
      dstenc -= 8;
    } else if (dstenc >= 4) {
      emit_opcode(cbuf, Assembler::REX);
    }
    // SETNZ $dst
    emit_opcode(cbuf, 0x0F);
    emit_opcode(cbuf, 0x95);
    emit_rm(cbuf, 0x3, 0x0, dstenc);
  
#line 28399 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2350 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(0)->reg(ra_,this)/* dst */ < 8) {
      if (opnd_array(0)->reg(ra_,this)/* dst */ >= 4) {
        emit_opcode(cbuf, opnd_array(0)->reg(ra_,this)/* dst */ < 8 ? Assembler::REX : Assembler::REX_B);
      }
    } else {
      if (opnd_array(0)->reg(ra_,this)/* dst */ < 8) {
        emit_opcode(cbuf, Assembler::REX_R);
      } else {
        emit_opcode(cbuf, Assembler::REX_RB);
      }
    }
  
#line 28417 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1799 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x0F));
  
#line 28425 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1799 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xB6));
  
#line 28433 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1815 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_rm(cbuf, 0x3, opnd_array(0)->reg(ra_,this)/* dst */ & 7, opnd_array(0)->reg(ra_,this)/* dst */ & 7);
  
#line 28441 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void convP2BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {

#line 2430 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->reg(ra_,this,idx1)/* src */ < 8) {
      if (opnd_array(1)->reg(ra_,this,idx1)/* src */ < 8) {
        emit_opcode(cbuf, Assembler::REX_W);
      } else {
        emit_opcode(cbuf, Assembler::REX_WB);
      }
    } else {
      if (opnd_array(1)->reg(ra_,this,idx1)/* src */ < 8) {
        emit_opcode(cbuf, Assembler::REX_WR);
      } else {
        emit_opcode(cbuf, Assembler::REX_WRB);
      }
    }
  
#line 28468 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1820 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x85));
    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1)/* src */ & 7, opnd_array(1)->reg(ra_,this,idx1)/* src */ & 7);
  
#line 28477 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2594 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    int dstenc = opnd_array(0)->reg(ra_,this)/* dst */;
    if (dstenc >= 8) {
      emit_opcode(cbuf, Assembler::REX_B);
      dstenc -= 8;
    } else if (dstenc >= 4) {
      emit_opcode(cbuf, Assembler::REX);
    }
    // SETNZ $dst
    emit_opcode(cbuf, 0x0F);
    emit_opcode(cbuf, 0x95);
    emit_rm(cbuf, 0x3, 0x0, dstenc);
  
#line 28495 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2350 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(0)->reg(ra_,this)/* dst */ < 8) {
      if (opnd_array(0)->reg(ra_,this)/* dst */ >= 4) {
        emit_opcode(cbuf, opnd_array(0)->reg(ra_,this)/* dst */ < 8 ? Assembler::REX : Assembler::REX_B);
      }
    } else {
      if (opnd_array(0)->reg(ra_,this)/* dst */ < 8) {
        emit_opcode(cbuf, Assembler::REX_R);
      } else {
        emit_opcode(cbuf, Assembler::REX_RB);
      }
    }
  
#line 28513 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1799 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x0F));
  
#line 28521 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1799 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xB6));
  
#line 28529 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1815 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_rm(cbuf, 0x3, opnd_array(0)->reg(ra_,this)/* dst */ & 7, opnd_array(0)->reg(ra_,this)/* dst */ & 7);
  
#line 28537 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void cmpLTMaskNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// p
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// q
  {

#line 2415 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->reg(ra_,this,idx1)/* p */ < 8) {
      if (opnd_array(2)->reg(ra_,this,idx2)/* q */ >= 8) {
        emit_opcode(cbuf, Assembler::REX_B);
      }
    } else {
      if (opnd_array(2)->reg(ra_,this,idx2)/* q */ < 8) {
        emit_opcode(cbuf, Assembler::REX_R);
      } else {
        emit_opcode(cbuf, Assembler::REX_RB);
      }
    }
  
#line 28563 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1820 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x3B));
    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1)/* p */ & 7, opnd_array(2)->reg(ra_,this,idx2)/* q */ & 7);
  
#line 28572 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2579 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    int dstenc = opnd_array(0)->reg(ra_,this)/* dst */;
    if (dstenc >= 8) {
      emit_opcode(cbuf, Assembler::REX_B);
      dstenc -= 8;
    } else if (dstenc >= 4) {
      emit_opcode(cbuf, Assembler::REX);
    }
    // SETLT $dst
    emit_opcode(cbuf, 0x0F);
    emit_opcode(cbuf, 0x9C);
    emit_rm(cbuf, 0x3, 0x0, dstenc);
  
#line 28590 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2350 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(0)->reg(ra_,this)/* dst */ < 8) {
      if (opnd_array(0)->reg(ra_,this)/* dst */ >= 4) {
        emit_opcode(cbuf, opnd_array(0)->reg(ra_,this)/* dst */ < 8 ? Assembler::REX : Assembler::REX_B);
      }
    } else {
      if (opnd_array(0)->reg(ra_,this)/* dst */ < 8) {
        emit_opcode(cbuf, Assembler::REX_R);
      } else {
        emit_opcode(cbuf, Assembler::REX_RB);
      }
    }
  
#line 28608 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1799 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x0F));
  
#line 28616 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1799 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xB6));
  
#line 28624 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1815 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_rm(cbuf, 0x3, opnd_array(0)->reg(ra_,this)/* dst */ & 7, opnd_array(0)->reg(ra_,this)/* dst */ & 7);
  
#line 28632 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2553 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    int dstenc = opnd_array(0)->reg(ra_,this)/* dst */;
    if (dstenc >= 8) {
      emit_opcode(cbuf, Assembler::REX_B);
      dstenc -= 8;
    }
    // NEG $dst
    emit_opcode(cbuf, 0xF7);
    emit_rm(cbuf, 0x3, 0x03, dstenc);
  
#line 28647 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void cmpLTMask0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {
    MacroAssembler _masm(&cbuf);

#line 9405 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

  __ sarl(opnd_array(1)->as_Register(ra_,this,idx1)/* dst */, 31);
  
#line 28664 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void cadd_cmpLTMaskNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// p
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// q
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// y
  {
    MacroAssembler _masm(&cbuf);

#line 9421 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    Register Rp = opnd_array(1)->as_Register(ra_,this,idx1)/* p */;
    Register Rq = opnd_array(2)->as_Register(ra_,this,idx2)/* q */;
    Register Ry = opnd_array(3)->as_Register(ra_,this,idx3)/* y */;
    Label done;
    __ subl(Rp, Rq);
    __ jccb(Assembler::greaterEqual, done);
    __ addl(Rp, Ry);
    __ bind(done);
  
#line 28689 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void cadd_cmpLTMask_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// p
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// q
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// y
  {
    MacroAssembler _masm(&cbuf);

#line 9421 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    Register Rp = opnd_array(1)->as_Register(ra_,this,idx1)/* p */;
    Register Rq = opnd_array(2)->as_Register(ra_,this,idx2)/* q */;
    Register Ry = opnd_array(3)->as_Register(ra_,this,idx3)/* y */;
    Label done;
    __ subl(Rp, Rq);
    __ jccb(Assembler::greaterEqual, done);
    __ addl(Rp, Ry);
    __ bind(done);
  
#line 28714 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void cadd_cmpLTMask_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// y
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// p
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// q
  {
    MacroAssembler _masm(&cbuf);

#line 9421 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    Register Rp = opnd_array(2)->as_Register(ra_,this,idx2)/* p */;
    Register Rq = opnd_array(3)->as_Register(ra_,this,idx3)/* q */;
    Register Ry = opnd_array(1)->as_Register(ra_,this,idx1)/* y */;
    Label done;
    __ subl(Rp, Rq);
    __ jccb(Assembler::greaterEqual, done);
    __ addl(Rp, Ry);
    __ bind(done);
  
#line 28739 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void cadd_cmpLTMask_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// p
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// q
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// y
  {
    MacroAssembler _masm(&cbuf);

#line 9421 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    Register Rp = opnd_array(1)->as_Register(ra_,this,idx1)/* p */;
    Register Rq = opnd_array(2)->as_Register(ra_,this,idx2)/* q */;
    Register Ry = opnd_array(3)->as_Register(ra_,this,idx3)/* y */;
    Label done;
    __ subl(Rp, Rq);
    __ jccb(Assembler::greaterEqual, done);
    __ addl(Rp, Ry);
    __ bind(done);
  
#line 28764 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void and_cmpLTMaskNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// p
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// q
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// y
  {
    MacroAssembler _masm(&cbuf);

#line 9446 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    Register Rp = opnd_array(1)->as_Register(ra_,this,idx1)/* p */;
    Register Rq = opnd_array(2)->as_Register(ra_,this,idx2)/* q */;
    Register Ry = opnd_array(3)->as_Register(ra_,this,idx3)/* y */;
    Label done;
    __ cmpl(Rp, Rq);
    __ jccb(Assembler::less, done);
    __ xorl(Ry, Ry);
    __ bind(done);
  
#line 28789 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void and_cmpLTMask_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// y
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// p
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// q
  {
    MacroAssembler _masm(&cbuf);

#line 9446 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    Register Rp = opnd_array(2)->as_Register(ra_,this,idx2)/* p */;
    Register Rq = opnd_array(3)->as_Register(ra_,this,idx3)/* q */;
    Register Ry = opnd_array(1)->as_Register(ra_,this,idx1)/* y */;
    Label done;
    __ cmpl(Rp, Rq);
    __ jccb(Assembler::less, done);
    __ xorl(Ry, Ry);
    __ bind(done);
  
#line 28814 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void cmpF_cc_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 9473 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ ucomiss(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */);
    emit_cmpfp_fixup(_masm);
  
#line 28832 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void cmpF_cc_reg_CFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 9485 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ ucomiss(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */);
  
#line 28849 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void cmpF_cc_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 9502 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ ucomiss(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_reloc()));
    emit_cmpfp_fixup(_masm);
  
#line 28867 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void cmpF_cc_memCFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 9514 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ ucomiss(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_reloc()));
  
#line 28884 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void cmpF_cc_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 9530 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ ucomiss(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, InternalAddress(__ code()->consts()->start() + constant_offset()));
    emit_cmpfp_fixup(_masm);
  
#line 28902 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void cmpF_cc_immNode::eval_constant(Compile* C) {
  {

#line 9531 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"
    _constant = C->constant_table().add(this, opnd_array(2));
#line 28911 "../generated/adfiles/ad_x86_64.cpp"
  }
}
void cmpF_cc_immCFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 9541 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ ucomiss(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, InternalAddress(__ code()->consts()->start() + constant_offset()));
  
#line 28927 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void cmpF_cc_immCFNode::eval_constant(Compile* C) {
  {

#line 9542 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"
    _constant = C->constant_table().add(this, opnd_array(2));
#line 28936 "../generated/adfiles/ad_x86_64.cpp"
  }
}
void cmpD_cc_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 9558 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ ucomisd(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */);
    emit_cmpfp_fixup(_masm);
  
#line 28953 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void cmpD_cc_reg_CFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 9570 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ ucomisd(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */);
  
#line 28970 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void cmpD_cc_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 9587 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ ucomisd(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_reloc()));
    emit_cmpfp_fixup(_masm);
  
#line 28988 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void cmpD_cc_memCFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 9599 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ ucomisd(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_reloc()));
  
#line 29005 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void cmpD_cc_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 9615 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ ucomisd(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, InternalAddress(__ code()->consts()->start() + constant_offset()));
    emit_cmpfp_fixup(_masm);
  
#line 29023 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void cmpD_cc_immNode::eval_constant(Compile* C) {
  {

#line 9616 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"
    _constant = C->constant_table().add(this, opnd_array(2));
#line 29032 "../generated/adfiles/ad_x86_64.cpp"
  }
}
void cmpD_cc_immCFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 9626 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ ucomisd(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, InternalAddress(__ code()->consts()->start() + constant_offset()));
  
#line 29048 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void cmpD_cc_immCFNode::eval_constant(Compile* C) {
  {

#line 9627 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"
    _constant = C->constant_table().add(this, opnd_array(2));
#line 29057 "../generated/adfiles/ad_x86_64.cpp"
  }
}
void cmpF_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 9646 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ ucomiss(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */);
    emit_cmpfp3(_masm, opnd_array(0)->as_Register(ra_,this)/* dst */);
  
#line 29074 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void cmpF_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 9667 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ ucomiss(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_reloc()));
    emit_cmpfp3(_masm, opnd_array(0)->as_Register(ra_,this)/* dst */);
  
#line 29092 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void cmpF_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 9687 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ ucomiss(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, InternalAddress(__ code()->consts()->start() + constant_offset()));
    emit_cmpfp3(_masm, opnd_array(0)->as_Register(ra_,this)/* dst */);
  
#line 29110 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void cmpF_immNode::eval_constant(Compile* C) {
  {

#line 9688 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"
    _constant = C->constant_table().add(this, opnd_array(2));
#line 29119 "../generated/adfiles/ad_x86_64.cpp"
  }
}
void cmpD_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 9708 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ ucomisd(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */);
    emit_cmpfp3(_masm, opnd_array(0)->as_Register(ra_,this)/* dst */);
  
#line 29136 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void cmpD_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 9729 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ ucomisd(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_reloc()));
    emit_cmpfp3(_masm, opnd_array(0)->as_Register(ra_,this)/* dst */);
  
#line 29154 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void cmpD_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 9749 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ ucomisd(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, InternalAddress(__ code()->consts()->start() + constant_offset()));
    emit_cmpfp3(_masm, opnd_array(0)->as_Register(ra_,this)/* dst */);
  
#line 29172 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void cmpD_immNode::eval_constant(Compile* C) {
  {

#line 9750 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"
    _constant = C->constant_table().add(this, opnd_array(2));
#line 29181 "../generated/adfiles/ad_x86_64.cpp"
  }
}
void cosD_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  {

#line 2668 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    MacroAssembler _masm(&cbuf);
    __ subptr(rsp, 8);
    __ movdbl(Address(rsp, 0), opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */);
    __ fld_d(Address(rsp, 0));
  
#line 29198 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xD9 /*primary()*/));
  
#line 29206 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1787 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xFF /*secondary()*/));
  
#line 29214 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2661 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    MacroAssembler _masm(&cbuf);
    __ fstp_d(Address(rsp, 0));
    __ movdbl(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, Address(rsp, 0));
    __ addptr(rsp, 8);
  
#line 29225 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void sinD_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  {

#line 2668 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    MacroAssembler _masm(&cbuf);
    __ subptr(rsp, 8);
    __ movdbl(Address(rsp, 0), opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */);
    __ fld_d(Address(rsp, 0));
  
#line 29243 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xD9 /*primary()*/));
  
#line 29251 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1787 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xFE /*secondary()*/));
  
#line 29259 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2661 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    MacroAssembler _masm(&cbuf);
    __ fstp_d(Address(rsp, 0));
    __ movdbl(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, Address(rsp, 0));
    __ addptr(rsp, 8);
  
#line 29270 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void tanD_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  {

#line 2668 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    MacroAssembler _masm(&cbuf);
    __ subptr(rsp, 8);
    __ movdbl(Address(rsp, 0), opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */);
    __ fld_d(Address(rsp, 0));
  
#line 29288 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1799 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xD9));
  
#line 29296 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1799 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xF2));
  
#line 29304 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1799 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xDD));
  
#line 29312 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1799 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xD8));
  
#line 29320 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2661 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    MacroAssembler _masm(&cbuf);
    __ fstp_d(Address(rsp, 0));
    __ movdbl(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, Address(rsp, 0));
    __ addptr(rsp, 8);
  
#line 29331 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void log10D_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  {

#line 1799 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xD9));
  
#line 29346 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1799 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xEC));
  
#line 29354 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2668 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    MacroAssembler _masm(&cbuf);
    __ subptr(rsp, 8);
    __ movdbl(Address(rsp, 0), opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */);
    __ fld_d(Address(rsp, 0));
  
#line 29365 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1799 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xD9));
  
#line 29373 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1799 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xF1));
  
#line 29381 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2661 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    MacroAssembler _masm(&cbuf);
    __ fstp_d(Address(rsp, 0));
    __ movdbl(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, Address(rsp, 0));
    __ addptr(rsp, 8);
  
#line 29392 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void logD_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  {

#line 1799 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xD9));
  
#line 29407 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1799 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xED));
  
#line 29415 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2668 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    MacroAssembler _masm(&cbuf);
    __ subptr(rsp, 8);
    __ movdbl(Address(rsp, 0), opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */);
    __ fld_d(Address(rsp, 0));
  
#line 29426 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1799 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xD9));
  
#line 29434 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1799 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xF1));
  
#line 29442 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2661 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    MacroAssembler _masm(&cbuf);
    __ fstp_d(Address(rsp, 0));
    __ movdbl(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, Address(rsp, 0));
    __ addptr(rsp, 8);
  
#line 29453 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void powD_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src0
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 9821 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ subptr(rsp, 8);
    __ movdbl(Address(rsp, 0), opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src1 */);
    __ fld_d(Address(rsp, 0));
    __ movdbl(Address(rsp, 0), opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src0 */);
    __ fld_d(Address(rsp, 0));
    __ fast_pow();
    __ fstp_d(Address(rsp, 0));
    __ movdbl(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, Address(rsp, 0));
    __ addptr(rsp, 8);
  
#line 29478 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void expD_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 9839 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ subptr(rsp, 8);
    __ movdbl(Address(rsp, 0), opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */);
    __ fld_d(Address(rsp, 0));
    __ fast_exp();
    __ fstp_d(Address(rsp, 0));
    __ movdbl(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, Address(rsp, 0));
    __ addptr(rsp, 8);
  
#line 29500 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void roundFloat_nopNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  // User did not define which encode class to use.
}

void roundDouble_nopNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  // User did not define which encode class to use.
}

void convF2D_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 9876 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ cvtss2sd (opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */);
  
#line 29532 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void convF2D_reg_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 9887 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ cvtss2sd (opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
  
#line 29548 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void convD2F_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 9898 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ cvtsd2ss (opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */);
  
#line 29564 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void convD2F_reg_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 9909 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ cvtsd2ss (opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
  
#line 29580 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void convF2I_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 9929 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    Label done;
    __ cvttss2sil(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */);
    __ cmpl(opnd_array(0)->as_Register(ra_,this)/* dst */, 0x80000000);
    __ jccb(Assembler::notEqual, done);
    __ subptr(rsp, 8);
    __ movflt(Address(rsp, 0), opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */);
    __ call(RuntimeAddress(CAST_FROM_FN_PTR(address, StubRoutines::x86::f2i_fixup())));
    __ pop(opnd_array(0)->as_Register(ra_,this)/* dst */);
    __ bind(done);
  
#line 29604 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void convF2L_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 9956 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    Label done;
    __ cvttss2siq(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */);
    __ cmp64(opnd_array(0)->as_Register(ra_,this)/* dst */,
             ExternalAddress((address) StubRoutines::x86::double_sign_flip()));
    __ jccb(Assembler::notEqual, done);
    __ subptr(rsp, 8);
    __ movflt(Address(rsp, 0), opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */);
    __ call(RuntimeAddress(CAST_FROM_FN_PTR(address, StubRoutines::x86::f2l_fixup())));
    __ pop(opnd_array(0)->as_Register(ra_,this)/* dst */);
    __ bind(done);
  
#line 29629 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void convD2I_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 9984 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    Label done;
    __ cvttsd2sil(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */);
    __ cmpl(opnd_array(0)->as_Register(ra_,this)/* dst */, 0x80000000);
    __ jccb(Assembler::notEqual, done);
    __ subptr(rsp, 8);
    __ movdbl(Address(rsp, 0), opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */);
    __ call(RuntimeAddress(CAST_FROM_FN_PTR(address, StubRoutines::x86::d2i_fixup())));
    __ pop(opnd_array(0)->as_Register(ra_,this)/* dst */);
    __ bind(done);
  
#line 29653 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void convD2L_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 10011 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    Label done;
    __ cvttsd2siq(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */);
    __ cmp64(opnd_array(0)->as_Register(ra_,this)/* dst */,
             ExternalAddress((address) StubRoutines::x86::double_sign_flip()));
    __ jccb(Assembler::notEqual, done);
    __ subptr(rsp, 8);
    __ movdbl(Address(rsp, 0), opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */);
    __ call(RuntimeAddress(CAST_FROM_FN_PTR(address, StubRoutines::x86::d2l_fixup())));
    __ pop(opnd_array(0)->as_Register(ra_,this)/* dst */);
    __ bind(done);
  
#line 29678 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void convI2F_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 10032 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ cvtsi2ssl (opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
  
#line 29694 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void convI2F_reg_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 10043 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ cvtsi2ssl (opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
  
#line 29710 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void convI2D_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 10055 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ cvtsi2sdl (opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
  
#line 29726 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void convI2D_reg_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 10066 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ cvtsi2sdl (opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
  
#line 29742 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void convXI2F_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 10079 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ movdl(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
    __ cvtdq2ps(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */);
  
#line 29759 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void convXI2D_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 10093 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ movdl(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
    __ cvtdq2pd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */);
  
#line 29776 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void convL2F_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 10105 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ cvtsi2ssq (opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
  
#line 29792 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void convL2F_reg_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 10116 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ cvtsi2ssq (opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
  
#line 29808 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void convL2D_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 10127 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ cvtsi2sdq (opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
  
#line 29824 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void convL2D_reg_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 10138 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ cvtsi2sdq (opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
  
#line 29840 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void convI2L_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 10150 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ movslq(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
  
#line 29856 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void convI2L_reg_reg_zexNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  {
    MacroAssembler _masm(&cbuf);

#line 10179 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(0)->reg(ra_,this)/* dst */!= opnd_array(1)->reg(ra_,this,idx1)/* src */) {
      __ movl(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
    }
  
#line 29875 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void convI2L_reg_mem_zexNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  {
    MacroAssembler _masm(&cbuf);

#line 10193 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ movl(opnd_array(0)->as_Register(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
  
#line 29892 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void zerox_long_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  {
    MacroAssembler _masm(&cbuf);

#line 10204 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ movl(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
  
#line 29909 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void convL2I_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 10215 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ movl(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
  
#line 29925 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void MoveF2I_stack_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 10228 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ movl(opnd_array(0)->as_Register(ra_,this)/* dst */, Address(rsp, opnd_array(1)->disp(ra_,this,idx1)));
  
#line 29941 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void MoveI2F_stack_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 10240 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ movflt(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, Address(rsp, opnd_array(1)->disp(ra_,this,idx1)));
  
#line 29957 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void MoveD2L_stack_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 10252 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ movq(opnd_array(0)->as_Register(ra_,this)/* dst */, Address(rsp, opnd_array(1)->disp(ra_,this,idx1)));
  
#line 29973 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void MoveL2D_stack_reg_partialNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 10265 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ movdbl(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, Address(rsp, opnd_array(1)->disp(ra_,this,idx1)));
  
#line 29989 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void MoveL2D_stack_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 10278 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ movdbl(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, Address(rsp, opnd_array(1)->disp(ra_,this,idx1)));
  
#line 30005 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void MoveF2I_reg_stackNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 10291 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ movflt(Address(rsp, opnd_array(0)->disp(ra_,this,0)), opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */);
  
#line 30021 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void MoveI2F_reg_stackNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 10303 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ movl(Address(rsp, opnd_array(0)->disp(ra_,this,0)), opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
  
#line 30037 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void MoveD2L_reg_stackNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 10315 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ movdbl(Address(rsp, opnd_array(0)->disp(ra_,this,0)), opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */);
  
#line 30053 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void MoveL2D_reg_stackNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 10327 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ movq(Address(rsp, opnd_array(0)->disp(ra_,this,0)), opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
  
#line 30069 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void MoveF2I_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 10338 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ movdl(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */);
  
#line 30085 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void MoveD2L_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 10349 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ movdq(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */);
  
#line 30101 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void MoveI2F_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 10360 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ movdl(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
  
#line 30117 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void MoveL2D_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 10371 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

     __ movdq(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
  
#line 30133 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void rep_stosNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// cnt
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// base
  {
    MacroAssembler _masm(&cbuf);

#line 10389 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ clear_mem(opnd_array(2)->as_Register(ra_,this,idx2)/* base */, opnd_array(1)->as_Register(ra_,this,idx1)/* cnt */, as_Register(RAX_enc));
  
#line 30150 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void rep_fast_stosbNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// cnt
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// base
  {
    MacroAssembler _masm(&cbuf);

#line 10404 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ clear_mem(opnd_array(2)->as_Register(ra_,this,idx2)/* base */, opnd_array(1)->as_Register(ra_,this,idx1)/* cnt */, as_Register(RAX_enc));
  
#line 30167 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void string_compareNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// str1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cnt1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// str2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// cnt2
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp1
  {
    MacroAssembler _masm(&cbuf);

#line 10417 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ string_compare(opnd_array(1)->as_Register(ra_,this,idx1)/* str1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* str2 */,
                      opnd_array(2)->as_Register(ra_,this,idx2)/* cnt1 */, opnd_array(4)->as_Register(ra_,this,idx4)/* cnt2 */, opnd_array(0)->as_Register(ra_,this)/* result */,
                      opnd_array(5)->as_XMMRegister(ra_,this,idx5)/* tmp1 */);
  
#line 30189 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void string_indexof_conNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// str1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cnt1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// str2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// int_cnt2
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// vec
  {
    MacroAssembler _masm(&cbuf);

#line 10434 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    int icnt2 = (int)opnd_array(4)->constant();
    if (icnt2 >= 8) {
      // IndexOf for constant substrings with size >= 8 elements
      // which don't need to be loaded through stack.
      __ string_indexofC8(opnd_array(1)->as_Register(ra_,this,idx1)/* str1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* str2 */,
                          opnd_array(2)->as_Register(ra_,this,idx2)/* cnt1 */, as_Register(RAX_enc),
                          icnt2, opnd_array(0)->as_Register(ra_,this)/* result */,
                          opnd_array(5)->as_XMMRegister(ra_,this,idx5)/* vec */, as_Register(RCX_enc));
    } else {
      // Small strings are loaded through stack if they cross page boundary.
      __ string_indexof(opnd_array(1)->as_Register(ra_,this,idx1)/* str1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* str2 */,
                        opnd_array(2)->as_Register(ra_,this,idx2)/* cnt1 */, as_Register(RAX_enc),
                        icnt2, opnd_array(0)->as_Register(ra_,this)/* result */,
                        opnd_array(5)->as_XMMRegister(ra_,this,idx5)/* vec */, as_Register(RCX_enc));
    }
  
#line 30223 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void string_indexofNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// str1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cnt1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// str2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// cnt2
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// vec
  {
    MacroAssembler _masm(&cbuf);

#line 10462 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ string_indexof(opnd_array(1)->as_Register(ra_,this,idx1)/* str1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* str2 */,
                      opnd_array(2)->as_Register(ra_,this,idx2)/* cnt1 */, opnd_array(4)->as_Register(ra_,this,idx4)/* cnt2 */,
                      (-1), opnd_array(0)->as_Register(ra_,this)/* result */,
                      opnd_array(5)->as_XMMRegister(ra_,this,idx5)/* vec */, as_Register(RCX_enc));
  
#line 30246 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void string_equalsNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// str1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// str2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// cnt
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp1
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp2
  {
    MacroAssembler _masm(&cbuf);

#line 10479 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ char_arrays_equals(false, opnd_array(1)->as_Register(ra_,this,idx1)/* str1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* str2 */,
                          opnd_array(3)->as_Register(ra_,this,idx3)/* cnt */, opnd_array(0)->as_Register(ra_,this)/* result */, as_Register(RBX_enc),
                          opnd_array(4)->as_XMMRegister(ra_,this,idx4)/* tmp1 */, opnd_array(5)->as_XMMRegister(ra_,this,idx5)/* tmp2 */);
  
#line 30268 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void array_equalsNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// ary1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// ary2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp2
  {
    MacroAssembler _masm(&cbuf);

#line 10496 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ char_arrays_equals(true, opnd_array(1)->as_Register(ra_,this,idx1)/* ary1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* ary2 */,
                          as_Register(RCX_enc), opnd_array(0)->as_Register(ra_,this)/* result */, as_Register(RBX_enc),
                          opnd_array(3)->as_XMMRegister(ra_,this,idx3)/* tmp1 */, opnd_array(4)->as_XMMRegister(ra_,this,idx4)/* tmp2 */);
  
#line 30289 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void encode_iso_arrayNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// len
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp1
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp2
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// tmp3
  unsigned idx7 = idx6 + opnd_array(6)->num_edges(); 	// tmp4
  {
    MacroAssembler _masm(&cbuf);

#line 10512 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ encode_iso_array(opnd_array(1)->as_Register(ra_,this,idx1)/* src */, opnd_array(2)->as_Register(ra_,this,idx2)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* len */,
                        opnd_array(4)->as_XMMRegister(ra_,this,idx4)/* tmp1 */, opnd_array(5)->as_XMMRegister(ra_,this,idx5)/* tmp2 */, opnd_array(6)->as_XMMRegister(ra_,this,idx6)/* tmp3 */,
                        opnd_array(7)->as_XMMRegister(ra_,this,idx7)/* tmp4 */, as_Register(RCX_enc), opnd_array(0)->as_Register(ra_,this)/* result */);
  
#line 30313 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void overflowAddI_rRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {
    MacroAssembler _masm(&cbuf);

#line 10529 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ addl(opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* op2 */);
  
#line 30330 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void overflowAddI_rReg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {
    MacroAssembler _masm(&cbuf);

#line 10542 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ addl(opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->constant());
  
#line 30347 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void overflowAddL_rRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {
    MacroAssembler _masm(&cbuf);

#line 10554 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ addq(opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* op2 */);
  
#line 30364 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void overflowAddL_rReg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {
    MacroAssembler _masm(&cbuf);

#line 10566 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ addq(opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->constantL());
  
#line 30381 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void overflowSubI_rRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {
    MacroAssembler _masm(&cbuf);

#line 10577 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ cmpl(opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* op2 */);
  
#line 30398 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void overflowSubI_rReg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {
    MacroAssembler _masm(&cbuf);

#line 10588 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ cmpl(opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->constant());
  
#line 30415 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void overflowSubL_rRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {
    MacroAssembler _masm(&cbuf);

#line 10599 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ cmpq(opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* op2 */);
  
#line 30432 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void overflowSubL_rReg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {
    MacroAssembler _masm(&cbuf);

#line 10610 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ cmpq(opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->constantL());
  
#line 30449 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void overflowNegI_rRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {
    MacroAssembler _masm(&cbuf);

#line 10622 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ negl(opnd_array(2)->as_Register(ra_,this,idx2)/* op2 */);
  
#line 30466 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void overflowNegL_rRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {
    MacroAssembler _masm(&cbuf);

#line 10634 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ negq(opnd_array(2)->as_Register(ra_,this,idx2)/* op2 */);
  
#line 30483 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void overflowMulI_rRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {
    MacroAssembler _masm(&cbuf);

#line 10646 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ imull(opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* op2 */);
  
#line 30500 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void overflowMulI_rReg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    MacroAssembler _masm(&cbuf);

#line 10658 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ imull(opnd_array(3)->as_Register(ra_,this,idx3)/* tmp */, opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->constant());
  
#line 30518 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void overflowMulL_rRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {
    MacroAssembler _masm(&cbuf);

#line 10670 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ imulq(opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* op2 */);
  
#line 30535 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void overflowMulL_rReg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    MacroAssembler _masm(&cbuf);

#line 10682 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ imulq(opnd_array(3)->as_Register(ra_,this,idx3)/* tmp */, opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->constantL());
  
#line 30553 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void compI_rRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 2415 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->reg(ra_,this,idx1)/* op1 */ < 8) {
      if (opnd_array(2)->reg(ra_,this,idx2)/* op2 */ >= 8) {
        emit_opcode(cbuf, Assembler::REX_B);
      }
    } else {
      if (opnd_array(2)->reg(ra_,this,idx2)/* op2 */ < 8) {
        emit_opcode(cbuf, Assembler::REX_R);
      } else {
        emit_opcode(cbuf, Assembler::REX_RB);
      }
    }
  
#line 30579 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x3B /*primary()*/));
  
#line 30587 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1815 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1)/* op1 */ & 7, opnd_array(2)->reg(ra_,this,idx2)/* op2 */ & 7);
  
#line 30595 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void compI_rReg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 1974 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // OpcSEr/m
    int dstenc = opnd_array(1)->reg(ra_,this,idx1)/* op1 */;
    if (dstenc >= 8) {
      emit_opcode(cbuf, Assembler::REX_B);
      dstenc -= 8;
    }
    // Emit primary opcode and set sign-extend bit
    // Check for 8-bit immediate, and set sign extend bit in opcode
    if (-0x80 <= opnd_array(2)->constant() && opnd_array(2)->constant() < 0x80) {
      emit_opcode(cbuf, (0x81 /*primary()*/) | 0x02);
    } else {
      // 32-bit immediate
      emit_opcode(cbuf, (0x81 /*primary()*/));
    }
    // Emit r/m byte with secondary opcode, after primary opcode.
    emit_rm(cbuf, 0x3, (0x07 /*secondary()*/), dstenc);
  
#line 30626 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2016 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // Check for 8-bit immediate, and set sign extend bit in opcode
    if (-0x80 <= opnd_array(2)->constant() && opnd_array(2)->constant() < 0x80) {
      emit_d8(cbuf, opnd_array(2)->constant());
    } else {
      // 32-bit immediate
      emit_d32(cbuf, opnd_array(2)->constant());
    }
  
#line 30640 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void compI_rReg_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 2447 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->reg(ra_,this,idx1)/* op1 */ < 8) {
      if (opnd_array(2)->base(ra_,this,idx2) < 8) {
        if (opnd_array(2)->index(ra_,this,idx2) >= 8) {
          emit_opcode(cbuf, Assembler::REX_X);
        }
      } else {
        if (opnd_array(2)->index(ra_,this,idx2) < 8) {
          emit_opcode(cbuf, Assembler::REX_B);
        } else {
          emit_opcode(cbuf, Assembler::REX_XB);
        }
      }
    } else {
      if (opnd_array(2)->base(ra_,this,idx2) < 8) {
        if (opnd_array(2)->index(ra_,this,idx2) < 8) {
          emit_opcode(cbuf, Assembler::REX_R);
        } else {
          emit_opcode(cbuf, Assembler::REX_RX);
        }
      } else {
        if (opnd_array(2)->index(ra_,this,idx2) < 8) {
          emit_opcode(cbuf, Assembler::REX_RB);
        } else {
          emit_opcode(cbuf, Assembler::REX_RXB);
        }
      }
    }
  
#line 30682 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x3B /*primary()*/));
  
#line 30690 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2511 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // High registers handle in encode_RegMem
    int reg = opnd_array(1)->reg(ra_,this,idx1)/* op1 */;
    int base = opnd_array(2)->base(ra_,this,idx2);
    int index = opnd_array(2)->index(ra_,this,idx2);
    int scale = opnd_array(2)->scale();
    int disp = opnd_array(2)->disp(ra_,this,idx2);
    relocInfo::relocType disp_reloc = opnd_array(2)->disp_reloc();

    encode_RegMem(cbuf, reg, base, index, scale, disp, disp_reloc);
  
#line 30706 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void testI_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 2415 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->reg(ra_,this,idx1)/* src */ < 8) {
      if (opnd_array(1)->reg(ra_,this,idx1)/* src */ >= 8) {
        emit_opcode(cbuf, Assembler::REX_B);
      }
    } else {
      if (opnd_array(1)->reg(ra_,this,idx1)/* src */ < 8) {
        emit_opcode(cbuf, Assembler::REX_R);
      } else {
        emit_opcode(cbuf, Assembler::REX_RB);
      }
    }
  
#line 30732 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x85 /*primary()*/));
  
#line 30740 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1815 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1)/* src */ & 7, opnd_array(1)->reg(ra_,this,idx1)/* src */ & 7);
  
#line 30748 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void testI_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// zero
  {

#line 2399 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->reg(ra_,this,idx1)/* src */ >= 8) {
      emit_opcode(cbuf, Assembler::REX_B);
    }
  
#line 30767 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xF7 /*primary()*/));
  
#line 30775 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2039 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // INC, DEC, IDIV, IMOD, JMP indirect, ...
    emit_rm(cbuf, 0x3, (0x00 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1)/* src */ & 7);
  
#line 30784 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2270 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // Output immediate
    emit_d32(cbuf, opnd_array(2)->constant());
  
#line 30793 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void testI_reg_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mem
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// zero
  {

#line 2447 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->reg(ra_,this,idx1)/* src */ < 8) {
      if (opnd_array(2)->base(ra_,this,idx2) < 8) {
        if (opnd_array(2)->index(ra_,this,idx2) >= 8) {
          emit_opcode(cbuf, Assembler::REX_X);
        }
      } else {
        if (opnd_array(2)->index(ra_,this,idx2) < 8) {
          emit_opcode(cbuf, Assembler::REX_B);
        } else {
          emit_opcode(cbuf, Assembler::REX_XB);
        }
      }
    } else {
      if (opnd_array(2)->base(ra_,this,idx2) < 8) {
        if (opnd_array(2)->index(ra_,this,idx2) < 8) {
          emit_opcode(cbuf, Assembler::REX_R);
        } else {
          emit_opcode(cbuf, Assembler::REX_RX);
        }
      } else {
        if (opnd_array(2)->index(ra_,this,idx2) < 8) {
          emit_opcode(cbuf, Assembler::REX_RB);
        } else {
          emit_opcode(cbuf, Assembler::REX_RXB);
        }
      }
    }
  
#line 30836 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x85 /*primary()*/));
  
#line 30844 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2511 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // High registers handle in encode_RegMem
    int reg = opnd_array(1)->reg(ra_,this,idx1)/* src */;
    int base = opnd_array(2)->base(ra_,this,idx2);
    int index = opnd_array(2)->index(ra_,this,idx2);
    int scale = opnd_array(2)->scale();
    int disp = opnd_array(2)->disp(ra_,this,idx2);
    relocInfo::relocType disp_reloc = opnd_array(2)->disp_reloc();

    encode_RegMem(cbuf, reg, base, index, scale, disp, disp_reloc);
  
#line 30860 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void testI_reg_mem_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// zero
  {

#line 2447 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(2)->reg(ra_,this,idx2)/* src */ < 8) {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) >= 8) {
          emit_opcode(cbuf, Assembler::REX_X);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_B);
        } else {
          emit_opcode(cbuf, Assembler::REX_XB);
        }
      }
    } else {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_R);
        } else {
          emit_opcode(cbuf, Assembler::REX_RX);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_RB);
        } else {
          emit_opcode(cbuf, Assembler::REX_RXB);
        }
      }
    }
  
#line 30903 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x85 /*primary()*/));
  
#line 30911 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2511 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // High registers handle in encode_RegMem
    int reg = opnd_array(2)->reg(ra_,this,idx2)/* src */;
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int disp = opnd_array(1)->disp(ra_,this,idx1);
    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();

    encode_RegMem(cbuf, reg, base, index, scale, disp, disp_reloc);
  
#line 30927 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void compU_rRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 2415 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->reg(ra_,this,idx1)/* op1 */ < 8) {
      if (opnd_array(2)->reg(ra_,this,idx2)/* op2 */ >= 8) {
        emit_opcode(cbuf, Assembler::REX_B);
      }
    } else {
      if (opnd_array(2)->reg(ra_,this,idx2)/* op2 */ < 8) {
        emit_opcode(cbuf, Assembler::REX_R);
      } else {
        emit_opcode(cbuf, Assembler::REX_RB);
      }
    }
  
#line 30953 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x3B /*primary()*/));
  
#line 30961 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1815 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1)/* op1 */ & 7, opnd_array(2)->reg(ra_,this,idx2)/* op2 */ & 7);
  
#line 30969 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void compU_rReg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 1974 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // OpcSEr/m
    int dstenc = opnd_array(1)->reg(ra_,this,idx1)/* op1 */;
    if (dstenc >= 8) {
      emit_opcode(cbuf, Assembler::REX_B);
      dstenc -= 8;
    }
    // Emit primary opcode and set sign-extend bit
    // Check for 8-bit immediate, and set sign extend bit in opcode
    if (-0x80 <= opnd_array(2)->constant() && opnd_array(2)->constant() < 0x80) {
      emit_opcode(cbuf, (0x81 /*primary()*/) | 0x02);
    } else {
      // 32-bit immediate
      emit_opcode(cbuf, (0x81 /*primary()*/));
    }
    // Emit r/m byte with secondary opcode, after primary opcode.
    emit_rm(cbuf, 0x3, (0x07 /*secondary()*/), dstenc);
  
#line 31000 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2016 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // Check for 8-bit immediate, and set sign extend bit in opcode
    if (-0x80 <= opnd_array(2)->constant() && opnd_array(2)->constant() < 0x80) {
      emit_d8(cbuf, opnd_array(2)->constant());
    } else {
      // 32-bit immediate
      emit_d32(cbuf, opnd_array(2)->constant());
    }
  
#line 31014 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void compU_rReg_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 2447 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->reg(ra_,this,idx1)/* op1 */ < 8) {
      if (opnd_array(2)->base(ra_,this,idx2) < 8) {
        if (opnd_array(2)->index(ra_,this,idx2) >= 8) {
          emit_opcode(cbuf, Assembler::REX_X);
        }
      } else {
        if (opnd_array(2)->index(ra_,this,idx2) < 8) {
          emit_opcode(cbuf, Assembler::REX_B);
        } else {
          emit_opcode(cbuf, Assembler::REX_XB);
        }
      }
    } else {
      if (opnd_array(2)->base(ra_,this,idx2) < 8) {
        if (opnd_array(2)->index(ra_,this,idx2) < 8) {
          emit_opcode(cbuf, Assembler::REX_R);
        } else {
          emit_opcode(cbuf, Assembler::REX_RX);
        }
      } else {
        if (opnd_array(2)->index(ra_,this,idx2) < 8) {
          emit_opcode(cbuf, Assembler::REX_RB);
        } else {
          emit_opcode(cbuf, Assembler::REX_RXB);
        }
      }
    }
  
#line 31056 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x3B /*primary()*/));
  
#line 31064 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2511 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // High registers handle in encode_RegMem
    int reg = opnd_array(1)->reg(ra_,this,idx1)/* op1 */;
    int base = opnd_array(2)->base(ra_,this,idx2);
    int index = opnd_array(2)->index(ra_,this,idx2);
    int scale = opnd_array(2)->scale();
    int disp = opnd_array(2)->disp(ra_,this,idx2);
    relocInfo::relocType disp_reloc = opnd_array(2)->disp_reloc();

    encode_RegMem(cbuf, reg, base, index, scale, disp, disp_reloc);
  
#line 31080 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void testU_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 2415 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->reg(ra_,this,idx1)/* src */ < 8) {
      if (opnd_array(1)->reg(ra_,this,idx1)/* src */ >= 8) {
        emit_opcode(cbuf, Assembler::REX_B);
      }
    } else {
      if (opnd_array(1)->reg(ra_,this,idx1)/* src */ < 8) {
        emit_opcode(cbuf, Assembler::REX_R);
      } else {
        emit_opcode(cbuf, Assembler::REX_RB);
      }
    }
  
#line 31106 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x85 /*primary()*/));
  
#line 31114 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1815 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1)/* src */ & 7, opnd_array(1)->reg(ra_,this,idx1)/* src */ & 7);
  
#line 31122 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void compP_rRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 2430 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->reg(ra_,this,idx1)/* op1 */ < 8) {
      if (opnd_array(2)->reg(ra_,this,idx2)/* op2 */ < 8) {
        emit_opcode(cbuf, Assembler::REX_W);
      } else {
        emit_opcode(cbuf, Assembler::REX_WB);
      }
    } else {
      if (opnd_array(2)->reg(ra_,this,idx2)/* op2 */ < 8) {
        emit_opcode(cbuf, Assembler::REX_WR);
      } else {
        emit_opcode(cbuf, Assembler::REX_WRB);
      }
    }
  
#line 31150 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x3B /*primary()*/));
  
#line 31158 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1815 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1)/* op1 */ & 7, opnd_array(2)->reg(ra_,this,idx2)/* op2 */ & 7);
  
#line 31166 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void compP_rReg_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 2478 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->reg(ra_,this,idx1)/* op1 */ < 8) {
      if (opnd_array(2)->base(ra_,this,idx2) < 8) {
        if (opnd_array(2)->index(ra_,this,idx2) < 8) {
          emit_opcode(cbuf, Assembler::REX_W);
        } else {
          emit_opcode(cbuf, Assembler::REX_WX);
        }
      } else {
        if (opnd_array(2)->index(ra_,this,idx2) < 8) {
          emit_opcode(cbuf, Assembler::REX_WB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WXB);
        }
      }
    } else {
      if (opnd_array(2)->base(ra_,this,idx2) < 8) {
        if (opnd_array(2)->index(ra_,this,idx2) < 8) {
          emit_opcode(cbuf, Assembler::REX_WR);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRX);
        }
      } else {
        if (opnd_array(2)->index(ra_,this,idx2) < 8) {
          emit_opcode(cbuf, Assembler::REX_WRB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRXB);
        }
      }
    }
  
#line 31210 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x3B /*primary()*/));
  
#line 31218 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2511 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // High registers handle in encode_RegMem
    int reg = opnd_array(1)->reg(ra_,this,idx1)/* op1 */;
    int base = opnd_array(2)->base(ra_,this,idx2);
    int index = opnd_array(2)->index(ra_,this,idx2);
    int scale = opnd_array(2)->scale();
    int disp = opnd_array(2)->disp(ra_,this,idx2);
    relocInfo::relocType disp_reloc = opnd_array(2)->disp_reloc();

    encode_RegMem(cbuf, reg, base, index, scale, disp, disp_reloc);
  
#line 31234 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void compP_mem_rRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 2478 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->reg(ra_,this,idx1)/* op1 */ < 8) {
      if (opnd_array(2)->base(ra_,this,idx2) < 8) {
        if (opnd_array(2)->index(ra_,this,idx2) < 8) {
          emit_opcode(cbuf, Assembler::REX_W);
        } else {
          emit_opcode(cbuf, Assembler::REX_WX);
        }
      } else {
        if (opnd_array(2)->index(ra_,this,idx2) < 8) {
          emit_opcode(cbuf, Assembler::REX_WB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WXB);
        }
      }
    } else {
      if (opnd_array(2)->base(ra_,this,idx2) < 8) {
        if (opnd_array(2)->index(ra_,this,idx2) < 8) {
          emit_opcode(cbuf, Assembler::REX_WR);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRX);
        }
      } else {
        if (opnd_array(2)->index(ra_,this,idx2) < 8) {
          emit_opcode(cbuf, Assembler::REX_WRB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRXB);
        }
      }
    }
  
#line 31278 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x3B /*primary()*/));
  
#line 31286 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2511 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // High registers handle in encode_RegMem
    int reg = opnd_array(1)->reg(ra_,this,idx1)/* op1 */;
    int base = opnd_array(2)->base(ra_,this,idx2);
    int index = opnd_array(2)->index(ra_,this,idx2);
    int scale = opnd_array(2)->scale();
    int disp = opnd_array(2)->disp(ra_,this,idx2);
    relocInfo::relocType disp_reloc = opnd_array(2)->disp_reloc();

    encode_RegMem(cbuf, reg, base, index, scale, disp, disp_reloc);
  
#line 31302 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void testP_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 2430 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->reg(ra_,this,idx1)/* src */ < 8) {
      if (opnd_array(1)->reg(ra_,this,idx1)/* src */ < 8) {
        emit_opcode(cbuf, Assembler::REX_W);
      } else {
        emit_opcode(cbuf, Assembler::REX_WB);
      }
    } else {
      if (opnd_array(1)->reg(ra_,this,idx1)/* src */ < 8) {
        emit_opcode(cbuf, Assembler::REX_WR);
      } else {
        emit_opcode(cbuf, Assembler::REX_WRB);
      }
    }
  
#line 31330 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x85 /*primary()*/));
  
#line 31338 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1815 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1)/* src */ & 7, opnd_array(1)->reg(ra_,this,idx1)/* src */ & 7);
  
#line 31346 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void testP_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// op
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 2324 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->base(ra_,this,idx1) >= 8) {
      if (opnd_array(1)->index(ra_,this,idx1) < 8) {
        emit_opcode(cbuf, Assembler::REX_WB);
      } else {
        emit_opcode(cbuf, Assembler::REX_WXB);
      }
    } else {
      if (opnd_array(1)->index(ra_,this,idx1) < 8) {
        emit_opcode(cbuf, Assembler::REX_W);
      } else {
        emit_opcode(cbuf, Assembler::REX_WX);
      }
    }
  
#line 31374 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xF7 /*primary()*/));
  
#line 31382 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2524 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    int rm_byte_opcode = (0x00);

    // High registers handle in encode_RegMem
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);

    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();       // disp-as-oop when
                                            // working with static
                                            // globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace,
                  disp_reloc);
  
#line 31402 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2291 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_d32(cbuf,(0xFFFFFFFF));
  
#line 31410 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void testP_mem_reg0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {
    MacroAssembler _masm(&cbuf);

#line 10889 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ cmpq(r12, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
  
#line 31427 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void compN_rRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {
    MacroAssembler _masm(&cbuf);

#line 10900 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"
__ cmpl(opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* op2 */); 
#line 31442 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void compN_rReg_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 10909 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ cmpl(opnd_array(1)->as_Register(ra_,this,idx1)/* src */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_reloc()));
  
#line 31459 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void compN_rReg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {
    MacroAssembler _masm(&cbuf);

#line 10919 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ cmp_narrow_oop(opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, (jobject)opnd_array(2)->constant());
  
#line 31476 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void compN_mem_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 10930 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ cmp_narrow_oop(Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_reloc()), (jobject)opnd_array(1)->constant());
  
#line 31493 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void compN_rReg_imm_klassNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {
    MacroAssembler _masm(&cbuf);

#line 10940 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ cmp_narrow_klass(opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, (Klass*)opnd_array(2)->constant());
  
#line 31510 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void compN_mem_imm_klassNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 10951 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ cmp_narrow_klass(Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_reloc()), (Klass*)opnd_array(1)->constant());
  
#line 31527 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void testN_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {
    MacroAssembler _masm(&cbuf);

#line 10961 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"
__ testl(opnd_array(1)->as_Register(ra_,this,idx1)/* src */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */); 
#line 31542 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void testN_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {
    MacroAssembler _masm(&cbuf);

#line 10972 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ cmpl(Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()), (int)0xFFFFFFFF);
  
#line 31559 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void testN_mem_reg0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {
    MacroAssembler _masm(&cbuf);

#line 10984 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ cmpl(r12, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
  
#line 31576 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void compL_rRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 2430 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->reg(ra_,this,idx1)/* op1 */ < 8) {
      if (opnd_array(2)->reg(ra_,this,idx2)/* op2 */ < 8) {
        emit_opcode(cbuf, Assembler::REX_W);
      } else {
        emit_opcode(cbuf, Assembler::REX_WB);
      }
    } else {
      if (opnd_array(2)->reg(ra_,this,idx2)/* op2 */ < 8) {
        emit_opcode(cbuf, Assembler::REX_WR);
      } else {
        emit_opcode(cbuf, Assembler::REX_WRB);
      }
    }
  
#line 31604 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x3B /*primary()*/));
  
#line 31612 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1815 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1)/* op1 */ & 7, opnd_array(2)->reg(ra_,this,idx2)/* op2 */ & 7);
  
#line 31620 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void compL_rReg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 1994 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // OpcSEr/m
    int dstenc = opnd_array(1)->reg(ra_,this,idx1)/* op1 */;
    if (dstenc < 8) {
      emit_opcode(cbuf, Assembler::REX_W);
    } else {
      emit_opcode(cbuf, Assembler::REX_WB);
      dstenc -= 8;
    }
    // Emit primary opcode and set sign-extend bit
    // Check for 8-bit immediate, and set sign extend bit in opcode
    if (-0x80 <= opnd_array(2)->constantL() && opnd_array(2)->constantL() < 0x80) {
      emit_opcode(cbuf, (0x81 /*primary()*/) | 0x02);
    } else {
      // 32-bit immediate
      emit_opcode(cbuf, (0x81 /*primary()*/));
    }
    // Emit r/m byte with secondary opcode, after primary opcode.
    emit_rm(cbuf, 0x3, (0x07 /*secondary()*/), dstenc);
  
#line 31653 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2016 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // Check for 8-bit immediate, and set sign extend bit in opcode
    if (-0x80 <= opnd_array(2)->constantL() && opnd_array(2)->constantL() < 0x80) {
      emit_d8(cbuf, opnd_array(2)->constantL());
    } else {
      // 32-bit immediate
      emit_d32(cbuf, opnd_array(2)->constantL());
    }
  
#line 31667 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void compL_rReg_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 2478 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->reg(ra_,this,idx1)/* op1 */ < 8) {
      if (opnd_array(2)->base(ra_,this,idx2) < 8) {
        if (opnd_array(2)->index(ra_,this,idx2) < 8) {
          emit_opcode(cbuf, Assembler::REX_W);
        } else {
          emit_opcode(cbuf, Assembler::REX_WX);
        }
      } else {
        if (opnd_array(2)->index(ra_,this,idx2) < 8) {
          emit_opcode(cbuf, Assembler::REX_WB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WXB);
        }
      }
    } else {
      if (opnd_array(2)->base(ra_,this,idx2) < 8) {
        if (opnd_array(2)->index(ra_,this,idx2) < 8) {
          emit_opcode(cbuf, Assembler::REX_WR);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRX);
        }
      } else {
        if (opnd_array(2)->index(ra_,this,idx2) < 8) {
          emit_opcode(cbuf, Assembler::REX_WRB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRXB);
        }
      }
    }
  
#line 31711 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x3B /*primary()*/));
  
#line 31719 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2511 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // High registers handle in encode_RegMem
    int reg = opnd_array(1)->reg(ra_,this,idx1)/* op1 */;
    int base = opnd_array(2)->base(ra_,this,idx2);
    int index = opnd_array(2)->index(ra_,this,idx2);
    int scale = opnd_array(2)->scale();
    int disp = opnd_array(2)->disp(ra_,this,idx2);
    relocInfo::relocType disp_reloc = opnd_array(2)->disp_reloc();

    encode_RegMem(cbuf, reg, base, index, scale, disp, disp_reloc);
  
#line 31735 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void testL_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 2430 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->reg(ra_,this,idx1)/* src */ < 8) {
      if (opnd_array(1)->reg(ra_,this,idx1)/* src */ < 8) {
        emit_opcode(cbuf, Assembler::REX_W);
      } else {
        emit_opcode(cbuf, Assembler::REX_WB);
      }
    } else {
      if (opnd_array(1)->reg(ra_,this,idx1)/* src */ < 8) {
        emit_opcode(cbuf, Assembler::REX_WR);
      } else {
        emit_opcode(cbuf, Assembler::REX_WRB);
      }
    }
  
#line 31763 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x85 /*primary()*/));
  
#line 31771 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1815 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1)/* src */ & 7, opnd_array(1)->reg(ra_,this,idx1)/* src */ & 7);
  
#line 31779 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void testL_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// zero
  {

#line 2406 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->reg(ra_,this,idx1)/* src */ < 8) {
      emit_opcode(cbuf, Assembler::REX_W);
    } else {
      emit_opcode(cbuf, Assembler::REX_WB);
    }
  
#line 31800 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xF7 /*primary()*/));
  
#line 31808 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2039 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // INC, DEC, IDIV, IMOD, JMP indirect, ...
    emit_rm(cbuf, 0x3, (0x00 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1)/* src */ & 7);
  
#line 31817 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2270 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // Output immediate
    emit_d32(cbuf, opnd_array(2)->constantL());
  
#line 31826 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void testL_reg_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mem
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// zero
  {

#line 2478 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->reg(ra_,this,idx1)/* src */ < 8) {
      if (opnd_array(2)->base(ra_,this,idx2) < 8) {
        if (opnd_array(2)->index(ra_,this,idx2) < 8) {
          emit_opcode(cbuf, Assembler::REX_W);
        } else {
          emit_opcode(cbuf, Assembler::REX_WX);
        }
      } else {
        if (opnd_array(2)->index(ra_,this,idx2) < 8) {
          emit_opcode(cbuf, Assembler::REX_WB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WXB);
        }
      }
    } else {
      if (opnd_array(2)->base(ra_,this,idx2) < 8) {
        if (opnd_array(2)->index(ra_,this,idx2) < 8) {
          emit_opcode(cbuf, Assembler::REX_WR);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRX);
        }
      } else {
        if (opnd_array(2)->index(ra_,this,idx2) < 8) {
          emit_opcode(cbuf, Assembler::REX_WRB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRXB);
        }
      }
    }
  
#line 31871 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x85 /*primary()*/));
  
#line 31879 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2511 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // High registers handle in encode_RegMem
    int reg = opnd_array(1)->reg(ra_,this,idx1)/* src */;
    int base = opnd_array(2)->base(ra_,this,idx2);
    int index = opnd_array(2)->index(ra_,this,idx2);
    int scale = opnd_array(2)->scale();
    int disp = opnd_array(2)->disp(ra_,this,idx2);
    relocInfo::relocType disp_reloc = opnd_array(2)->disp_reloc();

    encode_RegMem(cbuf, reg, base, index, scale, disp, disp_reloc);
  
#line 31895 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void testL_reg_mem_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// zero
  {

#line 2478 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(2)->reg(ra_,this,idx2)/* src */ < 8) {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_W);
        } else {
          emit_opcode(cbuf, Assembler::REX_WX);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WXB);
        }
      }
    } else {
      if (opnd_array(1)->base(ra_,this,idx1) < 8) {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WR);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRX);
        }
      } else {
        if (opnd_array(1)->index(ra_,this,idx1) < 8) {
          emit_opcode(cbuf, Assembler::REX_WRB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRXB);
        }
      }
    }
  
#line 31940 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x85 /*primary()*/));
  
#line 31948 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2511 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // High registers handle in encode_RegMem
    int reg = opnd_array(2)->reg(ra_,this,idx2)/* src */;
    int base = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int disp = opnd_array(1)->disp(ra_,this,idx1);
    relocInfo::relocType disp_reloc = opnd_array(1)->disp_reloc();

    encode_RegMem(cbuf, reg, base, index, scale, disp, disp_reloc);
  
#line 31964 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void cmpL3_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {

#line 2611 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    int src1enc = opnd_array(1)->reg(ra_,this,idx1)/* src1 */;
    int src2enc = opnd_array(2)->reg(ra_,this,idx2)/* src2 */;
    int dstenc = opnd_array(0)->reg(ra_,this)/* dst */;

    // cmpq $src1, $src2
    if (src1enc < 8) {
      if (src2enc < 8) {
        emit_opcode(cbuf, Assembler::REX_W);
      } else {
        emit_opcode(cbuf, Assembler::REX_WB);
      }
    } else {
      if (src2enc < 8) {
        emit_opcode(cbuf, Assembler::REX_WR);
      } else {
        emit_opcode(cbuf, Assembler::REX_WRB);
      }
    }
    emit_opcode(cbuf, 0x3B);
    emit_rm(cbuf, 0x3, src1enc & 7, src2enc & 7);

    // movl $dst, -1
    if (dstenc >= 8) {
      emit_opcode(cbuf, Assembler::REX_B);
    }
    emit_opcode(cbuf, 0xB8 | (dstenc & 7));
    emit_d32(cbuf, -1);

    // jl,s done
    emit_opcode(cbuf, 0x7C);
    emit_d8(cbuf, dstenc < 4 ? 0x06 : 0x08);

    // setne $dst
    if (dstenc >= 4) {
      emit_opcode(cbuf, dstenc < 8 ? Assembler::REX : Assembler::REX_B);
    }
    emit_opcode(cbuf, 0x0F);
    emit_opcode(cbuf, 0x95);
    emit_opcode(cbuf, 0xC0 | (dstenc & 7));

    // movzbl $dst, $dst
    if (dstenc >= 4) {
      emit_opcode(cbuf, dstenc < 8 ? Assembler::REX : Assembler::REX_RB);
    }
    emit_opcode(cbuf, 0x0F);
    emit_opcode(cbuf, 0xB6);
    emit_rm(cbuf, 0x3, dstenc & 7, dstenc & 7);
  
#line 32026 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void compUL_rRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 2430 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->reg(ra_,this,idx1)/* op1 */ < 8) {
      if (opnd_array(2)->reg(ra_,this,idx2)/* op2 */ < 8) {
        emit_opcode(cbuf, Assembler::REX_W);
      } else {
        emit_opcode(cbuf, Assembler::REX_WB);
      }
    } else {
      if (opnd_array(2)->reg(ra_,this,idx2)/* op2 */ < 8) {
        emit_opcode(cbuf, Assembler::REX_WR);
      } else {
        emit_opcode(cbuf, Assembler::REX_WRB);
      }
    }
  
#line 32054 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x3B /*primary()*/));
  
#line 32062 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1815 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1)/* op1 */ & 7, opnd_array(2)->reg(ra_,this,idx2)/* op2 */ & 7);
  
#line 32070 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void compUL_rReg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 1994 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // OpcSEr/m
    int dstenc = opnd_array(1)->reg(ra_,this,idx1)/* op1 */;
    if (dstenc < 8) {
      emit_opcode(cbuf, Assembler::REX_W);
    } else {
      emit_opcode(cbuf, Assembler::REX_WB);
      dstenc -= 8;
    }
    // Emit primary opcode and set sign-extend bit
    // Check for 8-bit immediate, and set sign extend bit in opcode
    if (-0x80 <= opnd_array(2)->constantL() && opnd_array(2)->constantL() < 0x80) {
      emit_opcode(cbuf, (0x81 /*primary()*/) | 0x02);
    } else {
      // 32-bit immediate
      emit_opcode(cbuf, (0x81 /*primary()*/));
    }
    // Emit r/m byte with secondary opcode, after primary opcode.
    emit_rm(cbuf, 0x3, (0x07 /*secondary()*/), dstenc);
  
#line 32103 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2016 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // Check for 8-bit immediate, and set sign extend bit in opcode
    if (-0x80 <= opnd_array(2)->constantL() && opnd_array(2)->constantL() < 0x80) {
      emit_d8(cbuf, opnd_array(2)->constantL());
    } else {
      // 32-bit immediate
      emit_d32(cbuf, opnd_array(2)->constantL());
    }
  
#line 32117 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void compUL_rReg_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 2478 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->reg(ra_,this,idx1)/* op1 */ < 8) {
      if (opnd_array(2)->base(ra_,this,idx2) < 8) {
        if (opnd_array(2)->index(ra_,this,idx2) < 8) {
          emit_opcode(cbuf, Assembler::REX_W);
        } else {
          emit_opcode(cbuf, Assembler::REX_WX);
        }
      } else {
        if (opnd_array(2)->index(ra_,this,idx2) < 8) {
          emit_opcode(cbuf, Assembler::REX_WB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WXB);
        }
      }
    } else {
      if (opnd_array(2)->base(ra_,this,idx2) < 8) {
        if (opnd_array(2)->index(ra_,this,idx2) < 8) {
          emit_opcode(cbuf, Assembler::REX_WR);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRX);
        }
      } else {
        if (opnd_array(2)->index(ra_,this,idx2) < 8) {
          emit_opcode(cbuf, Assembler::REX_WRB);
        } else {
          emit_opcode(cbuf, Assembler::REX_WRXB);
        }
      }
    }
  
#line 32161 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x3B /*primary()*/));
  
#line 32169 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2511 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // High registers handle in encode_RegMem
    int reg = opnd_array(1)->reg(ra_,this,idx1)/* op1 */;
    int base = opnd_array(2)->base(ra_,this,idx2);
    int index = opnd_array(2)->index(ra_,this,idx2);
    int scale = opnd_array(2)->scale();
    int disp = opnd_array(2)->disp(ra_,this,idx2);
    relocInfo::relocType disp_reloc = opnd_array(2)->disp_reloc();

    encode_RegMem(cbuf, reg, base, index, scale, disp, disp_reloc);
  
#line 32185 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void testUL_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 2430 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->reg(ra_,this,idx1)/* src */ < 8) {
      if (opnd_array(1)->reg(ra_,this,idx1)/* src */ < 8) {
        emit_opcode(cbuf, Assembler::REX_W);
      } else {
        emit_opcode(cbuf, Assembler::REX_WB);
      }
    } else {
      if (opnd_array(1)->reg(ra_,this,idx1)/* src */ < 8) {
        emit_opcode(cbuf, Assembler::REX_WR);
      } else {
        emit_opcode(cbuf, Assembler::REX_WRB);
      }
    }
  
#line 32213 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x85 /*primary()*/));
  
#line 32221 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1815 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1)/* src */ & 7, opnd_array(1)->reg(ra_,this,idx1)/* src */ & 7);
  
#line 32229 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void cmovI_reg_gNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// 
  {

#line 2415 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->reg(ra_,this,idx1)/* dst */ < 8) {
      if (opnd_array(2)->reg(ra_,this,idx2)/* src */ >= 8) {
        emit_opcode(cbuf, Assembler::REX_B);
      }
    } else {
      if (opnd_array(2)->reg(ra_,this,idx2)/* src */ < 8) {
        emit_opcode(cbuf, Assembler::REX_R);
      } else {
        emit_opcode(cbuf, Assembler::REX_RB);
      }
    }
  
#line 32256 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x0F /*primary()*/));
  
#line 32264 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1787 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x4F /*secondary()*/));
  
#line 32272 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1815 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1)/* dst */ & 7, opnd_array(2)->reg(ra_,this,idx2)/* src */ & 7);
  
#line 32280 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void cmovI_reg_lNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// 
  {

#line 2415 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->reg(ra_,this,idx1)/* dst */ < 8) {
      if (opnd_array(2)->reg(ra_,this,idx2)/* src */ >= 8) {
        emit_opcode(cbuf, Assembler::REX_B);
      }
    } else {
      if (opnd_array(2)->reg(ra_,this,idx2)/* src */ < 8) {
        emit_opcode(cbuf, Assembler::REX_R);
      } else {
        emit_opcode(cbuf, Assembler::REX_RB);
      }
    }
  
#line 32307 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x0F /*primary()*/));
  
#line 32315 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1787 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x4C /*secondary()*/));
  
#line 32323 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1815 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1)/* dst */ & 7, opnd_array(2)->reg(ra_,this,idx2)/* src */ & 7);
  
#line 32331 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void jmpDirNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 11174 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    Label* L = opnd_array(1)->label();
    __ jmp(*L, false); // Always long jump
  
#line 32348 "../generated/adfiles/ad_x86_64.cpp"
  }
}

uint jmpDirNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 5, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 5);
}

void jmpConNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cr
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// labl
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 11190 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    Label* L = opnd_array(3)->label();
    __ jcc((Assembler::Condition)(opnd_array(1)->ccode()), *L, false); // Always long jump
  
#line 32372 "../generated/adfiles/ad_x86_64.cpp"
  }
}

uint jmpConNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 6, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 6);
}

void jmpLoopEndNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cr
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// labl
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 11206 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    Label* L = opnd_array(3)->label();
    __ jcc((Assembler::Condition)(opnd_array(1)->ccode()), *L, false); // Always long jump
  
#line 32396 "../generated/adfiles/ad_x86_64.cpp"
  }
}

uint jmpLoopEndNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 6, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 6);
}

void jmpLoopEndUNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// labl
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 11221 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    Label* L = opnd_array(3)->label();
    __ jcc((Assembler::Condition)(opnd_array(1)->ccode()), *L, false); // Always long jump
  
#line 32420 "../generated/adfiles/ad_x86_64.cpp"
  }
}

uint jmpLoopEndUNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 6, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 6);
}

void jmpLoopEndUCFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// labl
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 11235 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    Label* L = opnd_array(3)->label();
    __ jcc((Assembler::Condition)(opnd_array(1)->ccode()), *L, false); // Always long jump
  
#line 32444 "../generated/adfiles/ad_x86_64.cpp"
  }
}

uint jmpLoopEndUCFNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 6, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 6);
}

void jmpConUNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// labl
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 11250 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    Label* L = opnd_array(3)->label();
    __ jcc((Assembler::Condition)(opnd_array(1)->ccode()), *L, false); // Always long jump
  
#line 32468 "../generated/adfiles/ad_x86_64.cpp"
  }
}

uint jmpConUNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 6, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 6);
}

void jmpConUCFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// labl
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 11264 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    Label* L = opnd_array(3)->label();
    __ jcc((Assembler::Condition)(opnd_array(1)->ccode()), *L, false); // Always long jump
  
#line 32492 "../generated/adfiles/ad_x86_64.cpp"
  }
}

uint jmpConUCFNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 6, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 6);
}

void jmpConUCF2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// labl
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 11286 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    Label* l = opnd_array(3)->label();
    if (opnd_array(1)->ccode()== Assembler::notEqual) {
      __ jcc(Assembler::parity, *l, false);
      __ jcc(Assembler::notEqual, *l, false);
    } else if (opnd_array(1)->ccode()== Assembler::equal) {
      Label done;
      __ jccb(Assembler::parity, done);
      __ jcc(Assembler::equal, *l, false);
      __ bind(done);
    } else {
       ShouldNotReachHere();
    }
  
#line 32526 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void partialSubtypeCheckNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// sub
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// super
  {

#line 2052 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    Register Rrdi = as_Register(RDI_enc); // result register
    Register Rrax = as_Register(RAX_enc); // super class
    Register Rrcx = as_Register(RCX_enc); // killed
    Register Rrsi = as_Register(RSI_enc); // sub class
    Label miss;
    const bool set_cond_codes = true;

    MacroAssembler _masm(&cbuf);
    __ check_klass_subtype_slow_path(Rrsi, Rrax, Rrcx, Rrdi,
                                     NULL, &miss,
                                     /*set_cond_codes:*/ true);
    if ((0x1 /*primary()*/)) {
      __ xorptr(Rrdi, Rrdi);
    }
    __ bind(miss);
  
#line 32556 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void partialSubtypeCheck_vs_ZeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// sub
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// super
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// zero
  {

#line 2052 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    Register Rrdi = as_Register(RDI_enc); // result register
    Register Rrax = as_Register(RAX_enc); // super class
    Register Rrcx = as_Register(RCX_enc); // killed
    Register Rrsi = as_Register(RSI_enc); // sub class
    Label miss;
    const bool set_cond_codes = true;

    MacroAssembler _masm(&cbuf);
    __ check_klass_subtype_slow_path(Rrsi, Rrax, Rrcx, Rrdi,
                                     NULL, &miss,
                                     /*set_cond_codes:*/ true);
    if ((0x0 /*primary()*/)) {
      __ xorptr(Rrdi, Rrdi);
    }
    __ bind(miss);
  
#line 32587 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void jmpDir_shortNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 11374 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    Label* L = opnd_array(1)->label();
    __ jmpb(*L);
  
#line 32604 "../generated/adfiles/ad_x86_64.cpp"
  }
}

uint jmpDir_shortNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 2, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 2);
}

void jmpCon_shortNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cr
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// labl
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 11390 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    Label* L = opnd_array(3)->label();
    __ jccb((Assembler::Condition)(opnd_array(1)->ccode()), *L);
  
#line 32628 "../generated/adfiles/ad_x86_64.cpp"
  }
}

uint jmpCon_shortNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 2, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 2);
}

void jmpLoopEnd_shortNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cr
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// labl
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 11406 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    Label* L = opnd_array(3)->label();
    __ jccb((Assembler::Condition)(opnd_array(1)->ccode()), *L);
  
#line 32652 "../generated/adfiles/ad_x86_64.cpp"
  }
}

uint jmpLoopEnd_shortNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 2, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 2);
}

void jmpLoopEndU_shortNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// labl
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 11422 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    Label* L = opnd_array(3)->label();
    __ jccb((Assembler::Condition)(opnd_array(1)->ccode()), *L);
  
#line 32676 "../generated/adfiles/ad_x86_64.cpp"
  }
}

uint jmpLoopEndU_shortNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 2, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 2);
}

void jmpLoopEndUCF_shortNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// labl
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 11437 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    Label* L = opnd_array(3)->label();
    __ jccb((Assembler::Condition)(opnd_array(1)->ccode()), *L);
  
#line 32700 "../generated/adfiles/ad_x86_64.cpp"
  }
}

uint jmpLoopEndUCF_shortNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 2, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 2);
}

void jmpConU_shortNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// labl
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 11453 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    Label* L = opnd_array(3)->label();
    __ jccb((Assembler::Condition)(opnd_array(1)->ccode()), *L);
  
#line 32724 "../generated/adfiles/ad_x86_64.cpp"
  }
}

uint jmpConU_shortNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 2, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 2);
}

void jmpConUCF_shortNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// labl
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 11468 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    Label* L = opnd_array(3)->label();
    __ jccb((Assembler::Condition)(opnd_array(1)->ccode()), *L);
  
#line 32748 "../generated/adfiles/ad_x86_64.cpp"
  }
}

uint jmpConUCF_shortNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 2, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 2);
}

void jmpConUCF2_shortNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// labl
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 11492 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    Label* l = opnd_array(3)->label();
    if (opnd_array(1)->ccode()== Assembler::notEqual) {
      __ jccb(Assembler::parity, *l);
      __ jccb(Assembler::notEqual, *l);
    } else if (opnd_array(1)->ccode()== Assembler::equal) {
      Label done;
      __ jccb(Assembler::parity, done);
      __ jccb(Assembler::equal, *l);
      __ bind(done);
    } else {
       ShouldNotReachHere();
    }
  
#line 32782 "../generated/adfiles/ad_x86_64.cpp"
  }
}

uint jmpConUCF2_shortNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void cmpFastLockRTMNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// object
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// box
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// scr
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// cx1
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// cx2
  {
    MacroAssembler _masm(&cbuf);

#line 11519 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ fast_lock(opnd_array(1)->as_Register(ra_,this,idx1)/* object */, opnd_array(2)->as_Register(ra_,this,idx2)/* box */, opnd_array(3)->as_Register(ra_,this,idx3)/* tmp */,
                 opnd_array(4)->as_Register(ra_,this,idx4)/* scr */, opnd_array(5)->as_Register(ra_,this,idx5)/* cx1 */, opnd_array(6)->as_Register(ra_,this,idx6)/* cx2 */,
                 _counters, _rtm_counters, _stack_rtm_counters,
                 ((Method*)(ra_->C->method()->constant_encoding()))->method_data(),
                 true, ra_->C->profile_rtm());
  
#line 32812 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void cmpFastLockNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// object
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// box
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// scr
  {
    MacroAssembler _masm(&cbuf);

#line 11535 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ fast_lock(opnd_array(1)->as_Register(ra_,this,idx1)/* object */, opnd_array(2)->as_Register(ra_,this,idx2)/* box */, opnd_array(3)->as_Register(ra_,this,idx3)/* tmp */,
                 opnd_array(4)->as_Register(ra_,this,idx4)/* scr */, noreg, noreg, _counters, NULL, NULL, NULL, false, false);
  
#line 32832 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void cmpFastUnlockNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// object
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// box
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    MacroAssembler _masm(&cbuf);

#line 11547 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ fast_unlock(opnd_array(1)->as_Register(ra_,this,idx1)/* object */, opnd_array(2)->as_Register(ra_,this,idx2)/* box */, opnd_array(3)->as_Register(ra_,this,idx3)/* tmp */, ra_->C->use_rtm());
  
#line 32850 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void safePoint_pollNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 5;
  unsigned idx1 = 5; 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 11565 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    AddressLiteral addr(os::get_polling_page(), relocInfo::poll_type);
    __ testl(rax, addr);
  
#line 32867 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void safePoint_poll_farNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 5;
  unsigned idx1 = 5; 	// cr
  {
    MacroAssembler _masm(&cbuf);

#line 11581 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    __ relocate(relocInfo::poll_type);
    __ testl(rax, Address(opnd_array(1)->as_Register(ra_,this,idx1)/* poll */, 0));
  
#line 32884 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void CallStaticJavaDirectNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {

#line 2070 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    debug_only(int off0 = cbuf.insts_size());
    if (ra_->C->max_vector_size() > 16) {
      // Clear upper bits of YMM registers when current compiled code uses
      // wide vectors to avoid AVX <-> SSE transition penalty during call.
      MacroAssembler _masm(&cbuf);
      __ vzeroupper();
    }
    debug_only(int off1 = cbuf.insts_size());
    assert(off1 - off0 == clear_avx_size(), "correct size prediction");
  
#line 32907 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2103 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // JAVA STATIC CALL
    // CALL to fixup routine.  Fixup routine uses ScopeDesc info to
    // determine who we intended to call.
    cbuf.set_insts_mark();
    emit_d8(cbuf, (0xE8 /*primary()*/));

    if (!_method) {
      emit_d32_reloc(cbuf,
                     (int) (opnd_array(1)->method() - ((intptr_t) cbuf.insts_end()) - 4),
                     runtime_call_Relocation::spec(),
                     RELOC_DISP32);
    } else if (_optimized_virtual) {
      emit_d32_reloc(cbuf,
                     (int) (opnd_array(1)->method() - ((intptr_t) cbuf.insts_end()) - 4),
                     opt_virtual_call_Relocation::spec(),
                     RELOC_DISP32);
    } else {
      emit_d32_reloc(cbuf,
                     (int) (opnd_array(1)->method() - ((intptr_t) cbuf.insts_end()) - 4),
                     static_call_Relocation::spec(),
                     RELOC_DISP32);
    }
    if (_method) {
      // Emit stub for static call.
      address stub = CompiledStaticCall::emit_to_interp_stub(cbuf);
      if (stub == NULL) {
        ciEnv::current()->record_failure("CodeCache is full");
        return;
      } 
    }
  
#line 32944 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 921 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    if (VerifyStackAtCalls) {
      // Check that stack depth is unchanged: find majik cookie on stack
      int framesize = ra_->reg2offset_unchecked(OptoReg::add(ra_->_matcher._old_SP, -3*VMRegImpl::slots_per_word));
      MacroAssembler _masm(&cbuf);
      Label L;
      __ cmpptr(Address(rsp, framesize), (int32_t)0xbadb100d);
      __ jccb(Assembler::equal, L);
      // Die if stack mismatch
      __ int3();
      __ bind(L);
    }
  
#line 32962 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void CallDynamicJavaDirectNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {

#line 2070 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    debug_only(int off0 = cbuf.insts_size());
    if (ra_->C->max_vector_size() > 16) {
      // Clear upper bits of YMM registers when current compiled code uses
      // wide vectors to avoid AVX <-> SSE transition penalty during call.
      MacroAssembler _masm(&cbuf);
      __ vzeroupper();
    }
    debug_only(int off1 = cbuf.insts_size());
    assert(off1 - off0 == clear_avx_size(), "correct size prediction");
  
#line 32985 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2136 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    MacroAssembler _masm(&cbuf);
    __ ic_call((address)opnd_array(1)->method());
  
#line 32994 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 921 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    if (VerifyStackAtCalls) {
      // Check that stack depth is unchanged: find majik cookie on stack
      int framesize = ra_->reg2offset_unchecked(OptoReg::add(ra_->_matcher._old_SP, -3*VMRegImpl::slots_per_word));
      MacroAssembler _masm(&cbuf);
      Label L;
      __ cmpptr(Address(rsp, framesize), (int32_t)0xbadb100d);
      __ jccb(Assembler::equal, L);
      // Die if stack mismatch
      __ int3();
      __ bind(L);
    }
  
#line 33012 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void CallRuntimeDirectNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {

#line 2070 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    debug_only(int off0 = cbuf.insts_size());
    if (ra_->C->max_vector_size() > 16) {
      // Clear upper bits of YMM registers when current compiled code uses
      // wide vectors to avoid AVX <-> SSE transition penalty during call.
      MacroAssembler _masm(&cbuf);
      __ vzeroupper();
    }
    debug_only(int off1 = cbuf.insts_size());
    assert(off1 - off0 == clear_avx_size(), "correct size prediction");
  
#line 33035 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2082 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // No relocation needed
    MacroAssembler _masm(&cbuf);
    __ mov64(r10, (int64_t) opnd_array(1)->method());
    __ call(r10);
  
#line 33046 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void CallLeafDirectNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {

#line 2070 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    debug_only(int off0 = cbuf.insts_size());
    if (ra_->C->max_vector_size() > 16) {
      // Clear upper bits of YMM registers when current compiled code uses
      // wide vectors to avoid AVX <-> SSE transition penalty during call.
      MacroAssembler _masm(&cbuf);
      __ vzeroupper();
    }
    debug_only(int off1 = cbuf.insts_size());
    assert(off1 - off0 == clear_avx_size(), "correct size prediction");
  
#line 33069 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2082 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // No relocation needed
    MacroAssembler _masm(&cbuf);
    __ mov64(r10, (int64_t) opnd_array(1)->method());
    __ call(r10);
  
#line 33080 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void CallLeafNoFPDirectNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {

#line 2082 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // No relocation needed
    MacroAssembler _masm(&cbuf);
    __ mov64(r10, (int64_t) opnd_array(1)->method());
    __ call(r10);
  
#line 33098 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void RetNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 5;
  unsigned idx1 = 5; 	// 
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xC3 /*primary()*/));
  
#line 33113 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void TailCalljmpIndNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 5;
  unsigned idx1 = 5; 	// method_oop
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// 
  {

#line 2399 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->reg(ra_,this,idx1)/* jump_target */ >= 8) {
      emit_opcode(cbuf, Assembler::REX_B);
    }
  
#line 33131 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xFF /*primary()*/));
  
#line 33139 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2039 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // INC, DEC, IDIV, IMOD, JMP indirect, ...
    emit_rm(cbuf, 0x3, (0x4 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1)/* jump_target */ & 7);
  
#line 33148 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void tailjmpIndNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 5;
  unsigned idx1 = 5; 	// ex_oop
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// 
  {

#line 1799 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0x5a));
  
#line 33164 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2399 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    if (opnd_array(1)->reg(ra_,this,idx1)/* jump_target */ >= 8) {
      emit_opcode(cbuf, Assembler::REX_B);
    }
  
#line 33174 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 1781 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    emit_opcode(cbuf, (0xFF /*primary()*/));
  
#line 33182 "../generated/adfiles/ad_x86_64.cpp"
  }
  {

#line 2039 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // INC, DEC, IDIV, IMOD, JMP indirect, ...
    emit_rm(cbuf, 0x3, (0x4 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1)/* jump_target */ & 7);
  
#line 33191 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void CreateExceptionNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  // User did not define which encode class to use.
}

uint CreateExceptionNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 0);
}

void RethrowExceptionNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 5;
  unsigned idx1 = 5; 	// 
  {

#line 2677 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    cbuf.set_insts_mark();
    emit_opcode(cbuf, 0xE9); // jmp entry
    emit_d32_reloc(cbuf,
                   (int) (OptoRuntime::rethrow_stub() - cbuf.insts_end() - 4),
                   runtime_call_Relocation::spec(),
                   RELOC_DISP32);
  
#line 33224 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void tlsLoadPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  // User did not define which encode class to use.
}

uint tlsLoadPNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 0);
}

void ShouldNotReachHereNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 5;
  unsigned idx1 = 5; 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 984 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ int3();
  
#line 33253 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void addF_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 998 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ addss(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 33270 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void addF_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 1010 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ addss(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_reloc()));
  
#line 33287 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void addF_mem_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  {
    MacroAssembler _masm(&cbuf);

#line 1010 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ addss(opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
  
#line 33304 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void addF_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 1021 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ addss(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, InternalAddress(__ code()->consts()->start() + constant_offset()));
  
#line 33321 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void addF_immNode::eval_constant(Compile* C) {
  {

#line 1022 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"
    _constant = C->constant_table().add(this, opnd_array(2));
#line 33330 "../generated/adfiles/ad_x86_64.cpp"
  }
}
void addF_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 1033 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ vaddss(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */);
  
#line 33346 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void addF_reg_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 1045 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ vaddss(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_reloc()));
  
#line 33363 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void addF_reg_mem_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 1045 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ vaddss(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src1 */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
  
#line 33380 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void addF_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 1057 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ vaddss(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, InternalAddress(__ code()->consts()->start() + constant_offset()));
  
#line 33397 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void addF_reg_immNode::eval_constant(Compile* C) {
  {

#line 1058 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"
    _constant = C->constant_table().add(this, opnd_array(2));
#line 33406 "../generated/adfiles/ad_x86_64.cpp"
  }
}
void addD_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 1069 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ addsd(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 33422 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void addD_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 1081 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ addsd(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_reloc()));
  
#line 33439 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void addD_mem_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  {
    MacroAssembler _masm(&cbuf);

#line 1081 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ addsd(opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
  
#line 33456 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void addD_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 1092 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ addsd(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, InternalAddress(__ code()->consts()->start() + constant_offset()));
  
#line 33473 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void addD_immNode::eval_constant(Compile* C) {
  {

#line 1093 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"
    _constant = C->constant_table().add(this, opnd_array(2));
#line 33482 "../generated/adfiles/ad_x86_64.cpp"
  }
}
void addD_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 1104 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ vaddsd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */);
  
#line 33498 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void addD_reg_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 1116 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ vaddsd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_reloc()));
  
#line 33515 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void addD_reg_mem_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 1116 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ vaddsd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src1 */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
  
#line 33532 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void addD_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 1128 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ vaddsd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, InternalAddress(__ code()->consts()->start() + constant_offset()));
  
#line 33549 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void addD_reg_immNode::eval_constant(Compile* C) {
  {

#line 1129 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"
    _constant = C->constant_table().add(this, opnd_array(2));
#line 33558 "../generated/adfiles/ad_x86_64.cpp"
  }
}
void subF_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 1140 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ subss(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 33574 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void subF_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 1152 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ subss(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_reloc()));
  
#line 33591 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void subF_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 1163 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ subss(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, InternalAddress(__ code()->consts()->start() + constant_offset()));
  
#line 33608 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void subF_immNode::eval_constant(Compile* C) {
  {

#line 1164 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"
    _constant = C->constant_table().add(this, opnd_array(2));
#line 33617 "../generated/adfiles/ad_x86_64.cpp"
  }
}
void subF_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 1175 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ vsubss(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */);
  
#line 33633 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void subF_reg_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 1187 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ vsubss(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_reloc()));
  
#line 33650 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void subF_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 1199 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ vsubss(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, InternalAddress(__ code()->consts()->start() + constant_offset()));
  
#line 33667 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void subF_reg_immNode::eval_constant(Compile* C) {
  {

#line 1200 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"
    _constant = C->constant_table().add(this, opnd_array(2));
#line 33676 "../generated/adfiles/ad_x86_64.cpp"
  }
}
void subD_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 1211 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ subsd(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 33692 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void subD_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 1223 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ subsd(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_reloc()));
  
#line 33709 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void subD_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 1234 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ subsd(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, InternalAddress(__ code()->consts()->start() + constant_offset()));
  
#line 33726 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void subD_immNode::eval_constant(Compile* C) {
  {

#line 1235 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"
    _constant = C->constant_table().add(this, opnd_array(2));
#line 33735 "../generated/adfiles/ad_x86_64.cpp"
  }
}
void subD_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 1246 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ vsubsd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */);
  
#line 33751 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void subD_reg_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 1258 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ vsubsd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_reloc()));
  
#line 33768 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void subD_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 1270 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ vsubsd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, InternalAddress(__ code()->consts()->start() + constant_offset()));
  
#line 33785 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void subD_reg_immNode::eval_constant(Compile* C) {
  {

#line 1271 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"
    _constant = C->constant_table().add(this, opnd_array(2));
#line 33794 "../generated/adfiles/ad_x86_64.cpp"
  }
}
void mulF_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 1282 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ mulss(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 33810 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void mulF_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 1294 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ mulss(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_reloc()));
  
#line 33827 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void mulF_mem_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  {
    MacroAssembler _masm(&cbuf);

#line 1294 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ mulss(opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
  
#line 33844 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void mulF_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 1305 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ mulss(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, InternalAddress(__ code()->consts()->start() + constant_offset()));
  
#line 33861 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void mulF_immNode::eval_constant(Compile* C) {
  {

#line 1306 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"
    _constant = C->constant_table().add(this, opnd_array(2));
#line 33870 "../generated/adfiles/ad_x86_64.cpp"
  }
}
void mulF_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 1317 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ vmulss(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */);
  
#line 33886 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void mulF_reg_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 1329 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ vmulss(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_reloc()));
  
#line 33903 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void mulF_reg_mem_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 1329 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ vmulss(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src1 */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
  
#line 33920 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void mulF_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 1341 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ vmulss(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, InternalAddress(__ code()->consts()->start() + constant_offset()));
  
#line 33937 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void mulF_reg_immNode::eval_constant(Compile* C) {
  {

#line 1342 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"
    _constant = C->constant_table().add(this, opnd_array(2));
#line 33946 "../generated/adfiles/ad_x86_64.cpp"
  }
}
void mulD_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 1353 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ mulsd(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 33962 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void mulD_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 1365 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ mulsd(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_reloc()));
  
#line 33979 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void mulD_mem_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  {
    MacroAssembler _masm(&cbuf);

#line 1365 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ mulsd(opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
  
#line 33996 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void mulD_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 1376 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ mulsd(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, InternalAddress(__ code()->consts()->start() + constant_offset()));
  
#line 34013 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void mulD_immNode::eval_constant(Compile* C) {
  {

#line 1377 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"
    _constant = C->constant_table().add(this, opnd_array(2));
#line 34022 "../generated/adfiles/ad_x86_64.cpp"
  }
}
void mulD_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 1388 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ vmulsd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */);
  
#line 34038 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void mulD_reg_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 1400 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ vmulsd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_reloc()));
  
#line 34055 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void mulD_reg_mem_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 1400 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ vmulsd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src1 */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
  
#line 34072 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void mulD_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 1412 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ vmulsd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, InternalAddress(__ code()->consts()->start() + constant_offset()));
  
#line 34089 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void mulD_reg_immNode::eval_constant(Compile* C) {
  {

#line 1413 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"
    _constant = C->constant_table().add(this, opnd_array(2));
#line 34098 "../generated/adfiles/ad_x86_64.cpp"
  }
}
void divF_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 1424 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ divss(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 34114 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void divF_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 1436 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ divss(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_reloc()));
  
#line 34131 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void divF_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 1447 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ divss(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, InternalAddress(__ code()->consts()->start() + constant_offset()));
  
#line 34148 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void divF_immNode::eval_constant(Compile* C) {
  {

#line 1448 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"
    _constant = C->constant_table().add(this, opnd_array(2));
#line 34157 "../generated/adfiles/ad_x86_64.cpp"
  }
}
void divF_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 1459 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ vdivss(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */);
  
#line 34173 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void divF_reg_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 1471 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ vdivss(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_reloc()));
  
#line 34190 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void divF_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 1483 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ vdivss(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, InternalAddress(__ code()->consts()->start() + constant_offset()));
  
#line 34207 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void divF_reg_immNode::eval_constant(Compile* C) {
  {

#line 1484 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"
    _constant = C->constant_table().add(this, opnd_array(2));
#line 34216 "../generated/adfiles/ad_x86_64.cpp"
  }
}
void divD_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 1495 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ divsd(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 34232 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void divD_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 1507 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ divsd(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_reloc()));
  
#line 34249 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void divD_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 1518 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ divsd(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, InternalAddress(__ code()->consts()->start() + constant_offset()));
  
#line 34266 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void divD_immNode::eval_constant(Compile* C) {
  {

#line 1519 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"
    _constant = C->constant_table().add(this, opnd_array(2));
#line 34275 "../generated/adfiles/ad_x86_64.cpp"
  }
}
void divD_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 1530 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ vdivsd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */);
  
#line 34291 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void divD_reg_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 1542 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ vdivsd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_reloc()));
  
#line 34308 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void divD_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 1554 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ vdivsd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, InternalAddress(__ code()->consts()->start() + constant_offset()));
  
#line 34325 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void divD_reg_immNode::eval_constant(Compile* C) {
  {

#line 1555 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"
    _constant = C->constant_table().add(this, opnd_array(2));
#line 34334 "../generated/adfiles/ad_x86_64.cpp"
  }
}
void absF_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  {
    MacroAssembler _masm(&cbuf);

#line 1565 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ andps(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, ExternalAddress(float_signmask()));
  
#line 34349 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void absF_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 1576 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vandps(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */,
              ExternalAddress(float_signmask()), vector256);
  
#line 34367 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void absD_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  {
    MacroAssembler _masm(&cbuf);

#line 1590 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ andpd(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, ExternalAddress(double_signmask()));
  
#line 34383 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void absD_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 1602 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vandpd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */,
              ExternalAddress(double_signmask()), vector256);
  
#line 34401 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void negF_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  {
    MacroAssembler _masm(&cbuf);

#line 1615 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ xorps(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, ExternalAddress(float_signflip()));
  
#line 34417 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void negF_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 1626 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vxorps(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */,
              ExternalAddress(float_signflip()), vector256);
  
#line 34435 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void negD_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  {
    MacroAssembler _masm(&cbuf);

#line 1640 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ xorpd(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, ExternalAddress(double_signflip()));
  
#line 34451 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void negD_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 1652 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vxorpd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */,
              ExternalAddress(double_signflip()), vector256);
  
#line 34469 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void sqrtF_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 1666 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ sqrtss(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */);
  
#line 34485 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void sqrtF_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 1678 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ sqrtss(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
  
#line 34501 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void sqrtF_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 1689 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ sqrtss(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, InternalAddress(__ code()->consts()->start() + constant_offset()));
  
#line 34517 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void sqrtF_immNode::eval_constant(Compile* C) {
  {

#line 1690 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"
    _constant = C->constant_table().add(this, opnd_array(1));
#line 34526 "../generated/adfiles/ad_x86_64.cpp"
  }
}
void sqrtD_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 1701 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ sqrtsd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */);
  
#line 34541 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void sqrtD_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 1713 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ sqrtsd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
  
#line 34557 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void sqrtD_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 1724 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ sqrtsd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, InternalAddress(__ code()->consts()->start() + constant_offset()));
  
#line 34573 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void sqrtD_immNode::eval_constant(Compile* C) {
  {

#line 1725 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"
    _constant = C->constant_table().add(this, opnd_array(1));
#line 34582 "../generated/adfiles/ad_x86_64.cpp"
  }
}
void loadV4Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 1739 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ movdl(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
  
#line 34597 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void loadV8Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 1751 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ movq(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
  
#line 34613 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void loadV16Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 1763 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ movdqu(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
  
#line 34629 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void loadV32Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 1775 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ vmovdqu(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
  
#line 34645 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void storeV4Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 1787 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ movdl(Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()), opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 34662 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void storeV8Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 1798 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ movq(Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()), opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 34679 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void storeV16Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 1809 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ movdqu(Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()), opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 34696 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void storeV32Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 1820 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ vmovdqu(Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()), opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 34713 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void Repl4BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 1833 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ movdl(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
    __ punpcklbw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */);
    __ pshuflw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, 0x00);
  
#line 34731 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void Repl8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 1847 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ movdl(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
    __ punpcklbw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */);
    __ pshuflw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, 0x00);
  
#line 34749 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void Repl16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 1862 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ movdl(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
    __ punpcklbw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */);
    __ pshuflw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, 0x00);
    __ punpcklqdq(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */);
  
#line 34768 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void Repl32BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 1879 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ movdl(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
    __ punpcklbw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */);
    __ pshuflw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, 0x00);
    __ punpcklqdq(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */);
    __ vinserti128h(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */);
  
#line 34788 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void Repl4B_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 1894 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ movdl(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, InternalAddress(__ code()->consts()->start() + constant_offset()));
  
#line 34804 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void Repl4B_immNode::eval_constant(Compile* C) {
  {

#line 1895 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"
    _constant = C->constant_table().add(this, replicate4_imm(opnd_array(1)->constant(), 1));
#line 34813 "../generated/adfiles/ad_x86_64.cpp"
  }
}
void Repl8B_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 1904 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ movq(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, InternalAddress(__ code()->consts()->start() + constant_offset()));
  
#line 34828 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void Repl8B_immNode::eval_constant(Compile* C) {
  {

#line 1905 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"
    _constant = C->constant_table().add(this, replicate8_imm(opnd_array(1)->constant(), 1));
#line 34837 "../generated/adfiles/ad_x86_64.cpp"
  }
}
void Repl16B_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 1915 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ movq(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, InternalAddress(__ code()->consts()->start() + constant_offset()));
    __ punpcklqdq(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */);
  
#line 34853 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void Repl16B_immNode::eval_constant(Compile* C) {
  {

#line 1916 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"
    _constant = C->constant_table().add(this, replicate8_imm(opnd_array(1)->constant(), 1));
#line 34862 "../generated/adfiles/ad_x86_64.cpp"
  }
}
void Repl32B_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 1928 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ movq(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, InternalAddress(__ code()->consts()->start() + constant_offset()));
    __ punpcklqdq(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */);
    __ vinserti128h(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */);
  
#line 34879 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void Repl32B_immNode::eval_constant(Compile* C) {
  {

#line 1929 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"
    _constant = C->constant_table().add(this, replicate8_imm(opnd_array(1)->constant(), 1));
#line 34888 "../generated/adfiles/ad_x86_64.cpp"
  }
}
void Repl4B_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  {
    MacroAssembler _masm(&cbuf);

#line 1941 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ pxor(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */);
  
#line 34903 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void Repl8B_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  {
    MacroAssembler _masm(&cbuf);

#line 1951 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ pxor(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */);
  
#line 34919 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void Repl16B_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  {
    MacroAssembler _masm(&cbuf);

#line 1961 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ pxor(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */);
  
#line 34935 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void Repl32B_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  {
    MacroAssembler _masm(&cbuf);

#line 1971 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    // Use vxorpd since AVX does not have vpxor for 256-bit (AVX2 will have it).
    bool vector256 = true;
    __ vpxor(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, vector256);
  
#line 34953 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void Repl2SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 1985 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ movdl(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
    __ pshuflw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, 0x00);
  
#line 34970 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void Repl4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 1997 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ movdl(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
    __ pshuflw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, 0x00);
  
#line 34987 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void Repl8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 2010 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ movdl(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
    __ pshuflw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, 0x00);
    __ punpcklqdq(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */);
  
#line 35005 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void Repl16SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 2025 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ movdl(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
    __ pshuflw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, 0x00);
    __ punpcklqdq(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */);
    __ vinserti128h(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */);
  
#line 35024 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void Repl2S_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 2039 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ movdl(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, InternalAddress(__ code()->consts()->start() + constant_offset()));
  
#line 35040 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void Repl2S_immNode::eval_constant(Compile* C) {
  {

#line 2040 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"
    _constant = C->constant_table().add(this, replicate4_imm(opnd_array(1)->constant(), 2));
#line 35049 "../generated/adfiles/ad_x86_64.cpp"
  }
}
void Repl4S_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 2049 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ movq(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, InternalAddress(__ code()->consts()->start() + constant_offset()));
  
#line 35064 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void Repl4S_immNode::eval_constant(Compile* C) {
  {

#line 2050 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"
    _constant = C->constant_table().add(this, replicate8_imm(opnd_array(1)->constant(), 2));
#line 35073 "../generated/adfiles/ad_x86_64.cpp"
  }
}
void Repl8S_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 2060 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ movq(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, InternalAddress(__ code()->consts()->start() + constant_offset()));
    __ punpcklqdq(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */);
  
#line 35089 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void Repl8S_immNode::eval_constant(Compile* C) {
  {

#line 2061 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"
    _constant = C->constant_table().add(this, replicate8_imm(opnd_array(1)->constant(), 2));
#line 35098 "../generated/adfiles/ad_x86_64.cpp"
  }
}
void Repl16S_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 2073 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ movq(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, InternalAddress(__ code()->consts()->start() + constant_offset()));
    __ punpcklqdq(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */);
    __ vinserti128h(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */);
  
#line 35115 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void Repl16S_immNode::eval_constant(Compile* C) {
  {

#line 2074 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"
    _constant = C->constant_table().add(this, replicate8_imm(opnd_array(1)->constant(), 2));
#line 35124 "../generated/adfiles/ad_x86_64.cpp"
  }
}
void Repl2S_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  {
    MacroAssembler _masm(&cbuf);

#line 2086 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ pxor(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */);
  
#line 35139 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void Repl4S_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  {
    MacroAssembler _masm(&cbuf);

#line 2096 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ pxor(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */);
  
#line 35155 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void Repl8S_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  {
    MacroAssembler _masm(&cbuf);

#line 2106 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ pxor(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */);
  
#line 35171 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void Repl16S_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  {
    MacroAssembler _masm(&cbuf);

#line 2116 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    // Use vxorpd since AVX does not have vpxor for 256-bit (AVX2 will have it).
    bool vector256 = true;
    __ vpxor(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, vector256);
  
#line 35189 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void Repl2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 2130 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ movdl(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
    __ pshufd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, 0x00);
  
#line 35206 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void Repl4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 2142 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ movdl(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
    __ pshufd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, 0x00);
  
#line 35223 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void Repl8INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 2155 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ movdl(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
    __ pshufd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, 0x00);
    __ vinserti128h(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */);
  
#line 35241 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void Repl2I_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 2168 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ movq(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, InternalAddress(__ code()->consts()->start() + constant_offset()));
  
#line 35257 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void Repl2I_immNode::eval_constant(Compile* C) {
  {

#line 2169 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"
    _constant = C->constant_table().add(this, replicate8_imm(opnd_array(1)->constant(), 4));
#line 35266 "../generated/adfiles/ad_x86_64.cpp"
  }
}
void Repl4I_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 2179 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ movq(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, InternalAddress(__ code()->consts()->start() + constant_offset()));
    __ punpcklqdq(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */);
  
#line 35282 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void Repl4I_immNode::eval_constant(Compile* C) {
  {

#line 2180 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"
    _constant = C->constant_table().add(this, replicate8_imm(opnd_array(1)->constant(), 4));
#line 35291 "../generated/adfiles/ad_x86_64.cpp"
  }
}
void Repl8I_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 2192 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ movq(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, InternalAddress(__ code()->consts()->start() + constant_offset()));
    __ punpcklqdq(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */);
    __ vinserti128h(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */);
  
#line 35308 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void Repl8I_immNode::eval_constant(Compile* C) {
  {

#line 2193 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"
    _constant = C->constant_table().add(this, replicate8_imm(opnd_array(1)->constant(), 4));
#line 35317 "../generated/adfiles/ad_x86_64.cpp"
  }
}
void Repl2I_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 2206 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ movdl(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
    __ pshufd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, 0x00);
  
#line 35333 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void Repl4I_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 2218 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ movdl(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
    __ pshufd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, 0x00);
  
#line 35350 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void Repl8I_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 2231 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ movdl(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
    __ pshufd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, 0x00);
    __ vinserti128h(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */);
  
#line 35368 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void Repl2I_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  {
    MacroAssembler _masm(&cbuf);

#line 2244 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ pxor(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */);
  
#line 35384 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void Repl4I_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  {
    MacroAssembler _masm(&cbuf);

#line 2254 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ pxor(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */);
  
#line 35400 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void Repl8I_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  {
    MacroAssembler _masm(&cbuf);

#line 2264 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    // Use vxorpd since AVX does not have vpxor for 256-bit (AVX2 will have it).
    bool vector256 = true;
    __ vpxor(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, vector256);
  
#line 35418 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void Repl2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 2279 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ movdq(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
    __ punpcklqdq(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */);
  
#line 35435 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void Repl4LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 2292 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ movdq(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
    __ punpcklqdq(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */);
    __ vinserti128h(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */);
  
#line 35453 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void Repl2L_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 2343 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ movq(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, InternalAddress(__ code()->consts()->start() + constant_offset()));
    __ punpcklqdq(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */);
  
#line 35470 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void Repl2L_immNode::eval_constant(Compile* C) {
  {

#line 2344 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"
    _constant = C->constant_table().add(this, opnd_array(1));
#line 35479 "../generated/adfiles/ad_x86_64.cpp"
  }
}
void Repl4L_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 2356 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ movq(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, InternalAddress(__ code()->consts()->start() + constant_offset()));
    __ punpcklqdq(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */);
    __ vinserti128h(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */);
  
#line 35496 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void Repl4L_immNode::eval_constant(Compile* C) {
  {

#line 2357 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"
    _constant = C->constant_table().add(this, opnd_array(1));
#line 35505 "../generated/adfiles/ad_x86_64.cpp"
  }
}
void Repl2L_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 2370 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ movq(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
    __ punpcklqdq(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */);
  
#line 35521 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void Repl4L_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 2383 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ movq(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
    __ punpcklqdq(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */);
    __ vinserti128h(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */);
  
#line 35539 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void Repl2L_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  {
    MacroAssembler _masm(&cbuf);

#line 2396 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ pxor(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */);
  
#line 35555 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void Repl4L_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  {
    MacroAssembler _masm(&cbuf);

#line 2406 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    // Use vxorpd since AVX does not have vpxor for 256-bit (AVX2 will have it).
    bool vector256 = true;
    __ vpxor(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, vector256);
  
#line 35573 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void Repl2FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 2419 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ pshufd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, 0x00);
  
#line 35589 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void Repl4FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 2429 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ pshufd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, 0x00);
  
#line 35605 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void Repl8FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 2440 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ pshufd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, 0x00);
    __ vinsertf128h(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */);
  
#line 35622 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void Repl2F_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  {
    MacroAssembler _masm(&cbuf);

#line 2452 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ xorps(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */);
  
#line 35638 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void Repl4F_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  {
    MacroAssembler _masm(&cbuf);

#line 2462 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ xorps(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */);
  
#line 35654 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void Repl8F_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  {
    MacroAssembler _masm(&cbuf);

#line 2472 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vxorps(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, vector256);
  
#line 35671 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void Repl2DNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 2484 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ pshufd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, 0x44);
  
#line 35687 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void Repl4DNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 2495 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ pshufd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, 0x44);
    __ vinsertf128h(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */);
  
#line 35704 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void Repl2D_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  {
    MacroAssembler _masm(&cbuf);

#line 2507 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ xorpd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */);
  
#line 35720 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void Repl4D_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  {
    MacroAssembler _masm(&cbuf);

#line 2517 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vxorpd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, vector256);
  
#line 35737 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vadd4BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 2533 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ paddb(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 35754 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vadd4B_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 2543 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpaddb(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 35772 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vadd8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 2554 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ paddb(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 35789 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vadd8B_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 2564 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpaddb(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 35807 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vadd16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 2575 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ paddb(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 35824 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vadd16B_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 2585 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpaddb(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 35842 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vadd16B_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 2596 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpaddb(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_reloc()), vector256);
  
#line 35860 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vadd32B_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 2607 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vpaddb(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 35878 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vadd32B_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 2618 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vpaddb(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_reloc()), vector256);
  
#line 35896 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vadd2SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 2630 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ paddw(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 35913 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vadd2S_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 2640 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpaddw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 35931 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vadd4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 2651 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ paddw(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 35948 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vadd4S_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 2661 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpaddw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 35966 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vadd8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 2672 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ paddw(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 35983 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vadd8S_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 2682 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpaddw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 36001 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vadd8S_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 2693 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpaddw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_reloc()), vector256);
  
#line 36019 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vadd16S_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 2704 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vpaddw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 36037 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vadd16S_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 2715 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vpaddw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_reloc()), vector256);
  
#line 36055 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vadd2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 2727 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ paddd(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 36072 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vadd2I_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 2737 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpaddd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 36090 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vadd4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 2748 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ paddd(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 36107 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vadd4I_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 2758 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpaddd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 36125 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vadd4I_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 2769 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpaddd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_reloc()), vector256);
  
#line 36143 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vadd8I_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 2780 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vpaddd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 36161 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vadd8I_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 2791 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vpaddd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_reloc()), vector256);
  
#line 36179 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vadd2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 2803 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ paddq(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 36196 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vadd2L_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 2813 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpaddq(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 36214 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vadd2L_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 2824 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpaddq(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_reloc()), vector256);
  
#line 36232 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vadd4L_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 2835 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vpaddq(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 36250 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vadd4L_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 2846 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vpaddq(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_reloc()), vector256);
  
#line 36268 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vadd2FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 2858 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ addps(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 36285 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vadd2F_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 2868 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vaddps(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 36303 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vadd4FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 2879 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ addps(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 36320 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vadd4F_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 2889 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vaddps(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 36338 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vadd4F_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 2900 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vaddps(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_reloc()), vector256);
  
#line 36356 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vadd8F_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 2911 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vaddps(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 36374 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vadd8F_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 2922 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vaddps(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_reloc()), vector256);
  
#line 36392 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vadd2DNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 2934 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ addpd(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 36409 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vadd2D_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 2944 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vaddpd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 36427 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vadd2D_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 2955 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vaddpd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_reloc()), vector256);
  
#line 36445 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vadd4D_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 2966 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vaddpd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 36463 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vadd4D_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 2977 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vaddpd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_reloc()), vector256);
  
#line 36481 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsub4BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 2991 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ psubb(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 36498 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsub4B_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 3001 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpsubb(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 36516 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsub8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 3012 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ psubb(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 36533 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsub8B_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 3022 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpsubb(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 36551 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsub16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 3033 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ psubb(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 36568 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsub16B_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 3043 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpsubb(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 36586 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsub16B_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 3054 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpsubb(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_reloc()), vector256);
  
#line 36604 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsub32B_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 3065 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vpsubb(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 36622 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsub32B_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 3076 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vpsubb(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_reloc()), vector256);
  
#line 36640 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsub2SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 3088 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ psubw(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 36657 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsub2S_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 3098 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpsubw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 36675 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsub4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 3109 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ psubw(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 36692 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsub4S_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 3119 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpsubw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 36710 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsub8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 3130 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ psubw(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 36727 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsub8S_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 3140 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpsubw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 36745 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsub8S_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 3151 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpsubw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_reloc()), vector256);
  
#line 36763 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsub16S_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 3162 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vpsubw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 36781 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsub16S_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 3173 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vpsubw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_reloc()), vector256);
  
#line 36799 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsub2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 3185 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ psubd(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 36816 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsub2I_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 3195 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpsubd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 36834 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsub4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 3206 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ psubd(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 36851 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsub4I_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 3216 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpsubd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 36869 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsub4I_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 3227 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpsubd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_reloc()), vector256);
  
#line 36887 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsub8I_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 3238 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vpsubd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 36905 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsub8I_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 3249 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vpsubd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_reloc()), vector256);
  
#line 36923 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsub2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 3261 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ psubq(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 36940 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsub2L_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 3271 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpsubq(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 36958 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsub2L_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 3282 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpsubq(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_reloc()), vector256);
  
#line 36976 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsub4L_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 3293 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vpsubq(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 36994 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsub4L_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 3304 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vpsubq(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_reloc()), vector256);
  
#line 37012 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsub2FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 3316 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ subps(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 37029 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsub2F_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 3326 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vsubps(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 37047 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsub4FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 3337 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ subps(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 37064 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsub4F_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 3347 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vsubps(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 37082 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsub4F_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 3358 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vsubps(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_reloc()), vector256);
  
#line 37100 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsub8F_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 3369 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vsubps(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 37118 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsub8F_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 3380 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vsubps(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_reloc()), vector256);
  
#line 37136 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsub2DNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 3392 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ subpd(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 37153 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsub2D_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 3402 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vsubpd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 37171 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsub2D_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 3413 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vsubpd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_reloc()), vector256);
  
#line 37189 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsub4D_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 3424 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vsubpd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 37207 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsub4D_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 3435 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vsubpd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_reloc()), vector256);
  
#line 37225 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vmul2SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 3449 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ pmullw(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 37242 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vmul2S_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 3459 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpmullw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 37260 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vmul4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 3470 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ pmullw(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 37277 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vmul4S_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 3480 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpmullw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 37295 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vmul8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 3491 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ pmullw(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 37312 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vmul8S_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 3501 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpmullw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 37330 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vmul8S_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 3512 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpmullw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_reloc()), vector256);
  
#line 37348 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vmul16S_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 3523 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vpmullw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 37366 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vmul16S_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 3534 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vpmullw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_reloc()), vector256);
  
#line 37384 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vmul2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 3546 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ pmulld(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 37401 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vmul2I_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 3556 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpmulld(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 37419 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vmul4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 3567 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ pmulld(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 37436 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vmul4I_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 3577 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpmulld(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 37454 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vmul4I_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 3588 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpmulld(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_reloc()), vector256);
  
#line 37472 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vmul8I_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 3599 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vpmulld(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 37490 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vmul8I_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 3610 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vpmulld(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_reloc()), vector256);
  
#line 37508 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vmul2FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 3622 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ mulps(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 37525 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vmul2F_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 3632 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vmulps(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 37543 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vmul4FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 3643 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ mulps(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 37560 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vmul4F_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 3653 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vmulps(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 37578 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vmul4F_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 3664 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vmulps(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_reloc()), vector256);
  
#line 37596 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vmul8F_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 3675 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vmulps(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 37614 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vmul8F_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 3686 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vmulps(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_reloc()), vector256);
  
#line 37632 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vmul2DNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 3698 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ mulpd(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 37649 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vmul2D_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 3708 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vmulpd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 37667 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vmul2D_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 3719 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vmulpd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_reloc()), vector256);
  
#line 37685 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vmul4D_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 3730 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vmulpd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 37703 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vmul4D_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 3741 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vmulpd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_reloc()), vector256);
  
#line 37721 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vdiv2FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 3755 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ divps(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 37738 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vdiv2F_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 3765 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vdivps(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 37756 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vdiv4FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 3776 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ divps(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 37773 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vdiv4F_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 3786 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vdivps(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 37791 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vdiv4F_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 3797 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vdivps(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_reloc()), vector256);
  
#line 37809 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vdiv8F_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 3808 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vdivps(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 37827 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vdiv8F_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 3819 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vdivps(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_reloc()), vector256);
  
#line 37845 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vdiv2DNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 3831 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ divpd(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 37862 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vdiv2D_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 3841 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vdivpd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 37880 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vdiv2D_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 3852 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vdivpd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_reloc()), vector256);
  
#line 37898 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vdiv4D_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 3863 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vdivpd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 37916 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vdiv4D_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 3874 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vdivpd(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_reloc()), vector256);
  
#line 37934 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vshiftcntNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cnt
  {
    MacroAssembler _masm(&cbuf);

#line 3889 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ movdl(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* cnt */);
  
#line 37950 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vshiftcnt_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cnt
  {
    MacroAssembler _masm(&cbuf);

#line 3889 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ movdl(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* cnt */);
  
#line 37966 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsll2SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 3902 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ psllw(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* shift */);
  
#line 37983 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsll2S_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 3912 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ psllw(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, (int)opnd_array(2)->constant());
  
#line 38000 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsll2S_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 3922 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpsllw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* shift */, vector256);
  
#line 38018 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsll2S_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 3933 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpsllw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, (int)opnd_array(2)->constant(), vector256);
  
#line 38036 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsll4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 3944 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ psllw(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* shift */);
  
#line 38053 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsll4S_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 3954 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ psllw(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, (int)opnd_array(2)->constant());
  
#line 38070 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsll4S_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 3964 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpsllw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* shift */, vector256);
  
#line 38088 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsll4S_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 3975 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpsllw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, (int)opnd_array(2)->constant(), vector256);
  
#line 38106 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsll8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 3986 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ psllw(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* shift */);
  
#line 38123 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsll8S_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 3996 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ psllw(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, (int)opnd_array(2)->constant());
  
#line 38140 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsll8S_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4006 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpsllw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* shift */, vector256);
  
#line 38158 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsll8S_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4017 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpsllw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, (int)opnd_array(2)->constant(), vector256);
  
#line 38176 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsll16S_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4028 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vpsllw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* shift */, vector256);
  
#line 38194 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsll16S_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4039 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vpsllw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, (int)opnd_array(2)->constant(), vector256);
  
#line 38212 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsll2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4051 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ pslld(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* shift */);
  
#line 38229 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsll2I_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4061 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ pslld(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, (int)opnd_array(2)->constant());
  
#line 38246 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsll2I_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4071 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpslld(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* shift */, vector256);
  
#line 38264 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsll2I_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4082 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpslld(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, (int)opnd_array(2)->constant(), vector256);
  
#line 38282 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsll4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4093 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ pslld(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* shift */);
  
#line 38299 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsll4I_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4103 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ pslld(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, (int)opnd_array(2)->constant());
  
#line 38316 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsll4I_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4113 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpslld(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* shift */, vector256);
  
#line 38334 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsll4I_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4124 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpslld(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, (int)opnd_array(2)->constant(), vector256);
  
#line 38352 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsll8I_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4135 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vpslld(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* shift */, vector256);
  
#line 38370 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsll8I_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4146 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vpslld(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, (int)opnd_array(2)->constant(), vector256);
  
#line 38388 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsll2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4158 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ psllq(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* shift */);
  
#line 38405 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsll2L_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4168 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ psllq(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, (int)opnd_array(2)->constant());
  
#line 38422 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsll2L_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4178 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpsllq(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* shift */, vector256);
  
#line 38440 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsll2L_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4189 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpsllq(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, (int)opnd_array(2)->constant(), vector256);
  
#line 38458 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsll4L_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4200 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vpsllq(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* shift */, vector256);
  
#line 38476 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsll4L_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4211 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vpsllq(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, (int)opnd_array(2)->constant(), vector256);
  
#line 38494 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsrl2SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4229 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ psrlw(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* shift */);
  
#line 38511 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsrl2S_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4239 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ psrlw(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, (int)opnd_array(2)->constant());
  
#line 38528 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsrl2S_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4249 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpsrlw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* shift */, vector256);
  
#line 38546 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsrl2S_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4260 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpsrlw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, (int)opnd_array(2)->constant(), vector256);
  
#line 38564 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsrl4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4271 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ psrlw(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* shift */);
  
#line 38581 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsrl4S_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4281 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ psrlw(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, (int)opnd_array(2)->constant());
  
#line 38598 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsrl4S_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4291 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpsrlw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* shift */, vector256);
  
#line 38616 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsrl4S_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4302 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpsrlw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, (int)opnd_array(2)->constant(), vector256);
  
#line 38634 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsrl8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4313 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ psrlw(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* shift */);
  
#line 38651 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsrl8S_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4323 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ psrlw(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, (int)opnd_array(2)->constant());
  
#line 38668 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsrl8S_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4333 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpsrlw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* shift */, vector256);
  
#line 38686 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsrl8S_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4344 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpsrlw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, (int)opnd_array(2)->constant(), vector256);
  
#line 38704 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsrl16S_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4355 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vpsrlw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* shift */, vector256);
  
#line 38722 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsrl16S_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4366 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vpsrlw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, (int)opnd_array(2)->constant(), vector256);
  
#line 38740 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsrl2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4378 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ psrld(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* shift */);
  
#line 38757 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsrl2I_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4388 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ psrld(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, (int)opnd_array(2)->constant());
  
#line 38774 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsrl2I_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4398 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpsrld(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* shift */, vector256);
  
#line 38792 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsrl2I_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4409 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpsrld(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, (int)opnd_array(2)->constant(), vector256);
  
#line 38810 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsrl4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4420 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ psrld(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* shift */);
  
#line 38827 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsrl4I_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4430 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ psrld(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, (int)opnd_array(2)->constant());
  
#line 38844 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsrl4I_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4440 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpsrld(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* shift */, vector256);
  
#line 38862 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsrl4I_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4451 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpsrld(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, (int)opnd_array(2)->constant(), vector256);
  
#line 38880 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsrl8I_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4462 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vpsrld(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* shift */, vector256);
  
#line 38898 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsrl8I_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4473 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vpsrld(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, (int)opnd_array(2)->constant(), vector256);
  
#line 38916 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsrl2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4485 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ psrlq(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* shift */);
  
#line 38933 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsrl2L_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4495 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ psrlq(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, (int)opnd_array(2)->constant());
  
#line 38950 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsrl2L_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4505 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpsrlq(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* shift */, vector256);
  
#line 38968 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsrl2L_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4516 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpsrlq(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, (int)opnd_array(2)->constant(), vector256);
  
#line 38986 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsrl4L_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4527 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vpsrlq(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* shift */, vector256);
  
#line 39004 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsrl4L_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4538 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vpsrlq(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, (int)opnd_array(2)->constant(), vector256);
  
#line 39022 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsra2SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4552 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ psraw(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* shift */);
  
#line 39039 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsra2S_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4562 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ psraw(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, (int)opnd_array(2)->constant());
  
#line 39056 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsra2S_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4572 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpsraw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* shift */, vector256);
  
#line 39074 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsra2S_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4583 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpsraw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, (int)opnd_array(2)->constant(), vector256);
  
#line 39092 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsra4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4594 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ psraw(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* shift */);
  
#line 39109 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsra4S_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4604 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ psraw(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, (int)opnd_array(2)->constant());
  
#line 39126 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsra4S_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4614 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpsraw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* shift */, vector256);
  
#line 39144 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsra4S_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4625 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpsraw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, (int)opnd_array(2)->constant(), vector256);
  
#line 39162 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsra8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4636 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ psraw(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* shift */);
  
#line 39179 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsra8S_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4646 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ psraw(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, (int)opnd_array(2)->constant());
  
#line 39196 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsra8S_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4656 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpsraw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* shift */, vector256);
  
#line 39214 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsra8S_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4667 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpsraw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, (int)opnd_array(2)->constant(), vector256);
  
#line 39232 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsra16S_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4678 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vpsraw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* shift */, vector256);
  
#line 39250 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsra16S_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4689 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vpsraw(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, (int)opnd_array(2)->constant(), vector256);
  
#line 39268 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsra2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4701 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ psrad(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* shift */);
  
#line 39285 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsra2I_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4711 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ psrad(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, (int)opnd_array(2)->constant());
  
#line 39302 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsra2I_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4721 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpsrad(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* shift */, vector256);
  
#line 39320 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsra2I_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4732 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpsrad(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, (int)opnd_array(2)->constant(), vector256);
  
#line 39338 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsra4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4743 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ psrad(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* shift */);
  
#line 39355 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsra4I_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4753 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ psrad(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, (int)opnd_array(2)->constant());
  
#line 39372 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsra4I_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4763 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpsrad(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* shift */, vector256);
  
#line 39390 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsra4I_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4774 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpsrad(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, (int)opnd_array(2)->constant(), vector256);
  
#line 39408 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsra8I_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4785 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vpsrad(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* shift */, vector256);
  
#line 39426 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vsra8I_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 4796 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vpsrad(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, (int)opnd_array(2)->constant(), vector256);
  
#line 39444 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vand4BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 4812 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ pand(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 39461 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vand4B_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 4822 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpand(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 39479 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vand8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 4833 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ pand(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 39496 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vand8B_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 4843 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpand(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 39514 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vand16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 4854 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ pand(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 39531 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vand16B_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 4864 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpand(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 39549 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vand16B_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 4875 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpand(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_reloc()), vector256);
  
#line 39567 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vand32B_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 4886 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vpand(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 39585 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vand32B_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 4897 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vpand(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_reloc()), vector256);
  
#line 39603 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vor4BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 4910 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ por(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 39620 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vor4B_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 4920 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpor(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 39638 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vor8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 4931 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ por(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 39655 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vor8B_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 4941 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpor(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 39673 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vor16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 4952 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ por(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 39690 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vor16B_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 4962 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpor(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 39708 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vor16B_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 4973 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpor(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_reloc()), vector256);
  
#line 39726 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vor32B_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 4984 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vpor(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 39744 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vor32B_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 4995 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vpor(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_reloc()), vector256);
  
#line 39762 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vxor4BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 5008 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ pxor(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 39779 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vxor4B_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 5018 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpxor(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 39797 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vxor8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 5029 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ pxor(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 39814 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vxor8B_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 5039 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpxor(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 39832 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vxor16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 5050 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    __ pxor(opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* dst */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src */);
  
#line 39849 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vxor16B_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 5060 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpxor(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 39867 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vxor16B_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 5071 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = false;
    __ vpxor(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_reloc()), vector256);
  
#line 39885 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vxor32B_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 5082 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vpxor(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_XMMRegister(ra_,this,idx2)/* src2 */, vector256);
  
#line 39903 "../generated/adfiles/ad_x86_64.cpp"
  }
}

void vxor32B_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 5093 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86.ad"

    bool vector256 = true;
    __ vpxor(opnd_array(0)->as_XMMRegister(ra_,this)/* dst */, opnd_array(1)->as_XMMRegister(ra_,this,idx1)/* src */, Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_reloc()), vector256);
  
#line 39921 "../generated/adfiles/ad_x86_64.cpp"
  }
}

const MachOper* loadBNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadB2LNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadUBNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadUB2LNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadUB2L_immI8Node::memory_operand() const { return _opnds[1]; }
const MachOper* loadSNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadS2BNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadS2LNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadUSNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadUS2BNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadUS2LNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadUS2L_immI_255Node::memory_operand() const { return _opnds[1]; }
const MachOper* loadUS2L_immI16Node::memory_operand() const { return _opnds[1]; }
const MachOper* loadINode::memory_operand() const { return _opnds[1]; }
const MachOper* loadI2BNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadI2UBNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadI2SNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadI2USNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadI2LNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadI2L_immI_255Node::memory_operand() const { return _opnds[1]; }
const MachOper* loadI2L_immI_65535Node::memory_operand() const { return _opnds[1]; }
const MachOper* loadI2L_immU31Node::memory_operand() const { return _opnds[1]; }
const MachOper* loadUI2LNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadLNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadRangeNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadPNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadNNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadKlassNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadNKlassNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadFNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadD_partialNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadDNode::memory_operand() const { return _opnds[1]; }
const MachOper* prefetchrNode::memory_operand() const { return _opnds[1]; }
const MachOper* prefetchrNTANode::memory_operand() const { return _opnds[1]; }
const MachOper* prefetchrT0Node::memory_operand() const { return _opnds[1]; }
const MachOper* prefetchrT2Node::memory_operand() const { return _opnds[1]; }
const MachOper* prefetchwNTANode::memory_operand() const { return _opnds[1]; }
const MachOper* prefetchAllocNode::memory_operand() const { return _opnds[1]; }
const MachOper* prefetchAllocNTANode::memory_operand() const { return _opnds[1]; }
const MachOper* prefetchAllocT0Node::memory_operand() const { return _opnds[1]; }
const MachOper* prefetchAllocT2Node::memory_operand() const { return _opnds[1]; }
const MachOper* storeBNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeCNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeINode::memory_operand() const { return _opnds[1]; }
const MachOper* storeLNode::memory_operand() const { return _opnds[1]; }
const MachOper* storePNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeImmP0Node::memory_operand() const { return _opnds[1]; }
const MachOper* storeImmPNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeNNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeNKlassNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeImmN0Node::memory_operand() const { return _opnds[1]; }
const MachOper* storeImmNNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeImmNKlassNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeImmI0Node::memory_operand() const { return _opnds[1]; }
const MachOper* storeImmINode::memory_operand() const { return _opnds[1]; }
const MachOper* storeImmL0Node::memory_operand() const { return _opnds[1]; }
const MachOper* storeImmLNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeImmC0Node::memory_operand() const { return _opnds[1]; }
const MachOper* storeImmI16Node::memory_operand() const { return _opnds[1]; }
const MachOper* storeImmB0Node::memory_operand() const { return _opnds[1]; }
const MachOper* storeImmBNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeImmCM0_regNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeImmCM0Node::memory_operand() const { return _opnds[1]; }
const MachOper* storeFNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeF0Node::memory_operand() const { return _opnds[1]; }
const MachOper* storeF_immNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeDNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeD0_immNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeD0Node::memory_operand() const { return _opnds[1]; }
const MachOper* popCountI_memNode::memory_operand() const { return _opnds[1]; }
const MachOper* popCountL_memNode::memory_operand() const { return _opnds[1]; }
const TypePtr *membar_acquireNode::adr_type() const { return TypePtr::BOTTOM; }
const MachOper* membar_acquireNode::memory_operand() const { return (MachOper*)-1; }
const TypePtr *membar_acquire_0Node::adr_type() const { return TypePtr::BOTTOM; }
const MachOper* membar_acquire_0Node::memory_operand() const { return (MachOper*)-1; }
const TypePtr *membar_acquire_lockNode::adr_type() const { return TypePtr::BOTTOM; }
const MachOper* membar_acquire_lockNode::memory_operand() const { return (MachOper*)-1; }
const TypePtr *membar_releaseNode::adr_type() const { return TypePtr::BOTTOM; }
const MachOper* membar_releaseNode::memory_operand() const { return (MachOper*)-1; }
const TypePtr *membar_release_0Node::adr_type() const { return TypePtr::BOTTOM; }
const MachOper* membar_release_0Node::memory_operand() const { return (MachOper*)-1; }
const TypePtr *membar_release_lockNode::adr_type() const { return TypePtr::BOTTOM; }
const MachOper* membar_release_lockNode::memory_operand() const { return (MachOper*)-1; }
const TypePtr *membar_volatileNode::adr_type() const { return TypePtr::BOTTOM; }
const MachOper* membar_volatileNode::memory_operand() const { return (MachOper*)-1; }
const TypePtr *unnecessary_membar_volatileNode::adr_type() const { return TypePtr::BOTTOM; }
const MachOper* unnecessary_membar_volatileNode::memory_operand() const { return (MachOper*)-1; }
const TypePtr *membar_storestoreNode::adr_type() const { return TypePtr::BOTTOM; }
const MachOper* membar_storestoreNode::memory_operand() const { return (MachOper*)-1; }
const MachOper* cmovI_memNode::memory_operand() const { return _opnds[4]; }
const MachOper* cmovI_memUNode::memory_operand() const { return _opnds[4]; }
const MachOper* cmovI_memUCFNode::memory_operand() const { return _opnds[4]; }
const MachOper* cmovL_memNode::memory_operand() const { return _opnds[4]; }
const MachOper* cmovL_memUNode::memory_operand() const { return _opnds[4]; }
const MachOper* cmovL_memUCFNode::memory_operand() const { return _opnds[4]; }
const MachOper* addI_rReg_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* addI_rReg_mem_0Node::memory_operand() const { return _opnds[1]; }
const MachOper* addI_mem_rRegNode::memory_operand() const { return _opnds[1]; }
const MachOper* addI_mem_rReg_0Node::memory_operand() const { return _opnds[1]; }
const MachOper* addI_mem_immNode::memory_operand() const { return _opnds[1]; }
const MachOper* incI_memNode::memory_operand() const { return _opnds[1]; }
const MachOper* decI_memNode::memory_operand() const { return _opnds[1]; }
const MachOper* addL_rReg_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* addL_rReg_mem_0Node::memory_operand() const { return _opnds[1]; }
const MachOper* addL_mem_rRegNode::memory_operand() const { return _opnds[1]; }
const MachOper* addL_mem_rReg_0Node::memory_operand() const { return _opnds[1]; }
const MachOper* addL_mem_immNode::memory_operand() const { return _opnds[1]; }
const MachOper* incL_memNode::memory_operand() const { return _opnds[1]; }
const MachOper* decL_memNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadPLockedNode::memory_operand() const { return _opnds[1]; }
const MachOper* storePConditionalNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeIConditionalNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeLConditionalNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndSwapPNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndSwapLNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndSwapINode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndSwapNNode::memory_operand() const { return _opnds[1]; }
const MachOper* xaddI_no_resNode::memory_operand() const { return _opnds[1]; }
const MachOper* xaddINode::memory_operand() const { return _opnds[1]; }
const MachOper* xaddL_no_resNode::memory_operand() const { return _opnds[1]; }
const MachOper* xaddLNode::memory_operand() const { return _opnds[1]; }
const MachOper* xchgINode::memory_operand() const { return _opnds[1]; }
const MachOper* xchgLNode::memory_operand() const { return _opnds[1]; }
const MachOper* xchgPNode::memory_operand() const { return _opnds[1]; }
const MachOper* xchgNNode::memory_operand() const { return _opnds[1]; }
const MachOper* subI_rReg_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* subI_mem_rRegNode::memory_operand() const { return _opnds[1]; }
const MachOper* subI_mem_immNode::memory_operand() const { return _opnds[1]; }
const MachOper* subL_rReg_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* subL_mem_rRegNode::memory_operand() const { return _opnds[1]; }
const MachOper* subL_mem_immNode::memory_operand() const { return _opnds[1]; }
const MachOper* negI_memNode::memory_operand() const { return _opnds[1]; }
const MachOper* negL_memNode::memory_operand() const { return _opnds[1]; }
const MachOper* mulI_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* mulI_mem_0Node::memory_operand() const { return _opnds[1]; }
const MachOper* mulI_mem_immNode::memory_operand() const { return _opnds[1]; }
const MachOper* mulL_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* mulL_mem_0Node::memory_operand() const { return _opnds[1]; }
const MachOper* mulL_mem_immNode::memory_operand() const { return _opnds[1]; }
const MachOper* salI_mem_1Node::memory_operand() const { return _opnds[1]; }
const MachOper* salI_mem_immNode::memory_operand() const { return _opnds[1]; }
const MachOper* salI_mem_CLNode::memory_operand() const { return _opnds[1]; }
const MachOper* sarI_mem_1Node::memory_operand() const { return _opnds[1]; }
const MachOper* sarI_mem_immNode::memory_operand() const { return _opnds[1]; }
const MachOper* sarI_mem_CLNode::memory_operand() const { return _opnds[1]; }
const MachOper* shrI_mem_1Node::memory_operand() const { return _opnds[1]; }
const MachOper* shrI_mem_immNode::memory_operand() const { return _opnds[1]; }
const MachOper* shrI_mem_CLNode::memory_operand() const { return _opnds[1]; }
const MachOper* salL_mem_1Node::memory_operand() const { return _opnds[1]; }
const MachOper* salL_mem_immNode::memory_operand() const { return _opnds[1]; }
const MachOper* salL_mem_CLNode::memory_operand() const { return _opnds[1]; }
const MachOper* sarL_mem_1Node::memory_operand() const { return _opnds[1]; }
const MachOper* sarL_mem_immNode::memory_operand() const { return _opnds[1]; }
const MachOper* sarL_mem_CLNode::memory_operand() const { return _opnds[1]; }
const MachOper* shrL_mem_1Node::memory_operand() const { return _opnds[1]; }
const MachOper* shrL_mem_immNode::memory_operand() const { return _opnds[1]; }
const MachOper* shrL_mem_CLNode::memory_operand() const { return _opnds[1]; }
const MachOper* andI_rReg_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* andI_rReg_mem_0Node::memory_operand() const { return _opnds[1]; }
const MachOper* andI_mem_rRegNode::memory_operand() const { return _opnds[1]; }
const MachOper* andI_mem_rReg_0Node::memory_operand() const { return _opnds[1]; }
const MachOper* andI_mem_immNode::memory_operand() const { return _opnds[1]; }
const MachOper* andnI_rReg_rReg_memNode::memory_operand() const { return _opnds[3]; }
const MachOper* andnI_rReg_rReg_mem_0Node::memory_operand() const { return _opnds[1]; }
const MachOper* blsiI_rReg_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* blsiI_rReg_mem_0Node::memory_operand() const { return _opnds[1]; }
const MachOper* blsmskI_rReg_memNode::memory_operand() const { return _opnds[1]; }
const MachOper* blsmskI_rReg_mem_0Node::memory_operand() const { return _opnds[1]; }
const MachOper* blsrI_rReg_memNode::memory_operand() const { return _opnds[1]; }
const MachOper* blsrI_rReg_mem_0Node::memory_operand() const { return _opnds[1]; }
const MachOper* orI_rReg_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* orI_rReg_mem_0Node::memory_operand() const { return _opnds[1]; }
const MachOper* orI_mem_rRegNode::memory_operand() const { return _opnds[1]; }
const MachOper* orI_mem_rReg_0Node::memory_operand() const { return _opnds[1]; }
const MachOper* orI_mem_immNode::memory_operand() const { return _opnds[1]; }
const MachOper* xorI_rReg_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* xorI_rReg_mem_0Node::memory_operand() const { return _opnds[1]; }
const MachOper* xorI_mem_rRegNode::memory_operand() const { return _opnds[1]; }
const MachOper* xorI_mem_rReg_0Node::memory_operand() const { return _opnds[1]; }
const MachOper* xorI_mem_immNode::memory_operand() const { return _opnds[1]; }
const MachOper* andL_rReg_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* andL_rReg_mem_0Node::memory_operand() const { return _opnds[1]; }
const MachOper* andL_mem_rRegNode::memory_operand() const { return _opnds[1]; }
const MachOper* andL_mem_rReg_0Node::memory_operand() const { return _opnds[1]; }
const MachOper* andL_mem_immNode::memory_operand() const { return _opnds[1]; }
const MachOper* andnL_rReg_rReg_memNode::memory_operand() const { return _opnds[3]; }
const MachOper* andnL_rReg_rReg_mem_0Node::memory_operand() const { return _opnds[1]; }
const MachOper* blsiL_rReg_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* blsiL_rReg_mem_0Node::memory_operand() const { return _opnds[1]; }
const MachOper* blsmskL_rReg_memNode::memory_operand() const { return _opnds[1]; }
const MachOper* blsmskL_rReg_mem_0Node::memory_operand() const { return _opnds[1]; }
const MachOper* blsrL_rReg_memNode::memory_operand() const { return _opnds[1]; }
const MachOper* blsrL_rReg_mem_0Node::memory_operand() const { return _opnds[1]; }
const MachOper* orL_rReg_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* orL_rReg_mem_0Node::memory_operand() const { return _opnds[1]; }
const MachOper* orL_mem_rRegNode::memory_operand() const { return _opnds[1]; }
const MachOper* orL_mem_rReg_0Node::memory_operand() const { return _opnds[1]; }
const MachOper* orL_mem_immNode::memory_operand() const { return _opnds[1]; }
const MachOper* xorL_rReg_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* xorL_rReg_mem_0Node::memory_operand() const { return _opnds[1]; }
const MachOper* xorL_mem_rRegNode::memory_operand() const { return _opnds[1]; }
const MachOper* xorL_mem_rReg_0Node::memory_operand() const { return _opnds[1]; }
const MachOper* xorL_mem_immNode::memory_operand() const { return _opnds[1]; }
const MachOper* cmpF_cc_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* cmpF_cc_memCFNode::memory_operand() const { return _opnds[2]; }
const MachOper* cmpD_cc_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* cmpD_cc_memCFNode::memory_operand() const { return _opnds[2]; }
const MachOper* cmpF_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* cmpD_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* convF2D_reg_memNode::memory_operand() const { return _opnds[1]; }
const MachOper* convD2F_reg_memNode::memory_operand() const { return _opnds[1]; }
const MachOper* convI2F_reg_memNode::memory_operand() const { return _opnds[1]; }
const MachOper* convI2D_reg_memNode::memory_operand() const { return _opnds[1]; }
const MachOper* convL2F_reg_memNode::memory_operand() const { return _opnds[1]; }
const MachOper* convL2D_reg_memNode::memory_operand() const { return _opnds[1]; }
const MachOper* convI2L_reg_mem_zexNode::memory_operand() const { return _opnds[1]; }
const MachOper* compI_rReg_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* testI_reg_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* testI_reg_mem_0Node::memory_operand() const { return _opnds[1]; }
const MachOper* compU_rReg_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* compP_rReg_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* compP_mem_rRegNode::memory_operand() const { return _opnds[2]; }
const MachOper* testP_memNode::memory_operand() const { return _opnds[1]; }
const MachOper* testP_mem_reg0Node::memory_operand() const { return _opnds[1]; }
const MachOper* compN_rReg_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* compN_mem_immNode::memory_operand() const { return _opnds[2]; }
const MachOper* compN_mem_imm_klassNode::memory_operand() const { return _opnds[2]; }
const MachOper* testN_memNode::memory_operand() const { return _opnds[1]; }
const MachOper* testN_mem_reg0Node::memory_operand() const { return _opnds[1]; }
const MachOper* compL_rReg_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* testL_reg_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* testL_reg_mem_0Node::memory_operand() const { return _opnds[1]; }
const MachOper* compUL_rReg_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* addF_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* addF_mem_0Node::memory_operand() const { return _opnds[1]; }
const MachOper* addF_reg_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* addF_reg_mem_0Node::memory_operand() const { return _opnds[1]; }
const MachOper* addD_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* addD_mem_0Node::memory_operand() const { return _opnds[1]; }
const MachOper* addD_reg_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* addD_reg_mem_0Node::memory_operand() const { return _opnds[1]; }
const MachOper* subF_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* subF_reg_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* subD_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* subD_reg_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* mulF_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* mulF_mem_0Node::memory_operand() const { return _opnds[1]; }
const MachOper* mulF_reg_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* mulF_reg_mem_0Node::memory_operand() const { return _opnds[1]; }
const MachOper* mulD_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* mulD_mem_0Node::memory_operand() const { return _opnds[1]; }
const MachOper* mulD_reg_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* mulD_reg_mem_0Node::memory_operand() const { return _opnds[1]; }
const MachOper* divF_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* divF_reg_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* divD_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* divD_reg_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* sqrtF_memNode::memory_operand() const { return _opnds[1]; }
const MachOper* sqrtD_memNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadV4Node::memory_operand() const { return _opnds[1]; }
const MachOper* loadV8Node::memory_operand() const { return _opnds[1]; }
const MachOper* loadV16Node::memory_operand() const { return _opnds[1]; }
const MachOper* loadV32Node::memory_operand() const { return _opnds[1]; }
const MachOper* storeV4Node::memory_operand() const { return _opnds[1]; }
const MachOper* storeV8Node::memory_operand() const { return _opnds[1]; }
const MachOper* storeV16Node::memory_operand() const { return _opnds[1]; }
const MachOper* storeV32Node::memory_operand() const { return _opnds[1]; }
const MachOper* Repl2I_memNode::memory_operand() const { return _opnds[1]; }
const MachOper* Repl4I_memNode::memory_operand() const { return _opnds[1]; }
const MachOper* Repl8I_memNode::memory_operand() const { return _opnds[1]; }
const MachOper* Repl2L_memNode::memory_operand() const { return _opnds[1]; }
const MachOper* Repl4L_memNode::memory_operand() const { return _opnds[1]; }
const MachOper* vadd16B_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* vadd32B_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* vadd8S_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* vadd16S_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* vadd4I_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* vadd8I_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* vadd2L_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* vadd4L_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* vadd4F_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* vadd8F_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* vadd2D_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* vadd4D_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* vsub16B_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* vsub32B_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* vsub8S_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* vsub16S_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* vsub4I_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* vsub8I_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* vsub2L_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* vsub4L_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* vsub4F_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* vsub8F_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* vsub2D_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* vsub4D_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* vmul8S_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* vmul16S_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* vmul4I_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* vmul8I_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* vmul4F_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* vmul8F_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* vmul2D_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* vmul4D_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* vdiv4F_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* vdiv8F_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* vdiv2D_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* vdiv4D_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* vand16B_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* vand32B_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* vor16B_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* vor32B_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* vxor16B_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* vxor32B_memNode::memory_operand() const { return _opnds[2]; }


const bool Matcher::has_match_rule(int opcode) {
  assert(_last_machine_leaf < opcode && opcode < _last_opcode, "opcode in range");
  return _hasMatchRule[opcode];
}

const bool Matcher::_hasMatchRule[_last_opcode] = {
    false,  // Node
    false,  // Set
    false,  // RegN
    false,  // RegI
    false,  // RegP
    false,  // RegF
    false,  // RegD
    false,  // RegL
    false,  // RegFlags
    false,  // VecS
    false,  // VecD
    false,  // VecX
    false,  // VecY
    false,  // _last_machine_leaf
    true ,  // AbsD
    true ,  // AbsF
    false,  // AbsI
    true ,  // AddD
    true ,  // AddF
    true ,  // AddI
    true ,  // AddL
    true ,  // AddP
    false,  // Allocate
    false,  // AllocateArray
    true ,  // AndI
    true ,  // AndL
    true ,  // AryEq
    false,  // AtanD
    true ,  // Binary
    true ,  // Bool
    false,  // BoxLock
    true ,  // ReverseBytesI
    true ,  // ReverseBytesL
    true ,  // ReverseBytesUS
    true ,  // ReverseBytesS
    false,  // CProj
    true ,  // CallDynamicJava
    false,  // CallJava
    true ,  // CallLeaf
    true ,  // CallLeafNoFP
    true ,  // CallRuntime
    true ,  // CallStaticJava
    true ,  // CastII
    true ,  // CastX2P
    true ,  // CastP2X
    true ,  // CastPP
    false,  // Catch
    false,  // CatchProj
    true ,  // CheckCastPP
    true ,  // ClearArray
    false,  // ConstraintCast
    true ,  // CMoveD
    true ,  // CMoveF
    true ,  // CMoveI
    true ,  // CMoveL
    true ,  // CMoveP
    true ,  // CMoveN
    true ,  // CmpN
    true ,  // CmpD
    true ,  // CmpD3
    true ,  // CmpF
    true ,  // CmpF3
    true ,  // CmpI
    true ,  // CmpL
    true ,  // CmpL3
    true ,  // CmpLTMask
    true ,  // CmpP
    true ,  // CmpU
    true ,  // CmpUL
    true ,  // CompareAndSwapI
    true ,  // CompareAndSwapL
    true ,  // CompareAndSwapP
    true ,  // CompareAndSwapN
    true ,  // GetAndAddI
    true ,  // GetAndAddL
    true ,  // GetAndSetI
    true ,  // GetAndSetL
    true ,  // GetAndSetP
    true ,  // GetAndSetN
    false,  // Con
    true ,  // ConN
    true ,  // ConNKlass
    true ,  // ConD
    true ,  // ConF
    true ,  // ConI
    true ,  // ConL
    true ,  // ConP
    true ,  // Conv2B
    true ,  // ConvD2F
    true ,  // ConvD2I
    true ,  // ConvD2L
    true ,  // ConvF2D
    true ,  // ConvF2I
    true ,  // ConvF2L
    true ,  // ConvI2D
    true ,  // ConvI2F
    true ,  // ConvI2L
    true ,  // ConvL2D
    true ,  // ConvL2F
    true ,  // ConvL2I
    true ,  // CosD
    false,  // CountedLoop
    true ,  // CountedLoopEnd
    true ,  // CountLeadingZerosI
    true ,  // CountLeadingZerosL
    true ,  // CountTrailingZerosI
    true ,  // CountTrailingZerosL
    true ,  // CreateEx
    true ,  // DecodeN
    true ,  // DecodeNKlass
    true ,  // DivD
    true ,  // DivF
    true ,  // DivI
    true ,  // DivL
    false,  // DivMod
    true ,  // DivModI
    true ,  // DivModL
    true ,  // EncodeISOArray
    true ,  // EncodeP
    true ,  // EncodePKlass
    true ,  // ExpD
    true ,  // FastLock
    true ,  // FastUnlock
    true ,  // Goto
    true ,  // Halt
    true ,  // If
    false,  // IfFalse
    false,  // IfTrue
    false,  // Initialize
    false,  // JProj
    true ,  // Jump
    false,  // JumpProj
    true ,  // LShiftI
    true ,  // LShiftL
    true ,  // LoadB
    true ,  // LoadUB
    true ,  // LoadUS
    true ,  // LoadD
    false,  // LoadD_unaligned
    true ,  // LoadF
    true ,  // LoadI
    true ,  // LoadKlass
    true ,  // LoadNKlass
    true ,  // LoadL
    false,  // LoadL_unaligned
    true ,  // LoadPLocked
    true ,  // LoadP
    true ,  // LoadN
    true ,  // LoadRange
    true ,  // LoadS
    false,  // Lock
    true ,  // LogD
    true ,  // Log10D
    false,  // Loop
    false,  // LoopLimit
    false,  // Mach
    false,  // MachProj
    true ,  // MaxI
    true ,  // MemBarAcquire
    true ,  // LoadFence
    true ,  // MemBarAcquireLock
    false,  // MemBarCPUOrder
    true ,  // MemBarRelease
    true ,  // StoreFence
    true ,  // MemBarReleaseLock
    true ,  // MemBarVolatile
    true ,  // MemBarStoreStore
    false,  // MergeMem
    true ,  // MinI
    false,  // ModD
    false,  // ModF
    true ,  // ModI
    true ,  // ModL
    true ,  // MoveI2F
    true ,  // MoveF2I
    true ,  // MoveL2D
    true ,  // MoveD2L
    true ,  // MulD
    true ,  // MulF
    true ,  // MulHiL
    true ,  // MulI
    true ,  // MulL
    false,  // Multi
    true ,  // NegD
    true ,  // NegF
    false,  // NeverBranch
    false,  // Opaque1
    false,  // Opaque2
    false,  // Opaque3
    false,  // ProfileBoolean
    true ,  // OrI
    true ,  // OrL
    true ,  // OverflowAddI
    true ,  // OverflowSubI
    true ,  // OverflowMulI
    true ,  // OverflowAddL
    true ,  // OverflowSubL
    true ,  // OverflowMulL
    false,  // PCTable
    false,  // Parm
    true ,  // PartialSubtypeCheck
    false,  // Phi
    true ,  // PopCountI
    true ,  // PopCountL
    true ,  // PowD
    true ,  // PrefetchAllocation
    true ,  // PrefetchRead
    true ,  // PrefetchWrite
    false,  // Proj
    true ,  // RShiftI
    true ,  // RShiftL
    false,  // Region
    true ,  // Rethrow
    true ,  // Return
    false,  // Root
    true ,  // RoundDouble
    true ,  // RoundFloat
    true ,  // SafePoint
    false,  // SafePointScalarObject
    false,  // SCMemProj
    true ,  // SinD
    true ,  // SqrtD
    false,  // Start
    false,  // StartOSR
    true ,  // StoreB
    true ,  // StoreC
    true ,  // StoreCM
    true ,  // StorePConditional
    true ,  // StoreIConditional
    true ,  // StoreLConditional
    true ,  // StoreD
    true ,  // StoreF
    true ,  // StoreI
    true ,  // StoreL
    true ,  // StoreP
    true ,  // StoreN
    true ,  // StoreNKlass
    true ,  // StrComp
    true ,  // StrEquals
    true ,  // StrIndexOf
    true ,  // SubD
    true ,  // SubF
    true ,  // SubI
    true ,  // SubL
    true ,  // TailCall
    true ,  // TailJump
    true ,  // TanD
    true ,  // ThreadLocal
    false,  // Unlock
    true ,  // URShiftI
    true ,  // URShiftL
    true ,  // XorI
    true ,  // XorL
    false,  // Vector
    true ,  // AddVB
    true ,  // AddVS
    true ,  // AddVI
    true ,  // AddVL
    true ,  // AddVF
    true ,  // AddVD
    true ,  // SubVB
    true ,  // SubVS
    true ,  // SubVI
    true ,  // SubVL
    true ,  // SubVF
    true ,  // SubVD
    true ,  // MulVS
    true ,  // MulVI
    true ,  // MulVF
    true ,  // MulVD
    true ,  // DivVF
    true ,  // DivVD
    true ,  // LShiftCntV
    true ,  // RShiftCntV
    false,  // LShiftVB
    true ,  // LShiftVS
    true ,  // LShiftVI
    true ,  // LShiftVL
    false,  // RShiftVB
    true ,  // RShiftVS
    true ,  // RShiftVI
    false,  // RShiftVL
    false,  // URShiftVB
    true ,  // URShiftVS
    true ,  // URShiftVI
    true ,  // URShiftVL
    true ,  // AndV
    true ,  // OrV
    true ,  // XorV
    true ,  // LoadVector
    true ,  // StoreVector
    false,  // Pack
    false,  // PackB
    false,  // PackS
    false,  // PackI
    false,  // PackL
    false,  // PackF
    false,  // PackD
    false,  // Pack2L
    false,  // Pack2D
    true ,  // ReplicateB
    true ,  // ReplicateS
    true ,  // ReplicateI
    true ,  // ReplicateL
    true ,  // ReplicateF
    true ,  // ReplicateD
    false,  // Extract
    false,  // ExtractB
    false,  // ExtractUB
    false,  // ExtractC
    false,  // ExtractS
    false,  // ExtractI
    false,  // ExtractL
    false,  // ExtractF
    false   // ExtractD
};


bool Matcher::stack_direction() const { return false; }

int Compile::sync_stack_slots() const { return 2; }

uint Matcher::stack_alignment_in_bytes() { return StackAlignmentInBytes; }

OptoReg::Name Matcher::return_addr() const { return OptoReg::stack2reg(- 2 +
              round_to((Compile::current()->in_preserve_stack_slots() +
                        Compile::current()->fixed_slots()),
                       stack_alignment_in_slots())); }

uint Compile::in_preserve_stack_slots() { return 4 + 2 * VerifyStackAtCalls; }

uint Compile::out_preserve_stack_slots() { return SharedRuntime::out_preserve_stack_slots(); }

uint Compile::varargs_C_out_slots_killed() const { return frame::arg_reg_save_area_bytes/BytesPerInt; }

void Matcher::calling_convention(BasicType *sig_bt, VMRegPair *regs, uint length, bool is_outgoing) {

#line 2805 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // No difference between ingoing/outgoing just pass false
    SharedRuntime::java_calling_convention(sig_bt, regs, length, false);
  
#line 40589 "../generated/adfiles/ad_x86_64.cpp"

}

void Matcher::c_calling_convention(BasicType *sig_bt, VMRegPair *regs, uint length) {

#line 2811 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    // This is obviously always outgoing
    (void) SharedRuntime::c_calling_convention(sig_bt, regs, /*regs2=*/NULL, length);
  
#line 40600 "../generated/adfiles/ad_x86_64.cpp"

}

OptoRegPair Matcher::return_value(int ideal_reg, bool is_outgoing) {

#line 2818 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    assert(ideal_reg >= Op_RegI && ideal_reg <= Op_RegL,
           "only return normal values");

    static const int lo[Op_RegL + 1] = {
      0,
      0,
      RAX_num,  // Op_RegN
      RAX_num,  // Op_RegI
      RAX_num,  // Op_RegP
      XMM0_num, // Op_RegF
      XMM0_num, // Op_RegD
      RAX_num   // Op_RegL
    };
    static const int hi[Op_RegL + 1] = {
      0,
      0,
      OptoReg::Bad, // Op_RegN
      OptoReg::Bad, // Op_RegI
      RAX_H_num,    // Op_RegP
      OptoReg::Bad, // Op_RegF
      XMM0b_num,    // Op_RegD
      RAX_H_num     // Op_RegL
    };
    // Excluded flags and vector registers.
    assert(ARRAY_SIZE(hi) == _last_machine_leaf - 5, "missing type");
    return OptoRegPair(hi[ideal_reg], lo[ideal_reg]);
  
#line 40635 "../generated/adfiles/ad_x86_64.cpp"

}

OptoRegPair Matcher::c_return_value(int ideal_reg, bool is_outgoing) {

#line 2818 "/mnt/workspace/build_x64/tmp-glibc/work/core2-64-nilrt-linux/openjdk-8/162b12-r0/jdk8u-4be07cb28b21/hotspot/src/cpu/x86/vm/x86_64.ad"

    assert(ideal_reg >= Op_RegI && ideal_reg <= Op_RegL,
           "only return normal values");

    static const int lo[Op_RegL + 1] = {
      0,
      0,
      RAX_num,  // Op_RegN
      RAX_num,  // Op_RegI
      RAX_num,  // Op_RegP
      XMM0_num, // Op_RegF
      XMM0_num, // Op_RegD
      RAX_num   // Op_RegL
    };
    static const int hi[Op_RegL + 1] = {
      0,
      0,
      OptoReg::Bad, // Op_RegN
      OptoReg::Bad, // Op_RegI
      RAX_H_num,    // Op_RegP
      OptoReg::Bad, // Op_RegF
      XMM0b_num,    // Op_RegD
      RAX_H_num     // Op_RegL
    };
    // Excluded flags and vector registers.
    assert(ARRAY_SIZE(hi) == _last_machine_leaf - 5, "missing type");
    return OptoRegPair(hi[ideal_reg], lo[ideal_reg]);
  
#line 40670 "../generated/adfiles/ad_x86_64.cpp"

}

OptoReg::Name Matcher::inline_cache_reg() { return OptoReg::Name(RAX_num); }

int Matcher::inline_cache_reg_encode() { return _regEncode[inline_cache_reg()]; }

OptoReg::Name Matcher::interpreter_method_oop_reg() { return OptoReg::Name(RBX_num); }

int Matcher::interpreter_method_oop_reg_encode() { return _regEncode[interpreter_method_oop_reg()]; }

OptoReg::Name Matcher::interpreter_frame_pointer_reg() { return OptoReg::Name(RBP_num); }

OptoReg::Name Matcher::c_frame_pointer() const { return OptoReg::Name(RSP_num); }

// Number of callee-save + always-save registers
int  Matcher::number_of_saved_registers() {
  return 0;
};

bool Compile::needs_clone_jvms() { return false; }

// Check consistency of C++ compilation with ADLC options:
// Check adlc -DLINUX=1
#ifndef LINUX
#  error "LINUX must be defined"
#endif // LINUX
// Check adlc -D_GNU_SOURCE=1
#ifndef _GNU_SOURCE
#  error "_GNU_SOURCE must be defined"
#endif // _GNU_SOURCE
// Check adlc -DAMD64=1
#ifndef AMD64
#  error "AMD64 must be defined"
#endif // AMD64
// Check adlc -D_LP64=1
#ifndef _LP64
#  error "_LP64 must be defined"
#endif // _LP64
